import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { IgxGridColumnAnimationSettings } from "./igx-grid-column-animation-settings";
import { IgxColumnWidth } from "./igx-column-width";
import { IgxHeaderComponent } from "./igx-header-component";
import { ColumnSortDirection, ColumnSortDirection_$type } from "./ColumnSortDirection";
import { IgxDefinitionBaseComponent } from "./igx-definition-base-component";
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "igniteui-angular-core";
import { ColumnWidth as ColumnWidth_internal } from "./ColumnWidth";
import { ColumnFilterCondition } from "./ColumnFilterCondition";
/**
 * A column in the data grid.
*/
export const IgxColumnComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxColumnComponent) }];
export class IgxColumnComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the amount of left padding to use for the cell content for this column.
    */
    get paddingLeft() {
        return this.i.ff;
    }
    set paddingLeft(v) {
        this.i.ff = +v;
    }
    /**
     * Gets or sets the amount of top padding to use for the cell content for this column.
    */
    get paddingTop() {
        return this.i.fh;
    }
    set paddingTop(v) {
        this.i.fh = +v;
    }
    /**
     * Gets or sets the amount of right padding to use for the cell content of this column.
    */
    get paddingRight() {
        return this.i.fg;
    }
    set paddingRight(v) {
        this.i.fg = +v;
    }
    /**
     * Gets or sets the amount of bottom padding to use for the cell content of this column.
    */
    get paddingBottom() {
        return this.i.fe;
    }
    set paddingBottom(v) {
        this.i.fe = +v;
    }
    /**
     * Gets or sets an unique name of the Column
    */
    get name() {
        return this.i.f5;
    }
    set name(v) {
        this.i.f5 = v;
    }
    /**
     * Gets or sets the key used for the column binding
    */
    get propertyPath() {
        return this.i.gb;
    }
    set propertyPath(v) {
        this.i.gb = v;
    }
    /**
     * Gets or sets the text displayed in the header of the column
    */
    get headerText() {
        return this.i.fw;
    }
    set headerText(v) {
        this.i.fw = v;
    }
    /**
     * Gets the actual text displayed in the header of the column
    */
    get actualHeaderText() {
        return this.i.fp;
    }
    set actualHeaderText(v) {
        this.i.fp = v;
    }
    /**
     * Gets or sets the background color to use for the cells when they are selected
    */
    get selectedBackground() {
        return brushToString(this.i.gs);
    }
    set selectedBackground(v) {
        this.i.gs = stringToBrush(v);
    }
    /**
     * Gets the actual background color that is used for the cells when they are selected
    */
    get actualSelectedBackground() {
        return brushToString(this.i.gq);
    }
    set actualSelectedBackground(v) {
        this.i.gq = stringToBrush(v);
    }
    /**
     * Gets or sets the animation settings to use for this column.
    */
    get animationSettings() {
        if (this.i.eh == null) {
            return null;
        }
        if (!this.i.eh.externalObject) {
            let e = new IgxGridColumnAnimationSettings();
            e._implementation = this.i.eh;
            this.i.eh.externalObject = e;
        }
        return this.i.eh.externalObject;
    }
    set animationSettings(v) {
        v == null ? this.i.eh = null : this.i.eh = v.i;
    }
    /**
     * Gets or sets the width to use for this column.
    */
    get width() {
        if (this.i.width == null) {
            return null;
        }
        if (!this.i.width.externalObject) {
            let e = new IgxColumnWidth();
            e._implementation = this.i.width;
            this.i.width.externalObject = e;
        }
        return this.i.width.externalObject;
    }
    set width(v) {
        if (typeof v == "string") {
            let int = ColumnWidth_internal.parse(v);
            let ext = new IgxColumnWidth();
            ext._implementation = int;
            v = ext;
        }
        v == null ? this.i.width = null : this.i.width = v.i;
    }
    /**
     * Gets or sets the minimum width to use for this column. Overrides the DefaultColumnMinWidth from the grid, if set.
    */
    get minWidth() {
        return this.i.e5;
    }
    set minWidth(v) {
        this.i.e5 = +v;
    }
    /**
     * Gets whether this column was projected from markup/templates and is constrained.
    */
    get isFromMarkup() {
        return this.i.e0;
    }
    set isFromMarkup(v) {
        this.i.e0 = ensureBool(v);
    }
    /**
     * Gets whether this column was auto generated.
    */
    get isAutoGenerated() {
        return this.i.ey;
    }
    set isAutoGenerated(v) {
        this.i.ey = ensureBool(v);
    }
    /**
     * Gets or sets a filter to apply on the values of this column
    */
    get filter() {
        return this.i.d1;
    }
    set filter(v) {
        this.i.d1 = v;
    }
    /**
     * Gets or sets the header definition for this column.
    */
    get header() {
        if (this.i.header == null) {
            return null;
        }
        if (!this.i.header.externalObject) {
            let e = IgxHeaderComponent._createFromInternal(this.i.header);
            if (e) {
                e._implementation = this.i.header;
            }
            this.i.header.externalObject = e;
        }
        return this.i.header.externalObject;
    }
    set header(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.header = null : this.i.header = v.i;
    }
    /**
     * Gets or sets whether filtering is enabled for this column.
    */
    get isFilteringEnabled() {
        return this.i.ez;
    }
    set isFilteringEnabled(v) {
        this.i.ez = ensureBool(v);
    }
    /**
     * Gets or sets whether resizing is enabled for this column.
    */
    get isResizingEnabled() {
        return this.i.e2;
    }
    set isResizingEnabled(v) {
        this.i.e2 = ensureBool(v);
    }
    /**
     * Gets or sets whether or not a column is hidden from the grid
    */
    get isHidden() {
        return this.i.e1;
    }
    set isHidden(v) {
        this.i.e1 = ensureBool(v);
    }
    /**
     * Gets or sets if a column should be removed from the grid when it is fully hidden
    */
    get shouldRemoveWhenHidden() {
        return this.i.e3;
    }
    set shouldRemoveWhenHidden(v) {
        this.i.e3 = ensureBool(v);
    }
    /**
     * Gets the current sort direction (None, Ascending, Descending) for this column.
    */
    get sortDirection() {
        return this.i.eb;
    }
    set sortDirection(v) {
        this.i.eb = ensureEnum(ColumnSortDirection_$type, v);
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.header && this.header._styling) {
            this.header._styling(container, component, this);
        }
        this._inStyling = false;
    }
    /**
     * Get the unique key used to identify this column.
    
    */
    getUniqueKey() {
        let iv = this.i.fu();
        return (iv);
    }
    setNamedHeaderValue(valueName, animationType, value) {
        this.i.gk(valueName, (animationType == null ? null : animationType), value);
    }
    /**
     * Returns if the column has named header values.
    
    */
    hasNamedHeaderValues() {
        let iv = this.i.ew();
        return (iv);
    }
    /**
     * Returns if there is a named header value with a given name.
    
    * @param valueName  * The named value to check for.
    */
    hasNamedHeaderValue(valueName) {
        let iv = this.i.ev(valueName);
        return (iv);
    }
    /**
     * Removes a named header value with the given name from the named header values for this column.
    
    * @param valueName  * The named header value to remove.
    */
    removeNamedHeaderValue(valueName) {
        this.i.gj(valueName);
    }
    /**
     * Gets the value of a named header value for this column by name.
    
    * @param valueName  * Name of the named header value to retrieve.
    */
    getNamedHeaderValue(valueName) {
        let iv = this.i.fk(valueName);
        return (iv);
    }
}
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "paddingLeft", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "paddingTop", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "paddingRight", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "paddingBottom", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "name", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "propertyPath", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "headerText", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "actualHeaderText", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "selectedBackground", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "actualSelectedBackground", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", IgxGridColumnAnimationSettings),
    tslib_1.__metadata("design:paramtypes", [IgxGridColumnAnimationSettings])
], IgxColumnComponent.prototype, "animationSettings", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", IgxColumnWidth),
    tslib_1.__metadata("design:paramtypes", [IgxColumnWidth])
], IgxColumnComponent.prototype, "width", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "minWidth", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Boolean),
    tslib_1.__metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "isFromMarkup", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Boolean),
    tslib_1.__metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "isAutoGenerated", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", ColumnFilterCondition),
    tslib_1.__metadata("design:paramtypes", [ColumnFilterCondition])
], IgxColumnComponent.prototype, "filter", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", IgxHeaderComponent),
    tslib_1.__metadata("design:paramtypes", [IgxHeaderComponent])
], IgxColumnComponent.prototype, "header", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Boolean),
    tslib_1.__metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "isFilteringEnabled", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Boolean),
    tslib_1.__metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "isResizingEnabled", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Boolean),
    tslib_1.__metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "isHidden", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Boolean),
    tslib_1.__metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "shouldRemoveWhenHidden", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "sortDirection", null);
//# sourceMappingURL=igx-column-component.js.map