import * as tslib_1 from "tslib";
import { EventEmitter, Output } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { IgxFormatGroupTextEventArgs } from "./igx-format-group-text-event-args";
import { IgxColumnSortDescription } from "./igx-column-sort-description";
import { ColumnGroupDescription as ColumnGroupDescription_internal } from "./ColumnGroupDescription";
/**
 * Represents an element in the current grouping applied to a data source or provider. Changes to this object are not observed or expected after it is initially assigned to a collection.
*/
export class IgxColumnGroupDescription extends IgxColumnSortDescription {
    constructor() {
        super();
        this._formatText = null;
        this._zoneRunner = null;
    }
    createImplementation() {
        return new ColumnGroupDescription_internal(0);
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets an INTL.DateTimeFormat or INTL.NumericFormat to use to format the value.
    */
    get formatOverride() {
        return this.i.k;
    }
    set formatOverride(v) {
        this.i.k = v;
    }
    /**
     * Gets or sets the display text for the group name.
    */
    get displayName() {
        return this.i.m;
    }
    set displayName(v) {
        this.i.m = v;
    }
    /**
     * Called when the value is being formatted.
    */
    get formatText() {
        if (this._formatText == null) {
            this._formatText = new EventEmitter();
            this.i.formatText = delegateCombine(this.i.formatText, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxFormatGroupTextEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeFormatText) {
                        this.beforeFormatText(this, outerArgs);
                    }
                    this._formatText.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._formatText;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxColumnGroupDescription.prototype, "formatText", null);
//# sourceMappingURL=igx-column-group-description.js.map