import * as tslib_1 from "tslib";
import { EventEmitter, Output } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { IgxFormatSummaryTextEventArgs } from "./igx-format-summary-text-event-args";
import { ColumnSummaryDescription as ColumnSummaryDescription_internal } from "./ColumnSummaryDescription";
/**
 * Represents a summary that is applied to a datasource. Changes to this object are not observed or expected after it is initially assigned to a collection.
*/
export class IgxColumnSummaryDescription {
    constructor() {
        this._formatText = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new ColumnSummaryDescription_internal(0);
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get propertyPath() {
        return this.i.t;
    }
    set propertyPath(v) {
        this.i.t = v;
    }
    get operand() {
        return this.i.e;
    }
    set operand(v) {
        this.i.e = v;
    }
    get calculator() {
        return this.i.c;
    }
    set calculator(v) {
        this.i.c = v;
    }
    /**
     * Gets or sets the name to use when displaying the calculator name.
    */
    get calculatorDisplayName() {
        return this.i.r;
    }
    set calculatorDisplayName(v) {
        this.i.r = v;
    }
    /**
     * Gets or sets the display name for the summary.
    */
    get displayName() {
        return this.i.s;
    }
    set displayName(v) {
        this.i.s = v;
    }
    /**
     * Gets or sets an INTL.DateTimeFormat or INTL.NumericFormat to use to format the value.
    */
    get formatOverride() {
        return this.i.n;
    }
    set formatOverride(v) {
        this.i.n = v;
    }
    /**
     * Gets or sets the minimum fraction digits. If FormatOverride is specificied this value is ignored.
    */
    get maxFractionDigits() {
        return this.i.l;
    }
    set maxFractionDigits(v) {
        this.i.l = +v;
    }
    equals(other) {
        let iv = this.i.equals(other);
        return (iv);
    }
    getHashCode() {
        let iv = this.i.getHashCode();
        return (iv);
    }
    /**
     * Called when the value is being formatted.
    */
    get formatText() {
        if (this._formatText == null) {
            this._formatText = new EventEmitter();
            this.i.formatText = delegateCombine(this.i.formatText, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxFormatSummaryTextEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeFormatText) {
                        this.beforeFormatText(this, outerArgs);
                    }
                    this._formatText.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._formatText;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxColumnSummaryDescription.prototype, "formatText", null);
//# sourceMappingURL=igx-column-summary-description.js.map