import * as tslib_1 from "tslib";
import { EventEmitter, Output, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { CellContentHorizontalAlignment, CellContentHorizontalAlignment_$type } from "./CellContentHorizontalAlignment";
import { CellContentVerticalAlignment, CellContentVerticalAlignment_$type } from "./CellContentVerticalAlignment";
import { TextCellLineBreakMode, TextCellLineBreakMode_$type } from "./TextCellLineBreakMode";
import { IgxDataBindingEventArgs } from "./igx-data-binding-event-args";
import { IgxCellStyleRequestedEventArgs } from "./igx-cell-style-requested-event-args";
import { NamePatcher } from "igniteui-angular-core";
import { brushToString, stringToBrush, ensureEnum, toSpinal, initializePropertiesFromCss } from "igniteui-angular-core";
import { FontInfo } from "igniteui-angular-core";
import { TypeRegistrar } from "igniteui-angular-core";
import { ColumnPropertyUpdatingAnimationMode } from './ColumnPropertyUpdatingAnimationMode';
/**
 * Base class for various definition types for the grid.
*/
export class IgxDefinitionBaseComponent {
    constructor() {
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._renderer = null;
        this._dataBinding = null;
        this._dataBound = null;
        this._cellStyleKeyRequested = null;
        this._zoneRunner = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return null;
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igx" + name + "Component";
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    ngOnInit() {
    }
    onImplementationCreated() {
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        this._stylingContainer = container;
        this._stylingParent = component;
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        let grid = component._grid;
        var prev;
        if (grid) {
            prev = grid.columnPropertyUpdatingAnimationMode;
            grid.columnPropertyUpdatingAnimationMode = ColumnPropertyUpdatingAnimationMode.None;
        }
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        let lowerTypeName = typeName.toLowerCase();
        if (lowerTypeName.indexOf("column") >= 0) {
            genericPrefix = "column";
        }
        else if (lowerTypeName.indexOf("sectionheader") >= 0) {
            genericPrefix = "section-header";
        }
        else if (lowerTypeName.indexOf("sectionfooter") >= 0) {
            genericPrefix = "section-footer";
        }
        else if (lowerTypeName.indexOf("rowseparator") >= 0) {
            genericPrefix = "row-separator";
        }
        else {
            genericPrefix = "header";
        }
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName == "Grid") {
                parentTypeName = "LiveGrid";
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (grid) {
            grid.columnPropertyUpdatingAnimationMode = prev;
        }
        this._inStyling = false;
    }
    _provideRenderer(renderer) {
        this._renderer = renderer;
        this._zoneRunner = (act) => renderer._ngZone.run(act);
    }
    /**
 * Gets or sets the background color to use.
*/
    get background() {
        return brushToString(this.i.dm);
    }
    set background(v) {
        this.i.dm = stringToBrush(v);
    }
    /**
     * Gets or sets the background color to use.
    */
    get border() {
        return brushToString(this.i.dn);
    }
    set border(v) {
        this.i.dn = stringToBrush(v);
    }
    /**
     * Gets or sets the background color to use.
    */
    get activationBorder() {
        return brushToString(this.i.de);
    }
    set activationBorder(v) {
        this.i.de = stringToBrush(v);
    }
    /**
     * Gets the actual border color that will be used.
    */
    get actualBorder() {
        return brushToString(this.i.dh);
    }
    set actualBorder(v) {
        this.i.dh = stringToBrush(v);
    }
    /**
     * Gets or sets the amount of left border to use for the cell content for this column.
    */
    get borderLeftWidth() {
        return this.i.ba;
    }
    set borderLeftWidth(v) {
        this.i.ba = +v;
    }
    /**
     * Gets or sets the amount of top border to use for the cell content for this column.
    */
    get borderTopWidth() {
        return this.i.bc;
    }
    set borderTopWidth(v) {
        this.i.bc = +v;
    }
    /**
     * Gets or sets the amount of right border to use for the cell content of this column.
    */
    get borderRightWidth() {
        return this.i.bb;
    }
    set borderRightWidth(v) {
        this.i.bb = +v;
    }
    /**
     * Gets or sets the amount of bottom border to use for the cell content of this column.
    */
    get borderBottomWidth() {
        return this.i.a9;
    }
    set borderBottomWidth(v) {
        this.i.a9 = +v;
    }
    /**
     * Gets or sets the amount of left activation border to use for the cell content for this column.
    */
    get activationBorderLeftWidth() {
        return this.i.a6;
    }
    set activationBorderLeftWidth(v) {
        this.i.a6 = +v;
    }
    /**
     * Gets or sets the amount of top activation border to use for the cell content for this column.
    */
    get activationBorderTopWidth() {
        return this.i.a8;
    }
    set activationBorderTopWidth(v) {
        this.i.a8 = +v;
    }
    /**
     * Gets or sets the amount of right activation border to use for the cell content of this column.
    */
    get activationBorderRightWidth() {
        return this.i.a7;
    }
    set activationBorderRightWidth(v) {
        this.i.a7 = +v;
    }
    /**
     * Gets or sets the amount of bottom activation border to use for the cell content of this column.
    */
    get activationBorderBottomWidth() {
        return this.i.a5;
    }
    set activationBorderBottomWidth(v) {
        this.i.a5 = +v;
    }
    /**
     * Gets the actual background color that will be used.
    */
    get actualBackground() {
        return brushToString(this.i.dg);
    }
    set actualBackground(v) {
        this.i.dg = stringToBrush(v);
    }
    /**
     * Gets the actual background color that will be used.
    */
    get actualActivationBorder() {
        return brushToString(this.i.df);
    }
    set actualActivationBorder(v) {
        this.i.df = stringToBrush(v);
    }
    /**
     * Gets or sets the background color for content that sticks to the top of the grid.
    */
    get stickyRowBackground() {
        return brushToString(this.i.dy);
    }
    set stickyRowBackground(v) {
        this.i.dy = stringToBrush(v);
    }
    /**
     * Gets the actual background color for content that sticks to the top of the grid.
    */
    get actualStickyRowBackground() {
        return brushToString(this.i.dk);
    }
    set actualStickyRowBackground(v) {
        this.i.dk = stringToBrush(v);
    }
    /**
     * Gets or sets the background color for cells belonging to rows marked as pinned.
    */
    get pinnedRowBackground() {
        return brushToString(this.i.dx);
    }
    set pinnedRowBackground(v) {
        this.i.dx = stringToBrush(v);
    }
    /**
     * Gets the actual background color for cells belonging to rows marked as pinned.
    */
    get actualPinnedRowBackground() {
        return brushToString(this.i.dj);
    }
    set actualPinnedRowBackground(v) {
        this.i.dj = stringToBrush(v);
    }
    /**
     * Gets or sets the color for the last row in the sticky row area.
    */
    get lastStickyRowBackground() {
        return brushToString(this.i.dw);
    }
    set lastStickyRowBackground(v) {
        this.i.dw = stringToBrush(v);
    }
    /**
     * Gets the actual color for the last row in the sticky row area.
    */
    get actualLastStickyRowBackground() {
        return brushToString(this.i.di);
    }
    set actualLastStickyRowBackground(v) {
        this.i.di = stringToBrush(v);
    }
    /**
     * Gets or sets the opacity of the content.
    */
    get contentOpacity() {
        return this.i.au;
    }
    set contentOpacity(v) {
        this.i.au = +v;
    }
    /**
     * Gets or sets the horizontal alignment to use for the cell content.
    */
    get horizontalAlignment() {
        return this.i.e;
    }
    set horizontalAlignment(v) {
        this.i.e = ensureEnum(CellContentHorizontalAlignment_$type, v);
    }
    /**
     * Gets or sets the vertical alignment to use for the cell content.
    */
    get verticalAlignment() {
        return this.i.j;
    }
    set verticalAlignment(v) {
        this.i.j = ensureEnum(CellContentVerticalAlignment_$type, v);
    }
    /**
     * Gets or sets the line breaking mode to use if text is present in the cell.
    */
    get lineBreakMode() {
        return this.i.y;
    }
    set lineBreakMode(v) {
        this.i.y = ensureEnum(TextCellLineBreakMode_$type, v);
    }
    /**
     * Gets the actual line break mode which will be used if text is present in the cell.
    */
    get actualLineBreakMode() {
        return this.i.x;
    }
    set actualLineBreakMode(v) {
        this.i.x = ensureEnum(TextCellLineBreakMode_$type, v);
    }
    /**
     * Gets or sets the color to use for displaying text.
    */
    get textColor() {
        return brushToString(this.i.dz);
    }
    set textColor(v) {
        this.i.dz = stringToBrush(v);
    }
    /**
     * Gets the actual color used for displaying text.
    */
    get actualTextColor() {
        return brushToString(this.i.dl);
    }
    set actualTextColor(v) {
        this.i.dl = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for displaying text.
    */
    get pinnedRowOpacity() {
        return this.i.aw;
    }
    set pinnedRowOpacity(v) {
        this.i.aw = +v;
    }
    /**
     * Gets or sets the color to use for displaying text.
    */
    get actualPinnedRowOpacity() {
        return this.i.at;
    }
    set actualPinnedRowOpacity(v) {
        this.i.at = +v;
    }
    get textStyle() {
        if (this.i.textStyle == null) {
            return null;
        }
        return this.i.textStyle.fontString;
    }
    set textStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.textStyle = fi;
    }
    setNamedValue(valueName, animationType, value) {
        this.i.cq(valueName, (animationType == null ? null : animationType), value);
    }
    /**
     * Returns if this definition has named value.
    
    */
    hasNamedValues() {
        let iv = this.i.ai();
        return (iv);
    }
    /**
     * Returns if this definition has a named value with a given name.
    
    * @param valueName  * The named value name to check for.
    */
    hasNamedValue(valueName) {
        let iv = this.i.ah(valueName);
        return (iv);
    }
    /**
     * Removes the named value from this definition by name.
    
    * @param valueName  * The named value name to remove.
    */
    removeNamedValue(valueName) {
        this.i.co(valueName);
    }
    /**
     * Gets the value for a named value from this definition.
    
    * @param valueName  * The named value name to check for.
    */
    getNamedValue(valueName) {
        let iv = this.i.bf(valueName);
        return (iv);
    }
    /**
     * Called when a cell is data binding.
    */
    get dataBinding() {
        if (this._dataBinding == null) {
            this._dataBinding = new EventEmitter();
            this.i.dataBinding = delegateCombine(this.i.dataBinding, (o, e) => {
                let outerArgs = new IgxDataBindingEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeDataBinding) {
                    this.beforeDataBinding(this, outerArgs);
                }
                this._dataBinding.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._dataBinding;
    }
    /**
     * Called when a cell has been data bound.
    */
    get dataBound() {
        if (this._dataBound == null) {
            this._dataBound = new EventEmitter();
            this.i.dataBound = delegateCombine(this.i.dataBound, (o, e) => {
                let outerArgs = new IgxDataBindingEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeDataBound) {
                    this.beforeDataBound(this, outerArgs);
                }
                this._dataBound.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._dataBound;
    }
    /**
     * Called when the style key for a cell is needed. Used for recycling the cell.
    */
    get cellStyleKeyRequested() {
        if (this._cellStyleKeyRequested == null) {
            this._cellStyleKeyRequested = new EventEmitter();
            this.i.cellStyleKeyRequested = delegateCombine(this.i.cellStyleKeyRequested, (o, e) => {
                let outerArgs = new IgxCellStyleRequestedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCellStyleKeyRequested) {
                    this.beforeCellStyleKeyRequested(this, outerArgs);
                }
                this._cellStyleKeyRequested.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._cellStyleKeyRequested;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "background", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "border", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "activationBorder", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualBorder", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "borderLeftWidth", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "borderTopWidth", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "borderRightWidth", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "borderBottomWidth", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "activationBorderLeftWidth", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "activationBorderTopWidth", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "activationBorderRightWidth", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "activationBorderBottomWidth", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualBackground", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualActivationBorder", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "stickyRowBackground", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualStickyRowBackground", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "pinnedRowBackground", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualPinnedRowBackground", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "lastStickyRowBackground", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualLastStickyRowBackground", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "contentOpacity", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "horizontalAlignment", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "verticalAlignment", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "lineBreakMode", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "actualLineBreakMode", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "textColor", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualTextColor", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "pinnedRowOpacity", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "actualPinnedRowOpacity", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "textStyle", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxDefinitionBaseComponent.prototype, "dataBinding", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxDefinitionBaseComponent.prototype, "dataBound", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxDefinitionBaseComponent.prototype, "cellStyleKeyRequested", null);
//# sourceMappingURL=igx-definition-base-component.js.map