import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { SortIndicatorStyle, SortIndicatorStyle_$type } from "./SortIndicatorStyle";
import { IgxDefinitionBaseComponent } from "./igx-definition-base-component";
import { brushToString, stringToBrush, ensureEnum } from "igniteui-angular-core";
/**
 * Represents a base class used to configure the appearance of the column header cells.
*/
export const IgxHeaderComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxHeaderComponent) }];
export class IgxHeaderComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the color to use for the sort indicator icon
    */
    get sortIndicatorColor() {
        return brushToString(this.i.er);
    }
    set sortIndicatorColor(v) {
        this.i.er = stringToBrush(v);
    }
    /**
     * Gets the actual background color that is used for the cells when they are selected
    */
    get actualSortIndicatorColor() {
        return brushToString(this.i.ep);
    }
    set actualSortIndicatorColor(v) {
        this.i.ep = stringToBrush(v);
    }
    get sortIndicatorStyle() {
        return this.i.d3;
    }
    set sortIndicatorStyle(v) {
        this.i.d3 = ensureEnum(SortIndicatorStyle_$type, v);
    }
    get actualSortIndicatorStyle() {
        return this.i.d2;
    }
    set actualSortIndicatorStyle(v) {
        this.i.d2 = ensureEnum(SortIndicatorStyle_$type, v);
    }
    /**
     * Gets or sets the amount of left padding to use for the cell content.
    */
    get paddingLeft() {
        return this.i.d9;
    }
    set paddingLeft(v) {
        this.i.d9 = +v;
    }
    /**
     * Gets or sets the amount of top padding to use for the cell content.
    */
    get paddingTop() {
        return this.i.eb;
    }
    set paddingTop(v) {
        this.i.eb = +v;
    }
    /**
     * Gets or sets the amount of right padding to use for the cell content.
    */
    get paddingRight() {
        return this.i.ea;
    }
    set paddingRight(v) {
        this.i.ea = +v;
    }
    /**
     * Gets or sets the amount of bottom padding to use for the cell content.
    */
    get paddingBottom() {
        return this.i.d8;
    }
    set paddingBottom(v) {
        this.i.d8 = +v;
    }
}
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxHeaderComponent.prototype, "sortIndicatorColor", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxHeaderComponent.prototype, "actualSortIndicatorColor", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "sortIndicatorStyle", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "actualSortIndicatorStyle", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "paddingLeft", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "paddingTop", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "paddingRight", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "paddingBottom", null);
//# sourceMappingURL=igx-header-component.js.map