import * as tslib_1 from "tslib";
import { EventEmitter, Output, Component, Input, ChangeDetectionStrategy } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { IgxGridFilterDialogOpeningEventArgs } from "./igx-grid-filter-dialog-opening-event-args";
import { IgxGridFilterDialogFilterChangeEventArgs } from "./igx-grid-filter-dialog-filter-change-event-args";
import { GridFilterDialog } from "./GridFilterDialog";
import { TypeRegistrar } from "igniteui-angular-core";
import { NamePatcher, ensureBool, toSpinal, initializePropertiesFromCss } from "igniteui-angular-core";
/**
 * An advanced grid for displaying data.
*/
export const IgxLiveGridFilterDialogComponent_PROVIDERS = [];
let IgxLiveGridFilterDialogComponent = class IgxLiveGridFilterDialogComponent {
    constructor() {
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._dialogOpening = null;
        this._filterChanging = null;
        this._filterChanged = null;
        this._zoneRunner = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridFilterDialog();
    }
    ngOnInit() {
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igx" + name + "Component";
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    get isAnimationEnabled() {
        return this.i.p;
    }
    set isAnimationEnabled(v) {
        this.i.p = ensureBool(v);
    }
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get pixelScalingRatio() {
        return this.i.u;
    }
    set pixelScalingRatio(v) {
        this.i.u = +v;
    }
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get actualPixelScalingRatio() {
        return this.i.t;
    }
    set actualPixelScalingRatio(v) {
        this.i.t = +v;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("LiveGridFilterDialogComponent");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    notifySizeChanged(width, height) {
        this.i.ai(width, height);
    }
    get dialogOpening() {
        if (this._dialogOpening == null) {
            this._dialogOpening = new EventEmitter();
            this.i.dialogOpening = delegateCombine(this.i.dialogOpening, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxGridFilterDialogOpeningEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeDialogOpening) {
                        this.beforeDialogOpening(this, outerArgs);
                    }
                    this._dialogOpening.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._dialogOpening;
    }
    get filterChanging() {
        if (this._filterChanging == null) {
            this._filterChanging = new EventEmitter();
            this.i.filterChanging = delegateCombine(this.i.filterChanging, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxGridFilterDialogFilterChangeEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeFilterChanging) {
                        this.beforeFilterChanging(this, outerArgs);
                    }
                    this._filterChanging.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._filterChanging;
    }
    get filterChanged() {
        if (this._filterChanged == null) {
            this._filterChanged = new EventEmitter();
            this.i.filterChanged = delegateCombine(this.i.filterChanged, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxGridFilterDialogFilterChangeEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeFilterChanged) {
                        this.beforeFilterChanged(this, outerArgs);
                    }
                    this._filterChanged.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._filterChanged;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
};
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Boolean),
    tslib_1.__metadata("design:paramtypes", [Boolean])
], IgxLiveGridFilterDialogComponent.prototype, "isAnimationEnabled", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxLiveGridFilterDialogComponent.prototype, "pixelScalingRatio", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxLiveGridFilterDialogComponent.prototype, "actualPixelScalingRatio", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxLiveGridFilterDialogComponent.prototype, "dialogOpening", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxLiveGridFilterDialogComponent.prototype, "filterChanging", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxLiveGridFilterDialogComponent.prototype, "filterChanged", null);
IgxLiveGridFilterDialogComponent = tslib_1.__decorate([
    Component({
        selector: 'igx-live-grid-filter-dialog',
        template: ``,
        providers: [],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    tslib_1.__metadata("design:paramtypes", [])
], IgxLiveGridFilterDialogComponent);
export { IgxLiveGridFilterDialogComponent };
//# sourceMappingURL=igx-live-grid-filter-dialog-component.js.map