import { IgxCellInfo } from "./igx-cell-info";
import { NumericCellModel as NumericCellModel_internal } from "./NumericCellModel";
import { ensureBool } from "igniteui-angular-core";
/**
 * Backing information for a numeric cell in the grid.
*/
export class IgxNumericCellInfo extends IgxCellInfo {
    createImplementation() {
        return new NumericCellModel_internal();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets the numeric value to use for the cell.
    */
    get numericValue() {
        return this.i.io;
    }
    set numericValue(v) {
        this.i.io = +v;
    }
    /**
     * Sets or gets whether there is a decimal numeric value to use for the cell.
    */
    get hasDecimalValue() {
        return this.i.ij;
    }
    set hasDecimalValue(v) {
        this.i.ij = ensureBool(v);
    }
    /**
     * The format options to apply to the value
    */
    get formatOverride() {
        return this.i.i8;
    }
    set formatOverride(v) {
        this.i.i8 = v;
    }
    /**
     * Sets or gets the text prepended to a negative numeric value
    */
    get negativePrefix() {
        return this.i.ji;
    }
    set negativePrefix(v) {
        this.i.ji = v;
    }
    /**
     * Sets or gets the text prepended to a positive numeric value
    */
    get positivePrefix() {
        return this.i.jn;
    }
    set positivePrefix(v) {
        this.i.jn = v;
    }
    /**
     * Sets or gets the text appended to a negative numeric value
    */
    get negativeSuffix() {
        return this.i.jk;
    }
    set negativeSuffix(v) {
        this.i.jk = v;
    }
    /**
     * Sets or gets the text appended to a positive numeric value
    */
    get positiveSuffix() {
        return this.i.jp;
    }
    set positiveSuffix(v) {
        this.i.jp = v;
    }
    /**
     * The maximum number of decimal places to display when formatting
    */
    get maxFractionDigits() {
        return this.i.iu;
    }
    set maxFractionDigits(v) {
        this.i.iu = +v;
    }
    /**
     * The minimum number of decimal places to display when formatting
    */
    get minFractionDigits() {
        return this.i.iw;
    }
    set minFractionDigits(v) {
        this.i.iw = +v;
    }
    /**
     * The minimum number of integer digits to display when formatting
    */
    get minIntegerDigits() {
        return this.i.iy;
    }
    set minIntegerDigits(v) {
        this.i.iy = +v;
    }
    /**
     * Sets or gets if the grouping separator is shown
    */
    get showGroupingSeparator() {
        return this.i.il;
    }
    set showGroupingSeparator(v) {
        this.i.il = ensureBool(v);
    }
}
//# sourceMappingURL=igx-numeric-cell-info.js.map