import * as tslib_1 from "tslib";
import { EventEmitter, Output } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { IgxResponsiveStateEnteringEventArgs } from "./igx-responsive-state-entering-event-args";
import { IgxResponsiveStateEnteredEventArgs } from "./igx-responsive-state-entered-event-args";
import { IgxResponsiveStateExitedEventArgs } from "./igx-responsive-state-exited-event-args";
import { ResponsiveState as ResponsiveState_internal } from "./ResponsiveState";
import { ensureBool } from "igniteui-angular-core";
/**
 * Describes a state that the grid can enter based on a set of responsive conditions.
*/
export class IgxResponsiveState {
    constructor() {
        this._stateEntering = null;
        this._stateEntered = null;
        this._stateExited = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new ResponsiveState_internal();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The name of the responsive state
    */
    get name() {
        return this.i.n;
    }
    set name(v) {
        this.i.n = v;
    }
    /**
     * Gets or sets the minimum width for which this state is active.
    */
    get minimumWidth() {
        return this.i.k;
    }
    set minimumWidth(v) {
        this.i.k = +v;
    }
    /**
     * Gets or sets the maximum width for which this state is active.
    */
    get maximumWidth() {
        return this.i.j;
    }
    set maximumWidth(v) {
        this.i.j = +v;
    }
    /**
     * Configures this responsive state to only be manually actived
    */
    get isManualState() {
        return this.i.i;
    }
    set isManualState(v) {
        this.i.i = ensureBool(v);
    }
    /**
     * Adds a responsive phase to the state.
    
    * @param phase  * The phase to add.
    */
    addResponsivePhase(phase) {
        let iv = this.i.d((phase == null ? null : phase.i));
        return (iv == null ? null : iv.externalObject);
    }
    /**
     * Adds a responsive phase to the state and returns it.
    
    */
    responsivePhase() {
        let iv = this.i.a();
        return (iv == null ? null : iv.externalObject);
    }
    /**
     * Called when a state is being entered.
    */
    get stateEntering() {
        if (this._stateEntering == null) {
            this._stateEntering = new EventEmitter();
            this.i.stateEntering = delegateCombine(this.i.stateEntering, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxResponsiveStateEnteringEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeStateEntering) {
                        this.beforeStateEntering(this, outerArgs);
                    }
                    this._stateEntering.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._stateEntering;
    }
    /**
     * Called when a state is entered.
    */
    get stateEntered() {
        if (this._stateEntered == null) {
            this._stateEntered = new EventEmitter();
            this.i.stateEntered = delegateCombine(this.i.stateEntered, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxResponsiveStateEnteredEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeStateEntered) {
                        this.beforeStateEntered(this, outerArgs);
                    }
                    this._stateEntered.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._stateEntered;
    }
    /**
     * Called when a state is exited.
    */
    get stateExited() {
        if (this._stateExited == null) {
            this._stateExited = new EventEmitter();
            this.i.stateExited = delegateCombine(this.i.stateExited, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxResponsiveStateExitedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeStateExited) {
                        this.beforeStateExited(this, outerArgs);
                    }
                    this._stateExited.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._stateExited;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxResponsiveState.prototype, "stateEntering", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxResponsiveState.prototype, "stateEntered", null);
tslib_1.__decorate([
    Output(),
    tslib_1.__metadata("design:type", EventEmitter),
    tslib_1.__metadata("design:paramtypes", [])
], IgxResponsiveState.prototype, "stateExited", null);
//# sourceMappingURL=igx-responsive-state.js.map