import * as tslib_1 from "tslib";
import { EventEmitter, Output } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { IgxResponsiveStateEnteringEventArgs } from "./igx-responsive-state-entering-event-args";
import { IgxResponsiveStateEnteredEventArgs } from "./igx-responsive-state-entered-event-args";
import { IgxResponsiveStateExitedEventArgs } from "./igx-responsive-state-exited-event-args";
import { ResponsiveState as ResponsiveState_internal } from "./ResponsiveState";
import { ensureBool } from "igniteui-angular-core";
/**
 * Describes a state that the grid can enter based on a set of responsive conditions.
*/
var IgxResponsiveState = /** @class */ (function () {
    function IgxResponsiveState() {
        this._stateEntering = null;
        this._stateEntered = null;
        this._stateExited = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgxResponsiveState.prototype.createImplementation = function () {
        return new ResponsiveState_internal();
    };
    Object.defineProperty(IgxResponsiveState.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    IgxResponsiveState.prototype.onImplementationCreated = function () {
    };
    IgxResponsiveState.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgxResponsiveState.prototype, "name", {
        /**
         * The name of the responsive state
        */
        get: function () {
            return this.i.n;
        },
        set: function (v) {
            this.i.n = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxResponsiveState.prototype, "minimumWidth", {
        /**
         * Gets or sets the minimum width for which this state is active.
        */
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            this.i.k = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxResponsiveState.prototype, "maximumWidth", {
        /**
         * Gets or sets the maximum width for which this state is active.
        */
        get: function () {
            return this.i.j;
        },
        set: function (v) {
            this.i.j = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxResponsiveState.prototype, "isManualState", {
        /**
         * Configures this responsive state to only be manually actived
        */
        get: function () {
            return this.i.i;
        },
        set: function (v) {
            this.i.i = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Adds a responsive phase to the state.
    
    * @param phase  * The phase to add.
    */
    IgxResponsiveState.prototype.addResponsivePhase = function (phase) {
        var iv = this.i.d((phase == null ? null : phase.i));
        return (iv == null ? null : iv.externalObject);
    };
    /**
     * Adds a responsive phase to the state and returns it.
    
    */
    IgxResponsiveState.prototype.responsivePhase = function () {
        var iv = this.i.a();
        return (iv == null ? null : iv.externalObject);
    };
    Object.defineProperty(IgxResponsiveState.prototype, "stateEntering", {
        /**
         * Called when a state is being entered.
        */
        get: function () {
            var _this = this;
            if (this._stateEntering == null) {
                this._stateEntering = new EventEmitter();
                this.i.stateEntering = delegateCombine(this.i.stateEntering, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxResponsiveStateEnteringEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeStateEntering) {
                            _this.beforeStateEntering(_this, outerArgs);
                        }
                        _this._stateEntering.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._stateEntering;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxResponsiveState.prototype, "stateEntered", {
        /**
         * Called when a state is entered.
        */
        get: function () {
            var _this = this;
            if (this._stateEntered == null) {
                this._stateEntered = new EventEmitter();
                this.i.stateEntered = delegateCombine(this.i.stateEntered, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxResponsiveStateEnteredEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeStateEntered) {
                            _this.beforeStateEntered(_this, outerArgs);
                        }
                        _this._stateEntered.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._stateEntered;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxResponsiveState.prototype, "stateExited", {
        /**
         * Called when a state is exited.
        */
        get: function () {
            var _this = this;
            if (this._stateExited == null) {
                this._stateExited = new EventEmitter();
                this.i.stateExited = delegateCombine(this.i.stateExited, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxResponsiveStateExitedEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeStateExited) {
                            _this.beforeStateExited(_this, outerArgs);
                        }
                        _this._stateExited.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._stateExited;
        },
        enumerable: true,
        configurable: true
    });
    IgxResponsiveState.prototype._runInZone = function (act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    };
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxResponsiveState.prototype, "stateEntering", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxResponsiveState.prototype, "stateEntered", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxResponsiveState.prototype, "stateExited", null);
    return IgxResponsiveState;
}());
export { IgxResponsiveState };
//# sourceMappingURL=igx-responsive-state.js.map