import { Type } from '@angular/core';
import { IgxGridColumnAnimationSettings } from "./igx-grid-column-animation-settings";
import { IgxColumnWidth } from "./igx-column-width";
import { IgxHeaderComponent } from "./igx-header-component";
import { ColumnSortDirection } from "./ColumnSortDirection";
import { CellPropertyAnimationType } from "./CellPropertyAnimationType";
import { IgxDefinitionBaseComponent } from "./igx-definition-base-component";
import { Column } from "./Column";
import { ColumnFilterCondition } from "./ColumnFilterCondition";
/**
 * A column in the data grid.
*/
export declare const IgxColumnComponent_PROVIDERS: {
    provide: typeof IgxDefinitionBaseComponent;
    useExisting: Type<any>;
}[];
export declare abstract class IgxColumnComponent extends IgxDefinitionBaseComponent {
    /**
                                 * @hidden
                                 */
    readonly i: Column;
    constructor();
    /**
     * Gets or sets the amount of left padding to use for the cell content for this column.
    */
    paddingLeft: number;
    /**
     * Gets or sets the amount of top padding to use for the cell content for this column.
    */
    paddingTop: number;
    /**
     * Gets or sets the amount of right padding to use for the cell content of this column.
    */
    paddingRight: number;
    /**
     * Gets or sets the amount of bottom padding to use for the cell content of this column.
    */
    paddingBottom: number;
    /**
     * Gets or sets an unique name of the Column
    */
    name: string;
    /**
     * Gets or sets the key used for the column binding
    */
    propertyPath: string;
    /**
     * Gets or sets the text displayed in the header of the column
    */
    headerText: string;
    /**
     * Gets the actual text displayed in the header of the column
    */
    actualHeaderText: string;
    /**
     * Gets or sets the background color to use for the cells when they are selected
    */
    selectedBackground: string;
    /**
     * Gets the actual background color that is used for the cells when they are selected
    */
    actualSelectedBackground: string;
    /**
     * Gets or sets the animation settings to use for this column.
    */
    animationSettings: IgxGridColumnAnimationSettings;
    /**
     * Gets or sets the width to use for this column.
    */
    width: IgxColumnWidth;
    /**
     * Gets or sets the minimum width to use for this column. Overrides the DefaultColumnMinWidth from the grid, if set.
    */
    minWidth: number;
    /**
     * Gets whether this column was projected from markup/templates and is constrained.
    */
    isFromMarkup: boolean;
    /**
     * Gets whether this column was auto generated.
    */
    isAutoGenerated: boolean;
    /**
     * Gets or sets a filter to apply on the values of this column
    */
    filter: ColumnFilterCondition;
    /**
     * Gets or sets the header definition for this column.
    */
    header: IgxHeaderComponent;
    /**
     * Gets or sets whether filtering is enabled for this column.
    */
    isFilteringEnabled: boolean;
    /**
     * Gets or sets whether resizing is enabled for this column.
    */
    isResizingEnabled: boolean;
    /**
     * Gets or sets whether or not a column is hidden from the grid
    */
    isHidden: boolean;
    /**
     * Gets or sets if a column should be removed from the grid when it is fully hidden
    */
    shouldRemoveWhenHidden: boolean;
    /**
     * Gets the current sort direction (None, Ascending, Descending) for this column.
    */
    sortDirection: ColumnSortDirection;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Get the unique key used to identify this column.
    
    */
    getUniqueKey(): string;
    setNamedHeaderValue(valueName: string, animationType: CellPropertyAnimationType, value: any): void;
    /**
     * Returns if the column has named header values.
    
    */
    hasNamedHeaderValues(): boolean;
    /**
     * Returns if there is a named header value with a given name.
    
    * @param valueName  * The named value to check for.
    */
    hasNamedHeaderValue(valueName: string): boolean;
    /**
     * Removes a named header value with the given name from the named header values for this column.
    
    * @param valueName  * The named header value to remove.
    */
    removeNamedHeaderValue(valueName: string): void;
    /**
     * Gets the value of a named header value for this column by name.
    
    * @param valueName  * Name of the named header value to retrieve.
    */
    getNamedHeaderValue(valueName: string): any;
}
