import { EventEmitter, ViewContainerRef, ComponentFactoryResolver, Injector, NgZone, AfterContentInit, OnInit, Renderer2, QueryList } from '@angular/core';
import { IgRect } from "igniteui-angular-core";
import { IgxSectionHeaderComponent } from './igx-section-header-component';
import { IgxSummaryRowRootComponent } from './igx-summary-row-root-component';
import { IgxSummaryRowSectionComponent } from './igx-summary-row-section-component';
import { IgxColumnWidth } from './igx-column-width';
import { HeaderClickAction } from './HeaderClickAction';
import { ColumnShowingAnimationMode } from './ColumnShowingAnimationMode';
import { ColumnPropertyUpdatingAnimationMode } from './ColumnPropertyUpdatingAnimationMode';
import { CellDataLoadedAnimationMode } from './CellDataLoadedAnimationMode';
import { RowSelectionAnimationMode } from './RowSelectionAnimationMode';
import { ColumnMovingAnimationMode } from './ColumnMovingAnimationMode';
import { ColumnHidingAnimationMode } from './ColumnHidingAnimationMode';
import { CellSelectionAnimationMode } from './CellSelectionAnimationMode';
import { ColumnExchangingAnimationMode } from './ColumnExchangingAnimationMode';
import { GridSelectionMode } from './GridSelectionMode';
import { GridActivationMode } from './GridActivationMode';
import { GridSelectionBehavior } from './GridSelectionBehavior';
import { IgxGridCellEventArgs } from './igx-grid-cell-event-args';
import { IgxGridColumnsAutoGeneratedEventArgs } from './igx-grid-columns-auto-generated-event-args';
import { IgxGridSelectedItemsChangedEventArgs } from './igx-grid-selected-items-changed-event-args';
import { IgxGridSelectedKeysChangedEventArgs } from './igx-grid-selected-keys-changed-event-args';
import { IgxGridSelectedCellsChangedEventArgs } from './igx-grid-selected-cells-changed-event-args';
import { IgxGridSelectedCellRangesChangedEventArgs } from './igx-grid-selected-cell-ranges-changed-event-args';
import { IgxGridSortDescriptionsChangedEventArgs } from './igx-grid-sort-descriptions-changed-event-args';
import { IgxGridGroupDescriptionsChangedEventArgs } from './igx-grid-group-descriptions-changed-event-args';
import { Grid } from "./Grid";
import { IgxColumnComponent } from './igx-column-component';
import { IgxGridColumnCollection } from './igx-grid-column-collection';
import { ScrollbarStyle } from "igniteui-angular-core";
import { IgxColumnSortDescriptionCollection } from './igx-column-sort-description-collection';
import { IgxColumnGroupDescriptionCollection } from './igx-column-group-description-collection';
import { IgxFilterExpressionCollection } from "igniteui-angular-core";
import { IgxColumnSummaryDescriptionCollection } from './igx-column-summary-description-collection';
import { IgxGridSelectedItemsCollection } from "./igx-grid-selected-items-collection";
import { IgxGridSelectedKeysCollection } from "./igx-grid-selected-keys-collection";
import { IgxGridSelectedCellsCollection } from "./igx-grid-selected-cells-collection";
import { IgxGridSelectedCellRangesCollection } from "./igx-grid-selected-cell-ranges-collection";
import { IgxCellKey } from "./igx-cell-key";
import { IgxGridFilterExpressionsEventArgs } from './igx-grid-filter-expressions-event-args';
import { IgxResponsiveStatesCollection } from './igx-responsive-states-collection';
import { IgxGridAnimationSettings } from './igx-grid-animation-settings';
import { IgxRowSeparatorComponent } from './igx-row-separator-component';
import { IDataSource } from "igniteui-angular-core";
import { IgxGridCellPosition } from "./igx-grid-cell-position";
import { IgxGridActiveCellChangedEventArgs } from "./igx-grid-active-cell-changed-event-args";
import { IgxCellInfo } from "./igx-cell-info";
import { IgxHeaderSeparatorComponent } from "./igx-header-separator-component";
import { IgxColumnResizingSeparatorComponent } from './igx-column-resizing-separator-component';
import { ColumnResizingMode } from "./ColumnResizingMode";
import { ColumnResizingAnimationMode } from "./ColumnResizingAnimationMode";
import { ColumnMovingMode } from "./ColumnMovingMode";
import { IgxColumnMovingSeparatorComponent } from './igx-column-moving-separator-component';
import { SortIndicatorStyle } from "./SortIndicatorStyle";
import { DataSourceSectionHeaderDisplayMode } from "igniteui-angular-core";
import { DataSourceSummaryScope } from "igniteui-angular-core";
import { GroupSummaryDisplayMode } from "./GroupSummaryDisplayMode";
import { ISummaryResult } from "igniteui-angular-core";
export declare const IgxGridComponent_PROVIDERS: any[];
export declare class IgxLiveGridComponent implements OnInit, AfterContentInit {
    private _renderer;
    private _elRef;
    private _ngZone;
    private _componentFactoryResolver;
    private _injector;
    contentColumns: QueryList<IgxColumnComponent>;
    _dynamicContent: ViewContainerRef;
    /**
     * The columns actually present in the grid. Do not directly modify this array.
     * This array's contents can be modified by causing Angular to reproject the child content.
     * Or adding and removing columns from the manual columns collection on the columns property.
     */
    combinedColumns: IgxColumnComponent[];
    private _container;
    private _columns;
    private _disableManualColumnSync;
    private _ensureColumnsAreManual;
    /**
     * A collection or manually added columns for the grid.
    */
    readonly columns: IgxGridColumnCollection;
    private _height;
    private _width;
    height: string;
    width: string;
    private _scrollerStyle;
    scrollbarStyle: ScrollbarStyle;
    private _columnsAdapter;
    protected createImplementation(): Grid;
    ngOnInit(): void;
    protected _implementation: any;
    readonly i: Grid;
    private onImplementationCreated;
    constructor(_renderer: Renderer2, _elRef: ViewContainerRef, _ngZone: NgZone, _componentFactoryResolver: ComponentFactoryResolver, _injector: Injector);
    private _focusScroller;
    private _setDefaultCursor;
    private _setResizeCursor;
    private _setHandCursor;
    private _scroller;
    private _dragger;
    private _wrapper;
    private _grid;
    private containerResized;
    private _insertExternalColumnAtIndex;
    private _removeExternalColumn;
    ngAfterContentInit(): void;
    readonly actualDataSource: IDataSource;
    private _contentLayout;
    private _contentDiv;
    private _useNativeScroll;
    private _content;
    private refreshContentSize;
    onScroll(): void;
    private _dataSource;
    dataSource: any;
    forColumnsWithPropertyPath(propertyPath: string, callback: (column: IgxColumnComponent) => void): void;
    /**
     * Gets or sets the default column width to use if a column as no local width.
     * */
    defaultColumnWidth: IgxColumnWidth;
    private _insetLeft;
    /**
     * Gets or sets the amount of left inset space to use around the grid content.
    */
    insetLeft: number;
    private _insetTop;
    /**
     * Gets or sets the amount of top inset space to use around the grid content.
    */
    insetTop: number;
    private _insetRight;
    /**
     * Gets or sets the amount of right inset space to use around the grid content.
    */
    insetRight: number;
    private _insetBottom;
    /**
     * Gets or sets the amount of bottom inset space to use around the grid content.
    */
    insetBottom: number;
    /**
 * Gets or sets the type of column resizing to use.
*/
    columnResizingMode: ColumnResizingMode;
    /**
     * Gets or sets the type column moving to use.
    */
    columnMovingMode: ColumnMovingMode;
    /**
     * Gets or sets the header type used for sectioning off groups of rows.
    */
    sectionHeader: IgxSectionHeaderComponent;
    /**
     * Gets or sets the cell definition used for summary rows at the root level.
    */
    summaryRowRoot: IgxSummaryRowRootComponent;
    /**
     * Gets or sets the cell definition used for summary rows at the section level.
    */
    summaryRowSection: IgxSummaryRowSectionComponent;
    /**
     * Gets or sets the row seperator settings.
    */
    rowSeparator: IgxRowSeparatorComponent;
    /**
     * Gets or sets the header seperator settings.
    */
    headerSeparator: IgxHeaderSeparatorComponent;
    /**
     * Gets or sets the column resizing seperator settings.
    */
    columnResizingSeparator: IgxColumnResizingSeparatorComponent;
    /**
     * Gets or sets the column resizing seperator settings.
    */
    columnMovingSeparator: IgxColumnMovingSeparatorComponent;
    /**
     * Gets or sets the desired properties for the data source to load. If specified the data source may decide to constrain the properties it fetches to these properties and must make sure that at least those properties are loaded, rather than the default behavior for that data source.
    */
    dataSourceDesiredProperties: string[];
    /**
     * Gets or sets the height to use for the rows in the grid.
    */
    rowHeight: number;
    /**
     * Gets or sets the default minimum width to use on all columns. Ignored if NaN.
    */
    defaultColumnMinWidth: number;
    /**
     * Gets or sets the height to use for the header row.
    */
    headerHeight: number;
    /**
     * Returns/sets the action to take when a column header is clicked.
    */
    headerClickAction: HeaderClickAction;
    /**
     * Configures whether or not the grid will autogenerate columns when the data source is set.
    */
    autoGenerateColumns: boolean;
    /**
     * Sets or gets the height to use for the row separators.
    */
    rowSeparatorHeight: number;
    /**
     * Configures whether or not place holders are used for cells who do not have their data yet.
    */
    isPlaceholderRenderingEnabled: boolean;
    /**
     * Sets or gets the Column Adding Animation mode to use.
    */
    columnAddingAnimationMode: ColumnShowingAnimationMode;
    /**
     * Sets or gets the Column Property Updating Animation mode to use.
    */
    columnPropertyUpdatingAnimationMode: ColumnPropertyUpdatingAnimationMode;
    /**
     * Sets or gets the cell data loaded animation mode to use.
    */
    cellDataLoadedAnimationMode: CellDataLoadedAnimationMode;
    /**
     * Sets or gets the row selection animation mode to use.
    */
    rowSelectionAnimationMode: RowSelectionAnimationMode;
    /**
     * Sets or gets the cell selection animation mode to use.
    */
    cellSelectionAnimationMode: CellSelectionAnimationMode;
    /**
     * Sets or gets the default animation settings for the grid.
    */
    animationSettings: IgxGridAnimationSettings;
    /**
     * Sets or gets the column resizing animation mode to use. Only applies when resizing in Deferred mode.
    */
    columnResizingAnimationMode: ColumnResizingAnimationMode;
    /**
     * Sets or gets the column showing animation mode to use.
    */
    columnShowingAnimationMode: ColumnShowingAnimationMode;
    /**
     * Sets or gets the column moving animation mode to use.
    */
    columnMovingAnimationMode: ColumnMovingAnimationMode;
    /**
     * Sets or gets the column hiding animation mode to use.
    */
    columnHidingAnimationMode: ColumnHidingAnimationMode;
    /**
     * Sets or gets the column exchanging animation mode to use.
    */
    columnExchangingAnimationMode: ColumnExchangingAnimationMode;
    /**
     * Sets or gets the grid selection mode.
    */
    selectionMode: GridSelectionMode;
    /**
     * Sets or gets the grid selection mode.
    */
    activationMode: GridActivationMode;
    /**
     * Sets or gets how selection behaves in the grid.
    */
    selectionBehavior: GridSelectionBehavior;
    private _selectedItems;
    /**
     * Gets which items are currently selected in the grid. Collection can be updated to programatically select items.
    */
    selectedItems: IgxGridSelectedItemsCollection;
    private _selectedKeys;
    /**
     * Gets which primary key values are currently selected in the grid. Collection can be updated to programatically select items.
    */
    selectedKeys: IgxGridSelectedKeysCollection;
    private _selectedCells;
    /**
     * Gets which cells are currently selected in the grid. Collection can be updated to programatically select cells.
    */
    selectedCells: IgxGridSelectedCellsCollection;
    private _selectedCellRanges;
    /**
     * Gets which cell ranges are currently selected in the grid. Collection can be updated to programatically select cells.
    */
    selectedCellRanges: IgxGridSelectedCellRangesCollection;
    private _pinnedItems;
    /**
     * Gets which items are currently pinned in the grid. Collection can be updated to programatically pin items.
    */
    pinnedItems: IgxGridSelectedItemsCollection;
    private _pinnedKeys;
    /**
     * Gets which primary keys are currently pinned in the grid. Collection can be updated to programatically pin items.
    */
    pinnedKeys: IgxGridSelectedKeysCollection;
    /**
     * Gets or sets whether to show the filtering UI in the headers for columns where filtering is enabled.
    */
    isFilterUIEnabled: boolean;
    /**
     * Gets or sets if group rows will stick to the top of the grid.
    */
    isGroupRowSticky: boolean;
    /**
     * Gets or sets if header separators are rendered.
    */
    isHeaderSeparatorVisible: boolean;
    /**
     * Gets or sets the default background color to use for content cells when a row is in a selected state
    */
    cellSelectedBackground: string;
    /**
     * Gets or sets the default background color to use for section header cells when a row is in a selected state
    */
    sectionHeaderSelectedBackground: string;
    /**
     * Gets or sets the default background color to use for summary cells at the root level.
    */
    summaryRootBackground: string;
    /**
     * Gets or sets the default background color to use for summary cells at the section level.
    */
    summarySectionBackground: string;
    /**
     * Gets or sets the default opacity to use for pinned rows
    */
    pinnedRowOpacity: number;
    /**
     * Gets or sets the default color to use for sticky rows
    */
    stickyRowBackground: string;
    /**
     * Gets or sets the default color to use for pinned rows
    */
    pinnedRowBackground: string;
    /**
     * Gets or sets the default color to use for the last sticky row
    */
    lastStickyRowBackground: string;
    /**
     * Gets or sets the position of the active cell.
    */
    activeCell: IgxGridCellPosition;
    /**
     * Gets or sets the default background color to use for content cells
    */
    cellBackground: string;
    /**
     * Gets or sets the default text color to use for content cells
    */
    cellTextColor: string;
    /**
     * Gets or sets the default text color to use for content cells
    */
    headerSortIndicatorColor: string;
    /**
     * Gets or sets the default render style for sort indicators in header cells.
    */
    headerSortIndicatorStyle: SortIndicatorStyle;
    /**
     * Gets or sets the font to use for content cells
    */
    cellTextStyle: string;
    /**
     * Gets or sets the default background color to use for section header cells
    */
    sectionHeaderBackground: string;
    /**
     * Gets or sets the default text color to use for section header cells
    */
    sectionHeaderTextColor: string;
    /**
     * Gets or sets the font to use for section header cells
    */
    sectionHeaderTextStyle: string;
    /**
     * Gets or sets the default text color to use for summary cells at the root level.
    */
    summaryRootTextColor: string;
    /**
     * Gets or sets the default text color to use for summary cells at the section level.
    */
    summarySectionTextColor: string;
    /**
     * Gets or sets the default text color to use for summary names in summary cells at the root level.
    */
    summaryRootNameTextColor: string;
    /**
     * Gets or sets the default text color to use for summary names in summary cells at the section level.
    */
    summarySectionNameTextColor: string;
    /**
     * Gets or sets the default background color to use for summary cells at the root level.
    */
    summaryRootSelectedBackground: string;
    /**
     * Gets or sets the default background color to use for summary cells at the section level.
    */
    summarySectionSelectedBackground: string;
    /**
     * Gets or sets the font to use for summary cells
    */
    summaryTextStyle: string;
    /**
     * Gets or sets the font to use for header cells
    */
    summarySectionTextStyle: string;
    /**
     * Gets or sets the default background color to use for header separators.
    */
    headerSeparatorWidth: number;
    /**
     * Gets or sets the default background color to use for header separators.
    */
    headerSeparatorBackground: string;
    /**
     * Gets or sets the default background color to use for header cells
    */
    headerBackground: string;
    /**
     * Gets or sets the default text color to use for header cells
    */
    headerTextColor: string;
    /**
     * Gets or sets the font to use for header cells
    */
    headerTextStyle: string;
    /**
     * Gets or sets the default background color to use for row separators
    */
    rowSeparatorBackground: string;
    /**
     * Gets or sets the default sticky row background color to use for row separators
    */
    rowSeparatorStickyRowBackground: string;
    /**
     * Gets or sets the default last sticky row background color to use for row separators
    */
    rowSeparatorLastStickyRowBackground: string;
    /**
     * Gets or sets the pinned row background color to use for row separators
    */
    rowSeparatorPinnedRowBackground: string;
    /**
     * Sets or gets the width to use for the column resizing separator.
    */
    columnResizingSeparatorWidth: number;
    /**
     * Sets or gets the width to use for the column resizing separator.
    */
    columnMovingSeparatorWidth: number;
    /**
     * Gets or sets the default background color to use for column resizing separator.
    */
    columnResizingSeparatorBackground: string;
    /**
     * Gets or sets the default background color to use for column moving separator.
    */
    columnMovingSeparatorBackground: string;
    private _responsiveStates;
    /**
     * A set of states that can be applied to the columns of the grid based on available space.
    */
    responsiveStates: IgxResponsiveStatesCollection;
    /**
     * Gets the region of the grid that is visible.
    */
    readonly actualVisibleRegion: IgRect;
    /**
     * Gets the current sort that is applied to the grid. Collection can be updated to modify the sort for the grid. Once sort descriptions are in this collection, the grid will no longer listen for changes on their properties.
    */
    readonly sortDescriptions: IgxColumnSortDescriptionCollection;
    /**
     * Gets the current grouping that is applied to the grid. Collection can be updated to modify the grouping for the grid. Once grouping descriptions are in this collection, the grid will no longer listen for changes on their properties.
    */
    readonly groupDescriptions: IgxColumnGroupDescriptionCollection;
    /**
     * Gets the current filter that is applied to the grid. Collection can be updated to modify the filter for the grid. Once filter expresisons are in this collection, the grid will no longer listen for changes on their properties.
    */
    readonly filterExpressions: IgxFilterExpressionCollection;
    /**
     * Gets the current summaries that are applied to the grid.
    */
    readonly summaryDescriptions: IgxColumnSummaryDescriptionCollection;
    /**
     * Gets or sets the scope which summaries are calculated for.
    */
    summaryScope: DataSourceSummaryScope;
    /**
     * Gets or sets whether group headers are collapsable.
    */
    isGroupCollapsable: boolean;
    groupHeaderDisplayMode: DataSourceSectionHeaderDisplayMode;
    /**
     * Gets or sets whether groups are expanded or collapsed by default.
    */
    isGroupExpandedDefault: boolean;
    /**
     * Gets or sets the display mode summaries will use inside groups.
    */
    groupSummaryDisplayMode: GroupSummaryDisplayMode;
    /**
     * Sets or gets the user provided primary key to assume for the data. Certain functionality of the grid requires a way to uniquely identify items in order to work correctly.
     * If a primary key cannot be inferred from the data source, you may need to provide one here.
    */
    primaryKey: string[];
    /**
     * Gets either the inferred primary key from the data source, or the user provided primary key, if present. Represents the actual primary key that the grid will use in operations that require it.
    */
    actualPrimaryKey: string[];
    private _actualColumns;
    actualColumns: IgxGridColumnCollection;
    /**
     * Sets or gets whether the grid will react to sort changes.
    */
    reactsToSortChanges: boolean;
    /**
     * Sets or gets whether the grid will react to group changes.
    */
    reactsToGroupChanges: boolean;
    /**
     * Sets or gets whether the grid will react to filter changes.
    */
    reactsToFilterChanges: boolean;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected readonly hasUserValues: Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    getHitCell(x: number, y: number): IgxCellInfo;
    /**
     * Forces a refresh of the grid content.
    
    */
    refresh(): void;
    /**
     * Makes sure pending work has completed if the grid need to be synchronously examined.
    
    */
    flush(): void;
    exchangeColumn(newColumn: IgxColumnComponent, oldColumn: IgxColumnComponent): void;
    moveColumn(oldIndex: number, newIndex: number): void;
    /**
     * Exports visual information about the current state of the grid.
    
    */
    exportVisualModel(): any;
    /**
     * Returns a serialized copy of the exported visual model
    
    */
    exportSerializedVisualModel(): string;
    /**
     * Scrolls the grid to given row, by index
    
    * @param rowNumber  * The row index to scroll to.
    */
    scrollToRowByIndex(rowNumber: number): void;
    /**
     * Scrolls the grid so that a row is the last visible, by index.
    
    * @param rowNumber  * The row index to scroll to.
    */
    scrollToLastRowByIndex(rowNumber: number): void;
    /**
     * Scrolls to an item, if found.
    
    * @param item  * The item to scroll to.
    */
    scrollToItem(item: any): boolean;
    scrollToPrimaryKey(key: any[]): boolean;
    /**
     * Scrolls the grid to given column, by index
    
    * @param columnNumber  * The column number to scroll to.
    */
    scrollToColumnByIndex(columnNumber: number): void;
    /**
     * Gets the last visible index in the grid.
    
    */
    getLastVisibleIndex(): number;
    /**
     * Gets the first visible index in the grid.
    
    */
    getFirstVisibleIndex(): number;
    /**
     * Invalidates the bound data for the rows currently visible.
    
    */
    invalidateVisibleRows(): void;
    /**
     * Manually set the active responsive state of the grid.
    
    * @param name
    */
    setActiveResponsiveState(name: string): void;
    notifySetItem(index: number, oldItem: any, newItem: any): void;
    /**
     * Manually notifies the grid's data source that the data it has bound to has been cleared and needs to be re-examined.
     * This should not be called if the data that the grid is bound to is already observable.
    
    */
    notifyClearItems(): void;
    notifyInsertItem(index: number, newItem: any): void;
    notifyRemoveItem(index: number, oldItem: any): void;
    /**
     * Returns the data index of an item within the bound data source.
    
    * @param item  * The item from which to get the index.
    */
    dataIndexOfItem(item: any): number;
    dataIndexOfPrimaryKey(key: any[]): number;
    /**
     * Resolves the value of a specific cell.
    
    * @param cellKey  * The cell to resolve.
    */
    resolveCellValue(cellKey: IgxCellKey): any;
    resolveCellValueFromPosition(row: number, column: number): any;
    /**
     * Gets the summary results for root level.
    
    */
    getRootSummaryResults(): ISummaryResult[];
    /**
     * Gets the summary results for a specific section.
    
    */
    getSectionSummaryResults(sectionIndex: number): ISummaryResult[];
    private _filterExpressionsChanging;
    readonly filterExpressionsChanging: EventEmitter<{
        sender: any;
        args: IgxGridFilterExpressionsEventArgs;
    }>;
    private _filterExpressionsChanged;
    readonly filterExpressionsChanged: EventEmitter<{
        sender: any;
        args: IgxGridFilterExpressionsEventArgs;
    }>;
    private _cellPreviewPointerDown;
    /**
     * Previews that a pointer is down on a cell.
    */
    readonly cellPreviewPointerDown: EventEmitter<{
        sender: any;
        args: IgxGridCellEventArgs;
    }>;
    private _cellPreviewPointerUp;
    /**
     * Previews that a pointer is up on a cell.
    */
    readonly cellPreviewPointerUp: EventEmitter<{
        sender: any;
        args: IgxGridCellEventArgs;
    }>;
    private _cellPointerDown;
    /**
     * Indicates a pointer is down on a cell.
    */
    readonly cellPointerDown: EventEmitter<{
        sender: any;
        args: IgxGridCellEventArgs;
    }>;
    private _cellPointerUp;
    /**
     * Indicates a pointer is up on a cell.
    */
    readonly cellPointerUp: EventEmitter<{
        sender: any;
        args: IgxGridCellEventArgs;
    }>;
    private _cellClicked;
    /**
     * Called when a cell is clicked.
    */
    readonly cellClicked: EventEmitter<{
        sender: any;
        args: IgxGridCellEventArgs;
    }>;
    private _sortDescriptionsChanged;
    /**
     * Called when sorting has changed.
    */
    readonly sortDescriptionsChanged: EventEmitter<{
        sender: any;
        args: IgxGridSortDescriptionsChangedEventArgs;
    }>;
    private _groupDescriptionsChanged;
    /**
     * Called when grouping has changed.
    */
    readonly groupDescriptionsChanged: EventEmitter<{
        sender: any;
        args: IgxGridGroupDescriptionsChangedEventArgs;
    }>;
    private _columnsAutoGenerated;
    /**
     * Called when the columns are autogenerated.
    */
    readonly columnsAutoGenerated: EventEmitter<{
        sender: any;
        args: IgxGridColumnsAutoGeneratedEventArgs;
    }>;
    private _selectedItemsChanged;
    /**
     * Called when the selected items change.
    */
    readonly selectedItemsChanged: EventEmitter<{
        sender: any;
        args: IgxGridSelectedItemsChangedEventArgs;
    }>;
    private _selectedKeysChanged;
    /**
     * Called when the selected keys change.
    */
    readonly selectedKeysChanged: EventEmitter<{
        sender: any;
        args: IgxGridSelectedKeysChangedEventArgs;
    }>;
    private _selectedCellsChanged;
    /**
     * Called when the selected cells change.
    */
    readonly selectedCellsChanged: EventEmitter<{
        sender: any;
        args: IgxGridSelectedCellsChangedEventArgs;
    }>;
    private _activeCellChanged;
    /**
     * Called when the active cell changes.
    */
    readonly activeCellChanged: EventEmitter<{
        sender: any;
        args: IgxGridActiveCellChangedEventArgs;
    }>;
    private _selectedCellRangesChanged;
    /**
     * Called when the selected cell ranges changed.
    */
    readonly selectedCellRangesChanged: EventEmitter<{
        sender: any;
        args: IgxGridSelectedCellRangesChangedEventArgs;
    }>;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
}
