import { IgxColumnPropertySetter } from "./igx-column-property-setter";
import { IgxColumnExchanger } from "./igx-column-exchanger";
import { ResponsivePhase as ResponsivePhase_internal } from "./ResponsivePhase";
/**
 * Describes one phase of a responsive state to apply to the grid.
*/
export declare class IgxResponsivePhase {
    protected createImplementation(): ResponsivePhase_internal;
    protected _implementation: any;
    /**
     * @hidden
     */
    readonly i: ResponsivePhase_internal;
    private onImplementationCreated;
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * The name of this responsive phase
    */
    name: string;
    /**
     * The amount of time to delay the responsive phase from starting, in milliseconds
    */
    delayMilliseconds: number;
    /**
     * Adds a column property setter to the phase.
    
    * @param setter  * The setter to add.
    */
    addColumnPropertySetter(setter: IgxColumnPropertySetter): IgxResponsivePhase;
    /**
     * Adds a column property setter to the phase, and returns it.
    
    */
    columnPropertySetter(): IgxColumnPropertySetter;
    /**
     * Adds a column exchanger the the phase.
    
    * @param exchanger  * The exchanger to add.
    */
    addColumnExchanger(exchanger: IgxColumnExchanger): IgxResponsivePhase;
    /**
     * Adds a column exchanger to the phase and returns it.
    
    */
    columnExchanger(): IgxResponsivePhase;
}
