import { EventEmitter } from '@angular/core';
import { IgxResponsiveStateEnteringEventArgs } from "./igx-responsive-state-entering-event-args";
import { IgxResponsiveStateEnteredEventArgs } from "./igx-responsive-state-entered-event-args";
import { IgxResponsiveStateExitedEventArgs } from "./igx-responsive-state-exited-event-args";
import { IgxResponsivePhase } from "./igx-responsive-phase";
import { ResponsiveState as ResponsiveState_internal } from "./ResponsiveState";
/**
 * Describes a state that the grid can enter based on a set of responsive conditions.
*/
export declare class IgxResponsiveState {
    protected createImplementation(): ResponsiveState_internal;
    protected _implementation: any;
    /**
     * @hidden
     */
    readonly i: ResponsiveState_internal;
    private onImplementationCreated;
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * The name of the responsive state
    */
    name: string;
    /**
     * Gets or sets the minimum width for which this state is active.
    */
    minimumWidth: number;
    /**
     * Gets or sets the maximum width for which this state is active.
    */
    maximumWidth: number;
    /**
     * Configures this responsive state to only be manually actived
    */
    isManualState: boolean;
    /**
     * Adds a responsive phase to the state.
    
    * @param phase  * The phase to add.
    */
    addResponsivePhase(phase: IgxResponsivePhase): IgxResponsiveState;
    /**
     * Adds a responsive phase to the state and returns it.
    
    */
    responsivePhase(): IgxResponsivePhase;
    private _stateEntering;
    /**
     * Called when a state is being entered.
    */
    readonly stateEntering: EventEmitter<{
        sender: any;
        args: IgxResponsiveStateEnteringEventArgs;
    }>;
    private _stateEntered;
    /**
     * Called when a state is entered.
    */
    readonly stateEntered: EventEmitter<{
        sender: any;
        args: IgxResponsiveStateEnteredEventArgs;
    }>;
    private _stateExited;
    /**
     * Called when a state is exited.
    */
    readonly stateExited: EventEmitter<{
        sender: any;
        args: IgxResponsiveStateExitedEventArgs;
    }>;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
}
