import { __decorate, __metadata } from 'tslib';
import { EventEmitter, Input, Output, forwardRef, Component, ChangeDetectionStrategy, ContentChildren, QueryList, ViewChild, ViewContainerRef, Renderer2, NgZone, ComponentFactoryResolver, Injector, NgModule } from '@angular/core';
import { markEnum, Type, Base, enumGetBox, markType, Brush, Color, FontInfo, DeviceUtils, StringBuilder, stringIsNullOrEmpty, isNaN_, stringEndsWith, SummaryOperand_$type, stringContains, stringReplace, List$1, String_$type, tryParseNumber, PropertyChangedEventArgs, INotifyPropertyChanged_$type, delegateRemove, runOn, delegateCombine, ObservableCollection$1, SyncableObservableCollection$2, SortDescription, CountSummaryCalculator, AverageSummaryCalculator, SumSummaryCalculator, MaxSummaryCalculator, MinSummaryCalculator, SummaryDescription, EventArgs, RectData, dateMinValue, Dictionary$2, Boolean_$type, Number_$type, truncate, BrushUtil, EnumUtil, AppearanceHelper, FontUtil, Delegate_$type, typeGetValue, IDataSourceUpdateNotifier_$type, Thickness, FilterExpressionCollection, Point_$type, intDivide, Rect, dateNow, timeSpanTotalSeconds, fromEnum, typeCast, DataSourceSummaryScope_$type, DataSourceSectionHeaderDisplayMode_$type, IDataSource_$type, stringStartsWith, InvalidOperationException, FilterFactory, NotSupportedException, HashSet$1, FastIterationDictionary$2, stringEmpty, stringIsNullOrWhiteSpace, Stack$1, DataSourceSpecialRow, IList$1_$type, DefaultSectionInformation, getInstanceType, Date_$type, EasingFunctions, timeSpanFromMilliseconds, timeSpanTotalMilliseconds, ensureBool, ensureEnum, brushToString, stringToBrush, NamePatcher, TypeRegistrar, toSpinal, initializePropertiesFromCss, IgCollection, SyncableObservableCollection$1, CanvasViewRenderer, RenderingContext, LocalDataSource, ITickProvider_$type, Rectangle, Line, TextBlock, PointUtil, Random, isDigit, Path, TransformGroup, TranslateTransform, RotateTransform, DoubleAnimator, PathFigure, LineSegment, PathGeometry, Geometry, dateTryParse, CanvasGestureDOMEventProxy, BaseDOMEventProxy, IgxFilterExpressionCollection, IScrollerKeyboardListener_$type, AngularRenderer, CollectionAdapter, Scroller, AngularWrapper, NotifyCollectionChangedAction, fromRect, IExecutionContext_$type, DataSourceSchemaPropertyType_$type } from 'igniteui-angular-core';
import { CommonModule } from '@angular/common';

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates how summaries are displayed inside groups.
 */
var GroupSummaryDisplayMode;
(function (GroupSummaryDisplayMode) {
    /**
     * Group summaries are displayed in a flat list in the spanning group header.
     */
    GroupSummaryDisplayMode[GroupSummaryDisplayMode["List"] = 0] = "List";
    /**
     * The group header is rendered as cells and summary values are rendered inside the cells
     * aligned with their column.
     */
    GroupSummaryDisplayMode[GroupSummaryDisplayMode["Cells"] = 1] = "Cells";
    /**
     * Group summaries are displayed as summary rows at the top of the group.
     */
    GroupSummaryDisplayMode[GroupSummaryDisplayMode["RowTop"] = 2] = "RowTop";
    /**
     * Group summaries are displayed as summary rows at the bottom of the group.
     */
    GroupSummaryDisplayMode[GroupSummaryDisplayMode["RowBottom"] = 3] = "RowBottom";
    /**
     * No summaries are displayed in the group.
     */
    GroupSummaryDisplayMode[GroupSummaryDisplayMode["None"] = 4] = "None";
})(GroupSummaryDisplayMode || (GroupSummaryDisplayMode = {}));
/**
 * @hidden
 */
let GroupSummaryDisplayMode_$type = markEnum('GroupSummaryDisplayMode', 'List,0|Cells,1|RowTop,2|RowBottom,3|None,4');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates the desired horizontal alignment of the cell content.
 */
var CellContentHorizontalAlignment;
(function (CellContentHorizontalAlignment) {
    /**
     * Align left.
     */
    CellContentHorizontalAlignment[CellContentHorizontalAlignment["Left"] = 0] = "Left";
    /**
     * Align center.
     */
    CellContentHorizontalAlignment[CellContentHorizontalAlignment["Center"] = 1] = "Center";
    /**
     * Align right.
     */
    CellContentHorizontalAlignment[CellContentHorizontalAlignment["Right"] = 2] = "Right";
    /**
     * Align stretch
     */
    CellContentHorizontalAlignment[CellContentHorizontalAlignment["Stretch"] = 3] = "Stretch";
    /**
     * Align auto
     */
    CellContentHorizontalAlignment[CellContentHorizontalAlignment["Auto"] = 4] = "Auto";
})(CellContentHorizontalAlignment || (CellContentHorizontalAlignment = {}));
/**
 * @hidden
 */
let CellContentHorizontalAlignment_$type = markEnum('CellContentHorizontalAlignment', 'Left,0|Center,1|Right,2|Stretch,3|Auto,4');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates the desired vertical alignment of the cell content.
 */
var CellContentVerticalAlignment;
(function (CellContentVerticalAlignment) {
    /**
     * Align top.
     */
    CellContentVerticalAlignment[CellContentVerticalAlignment["Top"] = 0] = "Top";
    /**
     * Align center.
     */
    CellContentVerticalAlignment[CellContentVerticalAlignment["Center"] = 1] = "Center";
    /**
     * Align bottom.
     */
    CellContentVerticalAlignment[CellContentVerticalAlignment["Bottom"] = 2] = "Bottom";
    /**
     * Align stretch
     */
    CellContentVerticalAlignment[CellContentVerticalAlignment["Stretch"] = 3] = "Stretch";
    /**
     * Align auto
     */
    CellContentVerticalAlignment[CellContentVerticalAlignment["Auto"] = 4] = "Auto";
})(CellContentVerticalAlignment || (CellContentVerticalAlignment = {}));
/**
 * @hidden
 */
let CellContentVerticalAlignment_$type = markEnum('CellContentVerticalAlignment', 'Top,0|Center,1|Bottom,2|Stretch,3|Auto,4');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates how to break lines of text for a cell.
 */
var TextCellLineBreakMode;
(function (TextCellLineBreakMode) {
    /**
     * Truncates the text content at the end and displays an ellipsis character if it can't fit on a line.
     */
    TextCellLineBreakMode[TextCellLineBreakMode["Ellipsis"] = 0] = "Ellipsis";
    /**
     * Keeps the text on a single line, but does not attempt to insert an ellipsis character.
     */
    TextCellLineBreakMode[TextCellLineBreakMode["NoWrap"] = 1] = "NoWrap";
    /**
     * If possible for the current platform, wraps to a new line on a word break, if necessary.
     */
    TextCellLineBreakMode[TextCellLineBreakMode["WordWrap"] = 2] = "WordWrap";
    /**
     * If possible for the current platform, wraps to a new line whenever necessary.
     */
    TextCellLineBreakMode[TextCellLineBreakMode["CharacterWrap"] = 3] = "CharacterWrap";
})(TextCellLineBreakMode || (TextCellLineBreakMode = {}));
/**
 * @hidden
 */
let TextCellLineBreakMode_$type = markEnum('TextCellLineBreakMode', 'Ellipsis,0|NoWrap,1|WordWrap,2|CharacterWrap,3');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let ICellActionManager_$type = new Type(null, 'ICellActionManager');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates some simple date formats to be used.
 */
var DateTimeFormats;
(function (DateTimeFormats) {
    /**
     * A standard short date format is used.
     */
    DateTimeFormats[DateTimeFormats["DateShort"] = 0] = "DateShort";
    /**
     * A standard long date format is used.
     */
    DateTimeFormats[DateTimeFormats["DateLong"] = 1] = "DateLong";
    /**
     * A standard short time format is used.
     */
    DateTimeFormats[DateTimeFormats["TimeShort"] = 2] = "TimeShort";
    /**
     * A standard long time format is used.
     */
    DateTimeFormats[DateTimeFormats["TimeLong"] = 3] = "TimeLong";
    /**
     * A standard short date/time format is used.
     */
    DateTimeFormats[DateTimeFormats["DateTimeShort"] = 4] = "DateTimeShort";
    /**
     * A standard long date/time format is used.
     */
    DateTimeFormats[DateTimeFormats["DateTimeLong"] = 5] = "DateTimeLong";
})(DateTimeFormats || (DateTimeFormats = {}));
/**
 * @hidden
 */
let DateTimeFormats_$type = markEnum('DateTimeFormats', 'DateShort,0|DateLong,1|TimeShort,2|TimeLong,3|DateTimeShort,4|DateTimeLong,5');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let ModelStates_$type = markEnum('ModelStates', 'New,0|Recycled,1|Inview,2');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let FixedCellPositions_$type = markEnum('FixedCellPositions', 'None,0|Left,1|Right,2|Top,3|Bottom,4');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class RowPath extends Base {
    constructor(a, b) {
        super();
        this.l = 0;
        this.k = 0;
        this.a = 0;
        this.j = -1;
        this.c = false;
        this.i = -1;
        this.b = 0;
        this.l = a;
        this.k = b;
        this.y();
    }
    get t() {
        return this.l;
    }
    set t(a) {
        this.l = a;
        this.y();
    }
    get s() {
        return this.k;
    }
    set s(a) {
        this.k = a;
        this.y();
    }
    get b() {
        return this.a;
    }
    set b(a) {
        this.a = a;
        this.y();
    }
    y() {
        this.j = (this.l * 1000000) + this.k;
    }
    getHashCode() {
        return this.j;
    }
    equals(a) {
        let b = a;
        if (this.a != b.a) {
            return false;
        }
        if (this.l != b.l) {
            return false;
        }
        if (this.k != b.k) {
            return false;
        }
        return true;
    }
    toString() {
        return "F" + enumGetBox(FixedCellPositions_$type, this.a) + "." + this.l + "." + this.k;
    }
    get e() {
        return ((this.k == -100 || this.k == -101) && this.l == -100);
    }
    get f() {
        return this.k == -101;
    }
    get h() {
        return (this.k == -200 || this.k == -201);
    }
    get g() {
        return this.c;
    }
    set g(a) {
        this.c = a;
    }
    get m() {
        return this.i;
    }
    set m(a) {
        this.i = a;
    }
    w() {
        let a = new RowPath(this.t, this.s);
        a.b = this.b;
        a.g = this.g;
        a.m = this.m;
        return a;
    }
}
RowPath.$t = markType(RowPath, 'RowPath');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CellPath extends RowPath {
    constructor(a, ..._rest) {
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0:
                {
                    let c = _rest[0];
                    let d = _rest[1];
                    let e = _rest[2];
                    let f = _rest[3];
                    let g = [d, e, f];
                    {
                        let i = g[0];
                        let j = g[1];
                        let k = g[2];
                        super(j, k);
                        this.ak = 0;
                        this.aj = -1;
                        this.aa = false;
                        this.z = false;
                        this.ak = i;
                        this.y();
                    }
                    this.b = c;
                    this.y();
                }
                break;
            case 1:
                {
                    let c = _rest[0];
                    let d = _rest[1];
                    let e = _rest[2];
                    super(d, e);
                    this.ak = 0;
                    this.aj = -1;
                    this.aa = false;
                    this.z = false;
                    this.ak = c;
                    this.y();
                }
                break;
        }
    }
    get al() {
        return this.ak;
    }
    set al(a) {
        this.ak = a;
        this.y();
    }
    y() {
        super.y();
        this.aj = (this.al * 100000000) + super.getHashCode();
    }
    getHashCode() {
        return this.aj;
    }
    equals(a) {
        if (!super.equals(a)) {
            return false;
        }
        let b = a;
        if (a == null) {
            return false;
        }
        if (this.ak != b.ak) {
            return false;
        }
        if (this.ag != b.ag) {
            return false;
        }
        if (this.ae != b.ae) {
            return false;
        }
        return true;
    }
    toString() {
        return this.ak + "." + super.toString();
    }
    w() {
        let a = new CellPath(0, this.b, this.ak, this.t, this.s);
        a.ag = this.ag;
        a.ae = this.ae;
        a.g = this.g;
        a.m = this.m;
        return a;
    }
    get af() {
        return (this.ak == -300);
    }
    get ab() {
        return ((this.ak >= 0 || this.ak == -800 || this.ak == -400) && this.s >= 0 && this.s >= 0);
    }
    get ah() {
        return this.ak == -400;
    }
    get ac() {
        return this.e && !this.af;
    }
    get ad() {
        return this.s == -102 && this.ak == -400;
    }
    get ag() {
        return this.aa;
    }
    set ag(a) {
        this.aa = a;
    }
    get ae() {
        return this.z;
    }
    set ae(a) {
        this.z = a;
    }
    get ai() {
        return this.ag || this.ae;
    }
}
CellPath.$t = markType(CellPath, 'CellPath', RowPath.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let ModelTypes_$type = markEnum('ModelTypes', 'ColumnHeader,0|Cell,1|SectionHeader,2|SectionFooter,3|RowSeparator,4|VerticalSeparator,5|ResizeSeparator,6');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates the direction a column should be sorted in.
 */
var ColumnSortDirection;
(function (ColumnSortDirection) {
    /**
     * Not sort applied.
     */
    ColumnSortDirection[ColumnSortDirection["None"] = 0] = "None";
    /**
     * Sort is ascending.
     */
    ColumnSortDirection[ColumnSortDirection["Ascending"] = 1] = "Ascending";
    /**
     * Sort is descending.
     */
    ColumnSortDirection[ColumnSortDirection["Descending"] = 2] = "Descending";
})(ColumnSortDirection || (ColumnSortDirection = {}));
/**
 * @hidden
 */
let ColumnSortDirection_$type = markEnum('ColumnSortDirection', 'None,0|Ascending,1|Descending,2');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridStyleRepository extends Base {
    static get al() {
        if (GridStyleRepository.t == null) {
            GridStyleRepository.t = ((() => {
                let $ret = new Brush();
                $ret.color = Color.u(255, 230, 230, 230);
                return $ret;
            })());
        }
        return GridStyleRepository.t;
    }
    static get ah() {
        if (GridStyleRepository.p == null) {
            let a = "#CCCCCC";
            GridStyleRepository.p = ((() => {
                let $ret = new Brush();
                $ret.fill = a;
                return $ret;
            })());
        }
        return GridStyleRepository.p;
    }
    static get z() {
        if (GridStyleRepository.h == null) {
            let a = "#999999";
            GridStyleRepository.h = ((() => {
                let $ret = new Brush();
                $ret.fill = a;
                return $ret;
            })());
        }
        return GridStyleRepository.h;
    }
    static get an() {
        if (GridStyleRepository.v == null) {
            GridStyleRepository.v = ((() => {
                let $ret = new Brush();
                $ret.color = Color.u(222, 0, 0, 0);
                return $ret;
            })());
        }
        return GridStyleRepository.v;
    }
    static get w() {
        if (GridStyleRepository.e == null) {
            GridStyleRepository.e = ((() => {
                let $ret = new Brush();
                $ret.color = Color.u(222, 0, 0, 0);
                return $ret;
            })());
        }
        return GridStyleRepository.e;
    }
    static get d() {
        if (GridStyleRepository.b == null) {
            GridStyleRepository.b = new FontInfo();
            GridStyleRepository.b.d = DeviceUtils.f(13);
            GridStyleRepository.b.n = "Verdana";
        }
        return GridStyleRepository.b;
    }
    static get c() {
        if (GridStyleRepository.a == null) {
            GridStyleRepository.a = new FontInfo();
            GridStyleRepository.a.d = DeviceUtils.f(12);
            GridStyleRepository.a.n = "Verdana";
        }
        return GridStyleRepository.a;
    }
    static get af() {
        if (GridStyleRepository.n == null) {
            GridStyleRepository.n = new Brush();
            GridStyleRepository.n.color = Color.u(255, 238, 238, 238);
        }
        return GridStyleRepository.n;
    }
    static get x() {
        if (GridStyleRepository.f == null) {
            GridStyleRepository.f = ((() => {
                let $ret = new Brush();
                $ret.fill = "White";
                return $ret;
            })());
        }
        return GridStyleRepository.f;
    }
    static get aj() {
        if (GridStyleRepository.r == null) {
            GridStyleRepository.r = ((() => {
                let $ret = new Brush();
                $ret.fill = "White";
                return $ret;
            })());
        }
        return GridStyleRepository.r;
    }
    static get am() {
        if (GridStyleRepository.u == null) {
            GridStyleRepository.u = ((() => {
                let $ret = new Brush();
                $ret.color = Color.u(138, 0, 0, 0);
                return $ret;
            })());
        }
        return GridStyleRepository.u;
    }
    static get ak() {
        if (GridStyleRepository.s == null) {
            GridStyleRepository.s = ((() => {
                let $ret = new Brush();
                $ret.color = Color.u(138, 0, 0, 0);
                return $ret;
            })());
        }
        return GridStyleRepository.s;
    }
    static get ad() {
        if (GridStyleRepository.l == null) {
            let a = "#DDDDDD";
            GridStyleRepository.l = ((() => {
                let $ret = new Brush();
                $ret.fill = a;
                return $ret;
            })());
        }
        return GridStyleRepository.l;
    }
    static get ac() {
        if (GridStyleRepository.k == null) {
            GridStyleRepository.k = ((() => {
                let $ret = new Brush();
                $ret.fill = "#f5f5dc";
                return $ret;
            })());
        }
        return GridStyleRepository.k;
    }
    static get ag() {
        if (GridStyleRepository.o == null) {
            let a = "#F5F5F5";
            GridStyleRepository.o = ((() => {
                let $ret = new Brush();
                $ret.fill = a;
                return $ret;
            })());
        }
        return GridStyleRepository.o;
    }
    static get aa() {
        if (GridStyleRepository.i == null) {
            let a = "White";
            GridStyleRepository.i = ((() => {
                let $ret = new Brush();
                $ret.fill = a;
                return $ret;
            })());
        }
        return GridStyleRepository.i;
    }
    static get ab() {
        if (GridStyleRepository.j == null) {
            let a = "#E0E0E0";
            GridStyleRepository.j = ((() => {
                let $ret = new Brush();
                $ret.fill = a;
                return $ret;
            })());
        }
        return GridStyleRepository.j;
    }
    static get ae() {
        if (GridStyleRepository.m == null) {
            let a = "#F4F4F4";
            GridStyleRepository.m = ((() => {
                let $ret = new Brush();
                $ret.fill = a;
                return $ret;
            })());
        }
        return GridStyleRepository.m;
    }
    static get ai() {
        if (GridStyleRepository.q == null) {
            let a = "#0099FF";
            GridStyleRepository.q = ((() => {
                let $ret = new Brush();
                $ret.fill = a;
                return $ret;
            })());
        }
        return GridStyleRepository.q;
    }
    static get y() {
        if (GridStyleRepository.g == null) {
            let a = "#F50000";
            GridStyleRepository.g = ((() => {
                let $ret = new Brush();
                $ret.fill = a;
                return $ret;
            })());
        }
        return GridStyleRepository.g;
    }
}
GridStyleRepository.$t = markType(GridStyleRepository, 'GridStyleRepository');
GridStyleRepository.t = null;
GridStyleRepository.p = null;
GridStyleRepository.h = null;
GridStyleRepository.v = null;
GridStyleRepository.e = null;
GridStyleRepository.b = null;
GridStyleRepository.a = null;
GridStyleRepository.n = null;
GridStyleRepository.f = null;
GridStyleRepository.r = null;
GridStyleRepository.u = null;
GridStyleRepository.s = null;
GridStyleRepository.l = null;
GridStyleRepository.k = null;
GridStyleRepository.o = null;
GridStyleRepository.i = null;
GridStyleRepository.j = null;
GridStyleRepository.m = null;
GridStyleRepository.q = null;
GridStyleRepository.g = null;

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CellModelExport extends Base {
    constructor() {
        super(...arguments);
        this.p = 0;
        this.q = 0;
        this.l = 0;
        this.m = 0;
        this.i = 0;
        this.o = 0;
        this.k = 0;
        this.g = 0;
        this.j = 0;
        this.a = null;
        this.c = 0;
        this.d = 0;
        this.y = null;
        this.b = null;
        this.u = null;
        this.v = null;
        this.w = null;
        this.h = 0;
        this.s = null;
        this.t = null;
        this.n = 0;
        this.e = 0;
        this.r = 0;
        this.f = false;
        this.x = null;
    }
    z() {
        let a = new StringBuilder(0);
        a.l("{ ");
        a.l("type : \"" + this.aa + "\", ");
        a.l("x : " + this.p + ", ");
        a.l("y : " + this.q + ", ");
        a.l("snappedX : " + this.l + ", ");
        a.l("snappedY : " + this.m + ", ");
        a.l("height : " + this.i + ", ");
        a.l("width : " + this.o + ", ");
        a.l("lineBreakMode: \"" + this.x + "\", ");
        a.l("selectedStatus : " + this.k + ", ");
        a.l("activationStatus : " + this.g + ", ");
        a.l("virtualizationPercentage : " + this.n + ", ");
        a.l("backgroundBrushData : " + this.a.serialize() + ", ");
        a.l("opacity : " + this.j + ", ");
        if (this.c != null) {
            a.l("horizontalAlignment : " + this.c + ", ");
        }
        if (this.d != null) {
            a.l("verticalAlignment : " + this.d + ", ");
        }
        a.l("renderValue : \"" + this.y + "\", ");
        if (this.b != null) {
            a.l("textColor : " + this.b.serialize() + ", ");
        }
        if (!stringIsNullOrEmpty(this.u)) {
            a.l("fontStyle : \"" + this.u + "\", ");
        }
        if (!stringIsNullOrEmpty(this.v)) {
            a.l("fontVariant : \"" + this.v + "\", ");
        }
        if (!stringIsNullOrEmpty(this.w)) {
            a.l("fontWeight : \"" + this.w + "\", ");
        }
        if (!stringIsNullOrEmpty(this.s)) {
            a.l("fontFamily : \"" + this.s + "\", ");
        }
        if (!stringIsNullOrEmpty(this.t)) {
            a.l("fontStretch : \"" + this.t + "\", ");
        }
        if (!isNaN_(this.h)) {
            a.l("fontSize : " + this.h + ", ");
        }
        a.l("sortDirection : " + this.e + ", ");
        a.l("indent : " + this.r + ", ");
        a.l("isCollapsable : " + this.f.toString().toLowerCase() + ", ");
        this.ab(a);
        let b = a.toString();
        if (stringEndsWith(b, ", ")) {
            b = b.substr(0, b.length - 2);
        }
        b += "} ";
        return b;
    }
    get_aa() {
        return "Cell";
    }
    get aa() {
        return this.get_aa();
    }
    ab(a) {
    }
}
CellModelExport.$t = markType(CellModelExport, 'CellModelExport');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DateTimeCellModelExport extends CellModelExport {
    constructor() {
        super(...arguments);
        this.ad = new Date();
        this.ae = 0;
        this.ac = false;
    }
    get_aa() {
        return "DateTimeCell";
    }
    ab(a) {
        super.ab(a);
        a.l("dateTimeFormat : " + this.ae + ", ");
    }
}
DateTimeCellModelExport.$t = markType(DateTimeCellModelExport, 'DateTimeCellModelExport', CellModelExport.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class SummaryCellModelExport extends CellModelExport {
    constructor() {
        super(...arguments);
        this.ac = null;
        this.ad = null;
    }
    get_aa() {
        return "SummaryCell";
    }
    ab(a) {
        super.ab(a);
        a.l("summaryText : \"" + this.ac + "\", ");
        a.l("summaryValue : \"" + this.ad + "\", ");
    }
}
SummaryCellModelExport.$t = markType(SummaryCellModelExport, 'SummaryCellModelExport', CellModelExport.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates how the images will be stretched.
 */
var ImageStretchOptions;
(function (ImageStretchOptions) {
    /**
     * Images stretch but try to maintain aspect ratio.
     */
    ImageStretchOptions[ImageStretchOptions["Uniform"] = 0] = "Uniform";
    /**
     * Image fills all available space but breaks aspect ratio.
     */
    ImageStretchOptions[ImageStretchOptions["Fill"] = 1] = "Fill";
    /**
     * Image is displayed unstreteched.
     */
    ImageStretchOptions[ImageStretchOptions["None"] = 2] = "None";
})(ImageStretchOptions || (ImageStretchOptions = {}));
/**
 * @hidden
 */
let ImageStretchOptions_$type = markEnum('ImageStretchOptions', 'Uniform,0|Fill,1|None,2');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates the image resource type to use.
 */
var ImageResourceType;
(function (ImageResourceType) {
    /**
     * Image resource type will attempt to be determined from any scheme specifiers on the paths.
     */
    ImageResourceType[ImageResourceType["Unspecified"] = 0] = "Unspecified";
    /**
     * Images are a local platform specific resource in the application.
     */
    ImageResourceType[ImageResourceType["LocalResource"] = 1] = "LocalResource";
    /**
     * Images are a local platform specific asset in the application. For platforms that don't support assets, this will fall back on local resource.
     */
    ImageResourceType[ImageResourceType["LocalAsset"] = 2] = "LocalAsset";
    /**
     * Images are a .NET embedded resource in the application. Path needs to be a valid embedded resource identifier.
     */
    ImageResourceType[ImageResourceType["EmbeddedResource"] = 3] = "EmbeddedResource";
    /**
     * Images are a remote URL resource.
     */
    ImageResourceType[ImageResourceType["RemoteResource"] = 4] = "RemoteResource";
})(ImageResourceType || (ImageResourceType = {}));
/**
 * @hidden
 */
let ImageResourceType_$type = markEnum('ImageResourceType', 'Unspecified,0|LocalResource,1|LocalAsset,2|EmbeddedResource,3|RemoteResource,4');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ImageCellModelExport extends CellModelExport {
    constructor() {
        super(...arguments);
        this.ac = null;
    }
    get_aa() {
        return "ImageCell";
    }
    ab(a) {
        super.ab(a);
        a.l("imagePath : \"" + this.ac + "\", ");
    }
}
ImageCellModelExport.$t = markType(ImageCellModelExport, 'ImageCellModelExport', CellModelExport.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class NumericCellModelExport extends CellModelExport {
    constructor() {
        super(...arguments);
        this.ac = 0;
        this.ad = 0;
        this.ae = 0;
    }
    get_aa() {
        return "NumericCell";
    }
    ab(a) {
        super.ab(a);
        a.l("numericValue : " + this.ac + ", ");
        a.l("maxDecimalPlaces : " + this.ad + ", ");
        a.l("minDecimalPlaces : " + this.ae + ", ");
    }
}
NumericCellModelExport.$t = markType(NumericCellModelExport, 'NumericCellModelExport', CellModelExport.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class RowSeparatorModelExport extends CellModelExport {
    get_aa() {
        return "RowSeparator";
    }
    ab(a) {
        super.ab(a);
    }
}
RowSeparatorModelExport.$t = markType(RowSeparatorModelExport, 'RowSeparatorModelExport', CellModelExport.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GroupData extends Base {
    constructor() {
        super(...arguments);
        this.c = null;
        this.a = null;
        this.b = null;
    }
}
GroupData.$t = markType(GroupData, 'GroupData');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class SummaryData extends Base {
    constructor() {
        super(...arguments);
        this.e = null;
        this.b = null;
        this.a = 0;
        this.c = null;
        this.d = null;
    }
}
SummaryData.$t = markType(SummaryData, 'SummaryData');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class SectionHeaderCellModelExport extends CellModelExport {
    constructor() {
        super(...arguments);
        this.ad = null;
        this.ae = null;
        this.ac = null;
        this.aj = null;
        this.ag = null;
        this.ai = null;
        this.ah = null;
        this.af = null;
        this.ak = null;
    }
    get_aa() {
        return "SectionHeaderCell";
    }
    ab(a) {
        super.ab(a);
        let b = "groupNames : [ ";
        let c = "groupValues : [ ";
        for (let d = 0; d < this.ad.length; d++) {
            b += "\"" + this.ad[d] + "\", ";
            c += "\"" + this.ae[d] + "\", ";
        }
        let e = "summaryNames : [ ";
        let f = "summaryValues : [ ";
        let g = "summaryOperands : [ ";
        let h = "summaryFormattedText : [ ";
        if (this.ag != null) {
            for (let i = 0; i < this.ag.length; i++) {
                e += "\"" + this.ag[i] + "\", ";
                f += "\"" + this.ai[i] + "\", ";
                g += "\"" + enumGetBox(SummaryOperand_$type, this.ah[i]) + "\", ";
                h += "\"" + this.af[i] + "\", ";
            }
        }
        a.l(b + " ], ");
        a.l(c + " ], ");
        a.l("formattedText : \"" + this.aj + "\", ");
        a.l(e + " ], ");
        a.l(f + " ], ");
        a.l(g + " ], ");
        a.l(h + " ], ");
        a.l("fullSummaryFormattedText : \"" + this.ak + "\", ");
    }
}
SectionHeaderCellModelExport.$t = markType(SectionHeaderCellModelExport, 'SectionHeaderCellModelExport', CellModelExport.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateCellModelExport extends CellModelExport {
    constructor() {
        super(...arguments);
        this.ac = null;
    }
    get_aa() {
        return "TemplateCell";
    }
    ab(a) {
        super.ab(a);
    }
}
TemplateCellModelExport.$t = markType(TemplateCellModelExport, 'TemplateCellModelExport', CellModelExport.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TextCellModelExport extends CellModelExport {
    constructor() {
        super(...arguments);
        this.ad = null;
        this.ac = null;
    }
    get_aa() {
        return "TextCell";
    }
    ab(a) {
        super.ab(a);
        a.l("textValue : \"" + this.ad + "\", ");
        a.l("formatString : \"" + this.ac + "\", ");
    }
}
TextCellModelExport.$t = markType(TextCellModelExport, 'TextCellModelExport', CellModelExport.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
var SortIndicatorStyle;
(function (SortIndicatorStyle) {
    /**
     * The sort indicator is rendered as a single arrow that points in the direction of the sort.
     */
    SortIndicatorStyle[SortIndicatorStyle["Default"] = 0] = "Default";
    /**
     * The sort indicator is rendered as two arrows pointing opposite of each other.  The direction of the sort determines which arrow
     * is faded and which is fully opaque.
     */
    SortIndicatorStyle[SortIndicatorStyle["FadingUpDownArrows"] = 1] = "FadingUpDownArrows";
    /**
     * The sort indicator is rendered as two arrows without the stem, one ontop of the other.  The direction of the sort determines which arrow
     * is faded and which is fully opaque.
     */
    SortIndicatorStyle[SortIndicatorStyle["FadingSimpleUpDownArrows"] = 2] = "FadingSimpleUpDownArrows";
    /**
     * No style is set.
     */
    SortIndicatorStyle[SortIndicatorStyle["Unset"] = 3] = "Unset";
})(SortIndicatorStyle || (SortIndicatorStyle = {}));
/**
 * @hidden
 */
let SortIndicatorStyle_$type = markEnum('SortIndicatorStyle', 'Default,0|FadingUpDownArrows,1|FadingSimpleUpDownArrows,2|Unset,3');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TextHeaderCellModelExport extends TextCellModelExport {
    get_aa() {
        return "TextHeaderCell";
    }
    ab(a) {
        super.ab(a);
    }
}
TextHeaderCellModelExport.$t = markType(TextHeaderCellModelExport, 'TextHeaderCellModelExport', TextCellModelExport.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
var ColumnResizingMode;
(function (ColumnResizingMode) {
    ColumnResizingMode[ColumnResizingMode["Deferred"] = 0] = "Deferred";
    ColumnResizingMode[ColumnResizingMode["Immediate"] = 1] = "Immediate";
    ColumnResizingMode[ColumnResizingMode["None"] = 2] = "None";
})(ColumnResizingMode || (ColumnResizingMode = {}));
/**
 * @hidden
 */
let ColumnResizingMode_$type = markEnum('ColumnResizingMode', 'Deferred,0|Immediate,1|None,2');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
var ColumnMovingMode;
(function (ColumnMovingMode) {
    ColumnMovingMode[ColumnMovingMode["Deferred"] = 0] = "Deferred";
    ColumnMovingMode[ColumnMovingMode["None"] = 1] = "None";
})(ColumnMovingMode || (ColumnMovingMode = {}));
/**
 * @hidden
 */
let ColumnMovingMode_$type = markEnum('ColumnMovingMode', 'Deferred,0|None,1');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnWidth extends Base {
    constructor() {
        super(...arguments);
        this.g = null;
        this.c = false;
        this.f = 0;
        this.d = 0;
    }
    get e() {
        return this.d;
    }
    set e(a) {
        this.d = a;
    }
    static get a() {
        return ((() => {
            let $ret = new ColumnWidth();
            $ret.c = true;
            $ret.e = 0;
            $ret.f = 1;
            return $ret;
        })());
    }
    static parse(a) {
        if (a == null) {
            return new ColumnWidth();
        }
        a = a.trim();
        let b = stringContains(a, "*");
        if (b || stringContains(a, "min=") || stringContains(a, "Min=") || stringContains(a, ",")) {
            let c = new ColumnWidth();
            c.c = b;
            a = stringReplace(a, " ", "");
            a = stringReplace(a, "min=", ",");
            a = stringReplace(a, "Min=", ",");
            a = stringReplace(a, "*,,", "*");
            a = stringReplace(a, "*,", "*");
            a = stringReplace(a, ",,", ",");
            let d = a.split('*');
            let e = new List$1(String_$type, 0);
            for (let f = 0; f < d.length; f++) {
                let g = d[f].split(',');
                for (let h = 0; h < g.length; h++) {
                    e.add(g[h]);
                }
            }
            let i = e._inner[0];
            if (i != null) {
                i = i.trim();
            }
            let j;
            if (stringIsNullOrEmpty(i)) {
                j = 1;
            }
            else {
                if (!((() => { let k = tryParseNumber(i, j); j = k.p1; return k.ret; })())) {
                    return new ColumnWidth();
                }
            }
            c.f = j;
            if (e.count > 1 && e._inner[1] != null) {
                e._inner[1] = stringReplace(e._inner[1], ">", "");
                let k;
                if (((() => { let l = tryParseNumber(e._inner[1], k); k = l.p1; return l.ret; })())) {
                    c.e = k;
                }
            }
            return c;
        }
        else {
            let l = new ColumnWidth();
            l.c = false;
            let m;
            if (!((() => { let n = tryParseNumber(a, m); m = n.p1; return n.ret; })())) {
                return new ColumnWidth();
            }
            l.f = m;
            return l;
        }
    }
}
ColumnWidth.$t = markType(ColumnWidth, 'ColumnWidth');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates what should occur on a header click event.
 */
var HeaderClickAction;
(function (HeaderClickAction) {
    /**
     * Sorting by one column is permitted and toggles between ascending and descending.
     */
    HeaderClickAction[HeaderClickAction["SortByOneColumnOnly"] = 0] = "SortByOneColumnOnly";
    /**
     * Sorting by multiple columns is permitted and each toggle between ascending and descending.
     */
    HeaderClickAction[HeaderClickAction["SortByMultipleColumns"] = 1] = "SortByMultipleColumns";
    /**
     * Sorting by one column is permitted and toggles between ascending, descending and unsorted.
     */
    HeaderClickAction[HeaderClickAction["SortByOneColumnOnlyTriState"] = 2] = "SortByOneColumnOnlyTriState";
    /**
     * Sorting by multiple columns is permitted and toggles between ascending, descending and unsorted.
     */
    HeaderClickAction[HeaderClickAction["SortByMultipleColumnsTriState"] = 3] = "SortByMultipleColumnsTriState";
    /**
     * No action is triggered.
     */
    HeaderClickAction[HeaderClickAction["None"] = 4] = "None";
})(HeaderClickAction || (HeaderClickAction = {}));
/**
 * @hidden
 */
let HeaderClickAction_$type = markEnum('HeaderClickAction', 'SortByOneColumnOnly,0|SortByMultipleColumns,1|SortByOneColumnOnlyTriState,2|SortByMultipleColumnsTriState,3|None,4');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Enumerates the options for how columns animate into view.
 */
var ColumnShowingAnimationMode;
(function (ColumnShowingAnimationMode) {
    /**
     * Automatically selects the correct animation mode.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["Auto"] = 0] = "Auto";
    /**
     * No animation should be performed.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["None"] = 1] = "None";
    /**
     * Cells slide in from the left.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["SlideFromLeft"] = 2] = "SlideFromLeft";
    /**
     * Cells slide in from the right.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["SlideFromRight"] = 3] = "SlideFromRight";
    /**
     * Cells slide in from the top.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["SlideFromTop"] = 4] = "SlideFromTop";
    /**
     * Cells slide in from the bottom.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["SlideFromBottom"] = 5] = "SlideFromBottom";
    /**
     * Cells fade in.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["FadeIn"] = 6] = "FadeIn";
    /**
     * Cells slide in from the left and fade in.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["SlideFromLeftAndFadeIn"] = 7] = "SlideFromLeftAndFadeIn";
    /**
     * Cells slide in from the right and fade in.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["SlideFromRightAndFadeIn"] = 8] = "SlideFromRightAndFadeIn";
    /**
     * Cells slide in from the top and fade in.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["SlideFromTopAndFadeIn"] = 9] = "SlideFromTopAndFadeIn";
    /**
     * Cells slide in from the bottom and fade in.
     */
    ColumnShowingAnimationMode[ColumnShowingAnimationMode["SlideFromBottomAndFadeIn"] = 10] = "SlideFromBottomAndFadeIn";
})(ColumnShowingAnimationMode || (ColumnShowingAnimationMode = {}));
/**
 * @hidden
 */
let ColumnShowingAnimationMode_$type = markEnum('ColumnShowingAnimationMode', 'Auto,0|None,1|SlideFromLeft,2|SlideFromRight,3|SlideFromTop,4|SlideFromBottom,5|FadeIn,6|SlideFromLeftAndFadeIn,7|SlideFromRightAndFadeIn,8|SlideFromTopAndFadeIn,9|SlideFromBottomAndFadeIn,10');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Enumerates the options for how changes to column properties are animated.
 */
var ColumnPropertyUpdatingAnimationMode;
(function (ColumnPropertyUpdatingAnimationMode) {
    /**
     * Automatically decides on the animation mode to use.
     */
    ColumnPropertyUpdatingAnimationMode[ColumnPropertyUpdatingAnimationMode["Auto"] = 0] = "Auto";
    /**
     * No animation is performed.
     */
    ColumnPropertyUpdatingAnimationMode[ColumnPropertyUpdatingAnimationMode["None"] = 1] = "None";
    /**
     * The previous value and the next value are interpolated between.
     */
    ColumnPropertyUpdatingAnimationMode[ColumnPropertyUpdatingAnimationMode["Interpolate"] = 2] = "Interpolate";
    /**
     * Deep values within the previous and next value are interpolated between.
     */
    ColumnPropertyUpdatingAnimationMode[ColumnPropertyUpdatingAnimationMode["InterpolateDeep"] = 3] = "InterpolateDeep";
})(ColumnPropertyUpdatingAnimationMode || (ColumnPropertyUpdatingAnimationMode = {}));
/**
 * @hidden
 */
let ColumnPropertyUpdatingAnimationMode_$type = markEnum('ColumnPropertyUpdatingAnimationMode', 'Auto,0|None,1|Interpolate,2|InterpolateDeep,3');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Enumerates the options for how data loaded animations are displayed.
 */
var CellDataLoadedAnimationMode;
(function (CellDataLoadedAnimationMode) {
    /**
     * The correct animation mode is automatically selected.
     */
    CellDataLoadedAnimationMode[CellDataLoadedAnimationMode["Auto"] = 0] = "Auto";
    /**
     * No animation is performed.
     */
    CellDataLoadedAnimationMode[CellDataLoadedAnimationMode["None"] = 1] = "None";
    /**
     * The previous value and the next value are crossfaded between.
     */
    CellDataLoadedAnimationMode[CellDataLoadedAnimationMode["CrossFade"] = 2] = "CrossFade";
})(CellDataLoadedAnimationMode || (CellDataLoadedAnimationMode = {}));
/**
 * @hidden
 */
let CellDataLoadedAnimationMode_$type = markEnum('CellDataLoadedAnimationMode', 'Auto,0|None,1|CrossFade,2');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Enumerates the option for how row selection is animated.
 */
var RowSelectionAnimationMode;
(function (RowSelectionAnimationMode) {
    /**
     * The correct animation mode is automatically selected.
     */
    RowSelectionAnimationMode[RowSelectionAnimationMode["Auto"] = 0] = "Auto";
    /**
     * No animation is performed.
     */
    RowSelectionAnimationMode[RowSelectionAnimationMode["None"] = 1] = "None";
    /**
     * The selection color and the normal background color are blended between.
     */
    RowSelectionAnimationMode[RowSelectionAnimationMode["ColorBlend"] = 2] = "ColorBlend";
})(RowSelectionAnimationMode || (RowSelectionAnimationMode = {}));
/**
 * @hidden
 */
let RowSelectionAnimationMode_$type = markEnum('RowSelectionAnimationMode', 'Auto,0|None,1|ColorBlend,2');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Enumerates the options for how cell selection is animated.
 */
var CellSelectionAnimationMode;
(function (CellSelectionAnimationMode) {
    /**
     * The correct animation mode is automatically selected.
     */
    CellSelectionAnimationMode[CellSelectionAnimationMode["Auto"] = 0] = "Auto";
    /**
     * No animation is performed.
     */
    CellSelectionAnimationMode[CellSelectionAnimationMode["None"] = 1] = "None";
    /**
     * The selection color and the normal background color are blended between.
     */
    CellSelectionAnimationMode[CellSelectionAnimationMode["ColorBlend"] = 2] = "ColorBlend";
})(CellSelectionAnimationMode || (CellSelectionAnimationMode = {}));
/**
 * @hidden
 */
let CellSelectionAnimationMode_$type = markEnum('CellSelectionAnimationMode', 'Auto,0|None,1|ColorBlend,2');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates the built in easing type to use for an animation.
 */
var GridEasingFunctionType;
(function (GridEasingFunctionType) {
    /**
     * Use linear easing.
     */
    GridEasingFunctionType[GridEasingFunctionType["Linear"] = 0] = "Linear";
    /**
     * Use cubic in/out easing.
     */
    GridEasingFunctionType[GridEasingFunctionType["CubicInOut"] = 1] = "CubicInOut";
    /**
     * Use exponential in/out easing.
     */
    GridEasingFunctionType[GridEasingFunctionType["ExponentialInOut"] = 2] = "ExponentialInOut";
    /**
     * Use circle in/out easing.
     */
    GridEasingFunctionType[GridEasingFunctionType["CircleInOut"] = 3] = "CircleInOut";
})(GridEasingFunctionType || (GridEasingFunctionType = {}));
/**
 * @hidden
 */
let GridEasingFunctionType_$type = markEnum('GridEasingFunctionType', 'Linear,0|CubicInOut,1|ExponentialInOut,2|CircleInOut,3');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridAnimationPhaseSettings extends Base {
    constructor() {
        super(...arguments);
        this.p = null;
        this.g = 300;
        this.h = 0;
        this.i = -1;
        this.j = -1;
        this.f = 300;
        this.d = false;
        this.b = 1;
        this.propertyChanged = null;
    }
    get l() {
        return this.g;
    }
    set l(a) {
        let b = this.g;
        this.g = a;
        if (b != this.g) {
            this.x("DurationMilliseconds", b, this.g);
        }
    }
    get m() {
        return this.h;
    }
    set m(a) {
        let b = this.h;
        this.h = a;
        if (b != this.h) {
            this.x("HoldInitialMilliseconds", b, this.h);
        }
    }
    get n() {
        return this.i;
    }
    set n(a) {
        let b = this.i;
        this.i = a;
        if (b != this.i) {
            this.x("PerItemDelayMilliseconds", b, this.i);
        }
    }
    get o() {
        return this.j;
    }
    set o(a) {
        let b = this.j;
        this.j = a;
        if (b != this.j) {
            this.x("SubItemDurationMilliseconds", b, this.j);
        }
    }
    get k() {
        return this.f;
    }
    set k(a) {
        let b = this.f;
        this.f = a;
        if (b != this.f) {
            this.x("DesiredSubItemDurationMilliseconds", b, this.f);
        }
    }
    get e() {
        return this.d;
    }
    set e(a) {
        let b = this.d;
        this.d = a;
        if (b != this.d) {
            this.x("ShouldItemsFinishSimultaneously", b, this.d);
        }
    }
    get c() {
        return this.b;
    }
    set c(a) {
        let b = this.b;
        this.b = a;
        if (b != this.b) {
            this.x("EasingFunctionType", enumGetBox(GridEasingFunctionType_$type, b), enumGetBox(GridEasingFunctionType_$type, this.b));
        }
    }
    x(a, b, c) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
    }
    a() {
        return ((() => {
            let $ret = new GridAnimationPhaseSettings();
            $ret.l = this.l;
            $ret.c = this.c;
            $ret.m = this.m;
            $ret.n = this.n;
            $ret.e = this.e;
            $ret.o = this.o;
            $ret.k = this.k;
            return $ret;
        })());
    }
}
GridAnimationPhaseSettings.$t = markType(GridAnimationPhaseSettings, 'GridAnimationPhaseSettings', Base.$, [INotifyPropertyChanged_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridColumnAnimationSettings extends Base {
    constructor() {
        super();
        this.y = null;
        this.i = null;
        this.a = null;
        this.b = null;
        this.k = null;
        this.l = null;
        this.j = null;
        this.g = null;
        this.h = null;
        this.e = null;
        this.f = null;
        this.d = null;
        this.c = null;
        this.propertyChanged = null;
        this.a = new GridAnimationPhaseSettings();
        this.a.l = 1000;
        this.a.c = 1;
        this.a.m = 500;
        this.a.e = false;
        this.k = this.a.a();
        this.i = new GridAnimationPhaseSettings();
        this.i.l = 1000;
        this.i.c = 1;
        this.i.e = false;
        this.b = new GridAnimationPhaseSettings();
        this.b.c = 1;
        this.b.l = 300;
        this.l = this.b.a();
        this.e = this.a.a();
        this.e.m = 0;
        this.f = new GridAnimationPhaseSettings();
        this.f.m = 1200;
        this.f.l = 300;
        this.f.c = 1;
        this.g = new GridAnimationPhaseSettings();
        this.g.l = 1000;
        this.g.c = 1;
        this.g.m = 500;
        this.g.e = false;
        this.h = new GridAnimationPhaseSettings();
        this.h.c = 1;
        this.h.l = 800;
        this.d = this.a.a();
        this.d.m = 0;
        this.c = new GridAnimationPhaseSettings();
        this.c.m = 0;
        this.c.l = 300;
        this.c.c = 0;
        this.j = new GridAnimationPhaseSettings();
        this.j.c = 1;
        this.j.l = 200;
    }
    get u() {
        return this.i;
    }
    set u(a) {
        let b = this.i;
        this.i = a;
        this.av("ColumnPropertyUpdatingMainPhase", b, this.i);
    }
    get m() {
        return this.a;
    }
    set m(a) {
        let b = this.a;
        this.a = a;
        this.av("ColumnAddingMainPhase", b, this.a);
    }
    get n() {
        return this.b;
    }
    set n(a) {
        let b = this.b;
        this.b = a;
        this.av("ColumnAddingPrePhase", b, this.b);
    }
    get w() {
        return this.k;
    }
    set w(a) {
        let b = this.k;
        this.k = a;
        this.av("ColumnShowingMainPhase", b, this.k);
    }
    get x() {
        return this.l;
    }
    set x(a) {
        let b = this.l;
        this.l = a;
        this.av("ColumnShowingPrePhase", b, this.l);
    }
    get v() {
        return this.j;
    }
    set v(a) {
        let b = this.j;
        this.j = a;
        this.av("ColumnResizingMainPhase", b, this.j);
    }
    get s() {
        return this.g;
    }
    set s(a) {
        let b = this.g;
        this.g = a;
        this.av("ColumnMovingMainPhase", b, this.g);
    }
    get t() {
        return this.h;
    }
    set t(a) {
        let b = this.h;
        this.h = a;
        this.av("ColumnMovingPrePhase", b, this.h);
    }
    get q() {
        return this.e;
    }
    set q(a) {
        let b = this.e;
        this.e = a;
        this.av("ColumnHidingMainPhase", b, this.e);
    }
    get r() {
        return this.f;
    }
    set r(a) {
        let b = this.f;
        this.f = a;
        this.av("ColumnHidingPostPhase", b, this.f);
    }
    get p() {
        return this.d;
    }
    set p(a) {
        let b = this.d;
        this.d = a;
        this.av("ColumnExchangingMainPhase", b, this.d);
    }
    get o() {
        return this.c;
    }
    set o(a) {
        let b = this.c;
        this.c = a;
        this.av("ColumnExchangingCleanupPhase", b, this.c);
    }
    av(a, b, c) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
        this.aw(a, b, c);
    }
    aw(a, b, c) {
        switch (a) {
            case "ColumnAddingMainPhase":
                if (b != null) {
                    let d = b;
                    d.propertyChanged = delegateRemove(d.propertyChanged, runOn(this, this.al));
                }
                if (c != null) {
                    let e = c;
                    e.propertyChanged = delegateCombine(e.propertyChanged, runOn(this, this.al));
                }
                break;
            case "ColumnAddingPrePhase":
                if (b != null) {
                    let f = b;
                    f.propertyChanged = delegateRemove(f.propertyChanged, runOn(this, this.am));
                }
                if (c != null) {
                    let g = c;
                    g.propertyChanged = delegateCombine(g.propertyChanged, runOn(this, this.am));
                }
                break;
            case "ColumnShowingMainPhase":
                if (b != null) {
                    let h = b;
                    h.propertyChanged = delegateRemove(h.propertyChanged, runOn(this, this.at));
                }
                if (c != null) {
                    let i = c;
                    i.propertyChanged = delegateCombine(i.propertyChanged, runOn(this, this.at));
                }
                break;
            case "ColumnShowingPrePhase":
                if (b != null) {
                    let j = b;
                    j.propertyChanged = delegateRemove(j.propertyChanged, runOn(this, this.au));
                }
                if (c != null) {
                    let k = c;
                    k.propertyChanged = delegateCombine(k.propertyChanged, runOn(this, this.au));
                }
                break;
            case "ColumnMovingMainPhase":
                if (b != null) {
                    let l = b;
                    l.propertyChanged = delegateRemove(l.propertyChanged, runOn(this, this.ar));
                }
                if (c != null) {
                    let m = c;
                    m.propertyChanged = delegateCombine(m.propertyChanged, runOn(this, this.ar));
                }
                break;
            case "ColumnMovingPrePhase":
                if (b != null) {
                    let n = b;
                    n.propertyChanged = delegateRemove(n.propertyChanged, runOn(this, this.as));
                }
                if (c != null) {
                    let o = c;
                    o.propertyChanged = delegateCombine(o.propertyChanged, runOn(this, this.as));
                }
                break;
            case "ColumnHidingMainPhase":
                if (b != null) {
                    let p = b;
                    p.propertyChanged = delegateRemove(p.propertyChanged, runOn(this, this.ap));
                }
                if (c != null) {
                    let q = c;
                    q.propertyChanged = delegateCombine(q.propertyChanged, runOn(this, this.ap));
                }
                break;
            case "ColumnHidingPostPhase":
                if (b != null) {
                    let r = b;
                    r.propertyChanged = delegateRemove(r.propertyChanged, runOn(this, this.aq));
                }
                if (c != null) {
                    let s = c;
                    s.propertyChanged = delegateCombine(s.propertyChanged, runOn(this, this.aq));
                }
                break;
            case "ColumnExchangingMainPhase":
                if (b != null) {
                    let t = b;
                    t.propertyChanged = delegateRemove(t.propertyChanged, runOn(this, this.ao));
                }
                if (c != null) {
                    let u = c;
                    u.propertyChanged = delegateCombine(u.propertyChanged, runOn(this, this.ao));
                }
                break;
            case "ColumnExchangingCleanupPhase":
                if (b != null) {
                    let v = b;
                    v.propertyChanged = delegateRemove(v.propertyChanged, runOn(this, this.an));
                }
                if (c != null) {
                    let w = c;
                    w.propertyChanged = delegateCombine(w.propertyChanged, runOn(this, this.an));
                }
                break;
        }
    }
    al(a, b) {
        this.av("ColumnAddingMainPhase", this.m, this.m);
    }
    am(a, b) {
        this.av("ColumnAddingPrePhase", this.n, this.n);
    }
    at(a, b) {
        this.av("ColumnShowingMainPhase", this.w, this.w);
    }
    au(a, b) {
        this.av("ColumnShowingPrePhase", this.x, this.x);
    }
    ar(a, b) {
        this.av("ColumnMovingMainPhase", this.s, this.s);
    }
    as(a, b) {
        this.av("ColumnMovingPrePhase", this.t, this.t);
    }
    ap(a, b) {
        this.av("ColumnHidingMainPhase", this.q, this.q);
    }
    aq(a, b) {
        this.av("ColumnHidingPostPhase", this.r, this.r);
    }
    ao(a, b) {
        this.av("ColumnExchangingMainPhase", this.p, this.p);
    }
    an(a, b) {
        this.av("ColumnExchangingCleanupPhase", this.o, this.o);
    }
}
GridColumnAnimationSettings.$t = markType(GridColumnAnimationSettings, 'GridColumnAnimationSettings', Base.$, [INotifyPropertyChanged_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridAnimationSettings extends Base {
    constructor() {
        super();
        this.g = null;
        this.b = null;
        this.c = null;
        this.a = null;
        this.propertyChanged = null;
        this.b = new GridAnimationPhaseSettings();
        this.b.l = 500;
        this.b.c = 1;
        this.b.e = false;
        this.c = new GridAnimationPhaseSettings();
        this.c.l = 300;
        this.c.c = 1;
        this.c.n = 0;
        this.c.e = true;
        this.a = new GridAnimationPhaseSettings();
        this.a.l = 0;
        this.a.c = 1;
        this.a.n = 0;
        this.a.e = true;
    }
    get e() {
        return this.b;
    }
    set e(a) {
        let b = this.b;
        this.b = a;
        this.m("CellDataLoadedMainPhase", b, this.b);
    }
    get f() {
        return this.c;
    }
    set f(a) {
        let b = this.c;
        this.c = a;
        this.m("RowSelectionMainPhase", b, this.c);
    }
    get d() {
        return this.a;
    }
    set d(a) {
        let b = this.a;
        this.a = a;
        this.m("CellActivationMainPhase", b, this.a);
    }
    m(a, b, c) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
        this.n(a, b, c);
    }
    n(a, b, c) {
        switch (a) {
            case "CellDataLoadedMainPhase":
                if (b != null) {
                    let d = b;
                    d.propertyChanged = delegateRemove(d.propertyChanged, runOn(this, this.l));
                }
                if (c != null) {
                    let e = c;
                    e.propertyChanged = delegateCombine(e.propertyChanged, runOn(this, this.l));
                }
                break;
            case "RowSelectionMainPhase":
                if (b != null) {
                    let f = b;
                    f.propertyChanged = delegateRemove(f.propertyChanged, runOn(this, this.o));
                }
                if (c != null) {
                    let g = c;
                    g.propertyChanged = delegateCombine(g.propertyChanged, runOn(this, this.o));
                }
                break;
            case "CellActivationMainPhase":
                if (b != null) {
                    let h = b;
                    h.propertyChanged = delegateRemove(h.propertyChanged, runOn(this, this.k));
                }
                if (c != null) {
                    let i = c;
                    i.propertyChanged = delegateCombine(i.propertyChanged, runOn(this, this.k));
                }
                break;
        }
    }
    l(a, b) {
        this.m("CellDataLoadedMainPhase", this.e, this.e);
    }
    o(a, b) {
        this.m("RowSelectionMainPhase", this.f, this.f);
    }
    k(a, b) {
        this.m("CellActivationMainPhase", this.d, this.d);
    }
}
GridAnimationSettings.$t = markType(GridAnimationSettings, 'GridAnimationSettings', Base.$, [INotifyPropertyChanged_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Enumerates the options for how columns animate while resizing.
 */
var ColumnResizingAnimationMode;
(function (ColumnResizingAnimationMode) {
    /**
     * Automatically decides on the animation mode to use.
     */
    ColumnResizingAnimationMode[ColumnResizingAnimationMode["Auto"] = 0] = "Auto";
    /**
     * No animation is performed.
     */
    ColumnResizingAnimationMode[ColumnResizingAnimationMode["None"] = 1] = "None";
    /**
     * The column width interpolates to the new width.
     */
    ColumnResizingAnimationMode[ColumnResizingAnimationMode["Interpolate"] = 2] = "Interpolate";
})(ColumnResizingAnimationMode || (ColumnResizingAnimationMode = {}));
/**
 * @hidden
 */
let ColumnResizingAnimationMode_$type = markEnum('ColumnResizingAnimationMode', 'Auto,0|None,1|Interpolate,2');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Enumerates the options for how columns animate while moving.
 */
var ColumnMovingAnimationMode;
(function (ColumnMovingAnimationMode) {
    /**
     * Automatically decides on the animation mode to use.
     */
    ColumnMovingAnimationMode[ColumnMovingAnimationMode["Auto"] = 0] = "Auto";
    /**
     * No animation is performed.
     */
    ColumnMovingAnimationMode[ColumnMovingAnimationMode["None"] = 1] = "None";
    /**
     * The cells slide on top of the others to its desired position.
     */
    ColumnMovingAnimationMode[ColumnMovingAnimationMode["SlideOver"] = 2] = "SlideOver";
})(ColumnMovingAnimationMode || (ColumnMovingAnimationMode = {}));
/**
 * @hidden
 */
let ColumnMovingAnimationMode_$type = markEnum('ColumnMovingAnimationMode', 'Auto,0|None,1|SlideOver,2');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Enumerates the options for how column hiding is animated.
 */
var ColumnHidingAnimationMode;
(function (ColumnHidingAnimationMode) {
    /**
     * The correct animation mode is automatically selected.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["Auto"] = 0] = "Auto";
    /**
     * No animation is performed.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["None"] = 1] = "None";
    /**
     * The cells slide to the left.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["SlideToLeft"] = 2] = "SlideToLeft";
    /**
     * The cells slide to the right.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["SlideToRight"] = 3] = "SlideToRight";
    /**
     * The cells slide to the top.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["SlideToTop"] = 4] = "SlideToTop";
    /**
     * The cells slide to the bottom.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["SlideToBottom"] = 5] = "SlideToBottom";
    /**
     * The cells fade out.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["FadeOut"] = 6] = "FadeOut";
    /**
     * The cells slide to the left and fade out.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["SlideToLeftAndFadeOut"] = 7] = "SlideToLeftAndFadeOut";
    /**
     * The cells slide to the right and fade out.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["SlideToRightAndFadeOut"] = 8] = "SlideToRightAndFadeOut";
    /**
     * The cells slide to the top and fade out.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["SlideToTopAndFadeOut"] = 9] = "SlideToTopAndFadeOut";
    /**
     * The cells slide to the bottom and fade out.
     */
    ColumnHidingAnimationMode[ColumnHidingAnimationMode["SlideToBottomAndFadeOut"] = 10] = "SlideToBottomAndFadeOut";
})(ColumnHidingAnimationMode || (ColumnHidingAnimationMode = {}));
/**
 * @hidden
 */
let ColumnHidingAnimationMode_$type = markEnum('ColumnHidingAnimationMode', 'Auto,0|None,1|SlideToLeft,2|SlideToRight,3|SlideToTop,4|SlideToBottom,5|FadeOut,6|SlideToLeftAndFadeOut,7|SlideToRightAndFadeOut,8|SlideToTopAndFadeOut,9|SlideToBottomAndFadeOut,10');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Enumerates the options for how column exchanging is animated.
 */
var ColumnExchangingAnimationMode;
(function (ColumnExchangingAnimationMode) {
    /**
     * The correct animation mode is automatically selected.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["Auto"] = 0] = "Auto";
    /**
     * No animation is performed.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["None"] = 1] = "None";
    /**
     * The cells slide to the left.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["SlideToLeft"] = 2] = "SlideToLeft";
    /**
     * The cells slide to the right.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["SlideToRight"] = 3] = "SlideToRight";
    /**
     * The cells slide to the top.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["SlideToTop"] = 4] = "SlideToTop";
    /**
     * The cells slide to the bottom.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["SlideToBottom"] = 5] = "SlideToBottom";
    /**
     * The cells crossfade.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["Crossfade"] = 6] = "Crossfade";
    /**
     * The cells slide to the left and crossfade.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["SlideToLeftAndCrossfade"] = 7] = "SlideToLeftAndCrossfade";
    /**
     * The cells slide to the right and crossfade.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["SlideToRightAndCrossfade"] = 8] = "SlideToRightAndCrossfade";
    /**
     * The cells slide to the top and crossfade.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["SlideToTopAndCrossfade"] = 9] = "SlideToTopAndCrossfade";
    /**
     * The cells slide to the bottom and crossfade.
     */
    ColumnExchangingAnimationMode[ColumnExchangingAnimationMode["SlideToBottomAndCrossfade"] = 10] = "SlideToBottomAndCrossfade";
})(ColumnExchangingAnimationMode || (ColumnExchangingAnimationMode = {}));
/**
 * @hidden
 */
let ColumnExchangingAnimationMode_$type = markEnum('ColumnExchangingAnimationMode', 'Auto,0|None,1|SlideToLeft,2|SlideToRight,3|SlideToTop,4|SlideToBottom,5|Crossfade,6|SlideToLeftAndCrossfade,7|SlideToRightAndCrossfade,8|SlideToTopAndCrossfade,9|SlideToBottomAndCrossfade,10');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates the selection mode to use for the grid.
 */
var GridSelectionMode;
(function (GridSelectionMode) {
    /**
     * No selection should be peformed based on interaction.
     */
    GridSelectionMode[GridSelectionMode["None"] = 0] = "None";
    /**
     * A single row is permitted to be selected at a time from interaction.
     */
    GridSelectionMode[GridSelectionMode["SingleRow"] = 1] = "SingleRow";
    /**
     * Multiple rows are permitted to be selected at a time from interaction.
     */
    GridSelectionMode[GridSelectionMode["MultipleRow"] = 2] = "MultipleRow";
    /**
     * A single cell is permitted to be selected at a time from interaction.
     */
    GridSelectionMode[GridSelectionMode["SingleCell"] = 3] = "SingleCell";
    /**
     * Multiple cells are permitted to be selected at a time from interaction.
     */
    GridSelectionMode[GridSelectionMode["MultipleCell"] = 4] = "MultipleCell";
    /**
     * Multiple cells are allowed to be selected however they are stored as ranges not individual cells.
     */
    GridSelectionMode[GridSelectionMode["RangeCell"] = 5] = "RangeCell";
})(GridSelectionMode || (GridSelectionMode = {}));
/**
 * @hidden
 */
let GridSelectionMode_$type = markEnum('GridSelectionMode', 'None,0|SingleRow,1|MultipleRow,2|SingleCell,3|MultipleCell,4|RangeCell,5');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates the activation mode to use for the grid.
 */
var GridActivationMode;
(function (GridActivationMode) {
    /**
     * No activation should be peformed based on interaction.
     */
    GridActivationMode[GridActivationMode["None"] = 0] = "None";
    /**
     * A single cell is permitted to be activated at a time.
     */
    GridActivationMode[GridActivationMode["Cell"] = 1] = "Cell";
})(GridActivationMode || (GridActivationMode = {}));
/**
 * @hidden
 */
let GridActivationMode_$type = markEnum('GridActivationMode', 'None,0|Cell,1');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Indicates the selection mode to use for the grid.
 */
var GridSelectionBehavior;
(function (GridSelectionBehavior) {
    /**
     * Rows and cells are selected using a toggleable behavior. Modifier selection is ignored (CTRL and SHIFT).
     */
    GridSelectionBehavior[GridSelectionBehavior["Toggle"] = 0] = "Toggle";
    /**
     * Only one row or cell is selected at a time and modifier keys are required to multi-select them.
     */
    GridSelectionBehavior[GridSelectionBehavior["ModifierBased"] = 1] = "ModifierBased";
})(GridSelectionBehavior || (GridSelectionBehavior = {}));
/**
 * @hidden
 */
let GridSelectionBehavior_$type = markEnum('GridSelectionBehavior', 'Toggle,0|ModifierBased,1');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridSelectedItemsCollection extends ObservableCollection$1 {
    constructor() {
        super(Base.$, 0);
    }
    get ae() {
        return this;
    }
    af(a) {
        this.collectionChanged = delegateCombine(this.collectionChanged, a);
    }
}
GridSelectedItemsCollection.$t = markType(GridSelectedItemsCollection, 'GridSelectedItemsCollection', ObservableCollection$1.$.specialize(Base.$));

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class PrimaryKeyValue extends Base {
    constructor(a, b) {
        super();
        this.a = null;
        this.b = null;
        this.a = a;
        this.b = b;
    }
    get key() {
        return this.a;
    }
    get value() {
        return this.b;
    }
    static createIdentityKey(a) {
        return new PrimaryKeyValue(null, [a]);
    }
    equals(a) {
        let b = a;
        if (b == null) {
            return false;
        }
        if (b.b == null && this.b == null) {
            return true;
        }
        if (b.b.length != this.b.length) {
            return false;
        }
        if (this.a == null && b.a == null && this.b.length == 1 && b.b.length == 1) {
            let v1_ = this.b[0];
            let v2_ = b.b[0];
            return (v1_ === v2_);
        }
        for (let c = 0; c < this.b.length; c++) {
            if (!this.f(this.b[c], b.b[c])) {
                return false;
            }
        }
        return true;
    }
    f(a, b) {
        if (a == null && b == null) {
            return true;
        }
        if (a == null && b != null) {
            return false;
        }
        return Base.equalsStatic(a, b);
    }
    getHashCode() {
        if (this.b == null || this.b.length == 0) {
            return 0;
        }
        let a = 0;
        a = this.i(this.b[0]);
        for (let b = 1; b < this.b.length; b++) {
            a = a * 17 + this.i(this.b[b]);
        }
        return a;
    }
    i(val_) {
        if (val_ == null) {
            return 0;
        }
        return Base.getHashCodeStatic(val_);
    }
}
PrimaryKeyValue.$t = markType(PrimaryKeyValue, 'PrimaryKeyValue');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridSelectedKeysCollection extends ObservableCollection$1 {
    constructor() {
        super(PrimaryKeyValue.$, 0);
    }
    get ae() {
        return this;
    }
    af(a) {
        this.collectionChanged = delegateCombine(this.collectionChanged, a);
    }
}
GridSelectedKeysCollection.$t = markType(GridSelectedKeysCollection, 'GridSelectedKeysCollection', ObservableCollection$1.$.specialize(PrimaryKeyValue.$));

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CellRange extends Base {
    constructor() {
        super(...arguments);
        this.g = -2147483648;
        this.e = -2147483648;
        this.h = -2147483648;
        this.f = -2147483648;
    }
    get k() {
        return this.g;
    }
    set k(a) {
        this.g = a;
    }
    get i() {
        return this.e;
    }
    set i(a) {
        this.e = a;
    }
    get l() {
        return this.h;
    }
    set l(a) {
        this.h = a;
    }
    get j() {
        return this.f;
    }
    set j(a) {
        this.f = a;
    }
    b(a, b) {
        return this.d(a) && this.c(b);
    }
    d(a) {
        return a >= this.l && a <= this.j;
    }
    c(a) {
        return a >= this.k && a <= this.i;
    }
    a() {
        let a = new CellRange();
        a.k = this.k;
        a.i = this.i;
        a.l = this.l;
        a.j = this.j;
        return a;
    }
}
CellRange.$t = markType(CellRange, 'CellRange');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridSelectedCellRangesCollection extends ObservableCollection$1 {
    constructor() {
        super(CellRange.$, 0);
    }
    get ae() {
        return this;
    }
}
GridSelectedCellRangesCollection.$t = markType(GridSelectedCellRangesCollection, 'GridSelectedCellRangesCollection', ObservableCollection$1.$.specialize(CellRange.$));

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridCellPosition extends Base {
    constructor() {
        super(...arguments);
        this.a = 0;
        this.c = null;
    }
    get b() {
        return this.a;
    }
    set b(a) {
        this.a = a;
    }
    get d() {
        return this.c;
    }
    set d(a) {
        this.c = a;
    }
}
GridCellPosition.$t = markType(GridCellPosition, 'GridCellPosition');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnSortDescription extends Base {
    constructor(a, ..._rest) {
        super();
        this.e = null;
        this.b = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    let c = _rest[0];
                    this.f = c;
                }
                break;
            case 2:
                {
                    let c = _rest[0];
                    let d = _rest[1];
                    this.f = c;
                    this.c = d;
                }
                break;
        }
    }
    get f() {
        return this.e;
    }
    set f(a) {
        this.e = a;
    }
    get c() {
        return this.b;
    }
    set c(a) {
        this.b = a;
    }
    equals(a) {
        let b = a;
        if (b == null) {
            return super.equals(a);
        }
        return b.f == this.f && b.c == this.c;
    }
    getHashCode() {
        return Base.getHashCodeStatic(this.f) * 17 + this.c;
    }
}
ColumnSortDescription.$t = markType(ColumnSortDescription, 'ColumnSortDescription');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnSortDescriptionCollection extends Base {
    constructor() {
        super();
        this.f = new SyncableObservableCollection$2(ColumnSortDescription.$, SortDescription.$, 0);
        this.a = null;
        let a = this.f;
        a.compare = (b, c) => {
            if (b.f == c.propertyName) {
                return true;
            }
            return false;
        };
        a.createFrom = (b) => new ColumnSortDescription(2, b.propertyName, b.direction);
        a.createTo = (b) => {
            let c = b.c;
            return SortDescription.create(b.f, c);
        };
    }
    get b() {
        return this.a;
    }
    set b(a) {
        if (a == null) {
            this.f.syncTarget = null;
            this.a = null;
            return;
        }
        this.a = a;
        this.f.syncTarget = this.a.g();
    }
    g(a) {
        return this.f.add(a);
    }
    n(a, b) {
        this.f.add1(a, b);
    }
    m() {
        this.f.clear();
    }
    get(a) {
        return this.f.get(a);
    }
    j(a) {
        return this.f.indexOf(a);
    }
    h(a) {
        return this.f.remove1(a);
    }
    d(a) {
        return this.f.remove(a);
    }
    set(a, b) {
        return this.f.set(a, b);
    }
    size() {
        return this.f.size();
    }
    l(a) {
        this.f.addListener(a);
    }
    o(a) {
        this.f.removeListener(a);
    }
    get i() {
        return this.f.all;
    }
}
ColumnSortDescriptionCollection.$t = markType(ColumnSortDescriptionCollection, 'ColumnSortDescriptionCollection');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class FormatGroupTextEventArgs extends Base {
    constructor() {
        super(...arguments);
        this.d = null;
        this.a = null;
        this.c = null;
        this.b = null;
    }
}
FormatGroupTextEventArgs.$t = markType(FormatGroupTextEventArgs, 'FormatGroupTextEventArgs');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnGroupDescription extends ColumnSortDescription {
    constructor(a, ..._rest) {
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0:
                {
                    super(0);
                    this.j = null;
                    this.l = null;
                    this.i = false;
                    this.g = 0;
                    this.formatText = null;
                    this.i = false;
                    this.g = 11;
                }
                break;
            case 1:
                {
                    let c = _rest[0];
                    super(1, c);
                    this.j = null;
                    this.l = null;
                    this.i = false;
                    this.g = 0;
                    this.formatText = null;
                    this.i = false;
                    this.g = 11;
                }
                break;
            case 2:
                {
                    let c = _rest[0];
                    let d = _rest[1];
                    super(2, c, d);
                    this.j = null;
                    this.l = null;
                    this.i = false;
                    this.g = 0;
                    this.formatText = null;
                    this.i = false;
                    this.g = 11;
                }
                break;
        }
    }
    get k() {
        return this.j;
    }
    set k(a) {
        this.j = a;
    }
    get m() {
        return this.l;
    }
    set m(a) {
        this.l = a;
    }
    n(a, b, c) {
        let d = null;
        if (this.formatText != null) {
            d = ((() => {
                let $ret = new FormatGroupTextEventArgs();
                $ret.d = this.f;
                $ret.a = a;
                $ret.c = b;
                $ret.b = c;
                return $ret;
            })());
            this.formatText(this, d);
        }
        return d == null ? c : d.b;
    }
}
ColumnGroupDescription.$t = markType(ColumnGroupDescription, 'ColumnGroupDescription', ColumnSortDescription.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnGroupDescriptionCollection extends Base {
    constructor() {
        super();
        this.f = new SyncableObservableCollection$2(ColumnGroupDescription.$, SortDescription.$, 0);
        this.a = null;
        let a = this.f;
        a.compare = (b, c) => {
            if (b.f == c.propertyName) {
                return true;
            }
            return false;
        };
        a.createFrom = (b) => new ColumnGroupDescription(2, b.propertyName, b.direction);
        a.createTo = (b) => {
            let c = b.c;
            return SortDescription.create(b.f, c);
        };
    }
    get b() {
        return this.a;
    }
    set b(a) {
        if (a == null) {
            this.f.syncTarget = null;
            this.a = null;
            return;
        }
        this.a = a;
        this.f.syncTarget = this.a.g();
    }
    g(a) {
        return this.f.add(a);
    }
    n(a, b) {
        this.f.add1(a, b);
    }
    m() {
        this.f.clear();
    }
    get(a) {
        return this.f.get(a);
    }
    j(a) {
        return this.f.indexOf(a);
    }
    h(a) {
        return this.f.remove1(a);
    }
    d(a) {
        return this.f.remove(a);
    }
    set(a, b) {
        return this.f.set(a, b);
    }
    size() {
        return this.f.size();
    }
    l(a) {
        this.f.addListener(a);
    }
    o(a) {
        this.f.removeListener(a);
    }
    get i() {
        return this.f.all;
    }
}
ColumnGroupDescriptionCollection.$t = markType(ColumnGroupDescriptionCollection, 'ColumnGroupDescriptionCollection');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class FormatSummaryTextEventArgs extends Base {
    constructor() {
        super(...arguments);
        this.e = null;
        this.b = null;
        this.a = null;
        this.c = null;
        this.d = null;
    }
}
FormatSummaryTextEventArgs.$t = markType(FormatSummaryTextEventArgs, 'FormatSummaryTextEventArgs');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnSummaryDescription extends Base {
    constructor(a, ..._rest) {
        super();
        this.i = false;
        this.a = 0;
        this.q = null;
        this.d = 0;
        this.b = null;
        this.o = null;
        this.p = null;
        this.m = null;
        this.j = 10;
        this.formatText = null;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    let c = _rest[0];
                    this.t = c;
                    this.e = 4;
                }
                break;
            case 2:
                {
                    let c = _rest[0];
                    let d = _rest[1];
                    this.t = c;
                    this.e = d;
                }
                break;
        }
    }
    get t() {
        return this.q;
    }
    set t(a) {
        this.q = a;
    }
    get e() {
        return this.d;
    }
    set e(a) {
        this.d = a;
        switch (this.d) {
            case 0:
                this.c = new MinSummaryCalculator();
                break;
            case 1:
                this.c = new MaxSummaryCalculator();
                break;
            case 2:
                this.c = new SumSummaryCalculator();
                break;
            case 3:
                this.c = new AverageSummaryCalculator();
                break;
            case 4:
                this.c = new CountSummaryCalculator();
                break;
        }
    }
    get c() {
        return this.b;
    }
    set c(a) {
        this.b = a;
    }
    get r() {
        return this.o;
    }
    set r(a) {
        this.o = a;
    }
    get s() {
        return this.p;
    }
    set s(a) {
        this.p = a;
    }
    get n() {
        return this.m;
    }
    set n(a) {
        this.m = a;
    }
    get l() {
        return this.j;
    }
    set l(a) {
        this.j = a;
    }
    equals(a) {
        let b = a;
        if (b == null) {
            return super.equals(a);
        }
        return b.t == this.t && b.e == this.e;
    }
    getHashCode() {
        return Base.getHashCodeStatic(this.t) * 17 + this.e;
    }
    f(a, b, c) {
        let d = ((() => {
            let $ret = new FormatSummaryTextEventArgs();
            $ret.e = this.t;
            $ret.b = this.s;
            $ret.a = a;
            $ret.c = b;
            $ret.d = c;
            return $ret;
        })());
        if (this.formatText != null) {
            this.formatText(this, d);
        }
        return d;
    }
}
ColumnSummaryDescription.$t = markType(ColumnSummaryDescription, 'ColumnSummaryDescription');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnSummaryDescriptionCollection extends Base {
    constructor() {
        super();
        this.f = new SyncableObservableCollection$2(ColumnSummaryDescription.$, SummaryDescription.$, 0);
        this.a = null;
        let a = this.f;
        a.compare = (b, c) => b.t == c.propertyName && b.e == c.operand && b.c == c.calculator;
        a.createFrom = (b) => {
            let c = new ColumnSummaryDescription(1, b.propertyName);
            c.e = b.operand;
            c.c = b.calculator;
            return c;
        };
        a.createTo = (b) => {
            let c = new SummaryDescription(1, b.t);
            c.operand = b.e;
            c.calculator = b.c;
            return c;
        };
    }
    get b() {
        return this.a;
    }
    set b(a) {
        if (a == null) {
            this.f.syncTarget = null;
            this.a = null;
            return;
        }
        this.a = a;
        this.f.syncTarget = this.a.g();
    }
    g(a) {
        return this.f.add(a);
    }
    n(a, b) {
        this.f.add1(a, b);
    }
    m() {
        this.f.clear();
    }
    get(a) {
        return this.f.get(a);
    }
    j(a) {
        return this.f.indexOf(a);
    }
    h(a) {
        return this.f.remove1(a);
    }
    d(a) {
        return this.f.remove(a);
    }
    set(a, b) {
        return this.f.set(a, b);
    }
    size() {
        return this.f.size();
    }
    l(a) {
        this.f.addListener(a);
    }
    o(a) {
        this.f.removeListener(a);
    }
    get i() {
        return this.f.all;
    }
}
ColumnSummaryDescriptionCollection.$t = markType(ColumnSummaryDescriptionCollection, 'ColumnSummaryDescriptionCollection');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridFilterExpressionsEventArgs extends Base {
    constructor() {
        super(...arguments);
        this.a = null;
    }
}
GridFilterExpressionsEventArgs.$t = markType(GridFilterExpressionsEventArgs, 'GridFilterExpressionsEventArgs');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let IPlatformPixelConverter_$type = new Type(null, 'IPlatformPixelConverter');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DefaultPlatformPixelConverter extends Base {
    devicePixelsToPixel(a) {
        return a;
    }
}
DefaultPlatformPixelConverter.$t = markType(DefaultPlatformPixelConverter, 'DefaultPlatformPixelConverter', Base.$, [IPlatformPixelConverter_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridGroupDescriptionsChangedEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._groupDescriptions = null;
    }
    get groupDescriptions() {
        return this._groupDescriptions;
    }
    set groupDescriptions(a) {
        this._groupDescriptions = a;
    }
}
GridGroupDescriptionsChangedEventArgs.$t = markType(GridGroupDescriptionsChangedEventArgs, 'GridGroupDescriptionsChangedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridSortDescriptionsChangedEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._sortDescriptions = null;
    }
    get sortDescriptions() {
        return this._sortDescriptions;
    }
    set sortDescriptions(a) {
        this._sortDescriptions = a;
    }
}
GridSortDescriptionsChangedEventArgs.$t = markType(GridSortDescriptionsChangedEventArgs, 'GridSortDescriptionsChangedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DefinitionPropertyUpdatedEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._propertyName = null;
        this._animationType = 0;
        this._oldValue = null;
        this._newValue = null;
    }
    get propertyName() {
        return this._propertyName;
    }
    set propertyName(a) {
        this._propertyName = a;
    }
    get animationType() {
        return this._animationType;
    }
    set animationType(a) {
        this._animationType = a;
    }
    get oldValue() {
        return this._oldValue;
    }
    set oldValue(a) {
        this._oldValue = a;
    }
    get newValue() {
        return this._newValue;
    }
    set newValue(a) {
        this._newValue = a;
    }
}
DefinitionPropertyUpdatedEventArgs.$t = markType(DefinitionPropertyUpdatedEventArgs, 'DefinitionPropertyUpdatedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Enumerates the options for how cell property animates are applied.
 */
var CellPropertyAnimationType;
(function (CellPropertyAnimationType) {
    /**
     * The property is animated as a double value.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["DoubleValue"] = 0] = "DoubleValue";
    /**
     * The property is animated as a number value.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["NumberValue"] = 1] = "NumberValue";
    /**
     * The property is animated as a brush value.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["BrushValue"] = 2] = "BrushValue";
    /**
     * The property is animated as a font value.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["FontValue"] = 3] = "FontValue";
    /**
     * The property is animated as a enum value.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["EnumValue"] = 4] = "EnumValue";
    /**
     * The property is animated as a bool value.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["BoolValue"] = 5] = "BoolValue";
    /**
     * The property is animated as an int value.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["IntValue"] = 6] = "IntValue";
    /**
     * The property is animated as a date value.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["DateValue"] = 7] = "DateValue";
    /**
     * The propety is animated as a string value.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["StringValue"] = 8] = "StringValue";
    /**
     * The property is animated as an object value.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["ObjectValue"] = 9] = "ObjectValue";
    /**
     * The property value is ignored and not propagated to live cells.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["IgnoredValue"] = 10] = "IgnoredValue";
    /**
     * The property value is not animated.
     */
    CellPropertyAnimationType[CellPropertyAnimationType["None"] = 11] = "None";
})(CellPropertyAnimationType || (CellPropertyAnimationType = {}));
/**
 * @hidden
 */
let CellPropertyAnimationType_$type = markEnum('CellPropertyAnimationType', 'DoubleValue,0|NumberValue,1|BrushValue,2|FontValue,3|EnumValue,4|BoolValue,5|IntValue,6|DateValue,7|StringValue,8|ObjectValue,9|IgnoredValue,10|None,11');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridColumnsAutoGeneratedEventArgs extends EventArgs {
}
GridColumnsAutoGeneratedEventArgs.$t = markType(GridColumnsAutoGeneratedEventArgs, 'GridColumnsAutoGeneratedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let ColumnStates_$type = markEnum('ColumnStates', 'Detached,0|Showing,1|Hiding,2|Hidden,3|Swapping,4|Visible,5|Moving,6');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridLayerExport extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.c = null;
        this.c = a;
        this.a = new List$1(CellModelExport.$, 0);
    }
    get b() {
        return this.a;
    }
    e(a) {
        this.a.add(a);
    }
    f() {
        this.a.clear();
    }
    d() {
        let a = new StringBuilder(0);
        a.u("{");
        a.u("name: \"" + this.c + "\", cells: [");
        for (let b = 0; b < this.a.count; b++) {
            a.l(this.a._inner[b].z());
            if (b < this.a.count - 1) {
                a.l(", ");
            }
        }
        a.l("]");
        a.l("}");
        return a.toString();
    }
}
GridLayerExport.$t = markType(GridLayerExport, 'GridLayerExport');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class VisualModelExport extends Base {
    constructor() {
        super();
        this.k = null;
        this.n = 0;
        this.m = 0;
        this.t = 0;
        this.s = 0;
        this.q = 0;
        this.r = 0;
        this.o = 0;
        this.w = 0;
        this.x = 0;
        this.y = 0;
        this.v = 0;
        this.u = 0;
        this.z = 0;
        this.j = null;
        this.a = null;
        this.d = null;
        this.b = null;
        this.f = null;
        this.e = null;
        this.c = null;
        this.g = null;
        this.h = null;
        this.i = null;
        this.p = 0;
        this.l = null;
        this.aa = 0;
        this.k = RectData.empty;
        this.j = new GridLayerExport("SubContentLayer");
        this.a = new GridLayerExport("ContentLayer");
        this.d = new GridLayerExport("FixedLayer");
        this.b = new GridLayerExport("DecoratorLayer");
        this.f = new GridLayerExport("HeaderLayer");
        this.e = new GridLayerExport("HeaderDecoratorLayer");
        this.c = new GridLayerExport("FixedHeaderLayer");
        this.g = new GridLayerExport("HiddenLayer");
        this.h = new GridLayerExport("PinnedRowsLayer");
        this.i = new GridLayerExport("PinnedSectionLayer");
        this.p = 1;
    }
    ad() {
        this.l = new List$1(GridLayerExport.$, 0);
        this.l.add(this.a);
        this.l.add(this.b);
        this.l.add(this.d);
        this.l.add(this.f);
        this.l.add(this.e);
        this.l.add(this.c);
        this.l.add(this.h);
        this.l.add(this.i);
    }
    ac() {
        this.a.f();
        this.d.f();
        this.b.f();
        this.f.f();
        this.e.f();
        this.c.f();
        this.h.f();
        this.i.f();
    }
    ab() {
        let a = new StringBuilder(0);
        a.l("{");
        a.l("top : " + this.y + ", ");
        a.l("left : " + this.v + ", ");
        a.l("height : " + this.u + ", ");
        a.l("width : " + this.z + ", ");
        a.l("absoluteWidth : " + this.n + ", ");
        a.l("absoluteHeight : " + this.m + ", ");
        a.l("headerHeight : " + this.t + ", ");
        a.l("fixedRowHeight : " + this.s + ", ");
        a.l("fixedColumnWidthLeft : " + this.q + ", ");
        a.l("fixedColumnWidthRight : " + this.r + ", ");
        a.l("dipScalingRatio: " + this.p + ", ");
        a.l("columnSpacing : " + this.o + ", ");
        a.l("separatorLeft : " + this.w + ", ");
        a.l("separatorRight : " + this.x + ", ");
        a.l("subContentLayer: " + this.j.d() + ", ");
        a.l("contentLayer : " + this.a.d() + ", ");
        a.l("fixedLayer : " + this.d.d() + ", ");
        a.l("decoratorLayer : " + this.b.d() + ", ");
        a.l("headerLayer : " + this.f.d() + ", ");
        a.l("headerDecoratorLayer : " + this.e.d() + ", ");
        a.l("fixedHeaderLayer : " + this.c.d() + ", ");
        a.l("pinnedRowsLayer : " + this.h.d() + ", ");
        a.l("pinnedSectionLayer : " + this.i.d() + ", ");
        a.l("actualVisibleRegion: { left: " + this.k.left + ", top: " + this.k.top + ", width: " + this.k.width + ", height: " + this.k.height + "}");
        a.l("}");
        return a.toString();
    }
}
VisualModelExport.$t = markType(VisualModelExport, 'VisualModelExport');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridActiveCellChangedEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._newActiveCell = null;
        this._oldActiveCell = null;
    }
    get newActiveCell() {
        return this._newActiveCell;
    }
    set newActiveCell(a) {
        this._newActiveCell = a;
    }
    get oldActiveCell() {
        return this._oldActiveCell;
    }
    set oldActiveCell(a) {
        this._oldActiveCell = a;
    }
}
GridActiveCellChangedEventArgs.$t = markType(GridActiveCellChangedEventArgs, 'GridActiveCellChangedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridSelectedItemsChangedEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._addedItems = null;
        this._removedItems = null;
    }
    get addedItems() {
        return this._addedItems;
    }
    set addedItems(a) {
        this._addedItems = a;
    }
    get removedItems() {
        return this._removedItems;
    }
    set removedItems(a) {
        this._removedItems = a;
    }
}
GridSelectedItemsChangedEventArgs.$t = markType(GridSelectedItemsChangedEventArgs, 'GridSelectedItemsChangedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridSelectedKeysChangedEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._addedKeys = null;
        this._removedKeys = null;
    }
    get addedKeys() {
        return this._addedKeys;
    }
    set addedKeys(a) {
        this._addedKeys = a;
    }
    get removedKeys() {
        return this._removedKeys;
    }
    set removedKeys(a) {
        this._removedKeys = a;
    }
}
GridSelectedKeysChangedEventArgs.$t = markType(GridSelectedKeysChangedEventArgs, 'GridSelectedKeysChangedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridSelectedCellRangesChangedEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._addedRanges = null;
        this._removedRanges = null;
        this._updatedRanges = null;
    }
    get addedRanges() {
        return this._addedRanges;
    }
    set addedRanges(a) {
        this._addedRanges = a;
    }
    get removedRanges() {
        return this._removedRanges;
    }
    set removedRanges(a) {
        this._removedRanges = a;
    }
    get updatedRanges() {
        return this._updatedRanges;
    }
    set updatedRanges(a) {
        this._updatedRanges = a;
    }
}
GridSelectedCellRangesChangedEventArgs.$t = markType(GridSelectedCellRangesChangedEventArgs, 'GridSelectedCellRangesChangedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridAnimationManagerAnimationCreatedEventArgs extends Base {
    constructor() {
        super(...arguments);
        this.a = 0;
    }
}
GridAnimationManagerAnimationCreatedEventArgs.$t = markType(GridAnimationManagerAnimationCreatedEventArgs, 'GridAnimationManagerAnimationCreatedEventArgs');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridAnimationManagerAnimationCompletedEventArgs extends Base {
    constructor() {
        super(...arguments);
        this.a = 0;
    }
}
GridAnimationManagerAnimationCompletedEventArgs.$t = markType(GridAnimationManagerAnimationCompletedEventArgs, 'GridAnimationManagerAnimationCompletedEventArgs');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridAnimationManagerAnimationCanceledEventArgs extends Base {
    constructor() {
        super(...arguments);
        this.a = 0;
    }
}
GridAnimationManagerAnimationCanceledEventArgs.$t = markType(GridAnimationManagerAnimationCanceledEventArgs, 'GridAnimationManagerAnimationCanceledEventArgs');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridColumnSpacer extends Base {
    constructor() {
        super();
        this.g = 0;
        this.h = 0;
        this.m = 0;
        this.c = false;
        this.l = 0;
        this.b = false;
        this.a = false;
        this.m = GridColumnSpacer.k;
        GridColumnSpacer.k++;
    }
    get i() {
        return this.g;
    }
    set i(a) {
        this.g = a;
    }
    get j() {
        return this.h;
    }
    set j(a) {
        this.h = a;
    }
    get o() {
        return this.m;
    }
    get f() {
        return this.c;
    }
    set f(a) {
        this.c = a;
    }
    get n() {
        return this.l;
    }
    set n(a) {
        this.l = a;
    }
    get e() {
        return this.b;
    }
    set e(a) {
        this.b = a;
    }
    get d() {
        return this.a;
    }
    set d(a) {
        this.a = a;
    }
}
GridColumnSpacer.$t = markType(GridColumnSpacer, 'GridColumnSpacer');
GridColumnSpacer.k = 0;

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridColumnSpacerCollection extends List$1 {
    constructor() {
        super(GridColumnSpacer.$, 0);
    }
    ac() {
        let a = this.count;
        let b = 0;
        for (let c = 0; c < a; c++) {
            b = b + this._inner[c].i;
        }
        return b;
    }
    ag() {
        let a = this.count;
        let b = 0;
        for (let c = 0; c < a; c++) {
            if (this._inner[c].f) {
                b = b + this._inner[c].i;
            }
        }
        return b;
    }
    ae() {
        let a = this.count;
        let b = 0;
        for (let c = 0; c < a; c++) {
            if (!this._inner[c].f) {
                b = b + this._inner[c].i;
            }
        }
        return b;
    }
    ah() {
        let a = this.count;
        let b = 0;
        for (let c = 0; c < a; c++) {
            if (this._inner[c].i > 0) {
                b = b + this._inner[c].j;
            }
        }
        return b;
    }
    ad(a) {
        let b = this.count;
        let c = 0;
        for (let d = 0; d < b; d++) {
            if (!this._inner[d].d && !(this._inner[d].n == a)) {
                c = c + this._inner[d].i;
            }
        }
        return c;
    }
    af(a) {
        let b = this.count;
        let c = 0;
        for (let d = 0; d < b; d++) {
            if (this._inner[d].d && !(this._inner[d].n == a)) {
                c = c + this._inner[d].i;
            }
        }
        return c;
    }
}
GridColumnSpacerCollection.$t = markType(GridColumnSpacerCollection, 'GridColumnSpacerCollection', List$1.$.specialize(GridColumnSpacer.$));

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CellStyleRequestedEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._styleKey = null;
        this._resolvedValue = null;
        this._rowNumber = 0;
    }
    get styleKey() {
        return this._styleKey;
    }
    set styleKey(a) {
        this._styleKey = a;
    }
    get resolvedValue() {
        return this._resolvedValue;
    }
    set resolvedValue(a) {
        this._resolvedValue = a;
    }
    get rowNumber() {
        return this._rowNumber;
    }
    set rowNumber(a) {
        this._rowNumber = a;
    }
}
CellStyleRequestedEventArgs.$t = markType(CellStyleRequestedEventArgs, 'CellStyleRequestedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CalculationParameters extends Base {
    constructor() {
        super(...arguments);
        this.j = 0;
        this.g = 0;
        this.h = 0;
        this.i = 0;
        this.k = 0;
        this.l = 0;
        this.b = null;
        this.a = null;
        this.d = 0;
        this.f = 0;
        this.e = 0;
        this.c = null;
        this.m = null;
    }
}
CalculationParameters.$t = markType(CalculationParameters, 'CalculationParameters');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnPropertySetter extends Base {
    constructor(a, ..._rest) {
        super();
        this.a = null;
        this.c = null;
        this.d = null;
        this.b = null;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    let c = _rest[0];
                    let d = _rest[1];
                    let e = _rest[2];
                    this.c = c;
                    this.d = d;
                    this.b = e;
                }
                break;
        }
    }
}
ColumnPropertySetter.$t = markType(ColumnPropertySetter, 'ColumnPropertySetter');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnPropertySettersCollection extends ObservableCollection$1 {
    constructor() {
        super(ColumnPropertySetter.$, 0);
    }
}
ColumnPropertySettersCollection.$t = markType(ColumnPropertySettersCollection, 'ColumnPropertySettersCollection', ObservableCollection$1.$.specialize(ColumnPropertySetter.$));

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ResponsiveStateEnteringEventArgs extends EventArgs {
}
ResponsiveStateEnteringEventArgs.$t = markType(ResponsiveStateEnteringEventArgs, 'ResponsiveStateEnteringEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ResponsiveStateEnteredEventArgs extends EventArgs {
}
ResponsiveStateEnteredEventArgs.$t = markType(ResponsiveStateEnteredEventArgs, 'ResponsiveStateEnteredEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ResponsiveStateExitedEventArgs extends EventArgs {
}
ResponsiveStateExitedEventArgs.$t = markType(ResponsiveStateExitedEventArgs, 'ResponsiveStateExitedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let IExternalGrid_$type = new Type(null, 'IExternalGrid');
/**
 * @hidden
 */
class DefaultCellActionManager extends Base {
    constructor(a, b) {
        super();
        this.b = null;
        this.a = null;
        this.c = false;
        this.d = false;
        this._isLeaveActionDesired = false;
        this.b = a;
        this.a = b;
    }
    clickExpansionIndicator() {
        if (this.b != null && this.a != null) {
            this.b.no(this.a);
        }
    }
    clickCell() {
        if (this.b != null && this.a != null) {
            this.b.ms(this.a, this.c, this.d);
        }
    }
    dragStarted() {
        if (this.b != null && this.b.am != null) {
            this.b.nn(this.b.am, this.mousePosition.x, this.mousePosition.y, this.c);
            this.mouseUpCell(this.mousePosition.x, this.mousePosition.y);
        }
    }
    previewPointerDownCell() {
        if (this.b != null && this.a != null) {
            this.b.mz(this.a);
        }
    }
    previewPointerUpCell() {
        if (this.b != null && this.a != null) {
            this.b.m0(this.a);
        }
    }
    pointerDownCell() {
        if (this.b != null && this.a != null) {
            this.b.mx(this.a);
        }
    }
    pointerUpCell() {
        if (this.b != null && this.a != null) {
            this.b.my(this.a);
        }
    }
    mouseDownCell(a, b) {
        if (this.b != null && this.a != null) {
            this.b.mv(this.a, a, b);
        }
    }
    mouseUpCell(a, b) {
        if (this.b != null && this.a != null) {
            this.b.mw(this.a, a, b);
        }
    }
    mouseLeaveCell(a, b) {
        if (this.b != null && this.a != null) {
            this.b.mu(this.a, a, b);
        }
    }
    mouseIsOver(a, b) {
        if (this.b != null && this.a != null) {
            this.b.ns(this.a, a, b);
        }
    }
    getColumnFilterCondition() {
        if (this.b == null) {
            return null;
        }
        return this.b.m(this.a);
    }
    getColumnPropertyType() {
        if (this.b == null) {
            return 11;
        }
        return this.b.n(this.a);
    }
    columnFilterChanging(a) {
        if (this.b == null) {
            return;
        }
        this.b.l5(this.a, a);
    }
    columnFilterChanged(a) {
        if (this.b == null) {
            return;
        }
        this.b.l4(this.a, a);
    }
    isCellDown() {
        if (this.b != null && this.b.am != null && this.a != null) {
            return this.b.am.equals(this.a.i);
        }
        return false;
    }
    get isLeaveActionDesired() {
        return this._isLeaveActionDesired;
    }
    set isLeaveActionDesired(a) {
        this._isLeaveActionDesired = a;
    }
    get isClickActionDesired() {
        return this.b.fj;
    }
    get isHoverActionDesired() {
        return this.b.fx;
    }
    get isPreviewPointerDownActionDesired() {
        return this.b.f2;
    }
    get isPreviewPointerUpActionDesired() {
        return this.b.f3;
    }
    get isPointerDownActionDesired() {
        return this.b.f0;
    }
    get isPointerUpActionDesired() {
        return this.b.f1;
    }
    get isControlPressed() {
        return this.c;
    }
    set isControlPressed(a) {
        this.c = a;
    }
    get isShiftPressed() {
        return this.d;
    }
    set isShiftPressed(a) {
        this.d = a;
    }
    get isDrag() {
        return this.b.dragger.isDragActive;
    }
    get isMouseDown() {
        return this.b.am != null;
    }
    get mousePosition() {
        return this.b.qm;
    }
}
DefaultCellActionManager.$t = markType(DefaultCellActionManager, 'DefaultCellActionManager', Base.$, [ICellActionManager_$type]);
/**
 * @hidden
 */
class DateTimeColumnValueFormatter extends Base {
    constructor() {
        super(...arguments);
        this.a = 0;
        this.b = false;
        this.f = null;
        this.e = null;
        this.c = null;
        this.d = null;
        this.g = null;
        this.h = null;
    }
    k() {
        this.b = true;
    }
    j(a) {
        this.a = a.ik;
        this.b = false;
    }
    i(a) {
        if (+a == +(dateMinValue())) {
            return "";
        }
        let b = (Intl && Intl.DateTimeFormat);
        if (b) {
            let format_ = null;
            switch (this.a) {
                case 4:
                    if (this.f == null) {
                        this.f = (new Intl.DateTimeFormat([], { month: 'numeric', day: 'numeric', year: 'numeric', hour: 'numeric', minute: 'numeric', second: 'numeric' }));
                    }
                    format_ = this.f;
                    break;
                case 5:
                    if (this.e == null) {
                        this.e = (new Intl.DateTimeFormat([], { weekday: 'long', month: 'long', day: 'numeric', year: 'numeric', hour: 'numeric', minute: 'numeric', second: 'numeric' }));
                    }
                    format_ = this.e;
                    break;
                case 1:
                    if (this.c == null) {
                        this.c = (new Intl.DateTimeFormat([], { weekday: 'long', month: 'long', day: 'numeric', year: 'numeric' }));
                    }
                    format_ = this.c;
                    break;
                case 0:
                    if (this.d == null) {
                        this.d = (new Intl.DateTimeFormat([], { month: 'numeric', day: 'numeric', year: 'numeric' }));
                    }
                    format_ = this.d;
                    break;
                case 3:
                    if (this.g == null) {
                        this.g = (new Intl.DateTimeFormat([], { hour: 'numeric', minute: 'numeric', second: 'numeric' }));
                    }
                    format_ = this.g;
                    break;
                case 2:
                    if (this.h == null) {
                        this.h = (new Intl.DateTimeFormat([], { hour: 'numeric', minute: 'numeric' }));
                    }
                    format_ = this.h;
                    break;
            }
            let date_ = a;
            return (format_.format(date_));
        }
        else {
            let date_ = a;
            switch (this.a) {
                case 4: return (date_.toLocaleString());
                case 5: return (date_.toLocaleString());
                case 1: return (date_.toLocaleDateString());
                case 0: return (date_.toLocaleDateString());
                case 3: return (date_.toLocaleTimeString());
                case 2: return (date_.toLocaleTimeString());
            }
            return a.toString();
        }
    }
}
DateTimeColumnValueFormatter.$t = markType(DateTimeColumnValueFormatter, 'DateTimeColumnValueFormatter');
/**
 * @hidden
 */
class CellModel extends Base {
    constructor() {
        super();
        this.l = null;
        this.p = null;
        this.q = 0;
        this.g1 = null;
        this.i = null;
        this.dq = 0;
        this.aq = false;
        this.av = false;
        this.ah = false;
        this.af = false;
        this.ao = false;
        this.aw = false;
        this.aj = false;
        this.ap = false;
        this.c = null;
        this.ab = false;
        this.ac = false;
        this.aa = false;
        this.cb = 0;
        this.ax = new Dictionary$2(String_$type, Boolean_$type, 0);
        this.b9 = -1;
        this.a = null;
        this.az = null;
        this.n = null;
        this.e8 = null;
        this.be = 0;
        this.bf = 0;
        this.ci = 0;
        this.cj = 0;
        this.a5 = 1;
        this.a8 = 1;
        this.a4 = 1;
        this.a6 = 0;
        this.bb = 0;
        this.a7 = 0;
        this.bc = 0;
        this.ca = 0;
        this.ck = 0;
        this.ad = false;
        this.s = 0;
        this.ba = 0;
        this.a3 = 0;
        this.d = 0;
        this.f = 1;
        this.hw = null;
        this.hx = null;
        this.hu = null;
        this.hv = null;
        this.ht = null;
        this.h0 = null;
        this.h1 = null;
        this.h2 = null;
        this.hz = null;
        this.hy = null;
        this.a9 = 0.3;
        this.e7 = null;
        this.fd = "";
        this.h3 = null;
        this.w = null;
        this.u = 0;
        this.bd = 0;
        this.cf = 0;
        this.ch = 0;
        this.cg = 0;
        this.ce = 0;
        this.b2 = 0;
        this.b4 = 0;
        this.b3 = 0;
        this.b1 = 0;
        this.b6 = 0;
        this.b8 = 0;
        this.b7 = 0;
        this.b5 = 0;
        this.bu = 1;
        this.bw = 1;
        this.bv = 1;
        this.bt = 1;
        this.by = 0;
        this.b0 = 0;
        this.bz = 0;
        this.bx = 0;
        this.j = 0;
        this.z = false;
        this.y = false;
        this.e6 = 0;
        this.propertyChanged = null;
        this.cellReconciling = null;
        this.r = 0;
        this.dq = -1;
        this.hp();
        this.h7 = GridStyleRepository.x;
    }
    get m() {
        return this.l;
    }
    set m(a) {
        this.l = a;
    }
    static ds(a) {
        if (CellModel.a0 == null || CellModel.a0 == undefined) {
            CellModel.a0 = new Dictionary$2(String_$type, Number_$type, 0);
        }
        if (CellModel.a0.containsKey(a)) {
            return CellModel.a0.item(a);
        }
        let b = CellModel.cd;
        CellModel.cd++;
        CellModel.cc = b;
        CellModel.a0.item(a, b);
        return b;
    }
    get r() {
        return this.q;
    }
    set r(a) {
        let b = this.q;
        this.q = a;
        if (this.q != b) {
            this.hl("State", CellModel.ev, enumGetBox(ModelStates_$type, b), enumGetBox(ModelStates_$type, this.q));
        }
    }
    get ar() {
        return this.ab;
    }
    set ar(a) {
        let b = this.ab;
        this.ab = a;
        if (this.ab != b) {
            this.hl("IsRowPinned", CellModel.d1, b, this.ab);
        }
    }
    get as() {
        return this.ac;
    }
    set as(a) {
        let b = this.ac;
        this.ac = a;
        if (this.ac != b) {
            this.hl("IsRowSticky", CellModel.d2, b, this.ac);
        }
    }
    get an() {
        return this.aa;
    }
    set an(a) {
        let b = this.aa;
        this.aa = a;
        if (this.aa != b) {
            this.hl("IsLastStickyRow", CellModel.d0, b, this.aa);
        }
    }
    get dw() {
        return this.cb;
    }
    set dw(a) {
        let b = this.cb;
        this.cb = a;
        if (this.cb != b) {
            this.hl("Indent", CellModel.dx, b, this.cb);
        }
    }
    ai(a) {
        if (this.ax.containsKey(a)) {
            return this.ax.item(a);
        }
        return false;
    }
    al(propertyId_) {
        if (this.b9 == -1) {
            return false;
        }
        let a = ((propertyId_ / 32) | 0);
        let b = propertyId_ % 32;
        return ((this.a[a] >> b) & 1) != 0;
    }
    ak(a) {
        let b = CellModel.a0.f(a);
        if (b != undefined) {
            return this.al(b);
        }
        if (this.ai(a)) {
            return true;
        }
        return false;
    }
    hf(propertyId_) {
        if (this.b9 == -1) {
            this.b9 = truncate(Math.ceil(CellModel.cc / 32));
            this.a = new Array(propertyId_);
        }
        let a = ((propertyId_ / 32) | 0);
        let b = propertyId_ % 32;
        this.a[a] = this.a[a] | (1 << b);
    }
    hc() {
        for (let a = 0; a < this.b9; a++) {
            this.a[a] = 0;
        }
    }
    hg(a) {
        let b = CellModel.a0.f(a);
        if (b != undefined) {
            this.hf(b);
            return;
        }
        this.ax.item(a, true);
    }
    hl(a, b, c, d) {
        this.hf(b);
        this.hn(a, c, d);
        if (this.m != null) {
            this.m.n9();
        }
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
    }
    hn(a, b, c) {
        switch (a) {
            case "State":
                this.aq = true;
                this.av = true;
                this.ah = true;
                this.aw = true;
                break;
            case "LeftOffset":
            case "TopOffset":
            case "LeftPercentOffset":
            case "TopPercentOffset":
            case "X":
            case "Y":
                this.aq = true;
                break;
            case "Width":
            case "Height":
                this.av = true;
                break;
            case "RowItem":
                this.hm();
                break;
            case "Background":
            case "SelectedBackground":
            case "SelectedStatus":
            case "IsLastStickyRow":
            case "StickyRowBackground":
            case "PinnedRowBackground":
            case "LastStickyRowBackground":
                this.hi();
                break;
            case "IsRowSticky":
            case "IsRowPinned":
                this.hi();
                this.hk();
                break;
            case "Border":
            case "ActivationBorder":
            case "BorderLeftWidth":
            case "BorderTopWidth":
            case "BorderBottomWidth":
            case "BorderRightWidth":
            case "ActivationBorderLeftWidth":
            case "ActivationBorderTopWidth":
            case "ActivationBorderBottomWidth":
            case "ActivationBorderRightWidth":
            case "ActivationStatus":
                this.af = true;
                this.hj();
                break;
            case "PaddingLeft":
            case "PaddingTop":
            case "PaddingBottom":
            case "PaddingRight":
                this.hj();
                break;
            case "Opacity":
            case "PinnedRowOpacity":
                this.hk();
                break;
            default:
                this.ah = true;
                break;
        }
    }
    hm() {
    }
    hi() {
        let a = this.h7;
        if (this.an && this.ia != null) {
            a = this.ia;
        }
        else if (this.as && this.ie != null) {
            a = this.ie;
        }
        else if (this.ar && this.ib != null) {
            a = this.ib;
        }
        this.h5 = this.h9(a, this.ic, this.bn);
    }
    hj() {
        let a = false;
        if (this.bg != 0) {
            a = true;
        }
        if (a && (this.dh == 0 || this.dm == 0 || this.dk == 0 || this.df == 0)) {
            let b = this.cn - this.dh;
            let c = this.cs - this.dm;
            let d = this.cq - this.dk;
            let e = this.cl - this.df;
            this.c8 = Math.max(0, this.ed - b);
            this.dc = Math.max(0, this.eh - c);
            this.da = Math.max(0, this.ef - d);
            this.c6 = Math.max(0, this.eb - e);
            this.cy = Math.max(0, this.dh + b);
            this.c3 = Math.max(0, this.dm + c);
            this.c1 = Math.max(0, this.dk + d);
            this.cw = Math.max(0, this.df + e);
        }
        else {
            this.c8 = this.ed;
            this.dc = this.eh;
            this.da = this.ef;
            this.c6 = this.eb;
            this.cy = this.dh;
            this.c3 = this.dm;
            this.c1 = this.dk;
            this.cw = this.df;
        }
        let f = this.h8;
        this.h6 = this.h9(f, this.h4, this.bg);
    }
    hk() {
        if (this.ar && !this.as) {
            this.bh = this.bm;
        }
        else {
            this.bh = this.bl;
        }
    }
    h9(a, b, c) {
        if (c == 0) {
            return a;
        }
        if (c == 1) {
            return b;
        }
        return BrushUtil.g(a, c, b, 0);
    }
    hp() {
        this.hq();
    }
    hq() {
        this.hc();
        if (this.az != null) {
            this.az.clear();
        }
        this.bn = 0;
        this.ah = true;
        this.aq = true;
        this.av = true;
        this.ao = false;
    }
    hr(a, b) {
        if (this.az == null) {
            this.az = new Dictionary$2(String_$type, Base.$, 0);
        }
        let c = null;
        if (this.az.containsKey(a)) {
            c = this.az.item(a);
        }
        this.az.item(a, b);
        let d = false;
        if (c == null && b != null) {
            d = true;
        }
        if (c != null) {
            if (!Base.equalsStatic(c, b)) {
                d = true;
            }
        }
        if (d) {
            this.hg(a);
            this.ah = true;
            if (this.m != null) {
                this.m.n9();
            }
        }
    }
    ae(a) {
        if (this.az == null) {
            return false;
        }
        return this.az.containsKey(a);
    }
    ho(a) {
        if (this.az == null) {
            return;
        }
        if (this.az.containsKey(a)) {
            this.az.removeItem(a);
        }
    }
    e9(a) {
        if (this.az == null) {
            return null;
        }
        if (this.az.containsKey(a)) {
            return this.az.item(a);
        }
        return null;
    }
    get o() {
        return this.n;
    }
    set o(a) {
        let b = this.n;
        this.n = a;
        if (this.n != b) {
            this.ao = true;
        }
    }
    get fc() {
        return this.e8;
    }
    set fc(a) {
        let b = this.e8;
        this.e8 = a;
        if (this.e8 != b) {
            this.hl("RowItem", CellModel.em, b, this.e8);
        }
    }
    get br() {
        return this.be;
    }
    set br(a) {
        let b = this.be;
        this.be = a;
        if (this.be != b) {
            this.hl("X", CellModel.e4, b, this.be);
        }
    }
    get bs() {
        return this.bf;
    }
    set bs(a) {
        let b = this.bf;
        this.bf = a;
        if (this.bf != b) {
            this.hl("Y", CellModel.e5, b, this.bf);
        }
    }
    get ep() {
        return this.ci;
    }
    set ep(a) {
        let b = this.ci;
        this.ci = a;
        if (this.ci != b) {
            this.hl("SnappedX", CellModel.eq, b, this.ci);
        }
    }
    get er() {
        return this.cj;
    }
    set er(a) {
        let b = this.cj;
        this.cj = a;
        if (this.cj != b) {
            this.hl("SnappedY", CellModel.es, b, this.cj);
        }
    }
    get bi() {
        return this.a5;
    }
    set bi(a) {
        let b = this.a5;
        this.a5 = a;
        if (this.a5 != b) {
            this.hl("ContentOpacity", CellModel.dp, b, this.a5);
        }
    }
    get bl() {
        return this.a8;
    }
    set bl(a) {
        let b = this.a8;
        this.a8 = a;
        if (this.a8 != b) {
            this.hl("Opacity", CellModel.d9, b, this.a8);
        }
    }
    get bh() {
        return this.a4;
    }
    set bh(a) {
        let b = this.a4;
        this.a4 = a;
        if (this.a4 != b) {
            this.hl("ActualOpacity", CellModel.c5, b, this.a4);
        }
    }
    hh() {
        if (this.cellReconciling != null) {
            this.cellReconciling(this);
        }
    }
    get bj() {
        return this.a6;
    }
    set bj(a) {
        let b = this.a6;
        this.a6 = a;
        if (this.a6 != b) {
            this.hl("LeftOffset", CellModel.d5, b, this.a6);
        }
    }
    get bo() {
        return this.bb;
    }
    set bo(a) {
        let b = this.bb;
        this.bb = a;
        if (this.bb != b) {
            this.hl("TopOffset", CellModel.ey, b, this.bb);
        }
    }
    get bk() {
        return this.a7;
    }
    set bk(a) {
        let b = this.a7;
        this.a7 = a;
        if (this.a7 != b) {
            this.hl("LeftPercentOffset", CellModel.d6, b, this.a7);
        }
    }
    get bp() {
        return this.bc;
    }
    set bp(a) {
        let b = this.bc;
        this.bc = a;
        if (this.bc != b) {
            this.hl("TopPercentOffset", CellModel.ez, b, this.bc);
        }
    }
    get dt() {
        return this.ca;
    }
    set dt(a) {
        let b = this.ca;
        this.ca = a;
        if (this.ca != b) {
            this.hl("Height", CellModel.du, b, this.ca);
        }
    }
    get e2() {
        return this.ck;
    }
    set e2(a) {
        let b = this.ck;
        this.ck = a;
        if (this.ck != b) {
            this.hl("Width", CellModel.e3, b, this.ck);
        }
    }
    get au() {
        return this.ad;
    }
    set au(a) {
        let b = this.ad;
        this.ad = a;
        if (this.ad != b) {
            this.hl("IsSelected", CellModel.d3, b, this.ad);
        }
    }
    get t() {
        return this.s;
    }
    set t(a) {
        let b = this.s;
        this.s = a;
        if (this.s != b) {
            this.hl("ModelType", CellModel.d8, enumGetBox(ModelTypes_$type, b), enumGetBox(ModelTypes_$type, this.s));
        }
    }
    get bn() {
        return this.ba;
    }
    set bn(a) {
        let b = this.ba;
        this.ba = a;
        if (this.ba != b) {
            this.hl("SelectedStatus", CellModel.eo, b, this.ba);
        }
    }
    get bg() {
        return this.a3;
    }
    set bg(a) {
        let b = this.a3;
        this.a3 = a;
        if (this.a3 != b) {
            this.hl("ActivationStatus", CellModel.cu, b, this.a3);
        }
    }
    get e() {
        return this.d;
    }
    set e(a) {
        let b = this.d;
        this.d = a;
        if (this.d != b) {
            this.hl("HorizontalAlignment", CellModel.dv, enumGetBox(CellContentHorizontalAlignment_$type, b), enumGetBox(CellContentHorizontalAlignment_$type, this.d));
        }
    }
    get g() {
        return this.f;
    }
    set g(a) {
        let b = this.f;
        this.f = a;
        if (this.f != b) {
            this.hl("VerticalAlignment", CellModel.e0, enumGetBox(CellContentVerticalAlignment_$type, b), enumGetBox(CellContentHorizontalAlignment_$type, this.d));
        }
    }
    get h7() {
        return this.hw;
    }
    set h7(a) {
        let b = this.hw;
        this.hw = a;
        if (this.hw != b) {
            this.hl("Background", CellModel.de, b, this.hw);
        }
    }
    get h8() {
        return this.hx;
    }
    set h8(a) {
        let b = this.hx;
        this.hx = a;
        if (this.hx != b) {
            this.hl("Border", CellModel.dj, b, this.hx);
        }
    }
    get h5() {
        return this.hu;
    }
    set h5(a) {
        let b = this.hu;
        this.hu = a;
        if (this.hu != b) {
            this.hl("ActualBackground", CellModel.cv, b, this.hu);
        }
    }
    get h6() {
        return this.hv;
    }
    set h6(a) {
        let b = this.hv;
        this.hv = a;
        if (this.hv != b) {
            this.hl("ActualBorder", CellModel.c0, b, this.hv);
        }
    }
    get h4() {
        return this.ht;
    }
    set h4(a) {
        let b = this.ht;
        this.ht = a;
        if (this.ht != b) {
            this.hl("ActivationBorder", CellModel.cp, b, this.ht);
        }
    }
    get ic() {
        return this.h0;
    }
    set ic(a) {
        let b = this.h0;
        this.h0 = a;
        if (this.h0 != b) {
            this.hl("SelectedBackground", CellModel.en, b, this.h0);
        }
    }
    get id() {
        return this.h1;
    }
    set id(a) {
        let b = this.h1;
        this.h1 = a;
        if (this.h1 != b) {
            this.hl("SortIndicatorColor", CellModel.eu, b, this.h1);
        }
    }
    get ie() {
        return this.h2;
    }
    set ie(a) {
        let b = this.h2;
        this.h2 = a;
        if (this.h2 != b) {
            this.hl("StickyRowBackground", CellModel.ew, b, this.h2);
        }
    }
    get ib() {
        return this.hz;
    }
    set ib(a) {
        let b = this.hz;
        this.hz = a;
        if (this.hz != b) {
            this.hl("PinnedRowBackground", CellModel.ej, b, this.hz);
        }
    }
    get ia() {
        return this.hy;
    }
    set ia(a) {
        let b = this.hy;
        this.hy = a;
        if (this.hy != b) {
            this.hl("LastStickyRowBackground", CellModel.d4, b, this.hy);
        }
    }
    get bm() {
        return this.a9;
    }
    set bm(a) {
        let b = this.a9;
        this.a9 = a;
        if (this.a9 != b) {
            this.hl("PinnedRowOpacity", CellModel.ek, b, this.a9);
        }
    }
    get fb() {
        return this.e7;
    }
    set fb(a) {
        let b = this.e7;
        this.e7 = a;
        if (this.e7 != b) {
            this.hl("OriginalValue", CellModel.ea, b, this.e7);
        }
    }
    get gq() {
        return this.fd;
    }
    set gq(a) {
        let b = this.fd;
        this.fd = a;
        if (this.fd != b) {
            this.hl("RenderValue", CellModel.el, b, this.fd);
        }
    }
    get ig() {
        return this.h3;
    }
    set ig(a) {
        let b = this.h3;
        this.h3 = a;
        if (this.h3 != b) {
            this.hl("TextColor", CellModel.ex, b, this.h3);
        }
    }
    get x() {
        return this.w;
    }
    set x(a) {
        let b = this.w;
        this.w = a;
        if (this.w != b) {
            this.hl("FontInfo", CellModel.dr, b, this.w);
        }
    }
    get v() {
        return this.u;
    }
    set v(a) {
        let b = this.u;
        this.u = a;
        if (this.u != b) {
            this.hl("LineBreakMode", CellModel.d7, enumGetBox(TextCellLineBreakMode_$type, b), enumGetBox(TextCellLineBreakMode_$type, this.u));
        }
    }
    get bq() {
        return this.bd;
    }
    set bq(a) {
        let b = this.bd;
        this.bd = a;
        if (this.bd != b) {
            this.hl("VirtualizationPercentage", CellModel.e1, b, this.bd);
        }
    }
    get ed() {
        return this.cf;
    }
    set ed(a) {
        let b = this.cf;
        this.cf = a;
        if (this.cf != b) {
            this.hl("PaddingLeft", CellModel.ee, b, this.cf);
        }
    }
    get eh() {
        return this.ch;
    }
    set eh(a) {
        let b = this.ch;
        this.ch = a;
        if (this.ch != b) {
            this.hl("PaddingTop", CellModel.ei, b, this.ch);
        }
    }
    get ef() {
        return this.cg;
    }
    set ef(a) {
        let b = this.cg;
        this.cg = a;
        if (this.cg != b) {
            this.hl("PaddingRight", CellModel.eg, b, this.cg);
        }
    }
    get eb() {
        return this.ce;
    }
    set eb(a) {
        let b = this.ce;
        this.ce = a;
        if (this.ce != b) {
            this.hl("PaddingBottom", CellModel.ec, b, this.ce);
        }
    }
    get c8() {
        return this.b2;
    }
    set c8(a) {
        let b = this.b2;
        this.b2 = a;
        if (this.b2 != b) {
            this.hl("ActualPaddingLeft", CellModel.c9, b, this.b2);
        }
    }
    get dc() {
        return this.b4;
    }
    set dc(a) {
        let b = this.b4;
        this.b4 = a;
        if (this.b4 != b) {
            this.hl("ActualPaddingTop", CellModel.dd, b, this.b4);
        }
    }
    get da() {
        return this.b3;
    }
    set da(a) {
        let b = this.b3;
        this.b3 = a;
        if (this.b3 != b) {
            this.hl("ActualPaddingRight", CellModel.db, b, this.b3);
        }
    }
    get c6() {
        return this.b1;
    }
    set c6(a) {
        let b = this.b1;
        this.b1 = a;
        if (this.b1 != b) {
            this.hl("ActualPaddingBottom", CellModel.c7, b, this.b1);
        }
    }
    get dh() {
        return this.b6;
    }
    set dh(a) {
        let b = this.b6;
        this.b6 = a;
        if (this.b6 != b) {
            this.hl("BorderLeftWidth", CellModel.di, b, this.b6);
        }
    }
    get dm() {
        return this.b8;
    }
    set dm(a) {
        let b = this.b8;
        this.b8 = a;
        if (this.b8 != b) {
            this.hl("BorderTopWidth", CellModel.dn, b, this.b8);
        }
    }
    get dk() {
        return this.b7;
    }
    set dk(a) {
        let b = this.b7;
        this.b7 = a;
        if (this.b7 != b) {
            this.hl("BorderRightWidth", CellModel.dl, b, this.b7);
        }
    }
    get df() {
        return this.b5;
    }
    set df(a) {
        let b = this.b5;
        this.b5 = a;
        if (this.b5 != b) {
            this.hl("BorderBottomWidth", CellModel.dg, b, this.b5);
        }
    }
    get cn() {
        return this.bu;
    }
    set cn(a) {
        let b = this.bu;
        this.bu = a;
        if (this.bu != b) {
            this.hl("ActivationBorderLeftWidth", CellModel.co, b, this.bu);
        }
    }
    get cs() {
        return this.bw;
    }
    set cs(a) {
        let b = this.bw;
        this.bw = a;
        if (this.bw != b) {
            this.hl("ActivationBorderTopWidth", CellModel.ct, b, this.bw);
        }
    }
    get cq() {
        return this.bv;
    }
    set cq(a) {
        let b = this.bv;
        this.bv = a;
        if (this.bv != b) {
            this.hl("ActivationBorderRightWidth", CellModel.cr, b, this.bv);
        }
    }
    get cl() {
        return this.bt;
    }
    set cl(a) {
        let b = this.bt;
        this.bt = a;
        if (this.bt != b) {
            this.hl("ActivationBorderBottomWidth", CellModel.cm, b, this.bt);
        }
    }
    get cy() {
        return this.by;
    }
    set cy(a) {
        let b = this.by;
        this.by = a;
        if (this.by != b) {
            this.hl("ActualBorderLeftWidth", CellModel.cz, b, this.by);
        }
    }
    get c3() {
        return this.b0;
    }
    set c3(a) {
        let b = this.b0;
        this.b0 = a;
        if (this.b0 != b) {
            this.hl("ActualBorderTopWidth", CellModel.c4, b, this.b0);
        }
    }
    get c1() {
        return this.bz;
    }
    set c1(a) {
        let b = this.bz;
        this.bz = a;
        if (this.bz != b) {
            this.hl("ActualBorderRightWidth", CellModel.c2, b, this.bz);
        }
    }
    get cw() {
        return this.bx;
    }
    set cw(a) {
        let b = this.bx;
        this.bx = a;
        if (this.bx != b) {
            this.hl("ActualBorderBottomWidth", CellModel.cx, b, this.bx);
        }
    }
    get k() {
        return this.j;
    }
    set k(a) {
        let b = this.j;
        this.j = a;
        if (this.j != b) {
            this.hl("SortDirection", CellModel.et, enumGetBox(ColumnSortDirection_$type, b), enumGetBox(ColumnSortDirection_$type, this.j));
        }
    }
    get am() {
        return this.z;
    }
    set am(a) {
        let b = this.z;
        this.z = a;
        if (this.z != b) {
            this.hl("IsExpanded", CellModel.dz, b, this.z);
        }
    }
    get ag() {
        return this.y;
    }
    set ag(a) {
        let b = this.y;
        this.y = a;
        if (this.y != b) {
            this.hl("IsCollapsable", CellModel.dy, b, this.y);
        }
    }
    ha() {
        this.hb();
    }
    hb() {
        this.aq = false;
        this.av = false;
        this.ah = false;
        this.af = false;
        this.ao = false;
        this.aw = false;
        this.aj = false;
        this.hc();
    }
    b(a) {
        if (a == null) {
            a = new CellModelExport();
        }
        a.p = this.br;
        a.q = this.bs;
        a.l = this.ep;
        a.m = this.er;
        a.i = this.dt;
        a.o = this.e2;
        a.k = this.bn;
        a.g = this.bg;
        a.x = EnumUtil.getName(TextCellLineBreakMode_$type, this.v);
        a.a = AppearanceHelper.a(this.h5);
        a.j = this.bh;
        a.r = this.dw;
        a.f = this.ag;
        a.c = this.e;
        a.d = this.g;
        a.y = this.gq;
        a.n = this.bq;
        a.e = this.k;
        a.b = AppearanceHelper.a(this.ig);
        if (this.x != null) {
            let b = this.x;
            if (this.m != null && b.n == null) {
                let c = this.m.externalGrid.renderer;
                let d = FontUtil.getFontInfoFromString(c, b.fontString);
                b.n = d.n;
                b.d = d.d;
                b.o = d.o;
                b.q = d.q;
                b.r = d.r;
                b.s = d.s;
            }
            if (this.x.n != null) {
                a.s = this.x.n;
            }
            if (!isNaN_(this.x.d)) {
                a.h = this.x.d;
            }
            if (this.x.s != null) {
                a.w = this.x.s;
            }
            if (this.x.q != null) {
                a.u = this.x.q;
            }
            if (this.x.o != null) {
                a.t = this.x.q;
            }
        }
        return a;
    }
    he() {
        if (CellModel.a1 == null) {
            CellModel.a1 = new Dictionary$2(String_$type, Delegate_$type, 0);
            CellModel.a1.addItem("X", (a, b) => a.br = typeGetValue(b));
            CellModel.a1.addItem("Y", (a, b) => a.bs = typeGetValue(b));
            CellModel.a1.addItem("SnappedX", (a, b) => a.ep = typeGetValue(b));
            CellModel.a1.addItem("SnappedY", (a, b) => a.er = typeGetValue(b));
            CellModel.a1.addItem("ContentOpacity", (a, b) => a.bi = b);
            CellModel.a1.addItem("Opacity", (a, b) => a.bl = b);
            CellModel.a1.addItem("LeftOffset", (a, b) => a.bj = b);
            CellModel.a1.addItem("LeftPercentOffset", (a, b) => a.bk = b);
            CellModel.a1.addItem("TopOffset", (a, b) => a.bo = b);
            CellModel.a1.addItem("TopPercentOffset", (a, b) => a.bp = b);
            CellModel.a1.addItem("Height", (a, b) => a.dt = typeGetValue(b));
            CellModel.a1.addItem("Width", (a, b) => a.e2 = typeGetValue(b));
            CellModel.a1.addItem("IsSelected", (a, b) => a.au = b);
            CellModel.a1.addItem("ModelType", (a, b) => a.t = EnumUtil.getEnumValue(ModelTypes_$type, b));
            CellModel.a1.addItem("SelectedStatus", (a, b) => a.bn = b);
            CellModel.a1.addItem("ActivationStatus", (a, b) => a.bg = b);
            CellModel.a1.addItem("HorizontalAlignment", (a, b) => a.e = EnumUtil.getEnumValue(CellContentHorizontalAlignment_$type, b));
            CellModel.a1.addItem("VerticalAlignment", (a, b) => a.g = EnumUtil.getEnumValue(CellContentVerticalAlignment_$type, b));
            CellModel.a1.addItem("Background", (a, b) => a.h7 = b);
            CellModel.a1.addItem("Border", (a, b) => a.h8 = b);
            CellModel.a1.addItem("ActivationBorder", (a, b) => a.h4 = b);
            CellModel.a1.addItem("SelectedBackground", (a, b) => a.ic = b);
            CellModel.a1.addItem("RenderValue", (a, b) => a.gq = b);
            CellModel.a1.addItem("OriginalValue", (a, b) => a.fb = b);
            CellModel.a1.addItem("TextColor", (a, b) => a.ig = b);
            CellModel.a1.addItem("SortIndicatorColor", (a, b) => a.id = b);
            CellModel.a1.addItem("FontInfo", (a, b) => a.x = b);
            CellModel.a1.addItem("LineBreakMode", (a, b) => a.v = EnumUtil.getEnumValue(TextCellLineBreakMode_$type, b));
            CellModel.a1.addItem("VirtualizationPercentage", (a, b) => a.bq = b);
            CellModel.a1.addItem("PaddingLeft", (a, b) => a.ed = typeGetValue(b));
            CellModel.a1.addItem("PaddingTop", (a, b) => a.eh = typeGetValue(b));
            CellModel.a1.addItem("PaddingRight", (a, b) => a.ef = typeGetValue(b));
            CellModel.a1.addItem("PaddingBottom", (a, b) => a.eb = typeGetValue(b));
            CellModel.a1.addItem("BorderLeftWidth", (a, b) => a.dh = typeGetValue(b));
            CellModel.a1.addItem("BorderTopWidth", (a, b) => a.dm = typeGetValue(b));
            CellModel.a1.addItem("BorderRightWidth", (a, b) => a.dk = typeGetValue(b));
            CellModel.a1.addItem("BorderBottomWidth", (a, b) => a.df = typeGetValue(b));
            CellModel.a1.addItem("ActivationBorderLeftWidth", (a, b) => a.cn = typeGetValue(b));
            CellModel.a1.addItem("ActivationBorderTopWidth", (a, b) => a.cs = typeGetValue(b));
            CellModel.a1.addItem("ActivationBorderRightWidth", (a, b) => a.cq = typeGetValue(b));
            CellModel.a1.addItem("ActivationBorderBottomWidth", (a, b) => a.cl = typeGetValue(b));
            CellModel.a1.addItem("SortDirection", (a, b) => a.k = EnumUtil.getEnumValue(ColumnSortDirection_$type, b));
            CellModel.a1.addItem("PinnedRowBackground", (a, b) => a.ib = b);
            CellModel.a1.addItem("StickyRowBackground", (a, b) => a.ie = b);
            CellModel.a1.addItem("LastStickyRowBackground", (a, b) => a.ia = b);
            CellModel.a1.addItem("PinnedRowOpacity", (a, b) => a.bm = b);
        }
    }
    hd() {
        if (CellModel.ay == null) {
            CellModel.ay = new Dictionary$2(String_$type, Delegate_$type, 0);
            CellModel.ay.addItem("X", (a) => a.br);
            CellModel.ay.addItem("Y", (a) => a.bs);
            CellModel.ay.addItem("SnappedX", (a) => a.ep);
            CellModel.ay.addItem("SnappedY", (a) => a.er);
            CellModel.ay.addItem("ContentOpacity", (a) => a.bi);
            CellModel.ay.addItem("Opacity", (a) => a.bl);
            CellModel.ay.addItem("LeftOffset", (a) => a.bj);
            CellModel.ay.addItem("LeftPercentOffset", (a) => a.bk);
            CellModel.ay.addItem("TopOffset", (a) => a.bo);
            CellModel.ay.addItem("TopPercentOffset", (a) => a.bp);
            CellModel.ay.addItem("Height", (a) => a.dt);
            CellModel.ay.addItem("Width", (a) => a.e2);
            CellModel.ay.addItem("IsSelected", (a) => a.au);
            CellModel.ay.addItem("ModelType", (a) => enumGetBox(ModelTypes_$type, a.t));
            CellModel.ay.addItem("SelectedStatus", (a) => a.bn);
            CellModel.ay.addItem("ActivationStatus", (a) => a.bg);
            CellModel.ay.addItem("HorizontalAlignment", (a) => enumGetBox(CellContentHorizontalAlignment_$type, a.e));
            CellModel.ay.addItem("VerticalAlignment", (a) => enumGetBox(CellContentVerticalAlignment_$type, a.g));
            CellModel.ay.addItem("Background", (a) => a.h7);
            CellModel.ay.addItem("Border", (a) => a.h8);
            CellModel.ay.addItem("ActivationBorder", (a) => a.h4);
            CellModel.ay.addItem("SelectedBackground", (a) => a.ic);
            CellModel.ay.addItem("RenderValue", (a) => a.gq);
            CellModel.ay.addItem("OriginalValue", (a) => a.fb);
            CellModel.ay.addItem("TextColor", (a) => a.ig);
            CellModel.ay.addItem("SortIndicatorColor", (a) => a.id);
            CellModel.ay.addItem("FontInfo", (a) => a.x);
            CellModel.ay.addItem("LineBreakMode", (a) => enumGetBox(TextCellLineBreakMode_$type, a.v));
            CellModel.ay.addItem("VirtualizationPercentage", (a) => a.bq);
            CellModel.ay.addItem("PaddingLeft", (a) => a.ed);
            CellModel.ay.addItem("PaddingTop", (a) => a.eh);
            CellModel.ay.addItem("PaddingRight", (a) => a.ef);
            CellModel.ay.addItem("PaddingBottom", (a) => a.eb);
            CellModel.ay.addItem("BorderLeftWidth", (a) => a.dh);
            CellModel.ay.addItem("BorderTopWidth", (a) => a.dm);
            CellModel.ay.addItem("BorderRightWidth", (a) => a.dk);
            CellModel.ay.addItem("BorderBottomWidth", (a) => a.df);
            CellModel.ay.addItem("ActivationBorderLeftWidth", (a) => a.cn);
            CellModel.ay.addItem("ActivationBorderTopWidth", (a) => a.cs);
            CellModel.ay.addItem("ActivationBorderRightWidth", (a) => a.cq);
            CellModel.ay.addItem("ActivationBorderBottomWidth", (a) => a.cl);
            CellModel.ay.addItem("SortDirection", (a) => enumGetBox(ColumnSortDirection_$type, a.k));
            CellModel.ay.addItem("PinnedRowBackground", (a) => a.ib);
            CellModel.ay.addItem("StickyRowBackground", (a) => a.ie);
            CellModel.ay.addItem("LastStickyRowBackground", (a) => a.ia);
            CellModel.ay.addItem("PinnedRowOpacity", (a) => a.bm);
        }
    }
    hs(a, b) {
        this.he();
        if (CellModel.a1.containsKey(a)) {
            CellModel.a1.item(a)(this, b);
        }
        else {
            this.hr(a, b);
        }
    }
    fa(a) {
        this.hd();
        if (CellModel.ay.containsKey(a)) {
            return CellModel.ay.item(a)(this);
        }
        if (this.ae(a)) {
            return this.e9(a);
        }
        return null;
    }
    at(a) {
        return (a != 1 || (a == 1 && this.l.c2 == 1)) && a != 2 && a != 4 && a != 5;
    }
}
CellModel.$t = markType(CellModel, 'CellModel');
CellModel.cd = 0;
CellModel.cc = 0;
CellModel.a0 = null;
CellModel.ev = CellModel.ds("State");
CellModel.d1 = CellModel.ds("IsRowPinned");
CellModel.d2 = CellModel.ds("IsRowSticky");
CellModel.d0 = CellModel.ds("IsLastStickyRow");
CellModel.dx = CellModel.ds("Indent");
CellModel.em = CellModel.ds("RowItem");
CellModel.e4 = CellModel.ds("X");
CellModel.e5 = CellModel.ds("Y");
CellModel.eq = CellModel.ds("SnappedX");
CellModel.es = CellModel.ds("SnappedY");
CellModel.dp = CellModel.ds("ContentOpacity");
CellModel.d9 = CellModel.ds("Opacity");
CellModel.c5 = CellModel.ds("ActualOpacity");
CellModel.d5 = CellModel.ds("LeftOffset");
CellModel.ey = CellModel.ds("TopOffset");
CellModel.d6 = CellModel.ds("LeftPercentOffset");
CellModel.ez = CellModel.ds("TopPercentOffset");
CellModel.du = CellModel.ds("Height");
CellModel.e3 = CellModel.ds("Width");
CellModel.d3 = CellModel.ds("IsSelected");
CellModel.d8 = CellModel.ds("ModelType");
CellModel.eo = CellModel.ds("SelectedStatus");
CellModel.cu = CellModel.ds("ActivationStatus");
CellModel.dv = CellModel.ds("HorizontalAlignment");
CellModel.e0 = CellModel.ds("VerticalAlignment");
CellModel.de = CellModel.ds("Background");
CellModel.dj = CellModel.ds("Border");
CellModel.cv = CellModel.ds("ActualBackground");
CellModel.c0 = CellModel.ds("ActualBorder");
CellModel.cp = CellModel.ds("ActivationBorder");
CellModel.en = CellModel.ds("SelectedBackground");
CellModel.eu = CellModel.ds("SortIndicatorColor");
CellModel.ew = CellModel.ds("StickyRowBackground");
CellModel.ej = CellModel.ds("PinnedRowBackground");
CellModel.d4 = CellModel.ds("LastStickyRowBackground");
CellModel.ek = CellModel.ds("PinnedRowOpacity");
CellModel.ea = CellModel.ds("OriginalValue");
CellModel.el = CellModel.ds("RenderValue");
CellModel.ex = CellModel.ds("TextColor");
CellModel.dr = CellModel.ds("FontInfo");
CellModel.d7 = CellModel.ds("LineBreakMode");
CellModel.e1 = CellModel.ds("VirtualizationPercentage");
CellModel.ee = CellModel.ds("PaddingLeft");
CellModel.ei = CellModel.ds("PaddingTop");
CellModel.eg = CellModel.ds("PaddingRight");
CellModel.ec = CellModel.ds("PaddingBottom");
CellModel.c9 = CellModel.ds("ActualPaddingLeft");
CellModel.dd = CellModel.ds("ActualPaddingTop");
CellModel.db = CellModel.ds("ActualPaddingRight");
CellModel.c7 = CellModel.ds("ActualPaddingBottom");
CellModel.di = CellModel.ds("BorderLeftWidth");
CellModel.dn = CellModel.ds("BorderTopWidth");
CellModel.dl = CellModel.ds("BorderRightWidth");
CellModel.dg = CellModel.ds("BorderBottomWidth");
CellModel.co = CellModel.ds("ActivationBorderLeftWidth");
CellModel.ct = CellModel.ds("ActivationBorderTopWidth");
CellModel.cr = CellModel.ds("ActivationBorderRightWidth");
CellModel.cm = CellModel.ds("ActivationBorderBottomWidth");
CellModel.cz = CellModel.ds("ActualBorderLeftWidth");
CellModel.c4 = CellModel.ds("ActualBorderTopWidth");
CellModel.c2 = CellModel.ds("ActualBorderRightWidth");
CellModel.cx = CellModel.ds("ActualBorderBottomWidth");
CellModel.et = CellModel.ds("SortDirection");
CellModel.dz = CellModel.ds("IsExpanded");
CellModel.dy = CellModel.ds("IsCollapsable");
CellModel.a1 = null;
CellModel.ay = null;
/**
 * @hidden
 */
class DateTimeCellModel extends CellModel {
    constructor() {
        super();
        this.io = new Date();
        this.iw = null;
        this._formatOverride = null;
        this.ij = 0;
        this.ih = null;
        this.il = false;
        this.ip = dateMinValue();
        this.hf(DateTimeCellModel.ir);
    }
    get ip() {
        return this.io;
    }
    set ip(a) {
        let b = this.io;
        this.io = a;
        if (+(this.io) != +b) {
            this.hl("DateTimeValue", DateTimeCellModel.ir, b, this.io);
        }
    }
    get ix() {
        return this._formatOverride;
    }
    set ix(a) {
        let b = this._formatOverride;
        this._formatOverride = a;
        if (this._formatOverride != b) {
            this.hl("FormatOverride", DateTimeCellModel.is, b, this._formatOverride);
        }
    }
    get ik() {
        return this.ij;
    }
    set ik(a) {
        let b = this.ij;
        this.ij = a;
        if (this.ij != b) {
            this.hl("DateTimeFormat", DateTimeCellModel.iq, enumGetBox(DateTimeFormats_$type, b), enumGetBox(DateTimeFormats_$type, this.ij));
        }
    }
    i0(a) {
        if (this._formatOverride != null) {
            let date_ = a;
            return (this._formatOverride.format(date_));
        }
        this.ih.j(this);
        return this.ih.i(a);
    }
    get ii() {
        return this.ih;
    }
    set ii(a) {
        let b = this.ih;
        this.ih = a;
        if (this.ih != b) {
            this.hl("Formatter", DateTimeCellModel.it, b, this.ih);
        }
    }
    get im() {
        return this.il;
    }
    set im(a) {
        let b = this.il;
        this.il = a;
        if (this.il != b) {
            this.hl("IsOffsetValue", DateTimeCellModel.iu, b, this.il);
        }
    }
    hs(a, b) {
        super.hs(a, b);
        if (a == "DateTimeFormat") {
            this.ik = EnumUtil.getEnumValue(DateTimeFormats_$type, b);
        }
        if (a == "DateTimeValue") {
            this.ip = b;
        }
        if (a == "IsOffsetValue") {
            this.im = b;
        }
        if (a == "FormatOverride") {
            this.ix = b;
        }
    }
    fa(a) {
        if (a == "DateTimeFormat") {
            return enumGetBox(DateTimeFormats_$type, this.ik);
        }
        if (a == "DateTimeValue") {
            return this.ip;
        }
        if (a == "IsOffsetValue") {
            return this.im;
        }
        if (a == "FormatOverride") {
            return this.ix;
        }
        return super.fa(a);
    }
    b(a) {
        if (a == null) {
            a = new DateTimeCellModelExport();
        }
        a = super.b(a);
        let b = a;
        b.ad = this.ip;
        b.ae = this.ik;
        b.ac = this.im;
        return b;
    }
}
DateTimeCellModel.$t = markType(DateTimeCellModel, 'DateTimeCellModel', CellModel.$);
DateTimeCellModel.ir = CellModel.ds("DateTimeValue");
DateTimeCellModel.is = CellModel.ds("FormatOverride");
DateTimeCellModel.iq = CellModel.ds("DateTimeFormat");
DateTimeCellModel.it = CellModel.ds("Formatter");
DateTimeCellModel.iu = CellModel.ds("IsOffsetValue");
/**
 * @hidden
 */
class SummaryCellModel extends CellModel {
    constructor() {
        super(...arguments);
        this.ik = null;
        this.il = null;
        this.is = null;
    }
    get im() {
        return this.ik;
    }
    set im(a) {
        let b = this.ik;
        this.ik = a;
        if (this.ik != b) {
            this.hl("ResolvedSummaryText", SummaryCellModel.ih, b, this.ik);
        }
    }
    get ip() {
        return this.il;
    }
    set ip(a) {
        let b = this.il;
        this.il = a;
        if (this.il != b) {
            this.hl("ResolvedSummaryValue", SummaryCellModel.ii, b, this.il);
        }
    }
    get it() {
        return this.is;
    }
    set it(a) {
        let b = this.is;
        this.is = a;
        if (this.is != b) {
            this.hl("SummaryNameTextColor", SummaryCellModel.ij, b, this.is);
        }
    }
    b(a) {
        if (a == null) {
            a = new SummaryCellModelExport();
        }
        a = super.b(a);
        let b = a;
        b.ac = this.im;
        b.ad = this.ip;
        return b;
    }
    at(a) {
        return a == 4 || a == 5;
    }
}
SummaryCellModel.$t = markType(SummaryCellModel, 'SummaryCellModel', CellModel.$);
SummaryCellModel.ih = CellModel.ds("ResolvedSummaryText");
SummaryCellModel.ii = CellModel.ds("ResolvedSummaryValue");
SummaryCellModel.ij = CellModel.ds("SummaryNameTextColor");
/**
 * @hidden
 */
class VerticalSeparatorCellModel extends CellModel {
    constructor() {
        super();
        this.ih = true;
    }
    get ii() {
        return this.ih;
    }
    set ii(a) {
        let b = this.ih;
        this.ih = a;
        if (b != this.ih) {
            this.hl("IsHitTestVisible", VerticalSeparatorCellModel.ij, b, this.ih);
        }
    }
}
VerticalSeparatorCellModel.$t = markType(VerticalSeparatorCellModel, 'VerticalSeparatorCellModel', CellModel.$);
VerticalSeparatorCellModel.ij = CellModel.ds("IsHitTestVisible");
/**
 * @hidden
 */
class ImageCellModel extends CellModel {
    constructor() {
        super();
        this.ip = "";
        this.ij = 0;
        this.ih = 0;
        this.e = 3;
    }
    get iq() {
        return this.ip;
    }
    set iq(a) {
        let b = this.ip;
        this.ip = a;
        if (this.ip != b) {
            this.hl("ImagePath", ImageCellModel.il, b, this.ip);
        }
    }
    get ik() {
        return this.ij;
    }
    set ik(a) {
        let b = this.ij;
        this.ij = a;
        if (this.ij != b) {
            this.hl("ImageStretchOption", ImageCellModel.io, enumGetBox(ImageStretchOptions_$type, b), enumGetBox(ImageStretchOptions_$type, this.ij));
        }
    }
    get ii() {
        return this.ih;
    }
    set ii(a) {
        let b = this.ih;
        this.ih = a;
        if (this.ih != b) {
            this.hl("ImageResourceType", ImageCellModel.im, enumGetBox(ImageResourceType_$type, b), enumGetBox(ImageResourceType_$type, this.ih));
        }
    }
    b(a) {
        if (a == null) {
            a = new ImageCellModelExport();
        }
        a = super.b(a);
        let b = a;
        b.ac = this.iq;
        return b;
    }
    hs(a, b) {
        super.hs(a, b);
        if (a == "ImageStretchOption") {
            this.ik = EnumUtil.getEnumValue(ImageStretchOptions_$type, b);
        }
        if (a == "ImageResourceType") {
            this.ii = EnumUtil.getEnumValue(ImageResourceType_$type, b);
        }
        if (a == "ImagePath") {
            this.iq = b;
        }
    }
    fa(a) {
        if (a == "ImageStretchOption") {
            return enumGetBox(ImageStretchOptions_$type, this.ik);
        }
        if (a == "ImageResourceType") {
            return enumGetBox(ImageResourceType_$type, this.ii);
        }
        if (a == "ImagePath") {
            return this.iq;
        }
        return super.fa(a);
    }
}
ImageCellModel.$t = markType(ImageCellModel, 'ImageCellModel', CellModel.$);
ImageCellModel.il = CellModel.ds("ImagePath");
ImageCellModel.io = CellModel.ds("ImageStretchOption");
ImageCellModel.im = CellModel.ds("ImageResourceType");
/**
 * @hidden
 */
class NumericCellModel extends CellModel {
    constructor() {
        super();
        this.im = NaN;
        this.ih = false;
        this.i7 = null;
        this._formatOverride = null;
        this.i9 = null;
        this.jb = null;
        this.ja = null;
        this.jc = "";
        this.ip = 5;
        this.iq = 0;
        this.ir = -1;
        this.ii = false;
        this.e = 2;
    }
    get io() {
        return this.im;
    }
    set io(a) {
        let b = this.im;
        this.im = a;
        if (this.im != b) {
            this.hl("NumericValue", NumericCellModel.i2, b, this.im);
        }
    }
    get ij() {
        return this.ih;
    }
    set ij(a) {
        let b = this.ih;
        this.ih = a;
        if (this.ih != b) {
            this.hl("HasDecimalValue", NumericCellModel.it, b, this.ih);
        }
    }
    get i8() {
        return this._formatOverride;
    }
    set i8(a) {
        let b = this._formatOverride;
        this._formatOverride = a;
        if (this._formatOverride != b) {
            this.hl("FormatOverride", NumericCellModel.is, b, this._formatOverride);
        }
    }
    get ji() {
        return this.i9;
    }
    set ji(a) {
        let b = this.i9;
        this.i9 = a;
        if (this.i9 != b) {
            this.hl("NegativePrefix", NumericCellModel.i0, b, this.i9);
        }
    }
    get jn() {
        return this.jb;
    }
    set jn(a) {
        let b = this.jb;
        this.jb = a;
        if (this.jb != b) {
            this.hl("PositivePrefix", NumericCellModel.i3, b, this.jb);
        }
    }
    get jk() {
        return this.ja;
    }
    set jk(a) {
        let b = this.ja;
        this.ja = a;
        if (this.ja != b) {
            this.hl("NegativeSuffix", NumericCellModel.i1, b, this.ja);
        }
    }
    get jp() {
        return this.jc;
    }
    set jp(a) {
        let b = this.jc;
        this.jc = a;
        if (this.jc != b) {
            this.hl("PositiveSuffix", NumericCellModel.i4, b, this.jc);
        }
    }
    get iu() {
        return this.ip;
    }
    set iu(a) {
        let b = this.ip;
        this.ip = a;
        if (this.ip != b) {
            this.hl("MaxFractionDigits", NumericCellModel.iv, b, this.ip);
        }
    }
    get iw() {
        return this.iq;
    }
    set iw(a) {
        let b = this.iq;
        this.iq = a;
        if (this.iq != b) {
            this.hl("MinFractionDigits", NumericCellModel.ix, b, this.iq);
        }
    }
    get iy() {
        return this.ir;
    }
    set iy(a) {
        let b = this.ir;
        this.ir = a;
        if (this.ir != b) {
            this.hl("MinIntegerDigits", NumericCellModel.iz, b, this.ir);
        }
    }
    get il() {
        return this.ii;
    }
    set il(a) {
        let b = this.ii;
        this.ii = a;
        if (this.ii != b) {
            this.hl("ShowGroupingSeparator", NumericCellModel.i5, b, this.ii);
        }
    }
    ik() {
        if (this.al(NumericCellModel.ix) || this.al(NumericCellModel.iv) || this.al(NumericCellModel.iz) || this.al(NumericCellModel.i4) || this.al(NumericCellModel.i1) || this.al(NumericCellModel.i3) || this.al(NumericCellModel.i0) || this.al(NumericCellModel.is) || this.al(NumericCellModel.i5)) {
            return true;
        }
        return false;
    }
    hs(a, b) {
        super.hs(a, b);
        if (a == "NumericValue") {
            this.io = b;
        }
        if (a == "NegativePrefix") {
            this.ji = b;
        }
        if (a == "PositivePrefix") {
            this.jn = b;
        }
        if (a == "NegativeSuffix") {
            this.jk = b;
        }
        if (a == "PositiveSuffix") {
            this.jp = b;
        }
        if (a == "MinFractionDigits") {
            this.iw = typeGetValue(b);
        }
        if (a == "MaxFractionDigits") {
            this.iu = typeGetValue(b);
        }
        if (a == "MinIntegerDigits") {
            this.iy = typeGetValue(b);
        }
        if (a == "ShowGroupingSeparator") {
            this.il = b;
        }
        if (a == "FormatOverride") {
            this.i8 = b;
        }
    }
    fa(a) {
        if (a == "NumericValue") {
            return this.io;
        }
        if (a == "NegativePrefix") {
            return this.ji;
        }
        if (a == "PositivePrefix") {
            return this.jn;
        }
        if (a == "NegativeSuffix") {
            return this.ji;
        }
        if (a == "PositiveSuffix") {
            return this.jp;
        }
        if (a == "MinFractionDigits") {
            return this.iw;
        }
        if (a == "MaxFractionDigits") {
            return this.iu;
        }
        if (a == "MinIntegerDigits") {
            return this.iy;
        }
        if (a == "ShowGroupingSeparator") {
            return this.il;
        }
        if (a == "FormatOverride") {
            return this.i8;
        }
        return super.fa(a);
    }
    b(a) {
        if (a == null) {
            a = new NumericCellModelExport();
        }
        a = super.b(a);
        let b = a;
        b.ac = this.io;
        return b;
    }
}
NumericCellModel.$t = markType(NumericCellModel, 'NumericCellModel', CellModel.$);
NumericCellModel.i2 = CellModel.ds("NumericValue");
NumericCellModel.it = CellModel.ds("HasDecimalValue");
NumericCellModel.is = CellModel.ds("FormatOverride");
NumericCellModel.i0 = CellModel.ds("NegativePrefix");
NumericCellModel.i3 = CellModel.ds("PositivePrefix");
NumericCellModel.i1 = CellModel.ds("NegativeSuffix");
NumericCellModel.i4 = CellModel.ds("PositiveSuffix");
NumericCellModel.iv = CellModel.ds("MaxFractionDigits");
NumericCellModel.ix = CellModel.ds("MinFractionDigits");
NumericCellModel.iz = CellModel.ds("MinIntegerDigits");
NumericCellModel.i5 = CellModel.ds("ShowGroupingSeparator");
/**
 * @hidden
 */
class RowSeparatorModel extends CellModel {
    constructor() {
        super();
    }
    b(a) {
        if (a == null) {
            a = new RowSeparatorModelExport();
        }
        a = super.b(a);
        return a;
    }
}
RowSeparatorModel.$t = markType(RowSeparatorModel, 'RowSeparatorModel', CellModel.$);
/**
 * @hidden
 */
class SectionHeaderCellModel extends CellModel {
    constructor() {
        super(...arguments);
        this.ih = null;
        this.ii = null;
        this.iu = null;
        this.it = null;
        this.il = 4;
    }
    get ij() {
        return this.ih;
    }
    set ij(a) {
        let b = this.ih;
        this.ih = a;
        if (this.ih != b) {
            this.hl("Groups", SectionHeaderCellModel.io, b, this.ih);
        }
    }
    get ik() {
        return this.ii;
    }
    set ik(a) {
        let b = this.ii;
        this.ii = a;
        if (this.ii != b) {
            this.hl("Summaries", SectionHeaderCellModel.ir, b, this.ii);
        }
    }
    get iy() {
        return this.iu;
    }
    set iy(a) {
        let b = this.iu;
        this.iu = a;
        if (this.iu != b) {
            this.hl("ResolvedText", SectionHeaderCellModel.iq, b, this.iu);
        }
    }
    get iw() {
        return this.it;
    }
    set iw(a) {
        let b = this.it;
        this.it = a;
        if (this.it != b) {
            this.hl("ResolvedSummaryText", SectionHeaderCellModel.ip, b, this.it);
        }
    }
    get im() {
        return this.il;
    }
    set im(a) {
        let b = this.il;
        this.il = a;
        if (this.il != b) {
            this.hl("SummaryDisplayMode", SectionHeaderCellModel.is, enumGetBox(GroupSummaryDisplayMode_$type, b), enumGetBox(GroupSummaryDisplayMode_$type, this.il));
        }
    }
    hs(a, b) {
        super.hs(a, b);
        if (a == "Groups") {
            this.ij = b;
        }
        else if (a == "SummaryDisplayMode") {
            this.im = EnumUtil.getEnumValue(GroupSummaryDisplayMode_$type, b);
        }
    }
    fa(a) {
        if (a == "Groups") {
            return this.ij;
        }
        else if (a == "IsCollapsable") {
            return this.ag;
        }
        else if (a == "SummaryDisplayMode") {
            return enumGetBox(GroupSummaryDisplayMode_$type, this.im);
        }
        return super.fa(a);
    }
    b(a) {
        if (a == null) {
            a = new SectionHeaderCellModelExport();
        }
        a = super.b(a);
        let b = a;
        b.ad = new Array(this.ij.length);
        b.ae = new Array(this.ij.length);
        b.ac = new Array(this.ij.length);
        b.aj = this.iy;
        b.ag = new Array(this.ik.length);
        b.ai = new Array(this.ik.length);
        b.ah = new Array(this.ik.length);
        b.af = new Array(this.ik.length);
        b.ak = this.iw;
        for (let c = 0; c < this.ij.length; c++) {
            b.ad[c] = this.ij[c].c;
            b.ae[c] = this.ij[c].a;
            b.ac[c] = this.ij[c].b;
        }
        for (let d = 0; d < this.ik.length; d++) {
            b.ag[d] = this.ik[d].e;
            b.ai[d] = this.ik[d].b;
            b.ah[d] = this.ik[d].a;
            b.af[d] = this.ik[d].c;
        }
        return b;
    }
    at(a) {
        return a == 1;
    }
}
SectionHeaderCellModel.$t = markType(SectionHeaderCellModel, 'SectionHeaderCellModel', CellModel.$);
SectionHeaderCellModel.io = CellModel.ds("Groups");
SectionHeaderCellModel.ir = CellModel.ds("Summaries");
SectionHeaderCellModel.iq = CellModel.ds("ResolvedText");
SectionHeaderCellModel.ip = CellModel.ds("ResolvedSummaryText");
SectionHeaderCellModel.is = CellModel.ds("SummaryDisplayMode");
/**
 * @hidden
 */
class TemplateCellModel extends CellModel {
    constructor() {
        super(...arguments);
        this.ii = null;
    }
    get ij() {
        return this.ii;
    }
    set ij(a) {
        let b = this.ii;
        this.ii = a;
        if (this.ii != b) {
            this.hl("Value", TemplateCellModel.ih, b, this.ii);
        }
    }
    hs(a, b) {
        super.hs(a, b);
        if (a == "Value") {
            this.ij = b;
        }
    }
    fa(a) {
        if (a == "Value") {
            return this.ij;
        }
        return super.fa(a);
    }
    b(a) {
        if (a == null) {
            a = new TemplateCellModelExport();
        }
        a = super.b(a);
        let b = a;
        b.ac = this.ij;
        return b;
    }
}
TemplateCellModel.$t = markType(TemplateCellModel, 'TemplateCellModel', CellModel.$);
TemplateCellModel.ih = CellModel.ds("Value");
/**
 * @hidden
 */
class TextCellModel extends CellModel {
    constructor() {
        super(...arguments);
        this.ii = "";
    }
    get ij() {
        return this.ii;
    }
    set ij(a) {
        let b = this.ii;
        this.ii = a;
        if (this.ii != b) {
            this.hl("TextValue", TextCellModel.ih, b, this.ii);
        }
    }
    hs(a, b) {
        super.hs(a, b);
        if (a == "TextValue") {
            this.ij = b;
        }
    }
    fa(a) {
        if (a == "TextValue") {
            return this.ij;
        }
        return super.fa(a);
    }
    b(a) {
        if (a == null) {
            a = new TextCellModelExport();
        }
        a = super.b(a);
        let b = a;
        b.ad = this.ij;
        return b;
    }
}
TextCellModel.$t = markType(TextCellModel, 'TextCellModel', CellModel.$);
TextCellModel.ih = CellModel.ds("TextValue");
/**
 * @hidden
 */
class TextHeaderCellModel extends TextCellModel {
    constructor() {
        super();
        this.io = false;
        this.il = 0;
    }
    get ip() {
        return this.io;
    }
    set ip(a) {
        let b = this.io;
        this.io = a;
        if (this.io != b) {
            this.hl("IsFilterUIVisible", TextHeaderCellModel.iq, b, this.io);
        }
    }
    get im() {
        return this.il;
    }
    set im(a) {
        let b = this.il;
        this.il = a;
        if (this.il != b) {
            this.hl("SortIndicatorStyle", TextHeaderCellModel.ir, enumGetBox(SortIndicatorStyle_$type, b), enumGetBox(SortIndicatorStyle_$type, this.il));
        }
    }
    hs(a, b) {
        super.hs(a, b);
        if (a == "IsFilterUIVisible") {
            this.ip = b;
        }
        else if (a == "SortIndicatorStyle") {
            this.im = EnumUtil.getEnumValue(SortIndicatorStyle_$type, b);
        }
    }
    fa(a) {
        if (a == "IsFilterUIVisible") {
            return this.ip;
        }
        if (a == "SortIndicatorStyle") {
            return enumGetBox(SortIndicatorStyle_$type, this.im);
        }
        return super.fa(a);
    }
    b(a) {
        if (a == null) {
            a = new TextHeaderCellModelExport();
        }
        a = super.b(a);
        let b = a;
        return b;
    }
}
TextHeaderCellModel.$t = markType(TextHeaderCellModel, 'TextHeaderCellModel', TextCellModel.$);
TextHeaderCellModel.iq = CellModel.ds("IsFilterUIVisible");
TextHeaderCellModel.ir = CellModel.ds("SortIndicatorStyle");
/**
 * @hidden
 */
let ICellPresenter_$type = new Type(null, 'ICellPresenter');
/**
 * @hidden
 */
class DataSourceNotificationBridge extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.a = a;
    }
    rangeActualized(a, b) {
        this.a.ng(a, b);
    }
    notifySetItem(a, b, c) {
        this.a.n1(a, b, c);
    }
    notifyClearItems() {
        this.a.m3();
    }
    notifyInsertItem(a, b) {
        this.a.np(a, b);
    }
    notifyRemoveItem(a, b) {
        this.a.nu(a, b);
    }
}
DataSourceNotificationBridge.$t = markType(DataSourceNotificationBridge, 'DataSourceNotificationBridge', Base.$, [IDataSourceUpdateNotifier_$type]);
/**
 * @hidden
 */
class ColumnController extends Base {
    constructor(a, b, c) {
        super();
        this.g = null;
        this.l = false;
        this.a = null;
        this.k = false;
        this.i = null;
        this.j = null;
        this.l = b;
        this.g = a;
        this.j = c;
    }
    get n() {
        return this.l;
    }
    set n(a) {
        let b = this.l;
        this.l = a;
        if (b != this.l) {
            this.k = false;
        }
        this.r();
    }
    get b() {
        return this.a;
    }
    set b(a) {
        let b = this.a;
        this.a = a;
        if (b != this.a) {
            this.k = false;
        }
        this.r();
    }
    get h() {
        return this.g;
    }
    get m() {
        return this.k;
    }
    set m(a) {
        this.k = a;
    }
    r() {
        if (this.k) {
            return false;
        }
        if (this.a == null) {
            return false;
        }
        let a = new Dictionary$2(String_$type, Boolean_$type, 0);
        for (let b = 0; b < this.g.count; b++) {
            let c = this.g._inner[b];
            if (!c.ey) {
                a.item(c.gb, true);
            }
        }
        let d = false;
        for (let e = this.g.count - 1; e >= 0; e--) {
            if (this.g._inner[e].ey) {
                this.i.removeExternalColumn(this.g._inner[e].externalObject);
            }
        }
        if (this.l && this.a != null) {
            d = this.o(a, this.a);
        }
        this.k = true;
        if (d) {
            this.j();
        }
        return d;
    }
    o(a, b) {
        let c = new GridColumnCollection();
        for (let d = 0; d < b.propertyNames.length; d++) {
            let e = b.propertyNames[d];
            if (!a.containsKey(e)) {
                let f = this.c(e, b.propertyTypes[d]);
                c.add(f);
                a.item(e, true);
            }
        }
        let g = new Dictionary$2(String_$type, Boolean_$type, 0);
        for (let h = 0; h < c.count; h++) {
            g.item(c._inner[h].gb, true);
        }
        let i = false;
        let j = this.g.count;
        for (let k = 0; k < c.count; k++) {
            i = true;
            this.i.insertExternalColumnAtIndex(j + k, c._inner[k].externalObject);
        }
        return i;
    }
    c(a, b) {
        let c = null;
        switch (b) {
            case 8:
            case 9:
                c = this.i.createDateTimeColumn(a);
                break;
            case 5:
            case 6:
            case 7:
            case 1:
            case 3:
            case 4:
            case 10:
                c = this.i.createNumericColumn(a);
                break;
            case 11:
                c = this.i.createTextColumn(a);
                break;
            case 0:
            case 2:
                c = this.i.createTextColumn(a);
                break;
        }
        c.gb = a;
        c.ey = true;
        return c;
    }
    f(a) {
        if (a.al < 0 || this.g.count == 0 || this.g.count <= a.al) {
            return null;
        }
        return this.g._inner[a.al];
    }
    d(a) {
        for (let b = 0; b < this.g.count; b++) {
            if (this.g._inner[b].fj == a) {
                return this.g._inner[b];
            }
        }
        return null;
    }
    e(a) {
        for (let b = 0; b < this.g.count; b++) {
            if (this.g._inner[b].fu() == a) {
                return this.g._inner[b];
            }
        }
        return null;
    }
    p(a) {
        return false;
    }
    q(a) {
        return false;
    }
}
ColumnController.$t = markType(ColumnController, 'ColumnController');
/**
 * @hidden
 */
class Grid extends Base {
    constructor() {
        super();
        this.iz = null;
        this._propertySetter = null;
        this.de = null;
        this.dc = null;
        this.hr = truncate(DeviceUtils.g(48));
        this.columnExchangingAnimationCompleted = null;
        this.columnExchangingAnimationCanceled = null;
        this.columnShowingAnimationCompleted = null;
        this.columnShowingAnimationCanceled = null;
        this.filterExpressionsChanging = null;
        this.filterExpressionsChanged = null;
        this.columnMovingAnimationCompleted = null;
        this.columnMovingAnimationCanceled = null;
        this.columnHidingAnimationCompleted = null;
        this.columnHidingAnimationCanceled = null;
        this.cellPreviewPointerDown = null;
        this.cellPreviewPointerUp = null;
        this.cellPointerDown = null;
        this.cellPointerUp = null;
        this.cellClicked = null;
        this.bf = 0;
        this.a6 = 0;
        this.qm = null;
        this.am = null;
        this.ev = false;
        this.hu = -1;
        this.e3 = false;
        this.e2 = false;
        this.g1 = 0;
        this.g6 = 0;
        this.g4 = 0;
        this.g5 = 0;
        this.gs = new Date();
        this.gx = 0;
        this.gy = 0;
        this.gz = 0;
        this.g0 = 0;
        this.an = null;
        this.hy = 0;
        this.hx = 0;
        this.e8 = false;
        this.hq = -1;
        this.hz = -1;
        this.aj = null;
        this.gv = -1;
        this.g3 = 0;
        this.ai = null;
        this.fy = false;
        this.fa = false;
        this.fc = false;
        this.e9 = false;
        this.b0 = new GridAnimationManager();
        this._delayedExecutionManager = null;
        this.di = null;
        this.c9 = null;
        this.at = null;
        this.cm = new GridLayerController();
        this.d2 = new SpatialEngine();
        this.ch = null;
        this.dw = null;
        this.ae = null;
        this.d0 = null;
        this.eo = null;
        this.du = null;
        this.ds = new SectionFooter();
        this.d4 = null;
        this.d6 = null;
        this.dq = null;
        this.c5 = null;
        this.bh = null;
        this.a8 = null;
        this.b = null;
        this.d8 = new VisibilityEngine();
        this._viewportManager = null;
        this.gu = 0;
        this.gt = 0;
        this.bu = ColumnWidth.a;
        this.gw = 0;
        this.hm = truncate(DeviceUtils.g(64));
        this.hw = truncate(DeviceUtils.g(0));
        this.gq = null;
        this.hv = truncate(DeviceUtils.g(0));
        this.ht = truncate(DeviceUtils.g(0));
        this.hl = truncate(DeviceUtils.g(0));
        this.c3 = 0;
        this.er = true;
        this.hs = truncate(DeviceUtils.g(1));
        this.e1 = true;
        this.bj = 1;
        this.ba = 0;
        this.ag = 0;
        this.dn = 0;
        this.aq = 0;
        this.cb = new GridColumnAnimationSettings();
        this.b2 = new GridAnimationSettings();
        this.bc = 1;
        this.bk = 1;
        this.a3 = 1;
        this.a0 = 1;
        this.av = 1;
        this.qp = new Thickness(1, 0, 0, 0, 0);
        this.cy = 0;
        this.bx = 0;
        this.cw = 0;
        this.et = false;
        this.x = new GridSelectedItemsCollection();
        this.ab = new GridSelectedKeysCollection();
        this.cs = new GridSelectedCellsCollection();
        this.cp = new GridSelectedCellRangesCollection();
        this.es = false;
        this.w = new GridSelectedItemsCollection();
        this.aa = new GridSelectedKeysCollection();
        this.ew = false;
        this.ez = true;
        this.e0 = true;
        this.o5 = null;
        this.pk = null;
        this.pn = null;
        this.pr = null;
        this.g2 = NaN;
        this.pm = null;
        this.pe = null;
        this.pd = null;
        this.b9 = null;
        this.o4 = null;
        this.o6 = null;
        this.pb = null;
        this.dy = 0;
        this.ec = null;
        this.pj = null;
        this.pl = null;
        this.ee = null;
        this.pq = null;
        this.pu = null;
        this.po = null;
        this.ps = null;
        this.pp = null;
        this.pt = null;
        this.eg = null;
        this.ef = null;
        this.hn = truncate(DeviceUtils.g(1));
        this.pa = null;
        this.o9 = null;
        this.pc = null;
        this.ed = null;
        this.pf = null;
        this.pi = null;
        this.pg = null;
        this.ph = null;
        this.hk = truncate(DeviceUtils.g(5));
        this.hj = truncate(DeviceUtils.g(2));
        this.o8 = null;
        this.o7 = null;
        this.em = new DefaultPlatformPixelConverter();
        this.c7 = null;
        this.dk = null;
        this.ea = new VisualModel();
        this.bp = null;
        this.ay = null;
        this.s = null;
        this.bs = null;
        this.sortDescriptionsChanged = null;
        this.groupDescriptionsChanged = null;
        this.q = 0;
        this.ex = false;
        this.o = 0;
        this.ey = true;
        this.c1 = 4;
        this.propertyChanged = null;
        this.e7 = false;
        this.u = null;
        this.c = null;
        this.a = null;
        this.ho = -1;
        this.hp = -1;
        this.cd = new GridColumnCollection();
        this.gp = false;
        this.eq = false;
        this.fj = false;
        this.fx = false;
        this.fb = false;
        this.columnsAutoGenerated = null;
        this.selectedItemsChanged = null;
        this.selectedKeysChanged = null;
        this.selectedCellsChanged = null;
        this.activeCellChanged = null;
        this.selectedCellRangesChanged = null;
        this.ao = null;
        this.eu = false;
        this.e6 = true;
        this.e5 = true;
        this.e4 = true;
        this.dv = new SectionHeader();
        this.dr = new RowSeparator();
        this.c6 = new HeaderSeparator();
        this.bi = new ColumnResizingSeparator();
        this.a9 = new ColumnMovingSeparator();
        this.d5 = new SummaryRowRoot();
        this.d7 = new SummaryRowSection();
        this.at = new ColumnController(this.cd, this.fd, runOn(this, this.mn));
        let a = this.at.h;
        a.collectionChanged = delegateCombine(a.collectionChanged, runOn(this, this.lv));
        this.c9 = new DataAdapter(this.at);
        this.dk = new ResponsiveStatesCollection();
        this.di = new ResponsiveEngine(this);
        this.di.g = this.dk;
        this.fj = this.gj();
        this.fx = this.gk();
        this.dx = new SelectionManager(this, this.b1);
        this.af = new ActivationManager(this, this.b1);
        this.x.af(runOn(this, this.oq));
        this.ab.af(runOn(this, this.or));
        this.cs.an(runOn(this, this.op));
        let b = this.cp;
        b.collectionChanged = delegateCombine(b.collectionChanged, runOn(this, this.oo));
        this.w.af(runOn(this, this.n4));
        this.aa.af(runOn(this, this.n5));
        this.bp = new ColumnSortDescriptionCollection();
        this.ay = new ColumnGroupDescriptionCollection();
        this.bs = new ColumnSummaryDescriptionCollection();
        this.bp.l(runOn(this, this.ow));
        this.ay.l(runOn(this, this.mc));
        this.bs.l(runOn(this, this.ox));
        this.s = new FilterExpressionCollection();
        this.d1 = new SortManager(this);
    }
    get i1() {
        return this.iz;
    }
    set i1(a) {
        this.iz = a;
    }
    get propertySetter() {
        return this._propertySetter;
    }
    set propertySetter(a) {
        this._propertySetter = a;
    }
    get externalGrid() {
        return this.de;
    }
    set externalGrid(a) {
        this.de = a;
        if (this.au != null) {
            this.au.i = this.de;
        }
    }
    get dragger() {
        return this.dc;
    }
    set dragger(a) {
        if (this.dc != null) {
            let b = this.dc;
            b.onDrag = delegateRemove(b.onDrag, runOn(this, this.ni));
            let c = this.dc;
            c.onDragEnd = delegateCombine(c.onDragEnd, runOn(this, this.nk));
        }
        this.dc = a;
        let d = this.dc;
        d.onDrag = delegateCombine(d.onDrag, runOn(this, this.ni));
        let e = this.dc;
        e.onDragEnd = delegateCombine(e.onDragEnd, runOn(this, this.nk));
    }
    m5(a) {
        if (this.columnExchangingAnimationCompleted != null) {
            this.columnExchangingAnimationCompleted(a.externalObject, new EventArgs());
        }
    }
    m4(a) {
        if (this.columnExchangingAnimationCanceled != null) {
            this.columnExchangingAnimationCanceled(a.externalObject, new EventArgs());
        }
    }
    m(a) {
        let b = this.as(a.i);
        if (b == null) {
            return null;
        }
        return b.d1;
    }
    n(a) {
        let b = this.as(a.i);
        if (b == null) {
            return 11;
        }
        if (this.actualDataSource == null) {
            return 11;
        }
        return this.actualDataSource.resolveSchemaPropertyType(b.gb);
    }
    ne(a) {
        if (this.columnShowingAnimationCompleted != null) {
            this.columnShowingAnimationCompleted(a.externalObject, new EventArgs());
        }
    }
    l5(a, b) {
        let c = this.as(a.i);
        if (c == null) {
            return;
        }
        if (!Base.equalsStatic(c.d1, b)) {
            c.d1 = b;
            if (this.filterExpressionsChanging != null) {
                this.filterExpressionsChanging(this, ((() => {
                    let $ret = new GridFilterExpressionsEventArgs();
                    $ret.a = this.t;
                    return $ret;
                })()));
            }
        }
    }
    l4(a, b) {
        let c = this.as(a.i);
        if (c == null) {
            return;
        }
        if (!Base.equalsStatic(c.d1, b)) {
            c.d1 = b;
        }
        if (this.filterExpressionsChanged != null) {
            this.filterExpressionsChanged(this, ((() => {
                let $ret = new GridFilterExpressionsEventArgs();
                $ret.a = this.t;
                return $ret;
            })()));
        }
    }
    nd(a) {
        if (this.columnShowingAnimationCanceled != null) {
            this.columnShowingAnimationCanceled(a.externalObject, new EventArgs());
        }
    }
    nb(a) {
        if (this.columnMovingAnimationCompleted != null) {
            this.columnMovingAnimationCompleted(a.externalObject, new EventArgs());
        }
    }
    na(a) {
        if (this.columnMovingAnimationCanceled != null) {
            this.columnMovingAnimationCanceled(a.externalObject, new EventArgs());
        }
    }
    m7(a) {
        if (this.columnHidingAnimationCompleted != null) {
            this.columnHidingAnimationCompleted(a.externalObject, new EventArgs());
        }
    }
    m6(a) {
        if (this.columnHidingAnimationCanceled != null) {
            this.columnHidingAnimationCanceled(a.externalObject, new EventArgs());
        }
    }
    mz(a) {
        if (this.cellPreviewPointerDown != null) {
            this.cellPreviewPointerDown(a, ((() => {
                let $ret = new GridCellEventArgs();
                $ret.cellInfo = a;
                $ret.grid = this;
                return $ret;
            })()));
        }
    }
    m0(a) {
        if (this.cellPreviewPointerUp != null) {
            this.cellPreviewPointerUp(a, ((() => {
                let $ret = new GridCellEventArgs();
                $ret.cellInfo = a;
                $ret.grid = this;
                return $ret;
            })()));
        }
    }
    mx(a) {
        if (this.cellPointerDown != null) {
            this.cellPointerDown(a, ((() => {
                let $ret = new GridCellEventArgs();
                $ret.cellInfo = a;
                $ret.grid = this;
                return $ret;
            })()));
        }
    }
    my(a) {
        if (this.cellPointerUp != null) {
            this.cellPointerUp(a, ((() => {
                let $ret = new GridCellEventArgs();
                $ret.cellInfo = a;
                $ret.grid = this;
                return $ret;
            })()));
        }
    }
    nw(a, b) {
        this.mg(a);
    }
    no(a) {
        if (a.t == 2) {
            this.o1(a.i.s);
        }
    }
    o1(a) {
        let b = !this.actualDataSource.getIsRowExpandedAtIndex(a);
        this.actualDataSource.setIsRowExpandedAtIndex(a, b);
        let c = this.actualDataSource.getRowLevel(a);
        if (a < this.model.aw.s) {
            this.on(a - c);
        }
    }
    ms(a, b, c) {
        this.externalGrid.focusScroller();
        if (a.t == 0 && this.c4 != 4) {
            this.d1.d(this.as(a.i));
        }
        if (this.cz == 5) {
            if (a.i.ab && !a.i.ah) {
                if (this.cx == 1) {
                    if (b) {
                        this.n8(a.i.s, a.i.al);
                    }
                    else {
                        if (c && this.ao != null) {
                            let d = a.i.al;
                            let e = a.i.s;
                            this.cq.remove(this.ao);
                            this.lx(Math.min(this.ao.k, d), Math.max(this.ao.k, d), Math.min(this.ao.l, e), Math.max(this.ao.l, e));
                        }
                        else {
                            this.oc();
                            this.lx(a.i.al, a.i.al, a.i.s, a.i.s);
                        }
                    }
                }
                else if (this.cx == 0) {
                    this.n8(a.i.s, a.i.al);
                }
            }
        }
        else {
            if (this.cx == 0) {
                this.dx.an(a);
            }
            else if (this.cx == 1) {
                if (b) {
                    this.dx.an(a);
                }
                else {
                    this.dx.am(a);
                }
            }
        }
        if (this.by == 1) {
            this.af.x(a);
        }
        if (this.cellClicked != null) {
            this.cellClicked(a, ((() => {
                let $ret = new GridCellEventArgs();
                $ret.cellInfo = a;
                $ret.grid = this;
                return $ret;
            })()));
        }
    }
    n8(a, b) {
        let c = false;
        for (let d = 0; d < this.cq.count; d++) {
            let e = this.cq._inner[d];
            if (e.k == b && e.i == b && e.l == a && e.j == a) {
                this.od(this.cq._inner[d]);
                c = true;
                break;
            }
        }
        if (!c) {
            this.lx(b, b, a, a);
        }
    }
    get bg() {
        return this.bf;
    }
    set bg(a) {
        let b = this.bf;
        this.bf = a;
        if (b != this.bf) {
            this.nt("ColumnResizingMode", enumGetBox(ColumnResizingMode_$type, b), enumGetBox(ColumnResizingMode_$type, this.bf));
        }
    }
    get a7() {
        return this.a6;
    }
    set a7(a) {
        let b = this.a6;
        this.a6 = a;
        if (b != this.a6) {
            this.nt("ColumnMovingMode", enumGetBox(ColumnMovingMode_$type, b), enumGetBox(ColumnMovingMode_$type, this.a6));
        }
    }
    mv(a, b, c) {
        this.am = a.i.w();
        this.qm = { $type: Point_$type, x: b, y: c };
        this.ev = a.ar && a.as;
        if (this.bg != 2 && this.am.f) {
            let d = this.au.h._inner[a.i.al];
            if (d.e2) {
                let e = this.model.a9._inner[this.am.al];
                this.g3 = e.j;
                this.g4 = this.model.actualVisibleRegion.left;
                this.g5 = this.model.actualVisibleRegion.top;
                let f = this.dragger.view.transformPoint(b, c);
                this.iq = truncate((f.x + this.g4)) - (intDivide(this.h3, 2));
                this.gv = -1;
                this.externalGrid.setResizeCursor();
                this.dragger.dragStart(b, c, this.model.actualVisibleRegion.x, this.model.actualVisibleRegion.y, 1, this.am, false);
                if (this.bg == 0) {
                    this.n9();
                }
            }
        }
    }
    mw(a, b, c) {
        this.am = null;
    }
    mu(a, b, c) {
        let d = 0;
        for (let e = 0; e < this.model.a9.count; e++) {
            let f = this.model.a9._inner[e];
            d += f.j;
        }
        let g = this.dragger.view.transformPoint(b, c);
        if (!this.dragger.isDragActive && g.x >= d) {
            this.externalGrid.setDefaultCursor();
        }
    }
    ns(a, b, c) {
        if (!this.dragger.isDragActive) {
            if (a.i.f && this.bg != 2) {
                let d = this.au.h._inner[a.i.al];
                if (d.e2) {
                    this.externalGrid.setResizeCursor();
                }
            }
            else {
                this.externalGrid.setDefaultCursor();
            }
        }
        else if (this.dragger.dragType != 1 && this.dragger.dragType != 2) {
            this.externalGrid.setDefaultCursor();
        }
    }
    l0() {
        if (this.hu != -1) {
            this.eo.teardownTicking(this.hu);
            this.hu = -1;
        }
    }
    nn(a, b, c, d) {
        this.g4 = this.model.actualVisibleRegion.left;
        this.g5 = this.model.actualVisibleRegion.top;
        if (!this.dragger.isDragActive && a.e && !a.f && this.a7 != 1) {
            let e = this.as(a);
            if (e != null && e.e0) {
                this.externalGrid.ensureColumnsAreManual();
            }
            this.externalGrid.setHandCursor();
            this.dragger.dragStart(b, c, this.model.actualVisibleRegion.x, this.model.actualVisibleRegion.y, 2, a, d);
        }
        else if (this.cz == 5 && a.ab && !a.ah) {
            if (!d) {
                this.oc();
            }
            this.hy = a.s;
            this.hx = a.al;
            this.e8 = this.ev;
            if (this.by == 1) {
                this.af.w(a);
            }
            this.dragger.dragStart(b, c, this.model.actualVisibleRegion.x, this.model.actualVisibleRegion.y, 0, a, d);
        }
    }
    nk(a, b) {
        this.l0();
        this.an = null;
        this.aj = null;
        this.hq = -1;
        this.am = null;
        if (this.dragger.dragType == 1) {
            this.externalGrid.setDefaultCursor();
            if (this.bg == 0) {
                if (this.gv != -1) {
                    let c = this.model.a9._inner[this.dragger.cellPath.al];
                    this.b1.ah(this, this.cc, c, this.gv);
                }
                else {
                    this.renderingEngine.refresh(this.model, false);
                }
            }
        }
        else if (this.dragger.dragType == 2) {
            this.externalGrid.setDefaultCursor();
            if (this.a7 == 0) {
                let d = true;
                if (this.hz != -1 && this.hz != this.dragger.cellPath.al) {
                    if (this.hz > this.dragger.cellPath.al) {
                        let e = this.columns._inner[this.hz - 1];
                        this.mk(this.dragger.cellPath.al, this.hz);
                        d = false;
                    }
                    else {
                        let f = this.columns._inner[this.hz];
                        this.mk(this.dragger.cellPath.al, this.hz);
                        d = false;
                    }
                }
                if (d) {
                    this.n9();
                }
                this.hz = -1;
            }
        }
    }
    ni(a, b) {
        this.gx = b.startX;
        this.gy = b.startY;
        this.gz = b.currentX;
        this.g0 = b.currentY;
        switch (this.dragger.dragType) {
            case 0:
                this.nm(false);
                break;
            case 1:
                this.nl();
                break;
            case 2:
                this.nj(false);
                break;
        }
    }
    get iq() {
        return this.hq;
    }
    set iq(a) {
        if (this.hq != a) {
            this.hq = a;
        }
    }
    nj(a) {
        let b = this.gz + this.model.actualVisibleRegion.x;
        if (a || !this.fe(b, NaN)) {
            let c = this.dragger.cellPath.al;
            let d = this.iq;
            for (let e = 0; e < this.model.a9.count; e++) {
                let f = this.model.a9._inner[e].k;
                let g = this.model.a9._inner[e].k + this.model.a9._inner[e].j;
                let h = this.model.a9._inner[e].k + (intDivide(this.model.a9._inner[e].j, 2));
                if (b > f && b <= h) {
                    d = f - (e > 0 ? (intDivide(this.h1, 2)) : 0);
                    if (e != c) {
                        c = e < this.dragger.cellPath.al ? e : e - 1;
                    }
                    break;
                }
                else if (b > h && b < g) {
                    d = g - (e < this.model.a9.count - 1 ? (intDivide(this.h1, 2)) : this.h1);
                    if (e != c) {
                        c = e < this.dragger.cellPath.al ? e + 1 : e;
                    }
                    break;
                }
            }
            if (d != this.iq) {
                let i = this.iq;
                this.iq = d;
                if (i == -1) {
                    this.renderingEngine.invalidateVisibility(() => this.d9.n(this));
                    this.renderingEngine.refresh(this.model, true);
                }
                else {
                    if (this.aj == null) {
                        this.aj = this.cn.c(new CellPath(1, -400, 0, -102), this.model);
                    }
                    this.aj.br = this.iq;
                    this.renderingEngine.refresh(this.model, false);
                }
                this.hz = c;
            }
        }
    }
    nl() {
        let a = this.au.f(this.dragger.cellPath);
        if (this.aj == null) {
            this.aj = this.cn.c(new CellPath(1, -400, 0, -102), this.model);
        }
        let b = (this.gz + this.model.actualVisibleRegion.x) - this.gx;
        let c = isNaN_(a.e5) ? isNaN_(this.g9) ? 5 : this.g9 : a.e5;
        this.gv = Math.max(this.g3 + b, c);
        if (this.bg == 0) {
            this.iq = truncate((this.gx - this.g3 + this.gv)) - (intDivide(this.h3, 2));
            if (this.aj != null) {
                this.aj.br = this.iq;
                this.renderingEngine.refresh(this.model, false);
            }
        }
        else {
            let d = ((() => {
                let $ret = new ColumnWidth();
                $ret.f = this.gv;
                $ret.c = false;
                return $ret;
            })());
            if (!isNaN_(a.e5)) {
                d.e = a.e5;
            }
            a.width = d;
        }
    }
    nm(a) {
        if (a || !this.fe(this.gz + this.model.actualVisibleRegion.x, this.g0 + this.model.actualVisibleRegion.y)) {
            let b = this.qo(this.gx, this.gy, this.gz, this.g0);
            let c = this.ap(b, this.hy, this.hx, this.e8);
            if (this.an == null) {
                this.an = c;
                this.lw(this.an);
            }
            else {
                this.o3(c);
            }
        }
    }
    qo(a, b, c, d) {
        c += this.model.actualVisibleRegion.x;
        d += this.model.actualVisibleRegion.y;
        return new Rect(0, Math.min(a, c), Math.min(b, d), Math.abs(c - a), Math.abs(d - b));
    }
    al(a, b) {
        if (this.ea == null) {
            return null;
        }
        return this.ea.d(a, b);
    }
    ap(a, b, c, d) {
        let e = this.model.ab.q;
        let f = this.model.ah.q;
        let g = this.model.ak.q;
        let h = new List$1(CellModel.$, 1, f);
        h.o(e);
        h.o(g);
        let i = b;
        let j = c;
        for (let k = 0; k < h.count; k++) {
            let l = h._inner[k];
            if (!l.i.ab || l.i.ah) {
                continue;
            }
            if (this.cz == 5) {
                if (d) {
                    if (!l.ar || (l.ar && !l.as)) {
                        continue;
                    }
                }
                else {
                    if (l.ar && l.as) {
                        continue;
                    }
                }
                let m = new Rect(0, l.br, l.bs, l.e2, l.dt);
                if (a.intersectsWith(m)) {
                    let n = Math.abs(l.i.s - b);
                    let o = Math.abs(Math.max(0, l.i.al) - c);
                    let p = Math.abs(i - b);
                    let q = Math.abs(j - c);
                    if (n > p) {
                        i = l.i.s;
                    }
                    if (o > q && !l.i.ah) {
                        j = l.i.al;
                    }
                }
            }
        }
        let r = new CellRange();
        r.k = Math.min(c, j);
        r.i = Math.max(c, j);
        r.l = Math.min(b, i);
        r.j = Math.max(b, i);
        return r;
    }
    fe(a, b) {
        let c = 20;
        let d = 20;
        let e = new Rect(0, this.model.actualVisibleRegion.x + d, this.model.actualVisibleRegion.y + c, this.model.actualVisibleRegion.width - d * 2, this.model.actualVisibleRegion.height - c * 2);
        let f = 5;
        let g = 1000;
        let h = 5;
        let i = 1000;
        if (!this.e8 && !isNaN_(b)) {
            if (b > e.bottom) {
                let j = b - e.bottom;
                this.g6 = Math.min(j * f, g);
                this.e3 = true;
            }
            else if (b < e.top) {
                let k = e.top - b;
                this.g6 = -Math.min(k * f, g);
                this.e3 = true;
            }
            else {
                this.g6 = 0;
                this.e3 = false;
            }
        }
        if (a > e.right) {
            let l = a - e.right;
            this.g1 = Math.min(l * h, i);
            this.e2 = true;
        }
        else if (a < e.left) {
            let m = e.left - a;
            this.g1 = -Math.min(m * h, i);
            this.e2 = true;
        }
        else {
            this.g1 = 0;
            this.e2 = false;
        }
        if ((this.e3 || this.e2) && this.hu == -1) {
            this.gs = dateNow();
            this.hu = this.eo.setupTicking(runOn(this, this.l8));
            this.eo.requestFrame(this.hu);
        }
        if (!this.e3 && !this.e2) {
            this.l0();
        }
        return this.e2 || this.e3;
    }
    l8() {
        let a = dateNow();
        let b = timeSpanTotalSeconds((+a - +(this.gs)));
        this.gs = a;
        this.g4 = Math.max(this.g4 + this.g1 * b, 0);
        this.g5 = Math.max(this.g5 + this.g6 * b, 0);
        if (this.model.absoluteWidth > 0 && this.model.actualVisibleRegion.width > 0 && this.g4 + this.model.actualVisibleRegion.width > this.model.absoluteWidth) {
            this.g4 = Math.round(this.model.absoluteWidth - this.model.actualVisibleRegion.width);
        }
        if (this.model.absoluteHeight > 0 && this.model.actualVisibleRegion.height > 0 && this.g5 + this.model.actualVisibleRegion.height > this.model.absoluteHeight) {
            this.g5 = Math.round(this.model.absoluteHeight - this.model.actualVisibleRegion.height);
        }
        this.viewportManager.moveViewportTo(truncate(this.g4), truncate(this.g5));
        switch (this.dragger.dragType) {
            case 0:
                this.nm(true);
                break;
            case 1:
                this.nl();
                break;
            case 2:
                this.nj(true);
                break;
        }
        this.eo.requestFrame(this.hu);
    }
    o3(a) {
        if (a.k != this.an.k || a.i != this.an.i || a.l != this.an.l || a.j != this.an.j) {
            this.an.k = a.k;
            this.an.i = a.i;
            this.an.l = a.l;
            this.an.j = a.j;
            this.fc = true;
            this.dx.at();
            this.fc = false;
            this.ml(this.an);
        }
    }
    og(a) {
        if (this.actualDataSource != null && this.actualDataSource.actualSchema != null) {
            a.g = this.actualDataSource.resolveSchemaPropertyType(a.f);
            a.i = true;
        }
    }
    oh(a) {
        if (this.actualDataSource != null && this.actualDataSource.actualSchema != null) {
            a.a = this.actualDataSource.resolveSchemaPropertyType(a.t);
            a.i = true;
        }
    }
    ox(a, b) {
        switch (b.action) {
            case 0:
                if (b.newItems != null) {
                    for (let c = 0; c < b.newItems.count; c++) {
                        let d = b.newItems.item(c);
                        if (!d.i) {
                            this.oh(d);
                        }
                    }
                }
                break;
        }
    }
    mc(a, b) {
        switch (b.action) {
            case 0:
                if (b.newItems != null) {
                    for (let c = 0; c < b.newItems.count; c++) {
                        let d = b.newItems.item(c);
                        if (!d.i) {
                            this.og(d);
                        }
                    }
                }
                break;
        }
        if (this.groupDescriptionsChanged != null) {
            this.groupDescriptionsChanged(this, ((() => {
                let $ret = new GridGroupDescriptionsChangedEventArgs();
                $ret.groupDescriptions = this.az;
                return $ret;
            })()));
        }
    }
    ow(a, b) {
        this.fy = true;
        try {
            switch (b.action) {
                case 0:
                    if (b.newItems != null) {
                        for (let c = 0; c < b.newItems.count; c++) {
                            let d = b.newItems.item(c);
                            this.o0(d.f, this.br(d.c));
                        }
                    }
                    break;
                case 1:
                    if (b.oldItems != null) {
                        for (let e = 0; e < b.oldItems.count; e++) {
                            let f = b.oldItems.item(e);
                            this.o0(f.f, 0);
                        }
                    }
                    break;
                case 2:
                    if (b.oldItems != null) {
                        for (let g = 0; g < b.oldItems.count; g++) {
                            let h = b.oldItems.item(g);
                            this.o0(h.f, 0);
                        }
                    }
                    if (b.newItems != null) {
                        for (let i = 0; i < b.newItems.count; i++) {
                            let j = b.newItems.item(i);
                            this.o0(j.f, this.br(j.c));
                        }
                    }
                    break;
                case 4:
                    for (let k of fromEnum(this.columns)) {
                        k.eb = 0;
                    }
                    break;
            }
            if (this.sortDescriptionsChanged != null) {
                this.sortDescriptionsChanged(this, ((() => {
                    let $ret = new GridSortDescriptionsChangedEventArgs();
                    $ret.sortDescriptions = this.bq;
                    return $ret;
                })()));
            }
        }
        finally {
            this.fy = false;
        }
    }
    o0(a, b) {
        for (let c = 0; c < this.columns.count; c++) {
            if (this.columns._inner[c].gb == a) {
                this.columns._inner[c].eb = b;
            }
        }
    }
    br(a) {
        switch (a) {
            case 0: return 1;
            case 1: return 2;
        }
        return 0;
    }
    oq(a, b) {
        if (!this.fg && this.actualDataSource != null) {
            if (!this.fa) {
                this.fa = true;
                switch (b.action) {
                    case 0:
                        if (b.newItems != null) {
                            for (let c = 0; c < b.newItems.count; c++) {
                                let d = this.da.getItemKey(this.g(), b.newItems.item(c));
                                this.ad.ae.insert(c + b.newStartingIndex, d);
                            }
                        }
                        break;
                    case 1:
                        if (b.oldItems != null) {
                            for (let e = 0; e < b.oldItems.count; e++) {
                                this.ad.ae.removeAt(b.oldStartingIndex);
                            }
                        }
                        break;
                    case 2:
                        if (b.oldItems != null) {
                            for (let f = 0; f < b.oldItems.count; f++) {
                                this.ad.ae.removeAt(b.oldStartingIndex);
                            }
                        }
                        if (b.newItems != null) {
                            for (let g = 0; g < b.newItems.count; g++) {
                                let h = this.da.getItemKey(this.g(), b.newItems.item(g));
                                this.ad.ae.insert(g + b.newStartingIndex, h);
                            }
                        }
                        break;
                    case 4:
                        this.ad.clear();
                        for (let i of fromEnum(this.z.ae)) {
                            let j = this.da.getItemKey(this.g(), i);
                            this.ad.add(j);
                        }
                        break;
                }
                this.dx.av();
                this.fa = false;
            }
        }
    }
    or(a, b) {
        if (!this.fg && this.actualDataSource != null) {
            if (!this.fa) {
                this.fa = true;
                switch (b.action) {
                    case 0:
                        if (b.newItems != null) {
                            for (let c = 0; c < b.newItems.count; c++) {
                                let d = this.da.getItemForKey(b.newItems.item(c));
                                this.z.ae.insert1(c + b.newStartingIndex, d);
                            }
                        }
                        break;
                    case 1:
                        if (b.oldItems != null) {
                            for (let e = 0; e < b.oldItems.count; e++) {
                                this.z.ae.removeAt(b.oldStartingIndex);
                            }
                        }
                        break;
                    case 2:
                        if (b.oldItems != null) {
                            for (let f = 0; f < b.oldItems.count; f++) {
                                this.z.ae.removeAt(b.oldStartingIndex);
                            }
                        }
                        if (b.newItems != null) {
                            for (let g = 0; g < b.newItems.count; g++) {
                                let h = this.da.getItemForKey(b.newItems.item(g));
                                this.z.ae.insert1(g + b.newStartingIndex, h);
                            }
                        }
                        break;
                    case 4:
                        this.z.clear();
                        for (let i of fromEnum(this.ad.ae)) {
                            let j = this.da.getItemForKey(i);
                            this.z.add1(j);
                        }
                        break;
                }
                this.dx.av();
                this.fa = false;
            }
        }
    }
    op(a, b) {
        switch (b.action) {
            case 0:
            case 2:
                for (let c = 0; c < b.newItems.count; c++) {
                    (typeCast(CellKey.$, b.newItems.item(c))).d = this;
                }
                break;
        }
        if (!this.fg) {
            this.fc = true;
            this.dx.au();
            this.fc = false;
        }
    }
    oo(a, b) {
        this.fc = true;
        this.dx.at();
        this.fc = false;
    }
    n4(a, b) {
        if (!this.ff && this.actualDataSource != null) {
            if (!this.e9) {
                this.e9 = true;
                switch (b.action) {
                    case 0:
                        if (b.newItems != null) {
                            for (let c = 0; c < b.newItems.count; c++) {
                                let d = this.da.getItemKey(this.g(), b.newItems.item(c));
                                this.ac.ae.insert(c + b.newStartingIndex, d);
                                this.da.pinRow(d);
                            }
                        }
                        break;
                    case 1:
                        if (b.oldItems != null) {
                            for (let e = 0; e < b.oldItems.count; e++) {
                                this.da.unpinRow(this.ac.ae._inner[b.oldStartingIndex]);
                                this.ac.ae.removeAt(b.oldStartingIndex);
                            }
                        }
                        break;
                    case 2:
                        if (b.oldItems != null) {
                            for (let f = 0; f < b.oldItems.count; f++) {
                                this.da.unpinRow(this.ac.ae._inner[b.oldStartingIndex]);
                                this.ac.ae.removeAt(b.oldStartingIndex);
                            }
                        }
                        if (b.newItems != null) {
                            for (let g = 0; g < b.newItems.count; g++) {
                                let h = this.da.getItemKey(this.g(), b.newItems.item(g));
                                this.ac.ae.insert(g + b.newStartingIndex, h);
                                this.da.pinRow(h);
                            }
                        }
                        break;
                    case 4:
                        this.ac.clear();
                        this.da.clearPinnedRows();
                        for (let i of fromEnum(this.y.ae)) {
                            let j = this.da.getItemKey(this.g(), i);
                            this.ac.add(j);
                            this.da.pinRow(j);
                        }
                        break;
                }
                this.e9 = false;
            }
        }
    }
    n5(a, b) {
        if (!this.ff && this.actualDataSource != null) {
            if (!this.e9) {
                this.e9 = true;
                switch (b.action) {
                    case 0:
                        if (b.newItems != null) {
                            for (let c = 0; c < b.newItems.count; c++) {
                                let d = this.da.getItemForKey(b.newItems.item(c));
                                this.y.ae.insert1(c + b.newStartingIndex, d);
                                this.da.pinRow(b.newItems.item(c));
                            }
                        }
                        break;
                    case 1:
                        if (b.oldItems != null) {
                            for (let e = 0; e < b.oldItems.count; e++) {
                                this.da.unpinRow(b.oldItems.item(e));
                                this.y.ae.removeAt(b.oldStartingIndex);
                            }
                        }
                        break;
                    case 2:
                        if (b.oldItems != null) {
                            for (let f = 0; f < b.oldItems.count; f++) {
                                this.da.unpinRow(b.oldItems.item(f));
                                this.y.ae.removeAt(b.oldStartingIndex);
                            }
                        }
                        if (b.newItems != null) {
                            for (let g = 0; g < b.newItems.count; g++) {
                                let h = this.da.getItemForKey(b.newItems.item(g));
                                let i = this.da.indexOfKey(b.newItems.item(g));
                                this.y.ae.insert1(g + b.newStartingIndex, h);
                                this.da.pinRow(b.newItems.item(g));
                            }
                        }
                        break;
                    case 4:
                        this.y.clear();
                        this.da.clearPinnedRows();
                        for (let j of fromEnum(this.ac.ae)) {
                            let k = this.da.getItemForKey(j);
                            this.y.add1(k);
                            this.da.pinRow(j);
                        }
                        break;
                }
                this.e9 = false;
            }
        }
    }
    get b1() {
        return this.b0;
    }
    set b1(a) {
        this.b0 = a;
    }
    get delayedExecutionManager() {
        return this._delayedExecutionManager;
    }
    set delayedExecutionManager(a) {
        this._delayedExecutionManager = a;
    }
    get dj() {
        return this.di;
    }
    get da() {
        return this.c9;
    }
    set da(a) {
        this.c9 = a;
    }
    get au() {
        return this.at;
    }
    set au(a) {
        this.at = a;
    }
    get cn() {
        return this.cm;
    }
    set cn(a) {
        this.cm = a;
    }
    get d3() {
        return this.d2;
    }
    set d3(a) {
        this.d2 = a;
    }
    get ci() {
        return this.ch;
    }
    set ci(a) {
        this.ch = a;
    }
    get dx() {
        return this.dw;
    }
    set dx(a) {
        this.dw = a;
    }
    get af() {
        return this.ae;
    }
    set af(a) {
        this.ae = a;
    }
    get d1() {
        return this.d0;
    }
    set d1(a) {
        this.d0 = a;
    }
    get tickProvider() {
        return this.eo;
    }
    set tickProvider(a) {
        this.eo = a;
        this.ch = new GridEffectManager(this.eo, this);
    }
    get dv() {
        return this.du;
    }
    set dv(a) {
        let b = this.du;
        this.du = a;
        if (this.du == null) {
            this.du = new SectionHeader();
        }
        this.du.grid = this;
        if (b != this.du) {
            this.nt("SectionHeader", b, this.du);
        }
    }
    get dt() {
        return this.ds;
    }
    set dt(a) {
        this.ds = a;
    }
    get d5() {
        return this.d4;
    }
    set d5(a) {
        let b = this.d4;
        this.d4 = a;
        if (this.d4 == null) {
            this.d4 = new SummaryRowRoot();
        }
        this.d4.grid = this;
        if (b != this.d4) {
            this.nt("SummaryRowRoot", b, this.d4);
        }
    }
    get d7() {
        return this.d6;
    }
    set d7(a) {
        let b = this.d6;
        this.d6 = a;
        if (this.d6 == null) {
            this.d6 = new SummaryRowSection();
        }
        this.d6.grid = this;
        if (b != this.d6) {
            this.nt("SummaryRowSection", b, this.d6);
        }
    }
    get dr() {
        return this.dq;
    }
    set dr(a) {
        let b = this.dq;
        this.dq = a;
        if (b != this.dq) {
            this.nt("RowSeparator", b, this.dq);
        }
    }
    get c6() {
        return this.c5;
    }
    set c6(a) {
        let b = this.c5;
        this.c5 = a;
        if (b != this.c5) {
            this.nt("HeaderSeparator", b, this.c5);
        }
    }
    get bi() {
        return this.bh;
    }
    set bi(a) {
        let b = this.bh;
        this.bh = a;
        if (b != this.bh) {
            this.nt("ColumnResizingSeparator", b, this.bh);
        }
    }
    get a9() {
        return this.a8;
    }
    set a9(a) {
        let b = this.a8;
        this.a8 = a;
        if (b != this.a8) {
            this.nt("ColumnMovingSeparator", b, this.a8);
        }
    }
    get e() {
        return this.b;
    }
    set e(a) {
        let b = this.b;
        this.b = a;
        if (b != this.b) {
            this.nt("RowSeparator", b, this.b);
        }
    }
    get d9() {
        return this.d8;
    }
    set d9(a) {
        this.d8 = a;
    }
    get viewportManager() {
        return this._viewportManager;
    }
    set viewportManager(a) {
        this._viewportManager = a;
    }
    get g8() {
        return this.gu;
    }
    set g8(a) {
        this.gu = a;
    }
    get g7() {
        return this.gt;
    }
    set g7(a) {
        this.gt = a;
    }
    get ir() {
        return this.hr;
    }
    set ir(a) {
        let b = this.hr;
        this.hr = a;
        if (b != this.hr) {
            this.nt("RowHeight", b, this.hr);
        }
    }
    get defaultColumnWidth() {
        return this.bu;
    }
    set defaultColumnWidth(a) {
        let b = this.bu;
        this.bu = a;
        if (b != this.bu) {
            this.nt("DefaultColumnWidth", b, this.bu);
        }
    }
    get g9() {
        return this.gw;
    }
    set g9(a) {
        let b = this.gw;
        this.gw = a;
        if (b != this.gw) {
            this.nt("DefaultColumnMinWidth", b, this.gw);
        }
    }
    get ik() {
        return this.hm;
    }
    set ik(a) {
        let b = this.hm;
        this.hm = a;
        if (b != this.hm) {
            this.nt("HeaderHeight", b, this.hm);
        }
    }
    get ix() {
        return this.hw;
    }
    set ix(a) {
        let b = this.hw;
        this.hw = a;
        if (b != this.hw) {
            this.nt("SectionHeaderHeight", b, this.hw);
        }
    }
    get itemsSource() {
        return this.gq;
    }
    set itemsSource(a) {
        let b = this.gq;
        this.gq = a;
        if (b != this.gq) {
            this.nt("ItemsSource", b, this.gq);
        }
    }
    get iv() {
        return this.hv;
    }
    set iv(a) {
        let b = this.hv;
        this.hv = a;
        if (b != this.hv) {
            this.nt("SectionFooterHeight", b, this.hv);
        }
    }
    get iu() {
        return this.ht;
    }
    set iu(a) {
        let b = this.ht;
        this.ht = a;
        if (b != this.ht) {
            this.nt("RowSpacingHeight", b, this.ht);
        }
    }
    get h4() {
        return this.hl;
    }
    set h4(a) {
        let b = this.hl;
        this.hl = a;
        if (b != this.hl) {
            this.nt("ColumnSpacingWidth", b, this.hl);
        }
    }
    get c4() {
        return this.c3;
    }
    set c4(a) {
        let b = this.c3;
        this.c3 = a;
        if (b != this.c3) {
            this.nt("HeaderClickAction", enumGetBox(HeaderClickAction_$type, b), enumGetBox(HeaderClickAction_$type, this.c3));
            if ((this.c3 == 0 || this.c3 == 2) && (b == 1 || b == 3)) {
                this.d1.h();
            }
        }
    }
    get fd() {
        return this.er;
    }
    set fd(a) {
        let b = this.er;
        this.er = a;
        if (b != this.er) {
            this.nt("AutoGenerateColumns", b, this.er);
        }
    }
    get it() {
        return this.hs;
    }
    set it(a) {
        let b = this.hs;
        this.hs = a;
        if (b != this.hs) {
            this.nt("RowSeparatorHeight", b, this.hs);
        }
    }
    get fz() {
        return this.e1;
    }
    set fz(a) {
        let b = this.e1;
        this.e1 = a;
        if (b != this.e1) {
            this.nt("IsPlaceholderRenderingEnabled", b, this.e1);
        }
    }
    fk(a) {
        return this.bn(a) != 1 && this.fl;
    }
    bn(a) {
        if (this.bj == 0) {
            return a.d9();
        }
        return this.bj;
    }
    get bl() {
        return this.bj;
    }
    set bl(a) {
        let b = this.bj;
        this.bj = a;
        this.nt("ColumnAddingAnimationMode", enumGetBox(ColumnShowingAnimationMode_$type, b), enumGetBox(ColumnShowingAnimationMode_$type, this.bj));
    }
    get fp() {
        return this.ba != 1 && this.fl;
    }
    get columnPropertyUpdatingAnimationMode() {
        return this.ba;
    }
    set columnPropertyUpdatingAnimationMode(a) {
        let b = this.ba;
        this.ba = a;
        this.nt("ColumnPropertyUpdatingAnimationMode", enumGetBox(ColumnPropertyUpdatingAnimationMode_$type, b), enumGetBox(ColumnPropertyUpdatingAnimationMode_$type, this.ba));
    }
    get fl() {
        return this.renderingEngine.initialRefreshFinished;
    }
    get fh() {
        return this.ag != 1;
    }
    get ah() {
        return this.ag;
    }
    set ah(a) {
        let b = this.ag;
        this.ag = a;
        this.nt("CellDataLoadedAnimationMode", enumGetBox(CellDataLoadedAnimationMode_$type, b), enumGetBox(CellDataLoadedAnimationMode_$type, this.ag));
    }
    get f4() {
        return this.dn != 1;
    }
    get dp() {
        return this.dn;
    }
    set dp(a) {
        let b = this.dn;
        this.dn = a;
        this.nt("RowSelectionAnimationMode", enumGetBox(RowSelectionAnimationMode_$type, b), enumGetBox(RowSelectionAnimationMode_$type, this.dn));
    }
    get fi() {
        return this.aq != 1;
    }
    get ar() {
        return this.aq;
    }
    set ar(a) {
        let b = this.aq;
        this.aq = a;
        this.nt("CellSelectionAnimationMode", enumGetBox(CellSelectionAnimationMode_$type, b), enumGetBox(CellSelectionAnimationMode_$type, this.aq));
    }
    get cc() {
        return this.cb;
    }
    set cc(a) {
        let b = this.cb;
        this.cb = a;
        if (b != this.cb) {
            this.nt("ColumnAnimationSettings", b, this.cb);
        }
    }
    get b3() {
        return this.b2;
    }
    set b3(a) {
        let b = this.b2;
        this.b2 = a;
        if (b != this.b2) {
            this.nt("AnimationSettings", b, this.b2);
        }
    }
    fq(a) {
        return this.be(a) != 1 && this.fl;
    }
    be(a) {
        if (this.bc == 0) {
            return a.d8();
        }
        return this.bc;
    }
    get bd() {
        return this.bc;
    }
    set bd(a) {
        let b = this.bc;
        this.bc = a;
        this.nt("ColumnResizingAnimationMode", enumGetBox(ColumnResizingAnimationMode_$type, b), enumGetBox(ColumnResizingAnimationMode_$type, this.bc));
    }
    fr(a) {
        return this.bo(a) != 1 && this.fl;
    }
    bo(a) {
        if (this.bk == 0) {
            return a.d9();
        }
        return this.bk;
    }
    get bm() {
        return this.bk;
    }
    set bm(a) {
        let b = this.bk;
        this.bk = a;
        this.nt("ColumnShowingAnimationMode", enumGetBox(ColumnShowingAnimationMode_$type, b), enumGetBox(ColumnShowingAnimationMode_$type, this.bk));
    }
    fo(a) {
        return this.a5(a) != 1 && this.fl;
    }
    a5(a) {
        if (this.a3 == 0) {
            return 2;
        }
        return this.a3;
    }
    get a4() {
        return this.a3;
    }
    set a4(a) {
        let b = this.a3;
        this.a3 = a;
        this.nt("ColumnMovingAnimationMode", enumGetBox(ColumnMovingAnimationMode_$type, b), enumGetBox(ColumnMovingAnimationMode_$type, this.a3));
    }
    fn(a) {
        return this.a2(a) != 1 && this.fl;
    }
    a2(a) {
        if (this.a0 == 0) {
            return a.d7();
        }
        return this.a0;
    }
    get a1() {
        return this.a0;
    }
    set a1(a) {
        let b = this.a0;
        this.a0 = a;
        this.nt("ColumnHidingAnimationMode", enumGetBox(ColumnHidingAnimationMode_$type, b), enumGetBox(ColumnHidingAnimationMode_$type, this.a0));
    }
    fm(a) {
        return this.ax(a) != 1 && this.fl;
    }
    ax(a) {
        if (this.av == 0) {
            return a.d6();
        }
        return this.av;
    }
    get aw() {
        return this.av;
    }
    set aw(a) {
        let b = this.av;
        this.av = a;
        this.nt("ColumnExchangingAnimationMode", enumGetBox(ColumnExchangingAnimationMode_$type, b), enumGetBox(ColumnExchangingAnimationMode_$type, this.av));
    }
    get inset() {
        return this.qp;
    }
    set inset(a) {
        let b = this.qp;
        this.qp = a;
        if (b != this.qp) {
            this.nt("Inset", b, this.qp);
        }
    }
    get cz() {
        return this.cy;
    }
    set cz(a) {
        let b = this.cy;
        this.cy = a;
        if (b != this.cy) {
            this.nt("SelectionMode", enumGetBox(GridSelectionMode_$type, b), enumGetBox(GridSelectionMode_$type, this.cy));
        }
    }
    get by() {
        return this.bx;
    }
    set by(a) {
        let b = this.bx;
        this.bx = a;
        if (b != this.bx) {
            this.nt("ActivationMode", enumGetBox(GridActivationMode_$type, b), enumGetBox(GridActivationMode_$type, this.bx));
        }
    }
    get cx() {
        return this.cw;
    }
    set cx(a) {
        let b = this.cw;
        this.cw = a;
        if (b != this.cw) {
            this.nt("SelectionBehavior", enumGetBox(GridSelectionBehavior_$type, b), enumGetBox(GridSelectionBehavior_$type, this.cw));
        }
    }
    get fg() {
        return this.et;
    }
    set fg(a) {
        this.et = a;
    }
    get z() {
        return this.x;
    }
    get ad() {
        return this.ab;
    }
    get ct() {
        return this.cs;
    }
    get cq() {
        return this.cp;
    }
    get ff() {
        return this.es;
    }
    set ff(a) {
        this.es = a;
    }
    get y() {
        return this.w;
    }
    get ac() {
        return this.aa;
    }
    oy(a, b) {
        if (this.actualDataSource == null) {
            return;
        }
        if (a.ae.count > 0 && b.ae.count == 0) {
            let c = this.g();
            for (let d of fromEnum(a.ae)) {
                let e = this.da.getItemKey(c, d);
                b.ae.add(e);
            }
        }
        else if (a.ae.count == 0 && b.ae.count > 0) {
            for (let f of fromEnum(b.ae)) {
                let g = this.da.getItemForKey(f);
                a.ae.add1(g);
            }
        }
        else {
            a.ae.clear();
            for (let h of fromEnum(b.ae)) {
                let i = this.da.getItemForKey(h);
                a.ae.add1(i);
            }
        }
    }
    get fs() {
        return this.ew;
    }
    set fs(a) {
        let b = this.ew;
        this.ew = a;
        if (b != this.ew) {
            this.nt("IsFilterUIEnabled", b, this.ew);
        }
    }
    get fv() {
        return this.ez;
    }
    set fv(a) {
        let b = this.ez;
        this.ez = a;
        if (b != this.ez) {
            this.nt("IsGroupRowSticky", b, this.ez);
        }
    }
    get fw() {
        return this.e0;
    }
    set fw(a) {
        let b = this.e0;
        this.e0 = a;
        if (b != this.e0) {
            this.nt("IsHeaderSeparatorVisible", b, this.e0);
        }
    }
    get pw() {
        return this.o5;
    }
    set pw(a) {
        let b = this.o5;
        this.o5 = a;
        if (b != this.o5) {
            this.nt("CellSelectedBackground", b, this.o5);
        }
    }
    get qb() {
        return this.pk;
    }
    set qb(a) {
        let b = this.pk;
        this.pk = a;
        if (b != this.pk) {
            this.nt("SectionHeaderSelectedBackground", b, this.pk);
        }
    }
    get qe() {
        return this.pn;
    }
    set qe(a) {
        let b = this.pn;
        this.pn = a;
        if (b != this.pn) {
            this.nt("SummaryRootBackground", b, this.pn);
        }
    }
    get qi() {
        return this.pr;
    }
    set qi(a) {
        let b = this.pr;
        this.pr = a;
        if (b != this.pr) {
            this.nt("SummarySectionBackground", b, this.pr);
        }
    }
    get ha() {
        return this.g2;
    }
    set ha(a) {
        let b = this.g2;
        this.g2 = a;
        if (b != this.g2) {
            this.nt("PinnedRowOpacity", b, this.g2);
        }
    }
    get qd() {
        return this.pm;
    }
    set qd(a) {
        let b = this.pm;
        this.pm = a;
        if (b != this.pm) {
            this.nt("StickyRowBackground", b, this.pm);
        }
    }
    get p5() {
        return this.pe;
    }
    set p5(a) {
        let b = this.pe;
        this.pe = a;
        if (b != this.pe) {
            this.nt("PinnedRowBackground", b, this.pe);
        }
    }
    get p4() {
        return this.pd;
    }
    set p4(a) {
        let b = this.pd;
        this.pd = a;
        if (b != this.pd) {
            this.nt("LastStickyRowBackground", b, this.pd);
        }
    }
    get ca() {
        return this.b9;
    }
    set ca(a) {
        let b = this.b9;
        this.b9 = a;
        if (b != this.b9) {
            this.nt("ActiveCell", b, this.b9);
        }
    }
    get pv() {
        return this.o4;
    }
    set pv(a) {
        let b = this.o4;
        this.o4 = a;
        if (b != this.o4) {
            this.nt("CellBackground", b, this.o4);
        }
    }
    get px() {
        return this.o6;
    }
    set px(a) {
        let b = this.o6;
        this.o6 = a;
        if (b != this.o6) {
            this.nt("CellTextColor", b, this.o6);
        }
    }
    get p2() {
        return this.pb;
    }
    set p2(a) {
        let b = this.pb;
        this.pb = a;
        if (b != this.pb) {
            this.nt("HeaderSortIndicatorColor", b, this.pb);
        }
    }
    get dz() {
        return this.dy;
    }
    set dz(a) {
        let b = this.dy;
        this.dy = a;
        if (b != this.dy) {
            this.nt("HeaderSortIndicatorStyle", enumGetBox(SortIndicatorStyle_$type, b), enumGetBox(SortIndicatorStyle_$type, this.dy));
        }
    }
    get eh() {
        return this.ec;
    }
    set eh(a) {
        let b = this.ec;
        this.ec = a;
        if (b != this.ec) {
            this.nt("CellTextStyle", b, this.ec);
        }
    }
    get qa() {
        return this.pj;
    }
    set qa(a) {
        let b = this.pj;
        this.pj = a;
        if (b != this.pj) {
            this.nt("SectionHeaderBackground", b, this.pj);
        }
    }
    get qc() {
        return this.pl;
    }
    set qc(a) {
        let b = this.pl;
        this.pl = a;
        if (b != this.pl) {
            this.nt("SectionHeaderTextColor", b, this.pl);
        }
    }
    get ej() {
        return this.ee;
    }
    set ej(a) {
        let b = this.ee;
        this.ee = a;
        if (b != this.ee) {
            this.nt("SectionHeaderTextStyle", b, this.ee);
        }
    }
    get qh() {
        return this.pq;
    }
    set qh(a) {
        let b = this.pq;
        this.pq = a;
        if (b != this.pq) {
            this.nt("SummaryRootTextColor", b, this.pq);
        }
    }
    get ql() {
        return this.pu;
    }
    set ql(a) {
        let b = this.pu;
        this.pu = a;
        if (b != this.pu) {
            this.nt("SummarySectionTextColor", b, this.pu);
        }
    }
    get qf() {
        return this.po;
    }
    set qf(a) {
        let b = this.po;
        this.po = a;
        if (b != this.po) {
            this.nt("SummaryRootNameTextColor", b, this.po);
        }
    }
    get qj() {
        return this.ps;
    }
    set qj(a) {
        let b = this.ps;
        this.ps = a;
        if (b != this.ps) {
            this.nt("SummarySectionNameTextColor", b, this.ps);
        }
    }
    get qg() {
        return this.pp;
    }
    set qg(a) {
        let b = this.pp;
        this.pp = a;
        if (b != this.pp) {
            this.nt("SummaryRootSelectedBackground", b, this.pp);
        }
    }
    get qk() {
        return this.pt;
    }
    set qk(a) {
        let b = this.pt;
        this.pt = a;
        if (b != this.pt) {
            this.nt("SummarySectionSelectedBackground", b, this.pt);
        }
    }
    get el() {
        return this.eg;
    }
    set el(a) {
        let b = this.eg;
        this.eg = a;
        if (b != this.eg) {
            this.nt("SummaryTextStyle", b, this.eg);
        }
    }
    get ek() {
        return this.ef;
    }
    set ek(a) {
        let b = this.ef;
        this.ef = a;
        if (b != this.ef) {
            this.nt("SummarySectionTextStyle", b, this.ef);
        }
    }
    get ip() {
        return this.hn;
    }
    set ip(a) {
        let b = this.hn;
        this.hn = a;
        if (b != this.hn) {
            this.nt("HeaderSeparatorWidth", b, this.hn);
        }
    }
    h0(a) {
        let b = 3;
        let c = Math.max(b - a, 0);
        if (c % 2 == 1) {
            c += 1;
        }
        return intDivide(c, 2);
    }
    get p1() {
        return this.pa;
    }
    set p1(a) {
        let b = this.pa;
        this.pa = a;
        if (b != this.pa) {
            this.nt("HeaderSeparatorBackground", b, this.pa);
        }
    }
    get p0() {
        return this.o9;
    }
    set p0(a) {
        let b = this.o9;
        this.o9 = a;
        if (b != this.o9) {
            this.nt("HeaderBackground", b, this.o9);
        }
    }
    get p3() {
        return this.pc;
    }
    set p3(a) {
        let b = this.pc;
        this.pc = a;
        if (b != this.pc) {
            this.nt("HeaderTextColor", b, this.pc);
        }
    }
    get ei() {
        return this.ed;
    }
    set ei(a) {
        let b = this.ed;
        this.ed = a;
        if (b != this.ed) {
            this.nt("HeaderTextStyle", b, this.ed);
        }
    }
    get p6() {
        return this.pf;
    }
    set p6(a) {
        let b = this.pf;
        this.pf = a;
        if (b != this.pf) {
            this.nt("RowSeparatorBackground", b, this.pf);
        }
    }
    get p9() {
        return this.pi;
    }
    set p9(a) {
        let b = this.pi;
        this.pi = a;
        if (b != this.pi) {
            this.nt("RowSeparatorStickyRowBackground", b, this.pi);
        }
    }
    get p7() {
        return this.pg;
    }
    set p7(a) {
        let b = this.pg;
        this.pg = a;
        if (b != this.pg) {
            this.nt("RowSeparatorLastStickyRowBackground", b, this.pg);
        }
    }
    get p8() {
        return this.ph;
    }
    set p8(a) {
        let b = this.ph;
        this.ph = a;
        if (b != this.ph) {
            this.nt("RowSeparatorPinnedRowBackground", b, this.ph);
        }
    }
    get h3() {
        return this.hk;
    }
    set h3(a) {
        let b = this.hk;
        this.hk = a;
        if (b != this.hk) {
            this.nt("ColumnResizingSeparatorWidth", b, this.hk);
        }
    }
    get h1() {
        return this.hj;
    }
    set h1(a) {
        let b = this.hj;
        this.hj = a;
        if (b != this.hj) {
            this.nt("ColumnMovingSeparatorWidth", b, this.hj);
        }
    }
    get pz() {
        return this.o8;
    }
    set pz(a) {
        let b = this.o8;
        this.o8 = a;
        if (b != this.o8) {
            this.nt("ColumnResizingSeparatorBackground", b, this.o8);
        }
    }
    get py() {
        return this.o7;
    }
    set py(a) {
        let b = this.o7;
        this.o7 = a;
        if (b != this.o7) {
            this.nt("ColumnMovingSeparatorBackground", b, this.o7);
        }
    }
    get platformPixelConverter() {
        return this.em;
    }
    set platformPixelConverter(a) {
        this.em = a;
    }
    get renderingEngine() {
        return this.c7;
    }
    set renderingEngine(a) {
        this.c7 = a;
        this.nv(this.c7);
    }
    nv(a) {
        if (a != null) {
            a.refresh(this.model, false);
        }
    }
    get dl() {
        return this.dk;
    }
    get model() {
        return this.ea;
    }
    set model(a) {
        this.ea = a;
    }
    get qn() {
        return new Rect(0, this.ea.bi, this.ea.bk, this.ea.bl, this.ea.bh);
    }
    get bq() {
        return this.bp;
    }
    get az() {
        return this.ay;
    }
    get t() {
        return this.s;
    }
    get bt() {
        return this.bs;
    }
    get r() {
        return this.q;
    }
    set r(a) {
        let b = this.q;
        this.q = a;
        if (b != this.q) {
            this.nt("SummaryScope", enumGetBox(DataSourceSummaryScope_$type, b), enumGetBox(DataSourceSummaryScope_$type, this.q));
        }
    }
    get ft() {
        return this.ex;
    }
    set ft(a) {
        let b = this.ex;
        this.ex = a;
        if (b != this.ex) {
            this.nt("IsGroupCollapsable", b, this.ex);
        }
    }
    get p() {
        return this.o;
    }
    set p(a) {
        let b = this.o;
        this.o = a;
        if (b != this.o) {
            this.nt("GroupHeaderDisplayMode", enumGetBox(DataSourceSectionHeaderDisplayMode_$type, b), enumGetBox(DataSourceSectionHeaderDisplayMode_$type, this.o));
        }
    }
    get fu() {
        return this.ey;
    }
    set fu(a) {
        let b = this.ey;
        this.ey = a;
        if (b != this.ey) {
            this.nt("IsGroupExpandedDefault", b, this.ey);
        }
    }
    get c2() {
        return this.c1;
    }
    set c2(a) {
        let b = this.c1;
        this.c1 = a;
        if (b != this.c1) {
            this.nt("GroupSummaryDisplayMode", enumGetBox(GroupSummaryDisplayMode_$type, b), enumGetBox(GroupSummaryDisplayMode_$type, this.c1));
        }
    }
    nt(a, b, c) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
        this.n6(a, b, c);
    }
    of() {
    }
    oa() {
        if (this.gu == 0) {
            return;
        }
        let a = this.model.absoluteWidth;
        let b = this.model.absoluteHeight;
        this.gi = true;
        this.d3.n(this, this.model, truncate(this.g8));
        if (a != this.model.absoluteWidth || b != this.model.absoluteHeight) {
            this.externalGrid.onContentSizeChanged();
        }
        this.gi = false;
        this.d9.w();
        this.renderingEngine.invalidateVisibility(() => this.d9.n(this));
        this.renderingEngine.refresh(this.model, false);
    }
    ob() {
        if (this.eu) {
            this.mb();
        }
        else {
            this.renderingEngine.invalidateVisibility(() => this.d9.n(this));
            this.renderingEngine.refresh(this.model, true);
        }
    }
    mb() {
        if (this.eu) {
            this.eu = false;
            this.oa();
            this.mj();
        }
    }
    get gi() {
        return this.e7;
    }
    set gi(a) {
        this.e7 = a;
    }
    n9() {
        if (this.e7) {
            return;
        }
        this.renderingEngine.invalidateVisibility(() => this.d9.n(this));
        this.renderingEngine.refresh(this.model, false);
    }
    ma() {
        if (this.actualDataSource != null) {
            this.actualDataSource.flushAutoRefresh();
        }
        this.ci.an(true);
        this.renderingEngine.refresh(this.model, true);
    }
    get actualDataSource() {
        return this.u;
    }
    set actualDataSource(a) {
        let b = this.u;
        this.u = a;
        if (this.u != b) {
            this.nt("ActualDataSource", b, this.u);
        }
    }
    get j() {
        return this.c;
    }
    set j(a) {
        let b = this.c;
        this.c = a;
        if (this.c != b) {
            this.nt("PrimaryKey", b, this.c);
        }
    }
    get d() {
        return this.a;
    }
    set d(a) {
        let b = this.a;
        this.a = a;
        if (this.a != b) {
            this.nt("ActualPrimaryKey", b, this.a);
        }
    }
    n6(a, b, c) {
        if (a == "ItemsSource") {
            if (this.u != null) {
                let d = this.u;
                d.schemaChanged = delegateRemove(d.schemaChanged, runOn(this, this.l7));
                this.u.updateNotifier = null;
                this.bq.b = null;
                this.az.b = null;
                this.t.syncTarget = null;
                this.bt.b = null;
                this.d = this.k();
            }
            if (typeCast(IDataSource_$type, this.itemsSource) !== null) {
                this.actualDataSource = this.itemsSource;
            }
            else {
                let e = this.externalGrid.createLocalDataSource(this.itemsSource);
                this.actualDataSource = e;
            }
            if (this.u != null) {
                let f = this.u;
                f.schemaChanged = delegateCombine(f.schemaChanged, runOn(this, this.l7));
                this.u.updateNotifier = new DataSourceNotificationBridge(this);
                if (this.u.isVirtual) {
                    this.model.a1 = this.fz;
                }
                if (this.gh) {
                    this.bq.b = this.u.sortDescriptions;
                }
                if (this.gg) {
                    this.az.b = this.u.groupDescriptions;
                }
                if (this.gf) {
                    this.t.syncTarget = this.u.filterExpressions;
                }
                this.bt.b = this.u.summaryDescriptions;
                this.u.propertiesRequested = this.l();
                if (this.j != null) {
                    this.actualDataSource.primaryKey = this.j;
                }
                this.d = this.k();
                if (this.u.actualSchema != null) {
                    this.nh();
                }
                this.fg = true;
                this.ff = true;
                this.fa = true;
                this.e9 = true;
                this.oy(this.z, this.ad);
                this.oy(this.y, this.ac);
                this.dx.av();
                this.fg = false;
                this.ff = false;
                this.fa = false;
                this.e9 = false;
                for (let g = 0; g < this.ac.ae.count; ++g) {
                    this.da.pinRow(this.ac.ae._inner[g]);
                }
                this.actualDataSource.isSectionCollapsable = this.ft;
                this.actualDataSource.sectionHeaderDisplayMode = this.p;
                this.actualDataSource.summaryScope = this.r;
                this.actualDataSource.isSectionExpandedDefault = this.fu;
                switch (this.c2) {
                    case 1:
                    case 0:
                    case 4:
                        this.actualDataSource.includeSummaryRowsInSection = false;
                        break;
                    case 2:
                        this.actualDataSource.includeSummaryRowsInSection = true;
                        this.actualDataSource.isSectionSummaryRowsAtBottom = false;
                        break;
                    case 3:
                        this.actualDataSource.includeSummaryRowsInSection = true;
                        this.actualDataSource.isSectionSummaryRowsAtBottom = true;
                        break;
                }
            }
        }
        if (a == "AutoGenerateColumns") {
            this.au.n = this.fd;
        }
        if (a == "IsPlaceholderRenderingEnabled") {
            if (this.u != null && this.u.isVirtual) {
                this.model.a1 = this.fz;
            }
        }
        if (a == "ColumnResizingMode") {
            this.fx = this.gk();
        }
        if (a == "ActivationMode") {
            this.fj = this.gj();
        }
        if (a == "SelectionMode") {
            this.fj = this.gj();
            switch (this.cz) {
                case 1:
                    if (this.cq.count > 0) {
                        this.cq.clear();
                    }
                    if (this.ct.count > 0) {
                        this.ct.clear();
                    }
                    if (this.ad.count > 1) {
                        let h = this.ad._inner[this.ad.count - 1];
                        this.ad.clear();
                        this.ad.add(h);
                    }
                    break;
                case 2:
                    if (this.cq.count > 0) {
                        this.cq.clear();
                    }
                    if (this.ct.count > 0) {
                        this.ct.clear();
                    }
                    break;
                case 3:
                    if (this.ad.count > 0) {
                        this.ad.clear();
                    }
                    if (this.cq.count > 0) {
                        this.cq.clear();
                    }
                    if (this.ct.count > 1) {
                        let i = this.ct._inner[this.ct.count - 1];
                        this.ct.clear();
                        this.ct.add(i);
                    }
                    break;
                case 4:
                    if (this.ad.count > 0) {
                        this.ad.clear();
                    }
                    if (this.cq.count > 0) {
                        this.cq.clear();
                    }
                    break;
                case 5:
                    if (this.ct.count > 0) {
                        this.ct.clear();
                    }
                    if (this.ad.count > 0) {
                        this.ad.clear();
                    }
                    break;
                case 0:
                    if (this.ad.count > 0) {
                        this.ad.clear();
                    }
                    if (this.ct.count > 0) {
                        this.ct.clear();
                    }
                    if (this.cq.count > 0) {
                        this.cq.clear();
                    }
                    break;
            }
        }
        if (a == "RowSeparator") {
            let j = b;
            let k = c;
            if (j != null) {
                j.definitionPropertyUpdated = delegateRemove(j.definitionPropertyUpdated, runOn(this, this.oi));
                j.grid = null;
            }
            if (k != null) {
                k.definitionPropertyUpdated = delegateCombine(k.definitionPropertyUpdated, runOn(this, this.oi));
                k.grid = this;
            }
        }
        if (a == "HeaderSeparator") {
            let l = b;
            let m = c;
            if (l != null) {
                l.definitionPropertyUpdated = delegateRemove(l.definitionPropertyUpdated, runOn(this, this.md));
                l.grid = null;
            }
            if (m != null) {
                m.definitionPropertyUpdated = delegateCombine(m.definitionPropertyUpdated, runOn(this, this.md));
                m.grid = this;
            }
        }
        if (a == "ColumnResizingSeparator") {
            let n = b;
            let o = c;
            if (n != null) {
                n.grid = null;
            }
            if (o != null) {
                o.grid = this;
            }
        }
        if (a == "ColumnMovingSeparator") {
            let p = b;
            let q = c;
            if (p != null) {
                p.grid = null;
            }
            if (q != null) {
                q.grid = this;
            }
        }
        if (a == "DataSourceDesiredProperties") {
            if (this.u != null) {
                this.u.propertiesRequested = this.e;
            }
        }
        if (a == "PrimaryKey") {
            if (this.actualDataSource != null && this.j != null) {
                this.actualDataSource.primaryKey = c;
            }
            this.d = this.k();
        }
        if (a == "RowHeight" || a == "HeaderHeight" || a == "RowSeparatorHeight" || a == "IsGroupRowSticky" || a == "IsHeaderSeparatorVisible") {
            this.fx = this.gk();
            if (this.gl()) {
                this.oa();
            }
        }
        if (a == "DefaultColumnWidth" || a == "DefaultColumnMinWidth" || a == "Inset" || a == "HeaderSeparatorWidth") {
            if (this.model != null && this.model.a9 != null && this.model.a9.count > 0) {
                this.oa();
            }
        }
        if (a == "SectionHeader") {
            if (b != null) {
                let r = typeCast(SectionHeader.$, b);
                r.sectionHeaderPropertyUpdating = delegateRemove(r.sectionHeaderPropertyUpdating, runOn(this, this.nz));
                r.grid = null;
            }
            if (this.dv != null) {
                let s = this.dv;
                s.sectionHeaderPropertyUpdating = delegateCombine(s.sectionHeaderPropertyUpdating, runOn(this, this.nz));
                this.dv.grid = this;
            }
            this.model.a3 = true;
            this.oa();
        }
        if (a == "ActiveCell") {
            this.fb = true;
            if (this.ca != null && this.ca.b >= 0) {
                this.af.y(this.ca.b, this.ca.d);
            }
            else {
                this.af.aa();
            }
            this.fb = false;
        }
        if (a == "ReactsToSortChanges") {
            let t = c;
            if (!t) {
                this.bq.b = null;
            }
            else {
                if (this.u != null) {
                    this.bq.b = this.u.sortDescriptions;
                }
            }
        }
        if (a == "ReactsToGroupChanges") {
            let u = c;
            if (!u) {
                this.az.b = null;
            }
            else {
                if (this.u != null) {
                    this.az.b = this.u.groupDescriptions;
                }
            }
        }
        if (a == "ReactsToFilterChanges") {
            let v = c;
            if (!v) {
                this.t.syncTarget = null;
            }
            else {
                if (this.u != null) {
                    this.t.syncTarget = this.u.filterExpressions;
                }
            }
        }
        if (a == "IsGroupCollapsable") {
            if (this.actualDataSource != null) {
                this.actualDataSource.isSectionCollapsable = c;
            }
        }
        if (a == "GroupHeaderDisplayMode") {
            if (this.actualDataSource != null) {
                this.actualDataSource.sectionHeaderDisplayMode = EnumUtil.getEnumValue(DataSourceSectionHeaderDisplayMode_$type, c);
            }
        }
        if (a == "SummaryScope") {
            if (this.actualDataSource != null) {
                this.actualDataSource.summaryScope = EnumUtil.getEnumValue(DataSourceSummaryScope_$type, c);
            }
        }
        if (a == "IsGroupExpandedDefault") {
            if (this.actualDataSource != null) {
                this.actualDataSource.isSectionExpandedDefault = c;
            }
        }
        if (a == "GroupSummaryDisplayMode") {
            this.dv.d2 = this.c2;
            this.model.a3 = true;
            if (this.actualDataSource != null) {
                switch (this.c2) {
                    case 1:
                    case 0:
                    case 4:
                        this.actualDataSource.includeSummaryRowsInSection = false;
                        break;
                    case 2:
                        this.actualDataSource.includeSummaryRowsInSection = true;
                        this.actualDataSource.isSectionSummaryRowsAtBottom = false;
                        break;
                    case 3:
                        this.actualDataSource.includeSummaryRowsInSection = true;
                        this.actualDataSource.isSectionSummaryRowsAtBottom = true;
                        break;
                }
            }
            this.oa();
        }
    }
    k() {
        if (this.j != null) {
            return this.j;
        }
        if (this.actualDataSource != null) {
            return this.actualDataSource.actualPrimaryKey;
        }
        return null;
    }
    l() {
        if (!this.fd && this.e == null && this.u.propertiesRequested == null && this.columns.count > 0) {
            return this.f();
        }
        if (this.e != null) {
            return this.e;
        }
        return this.u.propertiesRequested;
    }
    f() {
        let a = new Array(this.columns.count);
        for (let b = 0; b < this.columns.count; b++) {
            a[b] = this.columns._inner[b].gb;
        }
        return a;
    }
    oi(a, b) {
        this.oj(b.propertyName, b.animationType, b.oldValue, b.newValue);
    }
    md(a, b) {
        this.me(b.propertyName, b.animationType, b.oldValue, b.newValue);
    }
    oj(a, b, c, d) {
        if (b == 10) {
            return;
        }
        if (a != null && stringStartsWith(a, "Actual")) {
            a = a.substr(6);
        }
        this.b1.s(this, null, a, b, c, d, false, true, false, false);
    }
    me(a, b, c, d) {
        if (b == 10) {
            return;
        }
        if (a != null && stringStartsWith(a, "Actual")) {
            a = a.substr(6);
        }
        for (let e = 0; e < this.model.a9.count; e++) {
            let f = this.model.a9._inner[e];
            this.b1.s(this, f, a, b, c, d, true, false, false, true);
        }
    }
    l7(a, b) {
        this.nh();
    }
    nh() {
        this.c9.setDataSource(this.u);
        this.au.b = this.u.actualSchema;
        this.oz();
        for (let a = 0; a < this.az.i.count; a++) {
            this.og(this.az.i.item(a));
        }
        for (let b = 0; b < this.bt.i.count; b++) {
            this.oh(this.bt.i.item(b));
        }
        this.oa();
        this.mj();
    }
    mn() {
        if (this.columnsAutoGenerated != null) {
            this.columnsAutoGenerated(this, new GridColumnsAutoGeneratedEventArgs());
        }
    }
    sizeChanged(a, b) {
        this.g8 = a;
        this.g7 = b;
        this.di.y(a, b);
        this.oa();
    }
    setViewport(a, b, c, d) {
        this.ho = -1;
        this.hp = -1;
        let e = c - a;
        this.model.actualVisibleRegion = new Rect(0, a, b, c - a, d - b);
        this.ob();
    }
    get actualColumns() {
        return this.at.h;
    }
    get columns() {
        return this.cd;
    }
    nr(a, b, c) {
        let d = this.bw(a.i);
        d.ci(a, this, b, c);
        d.cj(a, this, b, c);
    }
    nq(a, b, c, d) {
        a.g1 = d;
        let e = this.bw(a.i);
        e.cj(a, this, b, c);
    }
    as(a) {
        return this.au.f(a);
    }
    mf(a) {
        a.ex = true;
        a.e1 = true;
    }
    l9(a, b) {
        let c = this.columns.indexOf(b);
        if (c == -1) {
            return;
        }
        if ((a != null && a.e0) || (b != null && b.e0)) {
            throw new InvalidOperationException(1, "Cannot exchange a column created from markup");
        }
        if (this.columns.contains(a)) {
            if (a.e1) {
                this.externalGrid.removeExternalColumn(a.externalObject);
            }
            else {
                return;
            }
        }
        let d = this.aw;
        if (d == 0) {
            d = a.d6();
        }
        let e = false;
        if (d == 2 || d == 7) {
            e = true;
        }
        a.ed = 3;
        if (e) {
            this.externalGrid.insertExternalColumnAtIndex(c + 1, a.externalObject);
        }
        else {
            this.externalGrid.insertExternalColumnAtIndex(c, a.externalObject);
        }
        if (!this.fm(a)) {
            a.e1 = false;
            a.ed = 5;
            this.externalGrid.removeExternalColumn(b.externalObject);
            this.m5(a);
        }
        this.oa();
        if (this.fm(a)) {
            let f = this.model.f(b.fj).a;
            b.ed = 2;
            a.ed = 1;
            this.b1.aj(this, this.cc, this.model.f(b.fj), this.model.f(a.fj), f);
        }
    }
    lv(a, b) {
        this.dx.w();
        this.af.ad();
        this.dx.au();
        if (this.gp) {
            return;
        }
        switch (b.action) {
            case 0:
                if (b.newItems != null) {
                    for (let c = 0; c < b.newItems.count; c++) {
                        this.m8(c + b.newStartingIndex, b.newItems.item(c));
                    }
                }
                break;
            case 1:
                if (b.oldItems != null) {
                    for (let d = 0; d < b.oldItems.count; d++) {
                        this.nc(b.oldStartingIndex, b.oldItems.item(d));
                    }
                }
                break;
            case 2:
                if (b.oldItems != null) {
                    for (let e = 0; e < b.oldItems.count; e++) {
                        this.nc(b.oldStartingIndex, b.oldItems.item(e));
                    }
                }
                if (b.newItems != null) {
                    for (let f = 0; f < b.newItems.count; f++) {
                        this.m8(f + b.newStartingIndex, b.newItems.item(f));
                    }
                }
                break;
            case 4:
                this.nf();
                break;
        }
        this.oa();
    }
    nf() {
        this.d3.r(this.cn, this.model);
    }
    nc(a, b) {
        b.grid = null;
        b.propertyChanged = delegateRemove(b.propertyChanged, runOn(this, this.l2));
        b.columnCellsPropertyUpdating = delegateRemove(b.columnCellsPropertyUpdating, runOn(this, this.l3));
        b.columnHeaderCellsPropertyUpdating = delegateRemove(b.columnHeaderCellsPropertyUpdating, runOn(this, this.l6));
        this.d3.q(this.cn, a, b, this.model);
        this.oa();
        b.ed = 0;
        this.dx.ac(a, b);
    }
    m8(a, b) {
        b.grid = this;
        b.propertyChanged = delegateCombine(b.propertyChanged, runOn(this, this.l2));
        b.columnCellsPropertyUpdating = delegateCombine(b.columnCellsPropertyUpdating, runOn(this, this.l3));
        b.columnHeaderCellsPropertyUpdating = delegateCombine(b.columnHeaderCellsPropertyUpdating, runOn(this, this.l6));
        this.d3.o(a, b, this.model);
        if (b.e1) {
            b.ed = 3;
        }
        if (this.fk(b) && !b.e1 && b.ed != 3) {
            let c = b.ed;
            b.ed = 1;
            this.oa();
            this.b1.ap(this, this.cc, this.model.f(b.fj), true, c);
        }
        else {
            this.oa();
        }
        for (let d = 0; d < this.bq.i.count; d++) {
            if (b.gb == this.bq.i.item(d).f) {
                b.eb = this.br(this.bq.i.item(d).c);
                break;
            }
        }
        this.dx.aa(a, b);
    }
    l3(a, b, c, d, e) {
        if (b == "Width" || b == "MinWidth") {
            this.oa();
            this.l1();
            return;
        }
        if (c == 10) {
            return;
        }
        let f = this.model.f(a.fj);
        if (f == null) {
            return;
        }
        if (b != null && stringStartsWith(b, "Actual")) {
            b = b.substr(6);
        }
        if (b == "HeaderText") {
            this.l6(a, "TextValue", c, d, e);
            return;
        }
        if (b == "FormatString") {
            if (typeCast(NumericColumn.$, a) !== null || typeCast(DateTimeColumn.$, a) !== null) {
                b = "FormatStringOverride";
            }
        }
        if (b == "SortDirection" && false == this.fy) {
            this.d1.f(a, a.eb);
        }
        this.b1.s(this, f, b, c, d, e, false, false, false, false);
    }
    nz(a, b, c, d, e) {
        if (c == 10) {
            return;
        }
        if (b != null && stringStartsWith(b, "Actual")) {
            b = b.substr(6);
        }
        this.b1.s(this, null, b, c, d, e, false, false, true, false);
    }
    l6(a, b, c, d, e) {
        if (c == 10) {
            return;
        }
        let f = this.model.f(a.fj);
        if (f == null) {
            return;
        }
        if (b != null && stringStartsWith(b, "Actual")) {
            b = b.substr(6);
        }
        this.b1.s(this, f, b, c, d, e, true, false, false, false);
    }
    mk(a, b) {
        this.externalGrid.ensureColumnsAreManual();
        let c = this.columns._inner[a];
        this.gp = true;
        if (c != null && c.e0) {
            throw new InvalidOperationException(1, "Can't move a column that was created from markup");
        }
        if (b > a) {
            let d = this.columns._inner[b - 1];
            if (d.e0) {
                throw new InvalidOperationException(1, "Can't move a column to before columns created from markup");
            }
        }
        else {
            let e = this.columns._inner[b];
            if (e.e0) {
                throw new InvalidOperationException(1, "Can't move a column to before columns created from markup");
            }
        }
        this.externalGrid.removeExternalColumn(c.externalObject);
        this.externalGrid.insertExternalColumnAtIndex(b, c.externalObject);
        this.gp = false;
        this.m9(a, b, c);
    }
    m9(a, b, c) {
        if (this.au.p(c)) {
            c.fd = this.d3.h(a, this.model.bi, this, this.model);
        }
        else if (this.au.q(c)) {
            c.fd = this.d3.i(a, this.model.bj, this, this.model);
        }
        else {
            c.fd = this.d3.g(a, this, this.model);
        }
        c.fc = a;
        let d = c.ed;
        this.d3.p(this.cn, this.model, a, b, c.fj);
        if (!this.fo(c) && d != 3) {
            c.ed = 5;
        }
        this.oa();
        if (this.fo(c)) {
            c.ed = 6;
            this.b1.al(this, this.cc, this.model.f(c.fj), d);
        }
        this.dx.ab(a, b, c);
    }
    l2(a, b) {
        let c = a;
        switch (b.propertyName) {
            case "Filter":
                this.oz();
                break;
            case "IsHidden":
                if (c.e1) {
                    if (this.fn(c)) {
                        let d = c.ed;
                        c.ed = 2;
                        this.oa();
                        this.b1.ak(this, this.cc, this.model.f(c.fj), false, d);
                    }
                    else {
                        c.ed = 3;
                        if (c.eu) {
                            this.externalGrid.ensureColumnsAreManual();
                            this.externalGrid.removeExternalColumn(c.externalObject);
                        }
                        this.oa();
                    }
                }
                else {
                    if (this.fr(c)) {
                        let e = c.ed;
                        c.ed = 1;
                        this.oa();
                        this.b1.ap(this, this.cc, this.model.f(c.fj), false, e);
                    }
                    else {
                        c.ed = 5;
                        this.b1.ai(this, this.model.f(c.fj));
                        this.ci.ab();
                        this.oa();
                    }
                }
                break;
        }
    }
    oz() {
        if (this.actualDataSource == null) {
            return;
        }
        let a = null;
        for (let b = 0; b < this.au.h.count; b++) {
            let c = this.au.h._inner[b];
            if (c.d1 != null) {
                let d = this.actualDataSource.resolveSchemaPropertyType(c.gb);
                let e = c.d1.a(c.gb, d);
                if (a != null) {
                    a = FilterFactory.instance.and(a, e);
                }
                else {
                    a = e;
                }
            }
        }
        if (a != null) {
            a.markAutoGenerated();
            let f = false;
            if (this.t != null) {
                for (let g = 0; g < this.t.j.count; g++) {
                    if (this.t.j.item(g).isAutoGenerated) {
                        this.t.j.item(g, a);
                        f = true;
                        break;
                    }
                }
            }
            if (!f) {
                this.t.add(a);
            }
        }
        else {
            for (let h = this.t.j.count - 1; h >= 0; h--) {
                if (this.t.j.item(h).isAutoGenerated) {
                    this.t.removeAt(h);
                }
            }
        }
    }
    bw(a) {
        let b = this.c9.getRowType(a.s);
        if (b != 0 && b != 3) {
            if (a.af) {
                return this.dr;
            }
            switch (b) {
                case 1: if (this.c2 != 1) {
                    return this.dv;
                }
                else {
                    return this.as(a);
                }
                case 2: return this.dt;
                case 4: return this.d5;
                case 5: return this.d7;
                default: throw new NotSupportedException(0);
            }
        }
        else {
            if (a.af) {
                return this.dr;
            }
            else {
                if (a.ad) {
                    if (this.dragger.dragType == 1) {
                        return this.bi;
                    }
                    else if (this.dragger.dragType == 2) {
                        return this.a9;
                    }
                }
                let c = this.as(a);
                if (a.e) {
                    if (a.f) {
                        return this.c6;
                    }
                    else {
                        return c.header;
                    }
                }
                else {
                    return c;
                }
            }
        }
    }
    j1(a, b, c, d) {
        return this.bw(a).b7(a, b, c, d);
    }
    ak(a, b) {
        let c = this.bw(a);
        let d = c.k(a, b);
        d.m = this;
        return d;
    }
    i0() {
        return this.model.b();
    }
    j0() {
        let a = this.model.b();
        return a.ab();
    }
    dm(a) {
        return this.da.getRowPathForRow(a);
    }
    on(a) {
        let b = truncate(this.model.actualVisibleRegion.left);
        if (this.ho != -1) {
            b = this.ho;
        }
        let c = 0;
        let d = 0;
        if (a < 0) {
            a = 0;
        }
        if (a >= this.da.getRowCount()) {
            a = this.da.getRowCount() - 1;
        }
        let e = 0;
        for (let f of fromEnum(this.model.bf)) {
            if (d + f.m > a) {
                e = truncate(Math.floor(a - d));
                let g = f.e(e);
                c = f.f(e);
                c += truncate(Math.round(g * ((a - d) - e)));
            }
            else {
                d += f.m;
                continue;
            }
        }
        let h = this.d9.i(this, this.model, new Rect(0, b, c, this.model.bl, this.model.bh));
        let i = 0;
        for (let j = 0; j < h.count; j++) {
            if (h._inner[j].k >= e) {
                break;
            }
            i += h._inner[j].i + this.it + this.iu;
        }
        c -= truncate(i);
        c = Math.max(c, 0);
        if (this.model.absoluteHeight > 0 && this.model.actualVisibleRegion.height > 0 && c + this.model.actualVisibleRegion.height > this.model.absoluteHeight) {
            c = truncate(Math.round(this.model.absoluteHeight - this.model.actualVisibleRegion.height));
        }
        if (c < 0) {
            c = 0;
        }
        this.hp = c;
        this.ho = b;
        this.viewportManager.moveViewportTo(b, c);
    }
    om(a) {
        let b = truncate(this.model.actualVisibleRegion.left);
        if (this.ho != -1) {
            b = this.ho;
        }
        let c = 0;
        let d = 0;
        if (a < 0) {
            a = 0;
        }
        if (a >= this.da.getRowCount()) {
            a = this.da.getRowCount() - 1;
        }
        let e = 0;
        for (let f of fromEnum(this.model.bf)) {
            if (d + f.m > a) {
                let g = truncate(Math.floor(a - d));
                let h = f.e(g);
                e = h;
                c = f.i + f.f(g);
                c += truncate(Math.round(h * ((a - d) - g)));
            }
            else {
                d += f.m;
                continue;
            }
        }
        c -= this.model.bs;
        c = Math.max(c, 0);
        if (this.model.absoluteHeight > 0 && this.model.actualVisibleRegion.height > 0) {
            c -= truncate(Math.round(this.model.actualVisibleRegion.height - (e + this.model.bs)));
        }
        if (this.model.absoluteHeight > 0 && this.model.actualVisibleRegion.height > 0 && c + this.model.actualVisibleRegion.height > this.model.absoluteHeight) {
            c = truncate(Math.round(this.model.absoluteHeight - this.model.actualVisibleRegion.height));
        }
        if (c < 0) {
            c = 0;
        }
        this.hp = c;
        this.ho = b;
        this.viewportManager.moveViewportTo(b, c);
    }
    gm(a) {
        let b = this.h5(a);
        if (b == -1) {
            return false;
        }
        this.on(b);
        return true;
    }
    gn(a) {
        let b = this.h6(a);
        if (b == -1) {
            return false;
        }
        this.on(b);
        return true;
    }
    ok(a) {
        let b = truncate(a);
        if (b < 0) {
            b = 0;
            a = 0;
        }
        if (a > this.model.a9.count) {
            b = this.model.a9.count - 1;
            a = this.model.a9.count - 1;
        }
        let c = this.columns._inner[b];
        let d = 0;
        if (this.au.p(c)) {
            d = this.d3.h(b, this.model.bi, this, this.model);
        }
        else {
            d = this.d3.g(b, this, this.model);
        }
        let e = truncate(this.model.actualVisibleRegion.top);
        if (this.hp != -1) {
            e = this.hp;
        }
        let f = d + truncate((this.model.a9._inner[b].j * (a - b)));
        if (this.model.absoluteWidth > 0 && this.model.actualVisibleRegion.width > 0 && f + this.model.actualVisibleRegion.width > this.model.absoluteWidth) {
            f = truncate(Math.round(this.model.absoluteWidth - this.model.actualVisibleRegion.width));
        }
        if (f < 0) {
            f = 0;
        }
        this.hp = e;
        this.ho = f;
        this.viewportManager.moveViewportTo(f, e);
    }
    ol(a) {
        let b = truncate(a);
        if (b < 0) {
            b = 0;
            a = 0;
        }
        if (a > this.model.a9.count) {
            b = this.model.a9.count - 1;
            a = this.model.a9.count - 1;
        }
        let c = this.columns._inner[b];
        let d = 0;
        if (this.au.p(c)) {
            d = this.d3.h(b, this.model.bi, this, this.model);
        }
        else {
            d = this.d3.g(b, this, this.model);
        }
        let e = truncate(this.model.actualVisibleRegion.top);
        if (this.hp != -1) {
            e = this.hp;
        }
        let f = d + truncate((this.model.a9._inner[b].j * (a - b)));
        if (this.model.absoluteWidth > 0 && this.model.actualVisibleRegion.width > 0) {
            f -= truncate(Math.round(this.model.actualVisibleRegion.width - this.model.a9._inner[b].j));
        }
        if (this.model.absoluteWidth > 0 && this.model.actualVisibleRegion.width > 0 && f + this.model.actualVisibleRegion.width > this.model.absoluteWidth) {
            f = truncate(Math.round(this.model.absoluteWidth - this.model.actualVisibleRegion.width));
        }
        if (f < 0) {
            f = 0;
        }
        this.hp = e;
        this.ho = f;
        this.viewportManager.moveViewportTo(f, e);
    }
    go(a) {
        return this.fk(a);
    }
    ng(a, b) {
        let c = this.ic();
        let d = this.ig();
        if (b < c || a > d) {
            return;
        }
        if (a < c) {
            a = c;
        }
        if (b > d) {
            b = d;
        }
        if (!this.gl()) {
            return;
        }
        this.b1.z(this, a, b, false);
        if (this.da.getRowCount() != this.model.bt()) {
            this.oa();
        }
        else {
            this.ob();
        }
        this.l1();
    }
    l1() {
        if (this.model.actualVisibleRegion.isEmpty) {
            return;
        }
        if (this.model.actualVisibleRegion.bottom > this.model.absoluteHeight || this.model.actualVisibleRegion.top > this.model.absoluteHeight) {
            let a = this.da.getRowCount() - 1;
            if (a < 0) {
                a = 0;
            }
            this.on(a);
        }
        if (this.model.actualVisibleRegion.right > this.model.absoluteWidth || this.model.actualVisibleRegion.left > this.model.absoluteWidth) {
            let b = this.au.h.count - 1;
            if (b < 0) {
                b = 0;
            }
            this.ol(b);
        }
    }
    h8(a) {
        return this.d3.f(this.model, a.i);
    }
    gl() {
        return this.model.av != null && this.model.aw != null && this.model.aw.s >= 0 && this.model.av.s >= 0;
    }
    ig() {
        return this.d3.f(this.model, this.model.av);
    }
    ic() {
        return this.d3.f(this.model, this.model.aw);
    }
    ia() {
        let a = this.d3.b(this.model.actualVisibleRegion.top + this.model.bu + this.model.bv + this.model.b1, this.model);
        return this.d3.f(this.model, a);
    }
    n2() {
        let a = this.ic();
        let b = this.ig();
        this.da.firstVisibleIndexRequested = a;
        this.da.lastVisibleIndexRequested = b;
    }
    get f2() {
        return this.cellPreviewPointerDown != null;
    }
    get f3() {
        return this.cellPreviewPointerUp != null;
    }
    get f0() {
        return this.cellPointerDown != null;
    }
    get f1() {
        return this.cellPointerUp != null;
    }
    gj() {
        return this.cz != 0 || this.cellClicked != null || this.by != 0 || this.bg != 2 || this.a7 != 1;
    }
    gk() {
        return (this.bg != 2 && this.fw) || this.a7 != 1;
    }
    nx(a, b) {
        this.fg = true;
        this.ly(a, b);
        this.fg = false;
    }
    ny(a, b) {
        this.fg = true;
        this.oe(a, b);
        this.fg = false;
    }
    n0(a, b, c) {
        this.fg = true;
        this.o2(a, b, c);
        this.fg = false;
    }
    mr(a, b) {
        let c = this.ca;
        if (!this.fb) {
            let d = new GridCellPosition();
            d.d = b;
            d.b = a;
            this.ca = d;
        }
        if (this.activeCellChanged != null) {
            let e = new GridActiveCellChangedEventArgs();
            e.newActiveCell = this.ca;
            e.oldActiveCell = c;
            this.activeCellChanged(this, e);
        }
    }
    mt(a, b) {
        if (b == null) {
            return;
        }
        let c = this.ca;
        if (!this.fb) {
            let d = new GridCellPosition();
            d.d = b;
            d.b = a;
            this.ca = d;
        }
        if (this.activeCellChanged != null) {
            let e = new GridActiveCellChangedEventArgs();
            e.newActiveCell = this.ca;
            e.oldActiveCell = c;
            this.activeCellChanged(this, e);
        }
    }
    f5(a, b) {
        if (this.by == 0 || this.ca == null) {
            return false;
        }
        let c = this.b9.b;
        let d = this.b9.d;
        if (c > this.da.getRowCount() - 1) {
            return false;
        }
        let e = c + 1;
        if (b) {
            e = this.da.getRowCount() - 1;
        }
        if (e > this.da.getRowCount() - 1) {
            e = this.da.getRowCount() - 1;
        }
        if (e == c) {
            return false;
        }
        let f = Math.min(this.af.r(), this.actualColumns.count - 1);
        f = this.h7(f);
        let g = this.actualColumns._inner[f];
        if (d != g.fu()) {
            d = g.fu();
        }
        let h = this.da.getRowType(e);
        if (h == 1 || h == 2) {
            d = null;
        }
        this.ca = ((() => {
            let $ret = new GridCellPosition();
            $ret.b = e;
            $ret.d = d;
            return $ret;
        })());
        let i = this.af.r();
        this.lz(e, i, false);
        return true;
    }
    f6(a, b) {
        if (this.by == 0 || this.ca == null) {
            return false;
        }
        if (!b) {
            return false;
        }
        let c = this.id();
        let d = this.actualColumns._inner[c];
        let e = this.b9.b;
        let f = this.b9.d;
        if (e >= this.da.getRowCount() - 1 && f == d.fu()) {
            return false;
        }
        e = this.da.getRowCount() - 1;
        f = d.fu();
        let g = this.da.getRowType(e);
        if (g == 1 || g == 2) {
            f = null;
        }
        this.ca = ((() => {
            let $ret = new GridCellPosition();
            $ret.b = e;
            $ret.d = f;
            return $ret;
        })());
        this.eq = true;
        this.om(e);
        this.eq = false;
        this.ok(c);
        return true;
    }
    id() {
        let a = this.actualColumns.count - 1;
        while (a > 0 && this.actualColumns._inner[a].e1) {
            a--;
        }
        return a;
    }
    h9() {
        let a = 0;
        while (a < this.actualColumns.count - 1 && this.actualColumns._inner[a].e1) {
            a++;
        }
        return a;
    }
    ii(a) {
        let b = Math.max(0, a - 1);
        if (this.actualColumns._inner[b].e1) {
            let c = b;
            while (c > 0 && this.actualColumns._inner[c].e1) {
                c--;
            }
            if (this.actualColumns._inner[c].e1) {
                c = b;
                while (c < this.actualColumns.count - 1 && this.actualColumns._inner[c].e1) {
                    c++;
                }
                if (!this.actualColumns._inner[c].e1) {
                    b = c;
                }
            }
        }
        return b;
    }
    ih(a) {
        let b = Math.min(this.actualColumns.count - 1, a + 1);
        return this.h7(b);
    }
    h7(a) {
        a = Math.min(a, this.actualColumns.count - 1);
        if (this.actualColumns._inner[a].e1) {
            let b = a;
            while (b < this.actualColumns.count - 1 && this.actualColumns._inner[b].e1) {
                b++;
            }
            if (this.actualColumns._inner[b].e1) {
                b = a;
                while (b > 0 && this.actualColumns._inner[b].e1) {
                    b--;
                }
                if (!this.actualColumns._inner[b].e1) {
                    a = b;
                }
            }
            else {
                a = b;
            }
        }
        return a;
    }
    lz(a, b, c) {
        if (b <= this.ib()) {
            this.ok(b);
        }
        else if (b >= this.ie()) {
            this.ol(b);
        }
        if (a <= this.ia()) {
            this.on(a);
        }
        else if (a >= this.ig()) {
            if (c) {
                this.on(a);
            }
            else {
                this.om(a);
            }
        }
    }
    f8(a, b) {
        if (!b) {
            return false;
        }
        let c = this.h9();
        let d = this.actualColumns._inner[c];
        let e = this.b9.b;
        let f = this.b9.d;
        if (e <= 0 && f == d.fu()) {
            return false;
        }
        e = 0;
        f = d.fu();
        let g = this.da.getRowType(e);
        if (g == 1 || g == 2) {
            f = null;
        }
        this.ca = ((() => {
            let $ret = new GridCellPosition();
            $ret.b = e;
            $ret.d = f;
            return $ret;
        })());
        this.eq = true;
        this.om(e);
        this.eq = false;
        this.ok(c);
        return true;
    }
    f9(a, b) {
        if (this.by == 0 || this.ca == null) {
            return false;
        }
        let c = this.h9();
        let d = this.af.r();
        let e = this.b9.b;
        let f = this.b9.d;
        if (f == null) {
            return false;
        }
        let g = this.ii(d);
        if (b) {
            g = this.h9();
        }
        let h = this.actualColumns._inner[g];
        if (f == h.fu()) {
            return false;
        }
        f = h.fu();
        this.ca = ((() => {
            let $ret = new GridCellPosition();
            $ret.b = e;
            $ret.d = f;
            return $ret;
        })());
        this.lz(e, g, false);
        return true;
    }
    ga(a, b) {
        if (this.by == 0 || this.ca == null) {
            return false;
        }
        let c = this.b9.d;
        let d = this.af.r();
        let e = this.ic();
        let f = this.ig();
        let g = f - e;
        let h = Math.min(f + 1, this.da.getRowCount() - 1);
        let i = this.da.getRowType(h);
        if (i == 1 || i == 2) {
            c = null;
        }
        this.ca = ((() => {
            let $ret = new GridCellPosition();
            $ret.b = h;
            $ret.d = c;
            return $ret;
        })());
        this.lz(h, d, true);
        return true;
    }
    gb(a, b) {
        if (this.by == 0 || this.ca == null) {
            return false;
        }
        let c = this.b9.d;
        let d = this.af.r();
        let e = this.ic();
        let f = this.ig();
        let g = f - e;
        let h = Math.max(e - g - 1, 0);
        let i = this.da.getRowType(h);
        if (i == 1 || i == 2) {
            c = null;
        }
        this.ca = ((() => {
            let $ret = new GridCellPosition();
            $ret.b = h;
            $ret.d = c;
            return $ret;
        })());
        this.lz(h, d, false);
        return true;
    }
    gc(a, b) {
        if (this.by == 0 || this.ca == null) {
            return false;
        }
        let c = this.h9();
        let d = this.af.r();
        let e = this.b9.b;
        let f = this.b9.d;
        if (f == null) {
            return false;
        }
        let g = this.ih(d);
        if (b) {
            g = this.id();
        }
        let h = this.actualColumns._inner[g];
        if (f == h.fu()) {
            return false;
        }
        f = h.fu();
        this.ca = ((() => {
            let $ret = new GridCellPosition();
            $ret.b = e;
            $ret.d = f;
            return $ret;
        })());
        this.lz(e, g, false);
        return true;
    }
    gd(a, b) {
        if (this.by == 0 || this.ca == null) {
            return false;
        }
        let c = this.h9();
        let d = this.af.r();
        let e = this.b9.b;
        let f = this.b9.d;
        let g = d;
        let h = 0;
        if (e >= 0 && e < this.da.getRowCount()) {
            h = this.da.getRowType(e);
        }
        if (a) {
            let i = this.ii(d);
            let j = this.actualColumns._inner[i];
            if (f == j.fu() || h == 1) {
                if (e > 0) {
                    e--;
                    if (this.da.getRowType(e) == 1) {
                        i = this.h9();
                    }
                    else {
                        i = this.id();
                    }
                    j = this.actualColumns._inner[i];
                }
                else {
                    return false;
                }
            }
            f = j.fu();
            this.ca = ((() => {
                let $ret = new GridCellPosition();
                $ret.b = e;
                $ret.d = f;
                return $ret;
            })());
            g = i;
        }
        else {
            let k = this.ih(d);
            let l = this.actualColumns._inner[k];
            if (f == l.fu() || h == 1) {
                if (e < this.da.getRowCount() - 1) {
                    k = this.h9();
                    l = this.actualColumns._inner[k];
                    e++;
                }
                else {
                    return false;
                }
            }
            f = l.fu();
            this.ca = ((() => {
                let $ret = new GridCellPosition();
                $ret.b = e;
                $ret.d = f;
                return $ret;
            })());
            g = k;
        }
        this.lz(e, g, false);
        return true;
    }
    n3() {
    }
    ge(a, b) {
        if (this.by == 0 || this.ca == null) {
            return false;
        }
        let c = this.b9.b;
        let d = this.b9.d;
        if (c < 0) {
            return false;
        }
        let e = c - 1;
        if (b) {
            e = 0;
        }
        if (e < 0) {
            e = 0;
        }
        if (e == c) {
            return false;
        }
        let f = Math.min(this.af.r(), this.actualColumns.count - 1);
        f = this.h7(f);
        let g = this.actualColumns._inner[f];
        if (d != g.fu()) {
            d = g.fu();
        }
        let h = this.da.getRowType(e);
        if (h == 1 || h == 2) {
            d = null;
        }
        this.ca = ((() => {
            let $ret = new GridCellPosition();
            $ret.b = e;
            $ret.d = d;
            return $ret;
        })());
        let i = this.af.r();
        this.lz(e, i, false);
        return true;
    }
    f7(a, b) {
        if (this.by != 0 && this.ca != null) {
            let c = this.da.getRowType(this.ca.b);
            if (c == 1) {
                this.o1(this.ca.b);
            }
        }
        return false;
    }
    m1(a, b) {
        this.fg = true;
        if (!this.fc) {
            let c = this.ct.af(a, this.au.d(b).fu());
        }
        if (this.selectedCellsChanged != null) {
            let d = new GridSelectedCellsChangedEventArgs();
            d.addedCells = new GridSelectedCellsCollection();
            d.addedCells.add(this.ct.ai(a, b));
            d.removedCells = new GridSelectedCellsCollection();
            this.selectedCellsChanged(this, d);
        }
        this.fg = false;
    }
    m2(a, b) {
        this.fg = true;
        let c = this.ct.ai(a, b);
        if (c != null) {
            if (!this.fc) {
                this.ct.remove(c);
            }
            if (this.selectedCellsChanged != null) {
                let d = new GridSelectedCellsChangedEventArgs();
                d.addedCells = new GridSelectedCellsCollection();
                d.removedCells = new GridSelectedCellsCollection();
                d.removedCells.add(c);
                this.selectedCellsChanged(this, d);
            }
        }
        this.fg = false;
    }
    ly(a, b) {
        if (!this.fa) {
            this.z.add1(a);
            this.ad.add(b);
        }
        let c = new GridSelectedItemsChangedEventArgs();
        let d = new List$1(Base.$, 0);
        d.add1(a);
        c.addedItems = d;
        if (this.selectedItemsChanged != null) {
            this.selectedItemsChanged(this, c);
        }
        let e = new GridSelectedKeysChangedEventArgs();
        let f = new GridSelectedKeysCollection();
        f.add(b);
        e.addedKeys = f;
        if (this.selectedKeysChanged != null) {
            this.selectedKeysChanged(this, e);
        }
    }
    o2(a, b, c) {
        let d = this.z.ae._inner[a];
        if (!this.fa) {
            this.z.ae._inner[a] = b;
        }
        let e = new GridSelectedItemsChangedEventArgs();
        let f = new List$1(Base.$, 0);
        f.add1(b);
        e.addedItems = f;
        let g = new List$1(Base.$, 0);
        g.add1(b);
        e.removedItems = g;
        if (this.selectedItemsChanged != null) {
            this.selectedItemsChanged(this, e);
        }
    }
    oe(a, b) {
        if (!this.fa) {
            this.z.remove1(a);
            this.ad.remove(b);
        }
        let c = new GridSelectedItemsChangedEventArgs();
        let d = new List$1(Base.$, 0);
        d.add1(a);
        c.removedItems = d;
        if (this.selectedItemsChanged != null) {
            this.selectedItemsChanged(this, c);
        }
        let e = new GridSelectedKeysChangedEventArgs();
        let f = new GridSelectedKeysCollection();
        f.add(b);
        e.removedKeys = f;
        if (this.selectedKeysChanged != null) {
            this.selectedKeysChanged(this, e);
        }
    }
    lx(a, b, c, d) {
        let e = new CellRange();
        e.k = a;
        e.i = b;
        e.l = c;
        e.j = d;
        this.lw(e);
    }
    lw(a) {
        this.cq.add(a);
        this.ao = a;
        if (this.selectedCellRangesChanged != null) {
            let b = new GridSelectedCellRangesChangedEventArgs();
            b.addedRanges = ((() => {
                let $ret = new GridSelectedCellRangesCollection();
                $ret.add(a);
                return $ret;
            })());
            this.selectedCellRangesChanged(this, b);
        }
    }
    od(a) {
        if (this.cq.contains(a)) {
            this.cq.remove(a);
            if (this.selectedCellRangesChanged != null) {
                let b = new GridSelectedCellRangesChangedEventArgs();
                b.removedRanges = ((() => {
                    let $ret = new GridSelectedCellRangesCollection();
                    $ret.add(a);
                    return $ret;
                })());
                this.selectedCellRangesChanged(this, b);
            }
        }
    }
    oc() {
        if (this.cq.count > 0) {
            let a = new GridSelectedCellRangesCollection();
            for (let b = 0; b < this.cq.count; b++) {
                a.add(this.cq._inner[b]);
            }
            this.cq.clear();
            if (this.selectedCellRangesChanged != null) {
                let c = new GridSelectedCellRangesChangedEventArgs();
                c.removedRanges = a;
                this.selectedCellRangesChanged(this, c);
            }
        }
    }
    ml(a) {
        if (this.cq.contains(a)) {
            if (this.selectedCellRangesChanged != null) {
                let b = new GridSelectedCellRangesChangedEventArgs();
                b.updatedRanges = ((() => {
                    let $ret = new GridSelectedCellRangesCollection();
                    $ret.add(a);
                    return $ret;
                })());
                this.selectedCellRangesChanged(this, b);
            }
        }
    }
    n1(a, b, c) {
        this.mg(a);
        if (b != c) {
            this.dx.af(a);
            this.af.ah(a);
        }
    }
    mg(a) {
        this.b1.am(this, a, a);
    }
    m3() {
        this.dx.z();
        this.oa();
        this.mj();
    }
    mj() {
        if (!this.gl()) {
            return;
        }
        let a = this.ic();
        let b = this.ig();
        this.mh(a, b);
    }
    mh(a, b) {
        let c = this.ic();
        let d = this.ig();
        if (b < c || a > d) {
            return;
        }
        if (a < c) {
            a = c;
        }
        if (b > d) {
            b = d;
        }
        this.b1.z(this, a, b, true);
        this.model.a3 = true;
        this.ob();
    }
    ib() {
        return this.d3.k(this.model.actualVisibleRegion.left, this, this.model);
    }
    ie() {
        return this.d3.k(this.model.actualVisibleRegion.right, this, this.model);
    }
    mi(a, b) {
        let c = this.d3.f(this.model, a);
        let d = this.d3.f(this.model, b);
        this.mh(c, d);
    }
    n7() {
        if (!this.eu) {
            this.eu = true;
            this.d9.w();
            this.renderingEngine.invalidateVisibility(() => this.d9.n(this));
            this.renderingEngine.refresh(this.model, false);
        }
    }
    np(a, b) {
        let c = this.da.getRowPathForRow(a);
        this.ci.ae(c);
        this.dx.ad(this.d3.f(this.model, c));
        this.af.af(this.d3.f(this.model, c));
        this.n7();
    }
    nu(a, b) {
        let c = this.da.getRowPathForRow(a);
        this.ci.af(c);
        this.dx.ae(this.d3.f(this.model, c));
        this.af.ag(this.d3.f(this.model, c));
        this.n7();
    }
    ot(a) {
        for (let b = 0; b < this.di.g.count; b++) {
            if (this.di.g._inner[b].n == a) {
                this.os(this.di.g._inner[b]);
            }
        }
    }
    os(a) {
        this.di.x(a);
    }
    mq(a, b, c) {
        if (this.u != null) {
            this.u.notifySetItem(a, b, c);
        }
    }
    mm() {
        if (this.u != null) {
            this.u.notifyClearItems();
        }
    }
    mo(a, b) {
        if (this.u != null) {
            this.u.notifyInsertItem(a, b);
        }
        ;
    }
    mp(a, b) {
        if (this.u != null) {
            this.u.notifyRemoveItem(a, b);
        }
        ;
    }
    h5(a) {
        if (this.u == null) {
            return -1;
        }
        return this.u.indexOfItem(a);
    }
    h6(a) {
        if (this.u == null) {
            return -1;
        }
        return this.u.indexOfKey(a);
    }
    g() {
        if (this.actualDataSource != null) {
            return this.actualDataSource.actualPrimaryKey;
        }
        return this.d;
    }
    i2(a) {
        let b = a.b != null ? a.b : this.au.e(a.j);
        let c = null;
        if (a.h != null) {
            c = a.h;
        }
        else if (a.primaryKey != null) {
            if (this.g() == null && a.primaryKey.key == null && a.primaryKey.value.length == 1) {
                c = a.primaryKey.value[0];
            }
            else {
                c = this.da.getItemForKey(a.primaryKey);
            }
        }
        if (b != null && c != null) {
            return this.actualDataSource.getItemProperty(c, b.gb);
        }
        return null;
    }
    i3(a, b) {
        if (b < 0 || b > this.au.h.count) {
            return null;
        }
        if (a < 0 || a > this.da.getRowCount() - 1) {
            return null;
        }
        let c = this.actualDataSource.getItemAtIndex(a);
        if (c == null) {
            return null;
        }
        else {
            let d = this.da.getRowType(a);
            if (d != 0 && d != 3) {
                return null;
            }
        }
        let e = this.au.h._inner[b];
        return this.actualDataSource.getItemProperty(c, e.gb);
    }
    h() {
        if (this.actualDataSource != null) {
            return this.actualDataSource.getRootSummaryResults();
        }
        return null;
    }
    i(a) {
        if (this.actualDataSource != null) {
            return this.actualDataSource.getSectionSummaryResults(a);
        }
        return null;
    }
    get gh() {
        return this.e6;
    }
    set gh(a) {
        let b = this.e6;
        this.e6 = a;
        if (b != this.e6) {
            this.nt("ReactsToSortChanges", b, this.e6);
        }
    }
    get gg() {
        return this.e5;
    }
    set gg(a) {
        let b = this.e5;
        this.e5 = a;
        if (b != this.e5) {
            this.nt("ReactsToGroupChanges", b, this.e5);
        }
    }
    get gf() {
        return this.e4;
    }
    set gf(a) {
        let b = this.e4;
        this.e4 = a;
        if (b != this.e4) {
            this.nt("ReactsToFilterChanges", b, this.e4);
        }
    }
}
Grid.$t = markType(Grid, 'Grid', Base.$, [INotifyPropertyChanged_$type]);
/**
 * @hidden
 */
class GridSelectedCellsChangedEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._addedCells = null;
        this._removedCells = null;
    }
    get addedCells() {
        return this._addedCells;
    }
    set addedCells(a) {
        this._addedCells = a;
    }
    get removedCells() {
        return this._removedCells;
    }
    set removedCells(a) {
        this._removedCells = a;
    }
}
GridSelectedCellsChangedEventArgs.$t = markType(GridSelectedCellsChangedEventArgs, 'GridSelectedCellsChangedEventArgs', EventArgs.$);
/**
 * @hidden
 */
class GridCellEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._cellInfo = null;
        this._grid = null;
    }
    get cellInfo() {
        return this._cellInfo;
    }
    set cellInfo(a) {
        this._cellInfo = a;
    }
    get grid() {
        return this._grid;
    }
    set grid(a) {
        this._grid = a;
    }
}
GridCellEventArgs.$t = markType(GridCellEventArgs, 'GridCellEventArgs', EventArgs.$);
/**
 * @hidden
 */
class GridAnimationManager extends Base {
    constructor() {
        super();
        this.l = new List$1(Number_$type, 0);
        this.i = false;
        this.animationCreated = null;
        this.animationCompleted = null;
        this.animationCanceled = null;
        this.g = new GridColumnAnimationSettings();
        this.f = new GridAnimationSettings();
        this.k = new Dictionary$2(Number_$type, List$1.$.specialize(Delegate_$type), 0);
        this.e = null;
        this.d = null;
        this.e = new GridAnimationPhaseSettings();
        this.e.l = 0;
        this.e.e = true;
        this.e.n = 0;
        this.d = new GridAnimationPhaseSettings();
        this.d.l = 0;
        this.d.e = true;
        this.d.n = 0;
    }
    get h() {
        return this.g;
    }
    p() {
        let a = GridAnimationManager.o;
        GridAnimationManager.o++;
        return a;
    }
    aq() {
        this.i = true;
        this.l = new List$1(Number_$type, 0);
    }
    m() {
        this.i = false;
        return this.l;
    }
    x(a) {
        if (this.i) {
            this.l.add(a);
        }
        if (this.animationCreated != null) {
            this.animationCreated(this, ((() => {
                let $ret = new GridAnimationManagerAnimationCreatedEventArgs();
                $ret.a = a;
                return $ret;
            })()));
        }
    }
    v(a) {
        if (this.i) {
            this.l.remove(a);
        }
        if (this.animationCanceled != null) {
            this.animationCanceled(this, ((() => {
                let $ret = new GridAnimationManagerAnimationCanceledEventArgs();
                $ret.a = a;
                return $ret;
            })()));
        }
    }
    w(a) {
        if (this.i) {
            this.l.remove(a);
        }
        if (this.animationCompleted != null) {
            this.animationCompleted(this, ((() => {
                let $ret = new GridAnimationManagerAnimationCompletedEventArgs();
                $ret.a = a;
                return $ret;
            })()));
        }
    }
    ap(a, b, c, d, e) {
        if (c == null) {
            return;
        }
        let f = this.p();
        this.x(f);
        let g;
        let h;
        let i = a.au.d(c.m);
        if (i == null) {
            return;
        }
        let j = new GridEffectGroup(1);
        j.effectsFinished = delegateCombine(j.effectsFinished, (k, l) => {
            i.ed = 5;
            c.a = 5;
            a.oa();
            a.ne(i);
            this.w(f);
        });
        j.effectsCanceled = delegateCombine(j.effectsCanceled, (k, l) => {
            a.nd(i);
            this.v(f);
        });
        if (d) {
            if (i.eh != null && i.eh.n != null) {
                g = i.eh.n;
            }
            else if (b != null && b.n != null) {
                g = b.n;
            }
            else {
                g = this.g.n;
            }
            if (i.eh != null && i.eh.m != null) {
                h = i.eh.m;
            }
            else if (b != null && b.m != null) {
                h = b.m;
            }
            else {
                h = this.g.m;
            }
        }
        else {
            if (i.eh != null && i.eh.x != null) {
                g = i.eh.x;
            }
            else if (b != null && b.x != null) {
                g = b.x;
            }
            else {
                g = this.g.x;
            }
            if (i.eh != null && i.eh.w != null) {
                h = i.eh.w;
            }
            else if (b != null && b.w != null) {
                h = b.w;
            }
            else {
                h = this.g.w;
            }
        }
        let k = a.bl;
        if (!d) {
            k = a.bm;
        }
        if (k == 0) {
            k = i.d9();
        }
        if (e == 3 || e == 0) {
            switch (k) {
                case 2:
                case 4:
                case 5:
                case 7:
                case 9:
                case 10:
                case 6:
                    c.g = -1;
                    break;
                case 3:
                case 8:
                    c.g = 1;
                    break;
            }
        }
        let l = new ColumnEffect();
        l.bx(g);
        l.al = true;
        l.bq = 0;
        l.x = (m, n, o, p, q) => {
            let r = o;
            let s = n;
            let t = p;
            t.g = s + (r - s) * m;
        };
        l.o = (m, n) => c.g;
        j.g(l);
        a.ci.u(c, l);
        let m = new ColumnCellsEffect();
        m.t = 1;
        m.bx(h);
        m.al = true;
        m.bq = 0;
        m.x = (n, o, p, q, r) => {
            let s = p;
            let t = o;
            let u = q;
            switch (k) {
                case 6:
                case 2:
                case 3:
                case 7:
                case 8:
                    u.bk = t + (s - t) * n;
                    break;
                case 4:
                case 5:
                case 9:
                case 10:
                    u.bo = t + (s - t) * n;
                    break;
            }
        };
        m.o = (n, o) => {
            let p = n;
            let q = p.bk;
            if (k == 4 || k == 5 || k == 9 || k == 10) {
                q = p.bo;
            }
            if (e == 0 || e == 3) {
                switch (k) {
                    case 6:
                        q = 0;
                        p.bk = q;
                        p.bp = q;
                        p.bj = 0;
                        p.bo = 0;
                        break;
                    case 2:
                    case 7:
                        q = -1;
                        p.bk = q;
                        p.bj = 0;
                        p.bp = 0;
                        p.bo = 0;
                        break;
                    case 3:
                    case 8:
                        q = 1;
                        p.bk = q;
                        p.bj = 0;
                        p.bp = 0;
                        p.bo = 0;
                        break;
                    case 4:
                    case 9:
                        q = (a.g7 + a.model.bs) * -1;
                        p.bo = q;
                        p.bj = 0;
                        p.bk = 0;
                        p.bp = 0;
                        break;
                    case 5:
                    case 10:
                        q = (a.g7 + a.model.bs) * 1;
                        p.bo = q;
                        p.bj = 0;
                        p.bk = 0;
                        p.bp = 0;
                        break;
                }
            }
            return q;
        };
        if (a.model.a2()) {
            m.g = new CellPath(0, 0, c.l, a.model.aw.t, a.model.aw.s);
            m.e = new CellPath(0, 0, c.l, a.model.av.t, a.model.av.s);
        }
        j.g(m);
        if (k == 4 || k == 9) {
            m.ao = true;
        }
        a.ci.t(c, m);
        let n = new ColumnCellsEffect();
        n.t = 2;
        n.bx(h);
        n.al = true;
        n.bq = 1;
        n.x = (o, p, q, r, s) => {
            let t = q;
            let u = p;
            let v = r;
            let w = u + (t - u) * o;
            if (w < 0) {
                w = 0;
            }
            v.bi = w;
        };
        n.o = (o, p) => {
            let q = o;
            if (e == 0 || e == 3) {
                switch (k) {
                    case 10:
                    case 7:
                    case 8:
                    case 9:
                        q.bi = -1;
                        break;
                    case 6:
                        q.bi = 0;
                        break;
                }
            }
            return q.bi;
        };
        if (a.model.a2()) {
            n.g = new CellPath(0, 0, c.l, a.model.aw.t, a.model.aw.s);
            n.e = new CellPath(0, 0, c.l, a.model.av.t, a.model.av.s);
        }
        j.g(n);
        if (k == 4 || k == 9) {
            n.ao = true;
        }
        a.ci.t(c, n);
    }
    aj(a, b, c, d, e) {
        if (c == null || d == null) {
            return;
        }
        let f = this.p();
        this.x(f);
        c.a = 2;
        d.a = 1;
        let g;
        let h;
        let i = a.au.d(d.m);
        let j = a.au.d(c.m);
        if (i == null || j == null) {
            return;
        }
        if (i.eh != null && i.eh.o != null) {
            g = i.eh.o;
        }
        else if (j.eh != null && j.eh.o != null) {
            g = j.eh.o;
        }
        else if (b != null && b.x != null) {
            g = b.o;
        }
        else {
            g = this.g.o;
        }
        if (i.eh != null && i.eh.p != null) {
            h = i.eh.p;
        }
        else if (j.eh != null && j.eh.p != null) {
            h = j.eh.p;
        }
        else if (b != null && b.p != null) {
            h = b.p;
        }
        else {
            h = this.g.p;
        }
        let k = a.aw;
        if (k == 0) {
            k = i.d6();
        }
        let l = false;
        if (k == 2 || k == 7) {
            l = true;
        }
        if (l) {
            d.g = 1;
        }
        else {
            d.g = -1;
        }
        if (this.k.containsKey(c.m)) {
            this.k.addItem(d.m, new List$1(Delegate_$type, 0));
            this.k.item(c.m).add(() => {
                c = a.model.f(c.m);
                d = a.model.f(d.m);
                if (c == null || d == null) {
                    return;
                }
                j.ed = 2;
                c.a = 2;
                i.ed = 1;
                d.a = 1;
                this.y(a, c, d, g, h, i, j, k, l, f);
            });
        }
        else {
            this.k.addItem(d.m, new List$1(Delegate_$type, 0));
            this.y(a, c, d, g, h, i, j, k, l, f);
        }
    }
    y(a, b, c, d, e, f, g, h, i, j) {
        if (b == null || c == null) {
            return;
        }
        let k = new GridEffectGroup(1);
        k.effectsFinished = delegateCombine(k.effectsFinished, (l, m) => {
            let n = a.model.f(b.m);
            let o = a.model.f(c.m);
            let p = new GridEffectGroup(1);
            p.effectsFinished = delegateCombine(p.effectsFinished, (q, r) => {
                g.ed = 3;
                b.a = 3;
                a.columns.remove(g);
                f.ed = 5;
                c.a = 5;
                a.oa();
                if (this.k.containsKey(c.m)) {
                    let s = this.k.item(c.m);
                    if (s.count == 0) {
                        this.k.removeItem(c.m);
                    }
                    else {
                        let t = s._inner[0];
                        s.removeAt(0);
                        t();
                    }
                }
                a.m5(f);
                this.w(j);
            });
            p.effectsCanceled = delegateCombine(p.effectsCanceled, (q, r) => {
                a.m4(f);
                this.v(j);
            });
            this.u(a, n, o, d, g, i, p);
            this.t(a, n, o, d, f, g, i, p);
        });
        k.effectsCanceled = delegateCombine(k.effectsCanceled, (l, m) => {
            a.m4(f);
            let n = new GridEffectGroup(1);
            n.effectsFinished = delegateCombine(n.effectsFinished, (o, p) => {
                g.ed = 3;
                b.a = 3;
                a.columns.remove(g);
                a.oa();
            });
            n.effectsCanceled = delegateCombine(n.effectsCanceled, (o, p) => {
            });
            let o = a.model.f(b.m);
            let p = a.model.f(c.m);
            this.u(a, o, p, d, g, i, n);
        });
        let l = new ColumnCellsEffect();
        l.t = 1;
        l.bx(e);
        l.al = true;
        k.g(l);
        if (i) {
            l.bq = -1 - b.g;
        }
        else {
            l.bq = 1 + b.g;
        }
        let m = false;
        switch (h) {
            case 4:
            case 9:
                l.bq = (a.g7 + a.model.bs) * -1;
                m = true;
                break;
            case 5:
            case 10:
                l.bq = (a.g7 + a.model.bs) * 1;
                m = true;
                break;
        }
        if (m) {
            l.bi = 0;
        }
        l.x = (n, o, p, q, r) => {
            let s = p;
            let t = o;
            let u = q;
            switch (h) {
                case 2:
                case 3:
                case 7:
                case 8:
                    u.bk = t + (s - t) * n;
                    break;
                case 4:
                case 5:
                case 9:
                case 10:
                    u.bo = t + (s - t) * n;
                    break;
            }
        };
        l.o = (n, o) => {
            let p = n;
            let q = p.bk;
            if (h == 4 || h == 5 || h == 9 || h == 10) {
                q = p.bo;
            }
            if (h == 6) {
                q = 0;
            }
            switch (h) {
                case 2:
                case 7:
                case 6:
                    p.bk = q;
                    p.bj = 0;
                    p.bp = 0;
                    p.bo = 0;
                    break;
                case 3:
                case 8:
                    p.bk = q;
                    p.bj = 0;
                    p.bp = 0;
                    p.bo = 0;
                    break;
                case 4:
                case 9:
                    q = p.bo;
                    p.bo = q;
                    p.bj = 0;
                    p.bk = 0;
                    p.bp = 0;
                    break;
                case 5:
                case 10:
                    q = p.bo;
                    p.bo = q;
                    p.bj = 0;
                    p.bk = 0;
                    p.bp = 0;
                    break;
            }
            return q;
        };
        if (a.model.a2()) {
            l.g = new CellPath(0, 0, b.l, a.model.aw.t, a.model.aw.s);
            l.e = new CellPath(0, 0, b.l, a.model.av.t, a.model.av.s);
        }
        l.onFinished = delegateCombine(l.onFinished, (n) => {
        });
        if (h == 4 || h == 9) {
            l.ao = true;
        }
        a.ci.t(b, l);
        let n = new ColumnCellsEffect();
        n.t = 1;
        n.bx(e);
        n.al = true;
        k.g(n);
        if (i) {
            n.bq = -1;
        }
        else {
            n.bq = 1;
        }
        if (m) {
            n.bq = 0;
        }
        if (m) {
            n.bi = 0;
        }
        n.x = (o, p, q, r, s) => {
            let t = q;
            let u = p;
            let v = r;
            switch (h) {
                case 2:
                case 3:
                case 7:
                case 8:
                    v.bk = u + (t - u) * o;
                    break;
                case 4:
                case 5:
                case 9:
                case 10:
                    v.bo = u + (t - u) * o;
                    break;
            }
        };
        n.o = (o, p) => {
            let q = o;
            let r = q.bk;
            if (h == 4 || h == 5 || h == 9 || h == 10) {
                r = q.bo;
            }
            if (h == 6) {
                r = n.bq;
            }
            else {
                r = 0;
            }
            switch (h) {
                case 2:
                case 7:
                case 6:
                    q.bk = r;
                    q.bj = 0;
                    q.bp = 0;
                    q.bo = 0;
                    break;
                case 3:
                case 8:
                    q.bk = r;
                    q.bj = 0;
                    q.bp = 0;
                    q.bo = 0;
                    break;
                case 4:
                case 9:
                    r = (a.g7 + a.model.bs) * 1;
                    q.bo = r;
                    q.bj = 0;
                    q.bk = 1;
                    q.bp = 0;
                    break;
                case 5:
                case 10:
                    r = (a.g7 + a.model.bs) * -1;
                    q.bo = r;
                    q.bj = 0;
                    q.bk = 1;
                    q.bp = 0;
                    break;
            }
            return r;
        };
        if (a.model.a2()) {
            n.g = new CellPath(0, 0, c.l, a.model.aw.t, a.model.aw.s);
            n.e = new CellPath(0, 0, c.l, a.model.av.t, a.model.av.s);
        }
        if (h == 5 || h == 10) {
            n.ao = true;
        }
        a.ci.t(c, n);
        let o = new ColumnCellsEffect();
        o.t = 2;
        o.bx(e);
        o.al = true;
        o.bq = 0;
        k.g(o);
        if (h != 6 && h != 10 && h != 7 && h != 9) {
            o.bq = 1;
        }
        o.x = (p, q, r, s, t) => {
            let u = r;
            let v = q;
            let w = s;
            w.bl = v + (u - v) * p;
        };
        o.o = (p, q) => {
            let r = p;
            let s = r.bl;
            return s;
        };
        if (a.model.a2()) {
            o.g = new CellPath(0, 0, b.l, a.model.aw.t, a.model.aw.s);
            o.e = new CellPath(0, 0, b.l, a.model.av.t, a.model.av.s);
        }
        o.onFinished = delegateCombine(o.onFinished, (p) => {
        });
        if (h == 5 || h == 10) {
            o.ao = true;
        }
        a.ci.t(b, o);
        let p = new ColumnCellsEffect();
        p.t = 2;
        p.bx(e);
        p.al = true;
        p.bq = 1;
        k.g(p);
        p.x = (q, r, s, t, u) => {
            let v = s;
            let w = r;
            let x = t;
            x.bl = w + (v - w) * q;
        };
        p.o = (q, r) => {
            let s = q;
            let t = s.bl;
            if (h == 6 || h == 10 || h == 8 || h == 7 || h == 9) {
                t = 0;
            }
            s.bl = t;
            return t;
        };
        if (a.model.a2()) {
            p.g = new CellPath(0, 0, c.l, a.model.aw.t, a.model.aw.s);
            p.e = new CellPath(0, 0, c.l, a.model.av.t, a.model.av.s);
        }
        if (h == 5 || h == 10) {
            p.ao = true;
        }
        a.ci.t(c, p);
    }
    u(a, b, c, d, e, f, g) {
        if (b == null) {
            return;
        }
        let h = new ColumnEffect();
        h.bx(d);
        h.al = true;
        g.g(h);
        if (f) {
            h.bq = -1;
        }
        else {
            h.bq = 1;
        }
        h.x = (i, j, k, l, m) => {
            let n = k;
            let o = j;
            let p = l;
            p.g = o + (n - o) * i;
        };
        h.o = (i, j) => {
            if (this.j(b, c)) {
                b.g = h.bq;
                return h.bq;
            }
            return b.g;
        };
        a.ci.u(b, h);
    }
    t(a, b, c, d, e, f, g, h) {
        if (c == null) {
            return;
        }
        let i = new ColumnEffect();
        i.bx(d);
        i.al = true;
        i.bq = 0;
        h.g(i);
        i.x = (j, k, l, m, n) => {
            let o = l;
            let p = k;
            let q = m;
            q.g = p + (o - p) * j;
        };
        i.o = (j, k) => {
            if (this.j(b, c)) {
                c.g = i.bq;
                return c.g;
            }
            return c.g;
        };
        a.ci.u(c, i);
        let j = new ColumnCellsEffect();
        j.bx(d);
        j.al = true;
        j.bq = 0;
        h.g(j);
        j.x = (k, l, m, n, o) => {
            let p = m;
            let q = l;
            let r = n;
            r.bk = q + (p - q) * k;
        };
        j.o = (k, l) => {
            let m = k;
            if (this.j(b, c)) {
                m.bk = j.bq;
                return m.bk;
            }
            return m.bk;
        };
        a.ci.t(c, j);
    }
    j(a, b) {
        if (a == null) {
            return true;
        }
        if (b == null) {
            return true;
        }
        if (a.b == null && b.b == null) {
            return true;
        }
        if (a.b == null && (b.b.c && b.b.f == 1)) {
            return true;
        }
        if ((a.b.c && a.b.f == 1) && b.b == null) {
            return true;
        }
        if (a.b.c && b.b.c && a.b.f == b.b.f) {
            return true;
        }
        if (!a.b.c && !b.b.c && a.b.f == b.b.f) {
            return true;
        }
        return false;
    }
    q(a, b) {
        if (b.c == 1) {
            return a.d3.h(b.l, a.model.bi, a, a.model);
        }
        else if (b.c == 2) {
            return a.d3.i(b.l, a.model.bj, a, a.model);
        }
        else {
            return a.d3.g(b.l, a, a.model);
        }
    }
    ah(a, b, c, d) {
        if (c == null) {
            return;
        }
        let e = a.au.d(c.m);
        if (e == null) {
            return;
        }
        let f = this.p();
        this.x(f);
        let g;
        if (e.eh != null && e.eh.v != null) {
            g = e.eh.v;
        }
        else if (b != null && b.v != null) {
            g = b.v;
        }
        else {
            g = this.g.v;
        }
        let h = new ColumnEffect();
        h.bx(g);
        h.al = true;
        h.bq = d;
        h.onFinished = delegateCombine(h.onFinished, (i) => this.w(f));
        h.onCanceled = delegateCombine(h.onCanceled, (i, j) => this.v(f));
        h.x = (i, j, k, l, m) => {
            let n = k;
            let o = j;
            let p = l;
            let q = o + (n - o) * i;
            let r = ((() => {
                let $ret = new ColumnWidth();
                $ret.f = q;
                $ret.c = false;
                return $ret;
            })());
            if (!isNaN_(e.e5)) {
                r.e = e.e5;
            }
            e.width = r;
        };
        h.o = (i, j) => c.j;
        if (!a.fq(e)) {
            h.ba = 0;
        }
        a.ci.u(c, h);
    }
    al(a, b, c, d) {
        if (c == null) {
            return;
        }
        let e = this.p();
        this.x(e);
        let f;
        let g;
        let h = a.au.d(c.m);
        if (h == null) {
            return;
        }
        if (h.eh != null && h.eh.t != null) {
            f = h.eh.t;
        }
        else if (b != null && b.t != null) {
            f = b.t;
        }
        else {
            f = this.g.t;
        }
        if (h.eh != null && h.eh.s != null) {
            g = h.eh.s;
        }
        else if (b != null && b.w != null) {
            g = b.s;
        }
        else {
            g = this.g.s;
        }
        let i = a.a4;
        let j = new GridEffectGroup(1);
        j.effectsFinished = delegateCombine(j.effectsFinished, (k, l) => {
            let m = a.model.f(c.m);
            let n = a.model.bd(m);
            for (let o = 0; o < n.count; o++) {
                a.model.b6(n._inner[o]);
            }
            h.ed = 5;
            a.oa();
            a.nb(h);
            this.w(e);
        });
        j.effectsCanceled = delegateCombine(j.effectsCanceled, (k, l) => {
            a.na(h);
            this.v(e);
        });
        if (i == 0) {
            i = 2;
        }
        let k = 0;
        let l = c.g;
        c.g = 0;
        k = this.q(a, c);
        c.g = l;
        let m = h.fc;
        let n = false;
        if (c.l < m) {
            n = true;
        }
        let o = null;
        if (d != 6) {
            o = a.model.g(m, c, (c.j + a.model.bo) - c.e(a.model), c.b == null || c.b.c, n);
        }
        let p = a.model.bd(c);
        for (let q = 0; q < p.count; q++) {
            p._inner[q].e = true;
        }
        let r = c.l;
        let s = null;
        let t = a.model.bg;
        if (t._inner[r].count > 0) {
            for (let u = 0; u < t._inner[r].count; u++) {
                if (t._inner[r]._inner[u].n == c.m) {
                    s = t._inner[r]._inner[u];
                    break;
                }
            }
        }
        let v;
        if (s != null) {
            v = s;
            v.e = false;
        }
        else {
            v = a.model.g(r, c, 0, c.b == null || c.b.c, !n);
            v.e = false;
        }
        let w = k - h.fd;
        let x = -1 * w;
        c.g = x / c.j;
        c.a = 6;
        let y = new ColumnEffect();
        y.bx(f);
        y.al = true;
        y.bq = 0;
        let z = c.j;
        let aa = false;
        let ab = 0;
        let ac = c.l;
        let ad = a.d3.g(c.l, a, a.model);
        let ae = this.n(a, c, c.l);
        ad = this.r(a, c, ad, a.model.bd(c), ae);
        j.g(y);
        y.x = (af, ag, ah, ai, aj) => {
            let ak = ah;
            let al = ag;
            let am = ai;
            am.g = al + (ak - al) * af;
            if (am.j > 0) {
                let an = a.d3.j(am.l, a, aj);
                if (an - h.fd != w) {
                    let ao = an - h.fd;
                    let ap = w - ao;
                    let aq = ab + (ap / am.j);
                    let ar = aq / (1 - af);
                    y.by(ar, aj, am.m);
                    am.g = aq;
                    ab = aq;
                    w = ao;
                    am.g = ar + (ak - ar) * af;
                }
                if (!aa) {
                    let as = a.model.bc(am);
                    for (let at = 0; at < as.count; at++) {
                        let au = as._inner[at];
                        au.bk += (ab - am.g);
                    }
                }
                ab = am.g;
                ac = am.l;
                let av = a.model.bd(am);
                ae = this.n(a, am, am.l);
                ad = this.r(a, am, ad, av, ae);
            }
        };
        y.o = (af, ag) => {
            ab = c.g;
            return c.g;
        };
        a.ci.u(c, y);
        let af = new ColumnCellsEffect();
        af.ar = true;
        af.bx(g);
        af.al = true;
        af.bq = 0;
        j.g(af);
        af.x = (ag, ah, ai, aj, ak) => {
            if (ag > 0) {
                aa = true;
            }
            if (aa) {
                let al = ai;
                let am = ah;
                let an = aj;
                let ao = am + (al - am) * ag;
                an.bk = ao;
            }
        };
        af.o = (ag, ah) => {
            let ai = ag;
            return ai.bk;
        };
        if (a.model.a2()) {
            af.g = new CellPath(0, 0, c.l, a.model.aw.t, a.model.aw.s);
            af.e = new CellPath(0, 0, c.l, a.model.av.t, a.model.av.s);
        }
        a.ci.t(c, af);
    }
    r(a, b, c, d, e) {
        if (e > 0) {
            let f = 0;
            for (let g = 0; g < d.count; g++) {
                if (!d._inner[g].e) {
                    if (e > d._inner[g].i) {
                        f = Math.abs(d._inner[g].i - e);
                        d._inner[g].i = e;
                    }
                }
            }
            let h = 0;
            for (let i = 0; i < d.count; i++) {
                if (d._inner[i].e) {
                    h += d._inner[i].i;
                }
            }
            let j = h - f;
            if (j < 0) {
                j = 0;
            }
            let k = 1;
            if (h == 0) {
                k = 0;
            }
            else {
                k = j / h;
            }
            for (let l = 0; l < d.count; l++) {
                if (d._inner[l].e) {
                    d._inner[l].i = d._inner[l].i * k;
                }
            }
        }
        if (b.m == 0) {
            c = a.d3.g(b.l, a, a.model);
        }
        return c;
    }
    n(a, b, c) {
        let d = a.d3.j(c, a, a.model);
        let e = d + b.j;
        let f = a.d3.g(b.l, a, a.model);
        if (d > f) {
            return Math.max(0, (f + b.j) - d);
        }
        else {
            return Math.max(0, (d + b.j) - f);
        }
    }
    ak(a, b, c, d, e) {
        if (c == null) {
            return;
        }
        let f = this.p();
        this.x(f);
        let g;
        let h;
        let i = a.au.d(c.m);
        if (i == null) {
            return;
        }
        if (i.eh != null && i.eh.q != null) {
            g = i.eh.q;
        }
        else if (b != null && b.q != null) {
            g = b.q;
        }
        else {
            g = this.g.q;
        }
        if (i.eh != null && i.eh.r != null) {
            h = i.eh.r;
        }
        else if (b != null && b.r != null) {
            h = b.r;
        }
        else {
            h = this.g.r;
        }
        let j = a.a1;
        let k = new GridEffectGroup(1);
        k.effectsFinished = delegateCombine(k.effectsFinished, (l, m) => {
            i.ed = 3;
            c.a = 3;
            if (i.eu) {
                a.externalGrid.ensureColumnsAreManual();
                a.externalGrid.removeExternalColumn(i.externalObject);
            }
            a.oa();
            a.m7(i);
            this.w(f);
        });
        k.effectsCanceled = delegateCombine(k.effectsCanceled, (l, m) => {
            a.m6(i);
            this.v(f);
        });
        if (j == 0) {
            j = i.d7();
        }
        let l = 0;
        switch (j) {
            case 2:
            case 7:
                l = -1;
                break;
            case 3:
            case 8:
                l = 1;
                break;
            case 4:
            case 9:
                l = (a.g7 + a.model.bs) * -1;
                break;
            case 5:
            case 10:
                l = (a.g7 + a.model.bs) * 1;
                break;
        }
        let m = new ColumnCellsEffect();
        m.bx(g);
        m.t = 1;
        m.al = true;
        m.bq = l;
        k.g(m);
        m.x = (n, o, p, q, r) => {
            let s = p;
            let t = o;
            let u = q;
            switch (j) {
                case 2:
                case 3:
                case 7:
                case 8:
                    u.bk = t + (s - t) * n;
                    break;
                case 4:
                case 5:
                case 9:
                case 10:
                    u.bo = t + (s - t) * n;
                    break;
            }
        };
        m.o = (n, o) => {
            let p = n;
            let q = p.bk;
            if (j == 4 || j == 5) {
                q = p.bo;
            }
            return q;
        };
        if (a.model.a2()) {
            m.g = new CellPath(0, 0, c.l, a.model.aw.t, a.model.aw.s);
            m.e = new CellPath(0, 0, c.l, a.model.av.t, a.model.av.s);
        }
        if (j == 5 || j == 10) {
            m.ao = true;
        }
        a.ci.t(c, m);
        let n = 0;
        switch (j) {
            case 2:
            case 4:
            case 5:
            case 7:
            case 9:
            case 10:
            case 6:
                n = -1;
                break;
            case 3:
            case 8:
                n = 1;
                break;
        }
        let o = new ColumnEffect();
        o.bx(h);
        o.al = true;
        o.bq = n;
        k.g(o);
        o.x = (p, q, r, s, t) => {
            let u = r;
            let v = q;
            let w = s;
            w.g = v + (u - v) * p;
        };
        o.o = (p, q) => c.g;
        a.ci.u(c, o);
        let p = new ColumnCellsEffect();
        p.t = 2;
        p.bx(g);
        p.al = true;
        if (j == 6 || j == 10 || j == 7 || j == 8 || j == 9) {
            p.bq = 0;
        }
        else {
            p.bq = 1;
        }
        p.x = (q, r, s, t, u) => {
            let v = s;
            let w = r;
            let x = t;
            let y = w + (v - w) * q;
            if (y < 0) {
                y = 0;
            }
            x.bi = y;
        };
        p.o = (q, r) => {
            let s = q;
            if (e == 0 || e == 3) {
                switch (j) {
                    case 10:
                    case 7:
                    case 8:
                    case 9:
                        s.bi = 1;
                        break;
                    case 6:
                        s.bi = 1;
                        break;
                }
            }
            return s.bi;
        };
        if (a.model.a2()) {
            p.g = new CellPath(0, 0, c.l, a.model.aw.t, a.model.aw.s);
            p.e = new CellPath(0, 0, c.l, a.model.av.t, a.model.av.s);
        }
        k.g(p);
        if (j == 5 || j == 10) {
            p.ao = true;
        }
        a.ci.t(c, p);
    }
    s(a, b, c, d, e, f, g, h, i, j) {
        if (!a.model.a2()) {
            return;
        }
        let k = this.p();
        this.x(k);
        let l = this.g.u;
        if (a.cc != null && a.cc.u != null) {
            l = a.cc.u;
        }
        let m = a.columnPropertyUpdatingAnimationMode;
        let n = new ColumnCellsEffect();
        n.bx(l);
        n.t = 7;
        n.as = true;
        if (g) {
            n.v = 5;
        }
        n.bs = c;
        n.al = true;
        n.bq = f;
        n.onFinished = delegateCombine(n.onFinished, (o) => this.w(k));
        n.onCanceled = delegateCombine(n.onCanceled, (o, p) => this.v(k));
        if (m == 0) {
            m = 2;
        }
        if (d == 11) {
            n.x = (o, p, q, r, s) => {
                let t = r;
                if (!h && g != t.i.e) {
                    return;
                }
                if (t.i.f && !j) {
                    return;
                }
                t.hs(c, q);
            };
        }
        if (d == 5 || d == 4 || d == 9 || d == 8 || (m != 3 && (d == 7 || d == 1 || d == 3))) {
            n.x = (o, p, q, r, s) => {
                let t = r;
                if (!h && g != t.i.e) {
                    return;
                }
                if (t.i.f && !j) {
                    return;
                }
                if (o > 0.5) {
                    t.hs(c, q);
                }
                else {
                    t.hs(c, p);
                }
            };
        }
        if (m == 3 && d == 1) {
            n.x = (o, p, q, r, s) => {
                let t = r;
                if (!h && g != t.i.e) {
                    return;
                }
                if (t.i.f && !j) {
                    return;
                }
                let u = p;
                let v = q;
                let w = u + (v - u) * o;
                t.hs(c, w);
            };
        }
        if (d == 0) {
            n.x = (o, p, q, r, s) => {
                let t = r;
                if (!h && g != t.i.e) {
                    return;
                }
                if (t.i.f && !j) {
                    return;
                }
                let u = p;
                let v = q;
                let w = u + (v - u) * o;
                t.hs(c, w);
            };
        }
        if (d == 2) {
            n.x = (o, p, q, r, s) => {
                let t = r;
                if (!h && g != t.i.e) {
                    return;
                }
                if (t.i.f && !j) {
                    return;
                }
                let u = p;
                let v = q;
                let w = BrushUtil.g(u, o, v, 0);
                t.hs(c, w);
            };
        }
        if (d == 3) {
            n.x = (o, p, q, r, s) => {
                let t = r;
                if (!h && g != t.i.e) {
                    return;
                }
                if (t.i.f && !j) {
                    return;
                }
                let u = p;
                let v = q;
                if (u != null) {
                    u.t(a.externalGrid.renderer);
                }
                if (v != null) {
                    v.t(a.externalGrid.renderer);
                }
                let w = new FontInfo();
                FontUtil.interpolateFont(w, o, u, v);
                t.hs(c, w);
            };
        }
        if (d == 6) {
            n.x = (o, p, q, r, s) => {
                let t = r;
                if (!h && g != t.i.e) {
                    return;
                }
                if (t.i.f && !j) {
                    return;
                }
                let u = typeGetValue(p);
                let v = typeGetValue(q);
                let w = truncate((Math.round(u + (v - u) * o)));
                t.hs(c, w);
            };
        }
        n.o = (o, p) => {
            let q = o;
            return q.fa(c);
        };
        if (a.model.a2()) {
            if (h) {
                n.g = new CellPath(0, 0, -300, a.model.aw.t, a.model.aw.s);
                n.e = new CellPath(0, 0, -300, a.model.av.t, a.model.av.s);
            }
            else if (i) {
                n.g = new CellPath(0, 0, -400, a.model.aw.t, a.model.aw.s);
                n.e = new CellPath(0, 0, -400, a.model.av.t, a.model.av.s);
            }
            else {
                n.g = new CellPath(0, 0, b.l, a.model.aw.t, a.model.aw.s);
                n.e = new CellPath(0, 0, b.l, a.model.av.t, a.model.av.s);
            }
        }
        if (!a.fp || d == 11) {
            n.ba = 0;
        }
        if (h) {
            a.ci.x(n);
        }
        else if (i) {
            a.ci.y(n);
        }
        else {
            a.ci.t(b, n);
        }
    }
    am(a, b, c) {
        let d = this.p();
        this.x(d);
        let e = this.e;
        let f = a.model;
        let g = new GridEffectGroup(1);
        g.effectsCanceled = delegateCombine(g.effectsCanceled, (h, i) => this.v(d));
        g.effectsFinished = delegateCombine(g.effectsFinished, (h, i) => this.w(d));
        for (let h = b; h <= c; h++) {
            let i = new RowCellsEffect();
            g.g(i);
            i.t = 6;
            i.bx(e);
            i.al = true;
            i.bq = 1;
            i.x = (j, k, l, m, n) => {
            };
            i.o = (j, k) => {
                let l = j;
                if (l.i.ab) {
                    let m = a.da.getDataRow(l.i);
                    l.dq = m;
                    if (m == -1) {
                        return l.gq;
                    }
                    let n = a.da.getRowType(m);
                    if (l.at(n)) {
                        let o = a.da.resolveValueForPath(a, l.i);
                        let p = a.j1(l.i, a, o, m);
                        a.nq(l, o, a.da.resolveRow(m), p);
                    }
                }
                return l.gq;
            };
            let j = a.dm(h);
            if (a.model.a2()) {
                i.g = new CellPath(0, 0, a.model.bw, j.t, j.s);
                i.e = new CellPath(0, 0, a.model.by, j.t, j.s);
            }
            if (!a.f4) {
                i.ba = 0;
            }
            a.ci.v(j, i);
        }
    }
    ai(a, b) {
        if (b == null) {
            return;
        }
        let c = this.p();
        this.x(c);
        let d = this.d;
        let e = a.model;
        let f = new GridEffectGroup(1);
        f.effectsFinished = delegateCombine(f.effectsFinished, (g, h) => this.w(c));
        f.effectsCanceled = delegateCombine(f.effectsCanceled, (g, h) => this.v(c));
        let g = a.au.d(b.m);
        if (g == null) {
            return;
        }
        let h = new ColumnEffect();
        f.g(h);
        h.bx(d);
        h.al = true;
        h.bq = 1;
        h.x = (i, j, k, l, m) => {
        };
        h.o = (i, j) => {
            let k = i;
            k.f = 0;
            k.g = 0;
            k.i = 0;
            a.oa();
            return k.f;
        };
        a.ci.u(b, h);
        let i = new ColumnCellsEffect();
        f.g(i);
        i.t = 1;
        i.bx(d);
        i.al = true;
        i.bq = 1;
        i.x = (j, k, l, m, n) => {
        };
        i.o = (j, k) => {
            let l = j;
            l.bj = 0;
            l.bk = 0;
            l.bo = 0;
            l.bp = 0;
            l.bi = 1;
            return l.bj;
        };
        a.ci.t(b, i);
    }
    z(a, b, c, d) {
        let e = this.p();
        this.x(e);
        let f = this.f.e;
        if (a.b3 != null && a.b3.e != null) {
            f = a.b3.e;
        }
        let g = a.ah;
        let h = a.model;
        let i = new GridEffectGroup(1);
        i.effectsFinished = delegateCombine(i.effectsFinished, (j, k) => this.w(e));
        i.effectsCanceled = delegateCombine(i.effectsCanceled, (j, k) => this.v(e));
        for (let j = 0; j < h.a9.count; j++) {
            let k = h.a9._inner[j];
            let l = a.au.d(k.m);
            if (l == null) {
                continue;
            }
            let m = new ColumnCellsEffect();
            i.g(m);
            m.t = 3;
            m.bx(f);
            m.al = true;
            m.bq = 0;
            if (g == 0) {
                g = 2;
            }
            m.x = (n, o, p, q, r) => {
                let s = q;
                let t = o;
                let u = p;
                if (s.i.ab) {
                    let v = a.as(s.i);
                    if (a.da.isPlaceholderValue(s.i)) {
                        n = 0;
                    }
                }
                s.bq = t + (u - t) * n;
            };
            m.o = (n, o) => {
                let p = n;
                if (p.i.ab) {
                    let q = a.da.getDataRow(p.i);
                    p.dq = q;
                    if (q == -1) {
                        return p.bq;
                    }
                    let r = a.da.resolveValueForPath(a, p.i);
                    let s = false;
                    if (r == null && a.da.isPlaceholderValue(p.i)) {
                        s = true;
                    }
                    if (p.at(a.da.getRowType(p.i.s))) {
                        let t = a.j1(p.i, a, r, q);
                        a.nq(p, r, a.da.resolveRow(q), t);
                    }
                    if (s) {
                        p.bq = 1;
                    }
                }
                return p.bq;
            };
            if (a.model.a2()) {
                m.g = new CellPath(0, 0, k.l, a.model.aw.t, a.model.aw.s);
                m.e = new CellPath(0, 0, k.l, a.model.av.t, a.model.av.s);
            }
            if (!a.fh || d) {
                m.ba = 0;
            }
            a.ci.t(k, m);
        }
    }
    ag(a, b, c, d, e) {
        let f = this.p();
        this.x(f);
        let g = this.f.e;
        if (a.b3 != null && a.b3.e != null) {
            g = a.b3.e;
        }
        let h = a.ah;
        let i = a.model;
        if (d < 0 || d >= i.a9.count) {
            return;
        }
        let j = i.a9._inner[d];
        let k = a.au.d(j.m);
        if (k == null) {
            return;
        }
        let l = new ColumnCellsEffect();
        l.onFinished = delegateCombine(l.onFinished, (m) => this.w(f));
        l.onCanceled = delegateCombine(l.onCanceled, (m, n) => this.v(f));
        l.t = 3;
        l.bx(g);
        l.al = true;
        l.bq = 0;
        if (h == 0) {
            h = 2;
        }
        l.x = (m, n, o, p, q) => {
            let r = p;
            let s = n;
            let t = o;
            if (r.i.ab) {
                let u = a.as(r.i);
                if (a.da.isPlaceholderValue(r.i)) {
                    m = 0;
                }
            }
            r.bq = s + (t - s) * m;
        };
        l.o = (m, n) => {
            let o = m;
            if (o.i.ab) {
                let p = a.da.getDataRow(o.i);
                o.dq = p;
                if (p == -1) {
                    return o.bq;
                }
                let q = a.da.resolveValueForPath(a, o.i);
                let r = false;
                if (q == null && a.da.isPlaceholderValue(o.i)) {
                    r = true;
                }
                if (o.at(a.da.getRowType(o.i.s))) {
                    let s = a.j1(o.i, a, q, p);
                    a.nq(o, q, a.da.resolveRow(p), s);
                }
                if (r) {
                    o.bq = 1;
                }
            }
            return o.bq;
        };
        if (a.model.a2()) {
            l.g = new CellPath(0, 0, j.l, a.model.aw.t, a.model.aw.s);
            l.e = new CellPath(0, 0, j.l, a.model.av.t, a.model.av.s);
        }
        if (!a.fh || e) {
            l.ba = 0;
        }
        a.ci.t(j, l);
    }
    an(a, b) {
        let c = this.p();
        this.x(c);
        let d = this.f.f;
        if (a.cc != null && a.b3.f != null) {
            d = a.b3.f;
        }
        let e = a.dp;
        let f = a.model;
        let g = new RowCellsEffect();
        g.onFinished = delegateCombine(g.onFinished, (h) => this.w(c));
        g.onCanceled = delegateCombine(g.onCanceled, (h, i) => this.v(c));
        g.t = 5;
        g.bx(d);
        g.al = true;
        g.bq = 1;
        if (e == 0) {
            e = 2;
        }
        g.x = (h, i, j, k, l) => {
            let m = k;
            let n = i;
            let o = j;
            if (m.i.ab) {
                m.bn = n + (o - n) * h;
            }
            else {
                m.bn = 0;
            }
        };
        g.o = (h, i) => {
            let j = h;
            return j.bn;
        };
        let h = a.dm(b);
        if (a.model.a2()) {
            g.g = new CellPath(0, 0, a.model.bw, h.t, h.s);
            g.e = new CellPath(0, 0, a.model.by, h.t, h.s);
        }
        if (!a.f4 || a.dragger.isDragActive) {
            g.ba = 0;
        }
        a.ci.v(h, g);
    }
    ao(a, b) {
        let c = this.p();
        this.x(c);
        let d = this.f.f;
        if (a.cc != null && a.b3.f != null) {
            d = a.b3.f;
        }
        let e = a.dp;
        let f = a.model;
        let g = new RowCellsEffect();
        g.onFinished = delegateCombine(g.onFinished, (h) => this.w(c));
        g.onCanceled = delegateCombine(g.onCanceled, (h, i) => this.v(c));
        g.t = 5;
        g.bx(d);
        g.al = true;
        g.bq = 0;
        if (e == 0) {
            e = 2;
        }
        g.x = (h, i, j, k, l) => {
            let m = k;
            let n = i;
            let o = j;
            if (m.i.ab) {
                m.bn = n + (o - n) * h;
            }
            else {
                m.bn = 0;
            }
        };
        g.o = (h, i) => {
            let j = h;
            return j.bn;
        };
        let h = a.dm(b);
        if (a.model.a2()) {
            g.g = new CellPath(0, 0, a.model.bw, h.t, h.s);
            g.e = new CellPath(0, 0, a.model.by, h.t, h.s);
        }
        if (!a.f4 || a.dragger.isDragActive) {
            g.ba = 0;
        }
        a.ci.v(h, g);
    }
    ae(a, b, c, d) {
        let e = this.p();
        this.x(e);
        let f = this.f.f;
        if (a.b3 != null && a.b3.f != null) {
            f = a.b3.f;
        }
        let g = a.model;
        let h = new CellEffect();
        h.onFinished = delegateCombine(h.onFinished, (i) => this.w(e));
        h.onCanceled = delegateCombine(h.onCanceled, (i, j) => this.v(e));
        h.t = 5;
        h.bx(f);
        h.al = true;
        h.bq = 1;
        h.x = (i, j, k, l, m) => {
            let n = l;
            let o = j;
            let p = k;
            if (n.i.ab) {
                n.bn = o + (p - o) * i;
            }
            else {
                n.bn = 0;
            }
        };
        h.o = (i, j) => {
            let k = i;
            return k.bn;
        };
        let i = new CellPath(1, c, 0, b);
        if (a.model.a2()) {
            h.g = new CellPath(0, 0, a.model.bw, i.t, i.s);
            h.e = new CellPath(0, 0, a.model.by, i.t, i.s);
        }
        if (!a.fi || a.dragger.isDragActive) {
            h.ba = 0;
        }
        a.ci.r(i, h, d);
    }
    aa(a, b, c, d) {
        let e = this.p();
        this.x(e);
        let f = this.f.d;
        if (a.b3 != null && a.b3.d != null) {
            f = a.b3.d;
        }
        let g = a.model;
        let h = new CellEffect();
        h.onFinished = delegateCombine(h.onFinished, (i) => this.w(e));
        h.onCanceled = delegateCombine(h.onCanceled, (i, j) => this.v(e));
        h.t = 8;
        h.bx(f);
        h.al = true;
        h.bq = 1;
        h.x = (i, j, k, l, m) => {
            let n = l;
            let o = j;
            let p = k;
            if (n.i.ab) {
                n.bg = o + (p - o) * i;
            }
            else {
                n.bg = 0;
            }
        };
        h.o = (i, j) => {
            let k = i;
            return k.bg;
        };
        let i = new CellPath(1, c, 0, b);
        if (a.model.a2()) {
            h.g = new CellPath(0, 0, c, i.t, i.s);
            h.e = new CellPath(0, 0, c, i.t, i.s);
        }
        a.ci.r(i, h, d);
    }
    af(a, b, c, d) {
        let e = this.p();
        this.x(e);
        let f = this.f.f;
        if (a.b3 != null && a.b3.f != null) {
            f = a.b3.f;
        }
        let g = a.model;
        let h = new CellEffect();
        h.onFinished = delegateCombine(h.onFinished, (i) => this.w(e));
        h.onCanceled = delegateCombine(h.onCanceled, (i, j) => this.v(e));
        h.t = 5;
        h.bx(f);
        h.al = true;
        h.bq = 0;
        h.x = (i, j, k, l, m) => {
            let n = l;
            let o = j;
            let p = k;
            if (n.i.ab) {
                n.bn = o + (p - o) * i;
            }
            else {
                n.bn = 0;
            }
        };
        h.o = (i, j) => {
            let k = i;
            return k.bn;
        };
        let i = new CellPath(1, c, 0, b);
        if (a.model.a2()) {
            h.g = new CellPath(0, 0, a.model.bw, i.t, i.s);
            h.e = new CellPath(0, 0, a.model.by, i.t, i.s);
        }
        if (!a.fi || a.dragger.isDragActive) {
            h.ba = 0;
        }
        a.ci.r(i, h, d);
    }
    ab(a, b, c, d) {
        let e = this.p();
        this.x(e);
        let f = this.f.d;
        if (a.b3 != null && a.b3.d != null) {
            f = a.b3.d;
        }
        let g = a.model;
        let h = new CellEffect();
        h.onFinished = delegateCombine(h.onFinished, (i) => this.w(e));
        h.onCanceled = delegateCombine(h.onCanceled, (i, j) => this.v(e));
        h.t = 8;
        h.bx(f);
        h.al = true;
        h.bq = 0;
        h.x = (i, j, k, l, m) => {
            let n = l;
            let o = j;
            let p = k;
            if (n.i.ab) {
                n.bg = o + (p - o) * i;
            }
            else {
                n.bg = 0;
            }
        };
        h.o = (i, j) => {
            let k = i;
            return k.bg;
        };
        let i = new CellPath(1, c, 0, b);
        if (a.model.a2()) {
            h.g = new CellPath(0, 0, c, i.t, i.s);
            h.e = new CellPath(0, 0, c, i.t, i.s);
        }
        a.ci.r(i, h, d);
    }
    ac(a, b, c) {
        let d = this.p();
        this.x(d);
        let e = this.f.f;
        if (a.b3 != null && a.b3.f != null) {
            e = a.b3.f;
        }
        let f = a.model;
        let g = new CellPositionEffect();
        g.onFinished = delegateCombine(g.onFinished, (h) => this.w(d));
        g.onCanceled = delegateCombine(g.onCanceled, (h, i) => this.v(d));
        g.t = 5;
        g.bx(e);
        g.al = true;
        g.bq = 1;
        g.x = (h, i, j, k, l) => {
            let m = k;
            let n = i;
            let o = j;
            if (m.i.ab) {
                m.bn = n + (o - n) * h;
            }
            else {
                m.bn = 0;
            }
        };
        g.o = (h, i) => {
            let j = h;
            return j.bn;
        };
        let h = new CellPath(1, c, 0, b);
        if (a.model.a2()) {
            g.g = new CellPath(0, 0, a.model.bw, h.t, h.s);
            g.e = new CellPath(0, 0, a.model.by, h.t, h.s);
        }
        if (!a.fi || a.dragger.isDragActive) {
            g.ba = 0;
        }
        a.ci.s(h, g);
    }
    ad(a, b, c) {
        let d = this.p();
        this.x(d);
        let e = this.f.f;
        if (a.b3 != null && a.b3.f != null) {
            e = a.b3.f;
        }
        let f = a.model;
        let g = new CellPositionEffect();
        g.onFinished = delegateCombine(g.onFinished, (h) => this.w(d));
        g.onCanceled = delegateCombine(g.onCanceled, (h, i) => this.v(d));
        g.t = 5;
        g.bx(e);
        g.al = true;
        g.bq = 0;
        g.x = (h, i, j, k, l) => {
            let m = k;
            let n = i;
            let o = j;
            if (m.i.ab) {
                m.bn = n + (o - n) * h;
            }
            else {
                m.bn = 0;
            }
        };
        g.o = (h, i) => {
            let j = h;
            return j.bn;
        };
        let h = new CellPath(1, c, 0, b);
        if (a.model.a2()) {
            g.g = new CellPath(0, 0, a.model.bw, h.t, h.s);
            g.e = new CellPath(0, 0, a.model.by, h.t, h.s);
        }
        if (!a.fi || a.dragger.isDragActive) {
            g.ba = 0;
        }
        a.ci.s(h, g);
    }
}
GridAnimationManager.$t = markType(GridAnimationManager, 'GridAnimationManager');
GridAnimationManager.o = 0;
/**
 * @hidden
 */
class CellKey extends Base {
    constructor() {
        super(...arguments);
        this.e = null;
        this.g = null;
        this.i = null;
        this.a = null;
        this.c = null;
    }
    get primaryKey() {
        if (this.e == null && this.g != null && this.d != null) {
            this.e = this.d.da.getItemKey(this.d.g(), this.g);
        }
        return this.e;
    }
    set primaryKey(a) {
        this.e = a;
    }
    get h() {
        if (this.g == null && this.e != null && this.d != null) {
            this.g = this.d.da.getItemForKey(this.primaryKey);
        }
        return this.g;
    }
    set h(a) {
        this.g = a;
    }
    get j() {
        return this.i;
    }
    set j(a) {
        this.i = a;
    }
    get b() {
        if ((this.a == null || this.a.grid != this.d) && this.d != null) {
            this.a = this.d.au.e(this.j);
        }
        return this.a;
    }
    get d() {
        return this.c;
    }
    set d(a) {
        this.c = a;
    }
}
CellKey.$t = markType(CellKey, 'CellKey');
/**
 * @hidden
 */
class GridSelectedCellsCollection extends ObservableCollection$1 {
    constructor() {
        super(CellKey.$, 0);
    }
    an(a) {
        this.collectionChanged = delegateCombine(this.collectionChanged, a);
    }
    ao(a) {
        this.collectionChanged = delegateRemove(this.collectionChanged, a);
    }
    get am() {
        return this;
    }
    ai(a, b) {
        for (let c = 0; c < this.count; c++) {
            if (this._inner[c].primaryKey != null && this._inner[c].primaryKey.equals(a) && this._inner[c].b != null && this._inner[c].b.fj == b) {
                return this._inner[c];
            }
        }
        return null;
    }
    aj(a, b) {
        for (let c = 0; c < this.count; c++) {
            if (this._inner[c].primaryKey.equals(a) && this._inner[c].j == b) {
                return this._inner[c];
            }
        }
        return null;
    }
    ak(a, b) {
        for (let c = 0; c < this.count; c++) {
            if (this._inner[c].h == a && this._inner[c].j == b) {
                return this._inner[c];
            }
        }
        return null;
    }
    ae(a, b) {
        return this.af(a, b.fu());
    }
    af(a, b) {
        if (this.aj(a, b) != null) {
            return null;
        }
        let c = new CellKey();
        c.primaryKey = a;
        c.j = b;
        this.add(c);
        return c;
    }
    ag(a, b) {
        return this.ah(a, b.fu());
    }
    ah(a, b) {
        if (this.ak(a, b) != null) {
            return null;
        }
        let c = new CellKey();
        c.h = a;
        c.j = b;
        this.add(c);
        return c;
    }
    al(a, b) {
        let c = this.ai(a, b);
        if (c != null) {
            this.remove(c);
        }
        return c;
    }
}
GridSelectedCellsCollection.$t = markType(GridSelectedCellsCollection, 'GridSelectedCellsCollection', ObservableCollection$1.$.specialize(CellKey.$));
/**
 * @hidden
 */
class DefinitionBase extends Base {
    constructor() {
        super();
        this.bd = null;
        this.t = null;
        this.c8 = null;
        this.c9 = null;
        this.c0 = null;
        this.c3 = null;
        this.a2 = truncate(DeviceUtils.g(0));
        this.a4 = truncate(DeviceUtils.g(0));
        this.a3 = truncate(DeviceUtils.g(0));
        this.a1 = truncate(DeviceUtils.g(0));
        this.ay = truncate(DeviceUtils.g(1));
        this.a0 = truncate(DeviceUtils.g(1));
        this.az = truncate(DeviceUtils.g(1));
        this.ax = truncate(DeviceUtils.g(1));
        this.r = null;
        this.c2 = null;
        this.c1 = null;
        this.dc = null;
        this.c6 = null;
        this.db = null;
        this.c5 = null;
        this.da = null;
        this.c4 = null;
        this.ar = 1;
        this.b = 4;
        this.g = 4;
        this.a = 0;
        this.f = 1;
        this.w = 0;
        this.v = 0;
        this.dd = null;
        this.c7 = null;
        this.as = NaN;
        this.aq = 0;
        this.ac = null;
        this.ab = null;
        this.dataBinding = null;
        this.dataBound = null;
        this.propertyChanged = null;
        this.ag = false;
        this.am = new HashSet$1(String_$type, 0);
        this.ao = new List$1(String_$type, 0);
        this.al = new Dictionary$2(String_$type, CellPropertyAnimationType_$type, 0);
        this.definitionPropertyUpdated = null;
        this.z = null;
        this.cellStyleKeyRequested = null;
        this.dg = this.dq();
        this.dk = this.du();
        this.dj = this.ds();
        this.di = this.dr();
        this.at = this.av();
        this.dl = this.dv();
        this.ad = this.af();
        this.df = this.dp();
    }
    get externalObject() {
        return this.bd;
    }
    set externalObject(a) {
        let b = this.bd;
        this.bd = a;
        this.t = typeCast(IExternalDefinitionBase_$type, this.bd);
        if (this.bd != b) {
            this.cm("ExternalObject", 10, b, this.bd);
        }
    }
    get dm() {
        return this.c8;
    }
    set dm(a) {
        let b = this.c8;
        this.c8 = a;
        if (this.c8 != b) {
            this.cm("Background", 10, b, this.c8);
        }
    }
    get dn() {
        return this.c9;
    }
    set dn(a) {
        let b = this.c9;
        this.c9 = a;
        if (this.c9 != b) {
            this.cm("Border", 10, b, this.c9);
        }
    }
    get de() {
        return this.c0;
    }
    set de(a) {
        let b = this.c0;
        this.c0 = a;
        if (this.c0 != b) {
            this.cm("ActivationBorder", 10, b, this.c0);
        }
    }
    get dh() {
        return this.c3;
    }
    set dh(a) {
        let b = this.c3;
        this.c3 = a;
        if (this.c3 != b) {
            this.cm("ActualBorder", 2, b, this.c3);
        }
    }
    get ba() {
        return this.a2;
    }
    set ba(a) {
        let b = this.a2;
        this.a2 = a;
        if (this.a2 != b) {
            this.cm("BorderLeftWidth", 6, b, this.a2);
        }
    }
    get bc() {
        return this.a4;
    }
    set bc(a) {
        let b = this.a4;
        this.a4 = a;
        if (this.a4 != b) {
            this.cm("BorderTopWidth", 6, b, this.a4);
        }
    }
    get bb() {
        return this.a3;
    }
    set bb(a) {
        let b = this.a3;
        this.a3 = a;
        if (this.a3 != b) {
            this.cm("BorderRightWidth", 6, b, this.a3);
        }
    }
    get a9() {
        return this.a1;
    }
    set a9(a) {
        let b = this.a1;
        this.a1 = a;
        if (this.a1 != b) {
            this.cm("BorderBottomWidth", 6, b, this.a1);
        }
    }
    get a6() {
        return this.ay;
    }
    set a6(a) {
        let b = this.ay;
        this.ay = a;
        if (this.ay != b) {
            this.cm("ActivationBorderLeftWidth", 6, b, this.ay);
        }
    }
    get a8() {
        return this.a0;
    }
    set a8(a) {
        let b = this.a0;
        this.a0 = a;
        if (this.a0 != b) {
            this.cm("ActivationBorderTopWidth", 6, b, this.a0);
        }
    }
    get a7() {
        return this.az;
    }
    set a7(a) {
        let b = this.az;
        this.az = a;
        if (this.az != b) {
            this.cm("ActivationBorderRightWidth", 6, b, this.az);
        }
    }
    get a5() {
        return this.ax;
    }
    set a5(a) {
        let b = this.ax;
        this.ax = a;
        if (this.ax != b) {
            this.cm("ActivationBorderBottomWidth", 6, b, this.ax);
        }
    }
    get grid() {
        return this.r;
    }
    set grid(a) {
        let b = this.r;
        this.r = a;
        this.cl(b, a);
    }
    cl(a, b) {
    }
    get dg() {
        return this.c2;
    }
    set dg(a) {
        let b = this.c2;
        this.c2 = a;
        if (this.c2 != b) {
            this.cm("ActualBackground", 2, b, this.c2);
        }
    }
    get df() {
        return this.c1;
    }
    set df(a) {
        let b = this.c1;
        this.c1 = a;
        if (this.c1 != b) {
            this.cm("ActualActivationBorder", 2, b, this.c1);
        }
    }
    get dy() {
        return this.dc;
    }
    set dy(a) {
        let b = this.dc;
        this.dc = a;
        if (this.dc != b) {
            this.cm("PinnedBackground", 10, b, this.dc);
        }
    }
    get dk() {
        return this.c6;
    }
    set dk(a) {
        let b = this.c6;
        this.c6 = a;
        if (this.c6 != b) {
            this.cm("ActualStickyRowBackground", 2, b, this.c6);
        }
    }
    get dx() {
        return this.db;
    }
    set dx(a) {
        let b = this.db;
        this.db = a;
        if (this.db != b) {
            this.cm("PinnedRowBackground", 10, b, this.db);
        }
    }
    get dj() {
        return this.c5;
    }
    set dj(a) {
        let b = this.c5;
        this.c5 = a;
        if (this.c5 != b) {
            this.cm("ActualPinnedRowBackground", 2, b, this.c5);
        }
    }
    get dw() {
        return this.da;
    }
    set dw(a) {
        let b = this.da;
        this.da = a;
        if (this.da != b) {
            this.cm("LastStickyRowBackground", 10, b, this.da);
        }
    }
    get di() {
        return this.c4;
    }
    set di(a) {
        let b = this.c4;
        this.c4 = a;
        if (this.c4 != b) {
            this.cm("ActualLastStickyRowBackground", 2, b, this.c4);
        }
    }
    get au() {
        return this.ar;
    }
    set au(a) {
        let b = this.ar;
        this.ar = a;
        if (this.ar != b) {
            this.cm("ContentOpacity", 0, b, this.ar);
        }
    }
    get e() {
        return this.b;
    }
    set e(a) {
        let b = this.b;
        this.b = a;
        if (this.b != b) {
            this.cm("HorizontalAlignment", 10, enumGetBox(CellContentHorizontalAlignment_$type, b), enumGetBox(CellContentHorizontalAlignment_$type, this.b));
        }
    }
    get j() {
        return this.g;
    }
    set j(a) {
        let b = this.g;
        this.g = a;
        if (this.g != b) {
            this.cm("VerticalAlignment", 10, enumGetBox(CellContentVerticalAlignment_$type, b), enumGetBox(CellContentVerticalAlignment_$type, this.g));
        }
    }
    get c() {
        return this.a;
    }
    set c(a) {
        let b = this.a;
        this.a = a;
        if (this.a != b) {
            this.cm("ActualHorizontalAlignment", 4, enumGetBox(CellContentHorizontalAlignment_$type, b), enumGetBox(CellContentHorizontalAlignment_$type, this.a));
        }
    }
    get h() {
        return this.f;
    }
    set h(a) {
        let b = this.f;
        this.f = a;
        if (this.f != b) {
            this.cm("VerticalAlignment", 4, enumGetBox(CellContentVerticalAlignment_$type, b), enumGetBox(CellContentVerticalAlignment_$type, this.f));
        }
    }
    get y() {
        return this.w;
    }
    set y(a) {
        let b = this.w;
        this.w = a;
        if (this.w != b) {
            this.cm("LineBreakMode", 10, enumGetBox(TextCellLineBreakMode_$type, b), enumGetBox(TextCellLineBreakMode_$type, this.w));
        }
    }
    get x() {
        return this.v;
    }
    set x(a) {
        let b = this.v;
        this.v = a;
        if (this.v != b) {
            this.cm("ActualLineBreakMode", 4, enumGetBox(TextCellLineBreakMode_$type, b), enumGetBox(TextCellLineBreakMode_$type, this.v));
        }
    }
    get dz() {
        return this.dd;
    }
    set dz(a) {
        let b = this.dd;
        this.dd = a;
        if (this.dd != b) {
            this.cm("TextColor", 10, b, this.dd);
        }
    }
    get dl() {
        return this.c7;
    }
    set dl(a) {
        let b = this.c7;
        this.c7 = a;
        if (this.c7 != b) {
            this.cm("ActualTextColor", 2, b, this.c7);
        }
    }
    get aw() {
        return this.as;
    }
    set aw(a) {
        let b = this.as;
        this.as = a;
        if (this.as != b) {
            this.cm("PinnedRowOpacity", 10, b, this.as);
        }
    }
    get at() {
        return this.aq;
    }
    set at(a) {
        let b = this.aq;
        this.aq = a;
        if (this.aq != b) {
            this.cm("ActualPinnedRowOpacity", 0, b, this.aq);
        }
    }
    get textStyle() {
        return this.ac;
    }
    set textStyle(a) {
        let b = this.ac;
        this.ac = a;
        if (this.ac != b) {
            this.cm("FontInfo", 10, b, this.ac);
        }
    }
    get ad() {
        return this.ab;
    }
    set ad(a) {
        let b = this.ab;
        this.ab = a;
        if (this.ab != b) {
            this.cm("ActualFontInfo", 3, b, this.ab);
        }
    }
    k(a, b) {
        let c = this.l(a);
        c.g1 = b;
        return c;
    }
    b7(a, b, c, d) {
        let e = this.b8(a, b, c);
        if (this.cellStyleKeyRequested == null) {
            return e;
        }
        let f = new CellStyleRequestedEventArgs();
        f.resolvedValue = c;
        f.rowNumber = d;
        f.styleKey = e;
        this.cellStyleKeyRequested(this, f);
        return f.styleKey;
    }
    ci(a, b, c, d) {
        a.ap = b.model.a1;
        a.e = this.c;
        a.g = this.h;
        a.bj = 0;
        a.bo = 0;
        a.bk = 0;
        a.bp = 0;
        a.bi = 1;
        a.bq = 0;
        a.bl = 1;
        a.bi = this.au;
        a.ig = this.dl;
        a.h7 = this.dg;
        a.h4 = this.df;
        a.cn = this.a6;
        a.cs = this.a8;
        a.cq = this.a7;
        a.cl = this.a5;
        if (this.ag) {
            a.h8 = this.dh;
            a.dh = this.ba;
            a.dk = this.bb;
            a.dm = this.bc;
            a.df = this.a9;
        }
        else {
            if (a.h8 != null) {
                a.h8 = null;
                a.dh = 0;
                a.dm = 0;
                a.dk = 0;
                a.df = 0;
            }
        }
        if (this.ad != null && this.grid != null) {
            this.ad.t(this.grid.externalGrid.renderer);
        }
        a.x = this.ad;
        a.v = this.x;
        a.ie = this.dk;
        a.ib = this.dj;
        a.ia = this.di;
        a.bm = this.at;
        if (a.c == null) {
            a.c = new DefaultCellActionManager(b, a);
        }
    }
    cj(a, b, c, d) {
        if (this.dataBinding != null) {
            let e = this.n(a, b, c, d);
            this.dataBinding(this, e);
            c = e.resolvedValue;
            d = e.rowObject;
        }
        this.ck(a, b, c, d);
        if (this.dataBound != null) {
            this.dataBound(this, this.n(a, b, c, d));
        }
    }
    n(a, b, c, d) {
        let e = new DataBindingEventArgs();
        e.cellInfo = a;
        e.resolvedValue = c;
        e.rowObject = d;
        return e;
    }
    ck(a, b, c, d) {
        a.fc = d;
        if (!a.i.e && this.ai()) {
            let e = this.aa;
            let f = e.o;
            let g = f.count;
            let h = e.p;
            let i = e.q;
            for (let j = 0; j < g; j++) {
                if (h._inner[j]) {
                    continue;
                }
                a.hr(f._inner[j], i._inner[j]);
            }
        }
    }
    cp() {
        for (let a = 0; a < this.ao.count; a++) {
            if (!this.ak(this.ao._inner[a])) {
                this.aj(this.ao._inner[a]);
            }
        }
    }
    aj(a) {
        if (this.ah(a)) {
            let b = 11;
            if (this.al.containsKey(a)) {
                b = this.al.item(a);
            }
            this.cn(a, b, this.bf(a), this.bf(a));
            return true;
        }
        return false;
    }
    ak(a) {
        if (stringStartsWith(a, "Actual")) {
            return false;
        }
        switch (a) {
            case "Background":
                this.cm("ActualBackground", 2, this.dg, this.dg);
                return true;
            case "ContentOpacity":
                this.cm("ContentOpacity", 0, this.au, this.au);
                return true;
            case "FontInfo":
                this.cm("ActualFontInfo", 3, this.ad, this.ad);
                return true;
            case "HorizontalAlignment":
                this.cm("ActualHorizontalAlignment", 4, enumGetBox(CellContentHorizontalAlignment_$type, this.c), enumGetBox(CellContentHorizontalAlignment_$type, this.c));
                return true;
            case "TextColor":
                this.cm("ActualTextColor", 2, this.dl, this.dl);
                return true;
            case "VerticalAlignment":
                this.cm("VerticalAlignment", 4, enumGetBox(CellContentVerticalAlignment_$type, this.h), enumGetBox(CellContentVerticalAlignment_$type, this.h));
                return true;
            case "Border":
                this.cm("ActualBorder", 2, this.dh, this.dh);
                return true;
            case "ActivationBorder":
                this.cm("ActualActivationBorder", 2, this.df, this.df);
                return true;
            case "BorderLeftWidth":
                this.cm("BorderLeftWidth", 0, this.ba, this.ba);
                return true;
            case "BorderTopWidth":
                this.cm("BorderTopWidth", 0, this.bc, this.bc);
                return true;
            case "BorderRightWidth":
                this.cm("BorderRightWidth", 0, this.bb, this.bb);
                return true;
            case "BorderBottomWidth":
                this.cm("BorderBottomWidth", 0, this.a9, this.a9);
                return true;
            case "ActivationBorderLeftWidth":
                this.cm("ActivationBorderLeftWidth", 0, this.a6, this.a6);
                return true;
            case "ActivationBorderTopWidth":
                this.cm("ActivationBorderTopWidth", 0, this.a8, this.a8);
                return true;
            case "ActivationBorderRightWidth":
                this.cm("ActivationBorderRightWidth", 0, this.a7, this.a7);
                return true;
            case "ActivationBorderBottomWidth":
                this.cm("ActivationBorderBottomWidth", 0, this.a5, this.a5);
                return true;
        }
        return false;
    }
    cm(a, b, c, d) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
        this.cn(a, b, c, d);
        if (this.definitionPropertyUpdated != null) {
            this.definitionPropertyUpdated(this, ((() => {
                let $ret = new DefinitionPropertyUpdatedEventArgs();
                $ret.propertyName = a;
                $ret.animationType = b;
                $ret.newValue = d;
                $ret.oldValue = c;
                return $ret;
            })()));
        }
    }
    cs() {
        if (this.dm != null) {
            this.dg = this.dm;
        }
        else {
            this.dg = this.dq();
        }
    }
    cy() {
        if (this.dz != null) {
            this.dl = this.dz;
        }
        else {
            this.dl = this.dv();
        }
    }
    cz() {
        this.ad = this.textStyle;
    }
    cw() {
        if (!isNaN_(this.aw)) {
            this.at = this.aw;
        }
        else {
            this.at = this.av();
        }
    }
    cv() {
        if (this.dx != null) {
            this.dj = this.dx;
        }
        else {
            this.dj = this.ds();
        }
    }
    cx() {
        if (this.dy != null) {
            this.dk = this.dy;
        }
        else {
            this.dk = this.du();
        }
    }
    cu() {
        if (this.dw != null) {
            this.di = this.dw;
        }
        else {
            this.di = this.dr();
        }
    }
    cn(a, b, c, d) {
        this.ch(a, b);
        switch (a) {
            case "TextColor":
                this.cy();
                break;
            case "Background":
                this.cs();
                break;
            case "PinnedBackground":
                this.cx();
                break;
            case "PinnedRowBackground":
                this.cv();
                break;
            case "LastStickyRowBackground":
                this.cu();
                break;
            case "PinnedRowOpacity":
                this.cw();
                break;
            case "VerticalAlignment":
                if (this.j == 4) {
                    this.h = this.i();
                }
                else {
                    this.h = this.j;
                }
                break;
            case "HorizontalAlignment":
                if (this.e == 4) {
                    this.c = this.d();
                }
                else {
                    this.c = this.e;
                }
                break;
            case "LineBreakMode":
                this.x = this.y;
                break;
            case "FontInfo":
                this.cz();
                break;
            case "Border":
            case "BorderLeftWidth":
            case "BorderTopWidth":
            case "BorderRightWidth":
            case "BorderBottomWidth":
                this.ct();
                break;
            case "ActivationBorder":
                this.cr();
                break;
        }
    }
    ct() {
        if (this.ba != 0 || this.bc != 0 || this.bb != 0 || this.a9 != 0) {
            if (this.dn != null) {
                this.ag = true;
                this.dh = this.dn;
            }
            else if (this.dh != null) {
                this.ag = true;
            }
        }
    }
    cr() {
        this.df = this.de;
    }
    get an() {
        return this.am;
    }
    get ap() {
        return this.ao;
    }
    ch(a, b) {
        if (this.am.contains(a)) {
            return;
        }
        this.am.add_1(a);
        this.ao.add(a);
        this.al.addItem(a, b);
    }
    d() {
        if (this.e != 4) {
            return this.e;
        }
        return 0;
    }
    i() {
        if (this.j != 4) {
            return this.j;
        }
        return 1;
    }
    dv() {
        return GridStyleRepository.an;
    }
    dp() {
        return GridStyleRepository.w;
    }
    af() {
        return GridStyleRepository.d;
    }
    dq() {
        return GridStyleRepository.x;
    }
    du() {
        return null;
    }
    ds() {
        return null;
    }
    dr() {
        return null;
    }
    dt() {
        return GridStyleRepository.af;
    }
    av() {
        return 0.3;
    }
    cq(a, b, c) {
        if (this.z == null) {
            this.z = new FastIterationDictionary$2(String_$type, Base.$, 0);
        }
        let d = null;
        if (this.z.d(a)) {
            d = this.z.item(a);
        }
        this.z.item(a, c);
        let e = false;
        if (d == null && c != null) {
            e = true;
        }
        if (d != null) {
            if (!Base.equalsStatic(d, c)) {
                e = true;
            }
        }
        if (e) {
            this.cm(a, b, d, c);
        }
    }
    ai() {
        if (this.z == null) {
            return false;
        }
        return this.z.r > 0;
    }
    get aa() {
        return this.z;
    }
    ah(a) {
        if (this.z == null) {
            return false;
        }
        return this.z.d(a);
    }
    co(a) {
        if (this.z == null) {
            return;
        }
        if (this.z.d(a)) {
            this.z.f(a);
        }
    }
    bf(a) {
        if (this.z == null) {
            return null;
        }
        if (this.z.d(a)) {
            return this.z.item(a);
        }
        return null;
    }
    b6(a, b, c) {
        let d = stringEmpty();
        switch (b) {
            case 10:
                if (c != null) {
                    let override_ = c;
                    let val_ = typeGetValue(a);
                    d = (override_.format(val_));
                }
                else {
                    d = (typeGetValue(a)).toString();
                }
                break;
            case 8:
                if (c != null) {
                    let override_ = c;
                    let val_ = a;
                    d = (override_.format(val_));
                }
                else {
                    d = a.toString();
                }
                break;
            case 5:
                if (c != null) {
                    let override_ = c;
                    let val_ = a;
                    d = (override_.format(val_));
                }
                else {
                    d = a.toString();
                }
                break;
            case 1:
                if (c != null) {
                    let override_ = c;
                    let val_ = typeGetValue(a);
                    d = (override_.format(val_));
                }
                else {
                    d = (typeGetValue(a)).toString();
                }
                break;
            case 3:
                if (c != null) {
                    let override_ = c;
                    let val_ = typeGetValue(a);
                    d = (override_.format(val_));
                }
                else {
                    d = typeGetValue(a).toString();
                }
                break;
            case 4:
                if (c != null) {
                    let override_ = c;
                    let val_ = typeGetValue(a);
                    d = (override_.format(val_));
                }
                else {
                    d = typeGetValue(a).toString();
                }
                break;
            case 7:
                if (c != null) {
                    let override_ = c;
                    let val_ = a;
                    d = (override_.format(val_));
                }
                else {
                    d = a.toString();
                }
                break;
            case 6:
                if (c != null) {
                    let override_ = c;
                    let val_ = a;
                    d = (override_.format(val_));
                }
                else {
                    d = a.toString();
                }
                break;
            case 0:
            case 2:
            case 11:
                d = a.toString();
                break;
        }
        return d;
    }
    u(a, b) {
        let c = b != null ? b.value.toString() : stringEmpty();
        let d = a.a;
        if (a.e == 4) {
            d = 1;
        }
        let e = b.value;
        switch (d) {
            case 10:
                if (a.n != null) {
                    let override_ = a.n;
                    let val_ = typeGetValue(e);
                    c = (override_.format(val_));
                }
                else {
                    c = (typeGetValue(e)).toString();
                }
                break;
            case 8:
                if (a.n != null) {
                    let override_ = a.n;
                    let val_ = e;
                    c = (override_.format(val_));
                }
                else {
                    c = e.toString();
                }
                break;
            case 5:
                if (a.n != null) {
                    let override_ = a.n;
                    let val_ = e;
                    c = (override_.format(val_));
                }
                else {
                    let summaryValue_ = e;
                    let maxFractionDigits_ = a.l;
                    c = (parseFloat(summaryValue_.toFixed(maxFractionDigits_)).toString());
                }
                break;
            case 1:
                if (a.n != null) {
                    let override_ = a.n;
                    let val_ = typeGetValue(e);
                    c = (override_.format(val_));
                }
                else {
                    c = (typeGetValue(e)).toString();
                }
                break;
            case 3:
                if (a.n != null) {
                    let override_ = a.n;
                    let val_ = typeGetValue(e);
                    c = (override_.format(val_));
                }
                else {
                    c = typeGetValue(e).toString();
                }
                break;
            case 4:
                if (a.n != null) {
                    let override_ = a.n;
                    let val_ = typeGetValue(e);
                    c = (override_.format(val_));
                }
                else {
                    c = typeGetValue(e).toString();
                }
                break;
            case 7:
                if (a.n != null) {
                    let override_ = a.n;
                    let val_ = e;
                    c = (override_.format(val_));
                }
                else {
                    let summaryValue_ = e;
                    let maxFractionDigits_ = a.l;
                    c = (parseFloat(summaryValue_.toFixed(maxFractionDigits_)).toString());
                }
                break;
            case 6:
                if (a.n != null) {
                    let override_ = a.n;
                    let val_ = e;
                    c = (override_.format(val_));
                }
                else {
                    let summaryValue_ = e;
                    let maxFractionDigits_ = a.l;
                    c = (parseFloat(summaryValue_.toFixed(maxFractionDigits_)).toString());
                }
                break;
            case 0:
            case 2:
            case 11:
                c = e.toString();
                break;
        }
        let f = a.r != null ? a.r : a.c.displayName;
        let g = stringIsNullOrWhiteSpace(a.s) ? a.t : a.s;
        let h = g + " " + f + " = " + c;
        let i = a.f(b, c, h);
        h = i.d;
        c = i.c;
        return ((() => {
            let $ret = new SummaryData();
            $ret.e = g;
            $ret.b = e;
            $ret.a = a.e;
            $ret.c = i.d;
            $ret.d = i.c;
            return $ret;
        })());
    }
}
DefinitionBase.$t = markType(DefinitionBase, 'DefinitionBase', Base.$, [INotifyPropertyChanged_$type]);
/**
 * @hidden
 */
class Column extends DefinitionBase {
    constructor() {
        super();
        this.fj = 0;
        this.ec = 0;
        this.e9 = truncate(DeviceUtils.g(10));
        this.fb = truncate(DeviceUtils.g(5));
        this.fa = truncate(DeviceUtils.g(10));
        this.e8 = truncate(DeviceUtils.g(5));
        this.fn = stringEmpty();
        this.e7 = 0;
        this.e6 = 0;
        this.fo = null;
        this.fm = null;
        this.fl = null;
        this.gp = null;
        this.go = null;
        this.eg = null;
        this.ee = null;
        this.e4 = NaN;
        this.eq = false;
        this.eo = false;
        this.d0 = null;
        this.ei = null;
        this.ep = true;
        this.es = true;
        this.er = false;
        this.et = false;
        this.ea = 0;
        this.en = false;
        this.columnCellsPropertyUpdating = null;
        this.columnHeaderCellsPropertyUpdating = null;
        this.ek = null;
        this.em = false;
        this.em = true;
        this.header = new TextHeader();
        this.em = false;
        this.c = this.d();
        this.h = this.i();
        this.gq = this.gr();
        this.fj = Column.fi++;
    }
    gr() {
        return GridStyleRepository.af;
    }
    get ed() {
        return this.ec;
    }
    set ed(a) {
        let b = this.ec;
        this.ec = a;
        if (this.ec != b) {
            this.cm("State", 10, enumGetBox(ColumnStates_$type, b), enumGetBox(ColumnStates_$type, this.ec));
        }
    }
    get ff() {
        return this.e9;
    }
    set ff(a) {
        let b = this.e9;
        this.e9 = a;
        if (this.e9 != b) {
            this.cm("PaddingLeft", 6, b, this.e9);
        }
    }
    get fh() {
        return this.fb;
    }
    set fh(a) {
        let b = this.fb;
        this.fb = a;
        if (this.fb != b) {
            this.cm("PaddingTop", 6, b, this.fb);
        }
    }
    get fg() {
        return this.fa;
    }
    set fg(a) {
        let b = this.fa;
        this.fa = a;
        if (this.fa != b) {
            this.cm("PaddingRight", 6, b, this.fa);
        }
    }
    get fe() {
        return this.e8;
    }
    set fe(a) {
        let b = this.e8;
        this.e8 = a;
        if (this.e8 != b) {
            this.cm("PaddingBottom", 6, b, this.e8);
        }
    }
    get f5() {
        return this.fn;
    }
    set f5(a) {
        let b = this.fn;
        this.fn = a;
        if (this.fn != b) {
            this.cm("Name", 10, b, this.fn);
        }
    }
    get fd() {
        return this.e7;
    }
    set fd(a) {
        this.e7 = a;
    }
    get fc() {
        return this.e6;
    }
    set fc(a) {
        this.e6 = a;
    }
    get gb() {
        return this.fo;
    }
    set gb(a) {
        this.fo = a;
        if (this.fw == null) {
            this.fp = this.gb;
        }
    }
    get fw() {
        return this.fm;
    }
    set fw(a) {
        let b = this.fm;
        this.fm = a;
        if (this.fm != b) {
            this.cm("HeaderText", 8, b, this.fm);
        }
    }
    get fp() {
        return this.fl;
    }
    set fp(a) {
        let b = this.fl;
        this.fl = a;
        if (this.fl != b) {
            this.cm("ActualHeaderText", 8, b, this.fl);
        }
    }
    get gs() {
        return this.gp;
    }
    set gs(a) {
        let b = this.gp;
        this.gp = a;
        if (this.gp != b) {
            this.cm("SelectedBackground", 10, b, this.gp);
        }
    }
    get gq() {
        return this.go;
    }
    set gq(a) {
        let b = this.go;
        this.go = a;
        if (this.go != b) {
            this.cm("ActualSelectedBackground", 2, b, this.go);
        }
    }
    get eh() {
        return this.eg;
    }
    set eh(a) {
        let b = this.eg;
        this.eg = a;
        if (this.eg != b) {
            this.cm("AnimationSettings", 10, b, "AnimationSettings");
        }
    }
    get width() {
        return this.ee;
    }
    set width(a) {
        let b = this.ee;
        this.ee = a;
        if (this.ee != b) {
            this.cm("Width", 10, b, a);
        }
    }
    get e5() {
        return this.e4;
    }
    set e5(a) {
        let b = this.e4;
        this.e4 = a;
        if (this.e4 != b) {
            this.cm("MinWidth", 10, b, a);
        }
    }
    get e0() {
        return this.eq;
    }
    set e0(a) {
        let b = this.eq;
        this.eq = a;
        if (this.eq != b) {
            this.cm("IsFromMarkup", 10, b, this.eq);
        }
    }
    get ey() {
        return this.eo;
    }
    set ey(a) {
        let b = this.eo;
        this.eo = a;
        if (this.eo != b) {
            this.cm("IsAutoGenerated", 10, b, this.eo);
        }
    }
    get d1() {
        return this.d0;
    }
    set d1(a) {
        let b = this.d0;
        this.d0 = a;
        if (this.d0 != b) {
            this.cm("Filter", 10, b, this.d0);
        }
    }
    get header() {
        return this.ei;
    }
    set header(a) {
        let b = this.ei;
        this.ei = a;
        if (this.ei != b) {
            this.cm("Header", 10, b, this.ei);
        }
        this.ei.grid = this.grid;
    }
    get ez() {
        return this.ep;
    }
    set ez(a) {
        let b = this.ep;
        this.ep = a;
        if (this.ep != b) {
            this.cm("IsFilteringEnabled", 10, b, this.ep);
        }
    }
    get e2() {
        return this.es;
    }
    set e2(a) {
        let b = this.es;
        this.es = a;
        if (this.es != b) {
            this.cm("IsResizingEnabled", 10, b, this.es);
        }
    }
    get e1() {
        return this.er;
    }
    set e1(a) {
        let b = this.er;
        this.er = a;
        if (this.er != b) {
            this.cm("IsHidden", 10, b, this.er);
        }
    }
    get e3() {
        return this.et;
    }
    set e3(a) {
        let b = this.et;
        this.et = a;
        if (this.et != b) {
            this.cm("ShouldRemoveWhenHidden", 10, b, this.et);
        }
    }
    get eb() {
        return this.ea;
    }
    set eb(a) {
        let b = this.ea;
        this.ea = a;
        if (this.ea != b) {
            this.cm("SortDirection", 11, enumGetBox(ColumnSortDirection_$type, b), enumGetBox(ColumnSortDirection_$type, this.ea));
        }
    }
    get ex() {
        return this.en;
    }
    set ex(a) {
        let b = this.en;
        this.en = a;
        if (this.en != b) {
            this.cm("InternalShouldRemoveWhenHidden", 10, b, this.en);
        }
    }
    get eu() {
        if (this.en) {
            return true;
        }
        return this.et;
    }
    ds() {
        return GridStyleRepository.aa;
    }
    du() {
        return GridStyleRepository.ag;
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        a.fb = c;
        if (b.dx.o(a)) {
            a.bn = 1;
        }
        else {
            a.bn = 0;
        }
        if (b.af.m(a)) {
            a.bg = 1;
        }
        else {
            a.bg = 0;
        }
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
        a.ic = this.gq;
        a.ed = this.ff;
        a.eh = this.fh;
        a.ef = this.fg;
        a.eb = this.fe;
    }
    cn(a, b, c, d) {
        super.cn(a, b, c, d);
        switch (a) {
            case "Header":
                let e = c;
                let f = d;
                if (e != null) {
                    e.definitionPropertyUpdated = delegateRemove(e.definitionPropertyUpdated, runOn(this, this.gi));
                }
                if (f != null) {
                    f.definitionPropertyUpdated = delegateCombine(f.definitionPropertyUpdated, runOn(this, this.gi));
                    if (f.e == 4) {
                        f.c = this.d2();
                    }
                    if (f.j == 4) {
                        f.h = this.d3();
                    }
                    if (!this.em) {
                        f.cp();
                    }
                }
                break;
            case "HeaderText":
                this.fp = d;
                break;
            case "SelectedBackground":
                this.gn();
                break;
            case "ActualHorizontalAlignment":
                if (this.header != null) {
                    if (this.header.e == 4) {
                        this.header.c = this.d2();
                    }
                }
                break;
            case "VerticalAlignment":
                if (this.header != null) {
                    if (this.header.j == 4) {
                        this.header.h = this.d3();
                    }
                }
                break;
            case "SortDirection":
                this.gm(this, "SortDirection", 11, c, d);
                break;
            case "ActualLastStickyRowBackground":
                if (c != null && this.di == null) {
                    d = this.dk;
                }
                break;
        }
        this.gl(a, b, c, d);
    }
    d3() {
        return this.h;
    }
    d2() {
        return this.c;
    }
    gm(a, b, c, d, e) {
        if (this.columnHeaderCellsPropertyUpdating != null) {
            this.columnHeaderCellsPropertyUpdating(this, b, c, d, e);
        }
    }
    gi(a, b) {
        this.gm(this, b.propertyName, b.animationType, b.oldValue, b.newValue);
    }
    cl(a, b) {
        if (a != null) {
            a.propertyChanged = delegateRemove(a.propertyChanged, runOn(this, this.gh));
        }
        if (b != null) {
            b.propertyChanged = delegateCombine(b.propertyChanged, runOn(this, this.gh));
        }
        if (this.header != null) {
            this.header.grid = b;
        }
        this.gn();
        this.gn();
        this.cs();
        this.cy();
        this.cz();
        this.cx();
        this.cu();
        this.cv();
        this.cw();
    }
    gh(a, b) {
        switch (b.propertyName) {
            case "CellSelectedBackground":
                this.gn();
                break;
            case "CellBackground":
                this.cs();
                break;
            case "CellTextColor":
                this.cy();
                break;
            case "CellTextStyle":
                this.cz();
                break;
            case "StickyRowBackground":
                this.cx();
                break;
            case "LastStickyRowBackground":
                this.cu();
                break;
            case "PinnedRowBackground":
                this.cv();
                break;
            case "PinnedRowOpacity":
                this.cw();
                break;
        }
    }
    gn() {
        if (this.gs == null) {
            if (this.grid != null && this.grid.pw != null) {
                this.gq = this.grid.pw;
                return;
            }
            this.gq = this.gr();
        }
        else {
            this.gq = this.gs;
        }
    }
    cs() {
        if (this.dm == null) {
            if (this.grid != null && this.grid.pv != null) {
                this.dg = this.grid.pv;
            }
            else {
                this.dg = this.dq();
            }
        }
        else {
            this.dg = this.dm;
        }
    }
    cy() {
        if (this.dz == null) {
            if (this.grid != null && this.grid.px != null) {
                this.dl = this.grid.px;
                return;
            }
            this.dl = this.dv();
        }
        else {
            this.dl = this.dz;
        }
    }
    cz() {
        if (this.textStyle == null) {
            if (this.grid != null && this.grid.eh != null) {
                this.ad = this.grid.eh;
                return;
            }
            this.ad = this.af();
        }
        else {
            this.ad = this.textStyle;
        }
    }
    cw() {
        if (isNaN_(this.aw)) {
            if (this.grid != null && !isNaN_(this.grid.ha)) {
                this.at = this.grid.ha;
                return;
            }
            this.at = this.av();
        }
        else {
            this.at = this.aw;
        }
    }
    cv() {
        if (this.dx == null) {
            if (this.grid != null && this.grid.p5 != null) {
                this.dj = this.grid.p5;
                return;
            }
            this.dj = this.ds();
        }
        else {
            this.dj = this.dx;
        }
    }
    cx() {
        if (this.dy == null) {
            if (this.grid != null && this.grid.qd != null) {
                this.dk = this.grid.qd;
                return;
            }
            this.dk = this.du();
        }
        else {
            this.dk = this.dy;
        }
    }
    cu() {
        if (this.dw == null) {
            if (this.grid != null && this.grid.p4 != null) {
                this.di = this.grid.p4;
                return;
            }
            this.di = this.dr();
        }
        else {
            this.di = this.dw;
        }
    }
    gl(a, b, c, d) {
        if (this.columnCellsPropertyUpdating != null) {
            this.columnCellsPropertyUpdating(this, a, b, c, d);
        }
    }
    d7() {
        if (this.c == 0) {
            return 3;
        }
        return 2;
    }
    d9() {
        if (this.c == 0) {
            return 3;
        }
        return 2;
    }
    d6() {
        return 2;
    }
    d8() {
        return 2;
    }
    fu() {
        return this.f5 != null && this.f5 != "" ? this.f5 : this.gb;
    }
    gk(a, b, c) {
        if (this.ek == null) {
            this.ek = new FastIterationDictionary$2(String_$type, Base.$, 0);
        }
        let d = null;
        if (this.ek.d(a)) {
            d = this.ek.item(a);
        }
        this.ek.item(a, c);
        let e = false;
        if (d == null && c != null) {
            e = true;
        }
        if (d != null) {
            if (!Base.equalsStatic(d, c)) {
                e = true;
            }
        }
        if (e) {
            this.gm(this, a, b, d, c);
        }
    }
    ew() {
        if (this.ek == null) {
            return false;
        }
        return this.ek.r > 0;
    }
    get el() {
        return this.ek;
    }
    ev(a) {
        if (this.ek == null) {
            return false;
        }
        return this.ek.d(a);
    }
    gj(a) {
        if (this.ek == null) {
            return;
        }
        if (this.ek.d(a)) {
            this.ek.f(a);
        }
    }
    fk(a) {
        if (this.ek == null) {
            return null;
        }
        if (this.ek.d(a)) {
            return this.ek.item(a);
        }
        return null;
    }
}
Column.$t = markType(Column, 'Column', DefinitionBase.$);
Column.fi = 0;
/**
 * @hidden
 */
class GridColumnCollection extends ObservableCollection$1 {
    constructor() {
        super(Column.$, 0);
    }
}
GridColumnCollection.$t = markType(GridColumnCollection, 'GridColumnCollection', ObservableCollection$1.$.specialize(Column.$));
/**
 * @hidden
 */
class GridEffectGroup extends Base {
    constructor(a, ..._rest) {
        super();
        this.c = null;
        this.f = 0;
        this.a = false;
        this.b = false;
        this.effectsFinished = null;
        this.effectsCanceled = null;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0:
                {
                    let c = _rest[0];
                    this.a = c;
                    this.c = new List$1(GridEffect.$, 0);
                    this.b = false;
                }
                break;
            case 1:
                {
                    let c = [true];
                    {
                        let e = c[0];
                        this.a = e;
                        this.c = new List$1(GridEffect.$, 0);
                        this.b = false;
                    }
                }
                break;
        }
    }
    k() {
        this.b = false;
        for (let a = 0; a < this.c.count; a++) {
            let b = this.c._inner[a];
            b.onFinished = delegateRemove(b.onFinished, runOn(this, this.i));
            let c = this.c._inner[a];
            c.onCanceled = delegateRemove(c.onCanceled, runOn(this, this.h));
        }
        this.f = 0;
        this.c.clear();
    }
    g(a) {
        this.c.add(a);
        a.onFinished = delegateCombine(a.onFinished, runOn(this, this.i));
        a.onCanceled = delegateCombine(a.onCanceled, runOn(this, this.h));
    }
    h(a, b) {
        this.b = true;
        this.f++;
        if (this.f == this.c.count) {
            this.j();
        }
    }
    i(a) {
        this.f++;
        if (this.f == this.c.count) {
            this.j();
        }
    }
    j() {
        if (this.b) {
            if (this.effectsCanceled != null) {
                this.effectsCanceled(this, new EventArgs());
            }
        }
        else {
            if (this.effectsFinished != null) {
                this.effectsFinished(this, new EventArgs());
            }
        }
        if (this.a) {
            this.k();
        }
    }
}
GridEffectGroup.$t = markType(GridEffectGroup, 'GridEffectGroup');
/**
 * @hidden
 */
class RecyclingManager extends Base {
    constructor() {
        super();
        this.b = null;
        this.b = new Dictionary$2(String_$type, Stack$1.$.specialize(CellModel.$), 0);
    }
    a(a) {
        if (!this.b.containsKey(a)) {
            this.b.addItem(a, new Stack$1(CellModel.$));
            return null;
        }
        let b = this.b.item(a);
        if (b.f > 0) {
            let c = b.e();
            if (c.r == 2) {
                c.r = 1;
            }
            return c;
        }
        return null;
    }
    c(a) {
        a.r = 1;
        if (!this.b.containsKey(a.g1)) {
            this.b.addItem(a.g1, new Stack$1(CellModel.$));
        }
        this.b.item(a.g1).h(a);
    }
}
RecyclingManager.$t = markType(RecyclingManager, 'RecyclingManager');
/**
 * @hidden
 */
class ActivationManager extends Base {
    constructor(a, b) {
        super();
        this.a = null;
        this.b = null;
        this.c = new FastIterationDictionary$2(Number_$type, Number_$type, 0);
        this.e = new FastIterationDictionary$2(Number_$type, Number_$type, 0);
        this.d = new FastIterationDictionary$2(Number_$type, String_$type, 0);
        this.f = new FastIterationDictionary$2(String_$type, Number_$type, 0);
        this.k = false;
        this.l = false;
        this.q = -1;
        this.s = -1;
        this.p = -1;
        this.a = a;
        this.b = b;
    }
    get g() {
        if (this.k) {
            this.z();
            this.k = false;
        }
        return this.c;
    }
    get i() {
        if (this.k) {
            this.z();
            this.k = false;
        }
        return this.e;
    }
    get h() {
        if (this.k) {
            this.z();
            this.k = false;
        }
        return this.d;
    }
    get j() {
        if (this.k) {
            this.z();
            this.k = false;
        }
        return this.f;
    }
    ai(a) {
        if (!a.i.ab) {
            return;
        }
        if (this.m(a)) {
            this.ac(a);
        }
        else {
            this.x(a);
        }
    }
    m(a) {
        let b = false;
        let c = this.a.da.getDataRow(a.i);
        if (c == -1) {
            return false;
        }
        if (this.q < 0) {
            return false;
        }
        if (c != this.q) {
            return false;
        }
        if (typeCast(SectionHeaderCellModel.$, a) !== null) {
            return true;
        }
        if (this.i.d(a.i.al)) {
            let d = this.i.item(a.i.al);
            if (d >= 0) {
                b = this.n(c, d);
            }
        }
        return b;
    }
    n(a, b) {
        return this.q == a && b == this.s;
    }
    o() {
        return this.a.by == 1;
    }
    aa() {
        if (this.q >= 0 && this.s >= 0) {
            this.ab(this.q, this.s, true);
        }
    }
    ac(a) {
        let b = this.a.da.getDataRow(a.i);
        if (b == -1) {
            return;
        }
        if (this.i.d(a.i.al)) {
            let c = this.i.item(a.i.al);
            if (this.n(b, c)) {
                this.ab(b, c, true);
            }
        }
    }
    x(a) {
        this.w(a.i);
    }
    w(a) {
        if (!a.ab) {
            return;
        }
        if (!this.o()) {
            return;
        }
        if (this.q >= 0 && this.s != null) {
            this.ab(this.q, this.s, false);
        }
        let b = this.a.da.getDataRow(a);
        if (b == -1) {
            return;
        }
        if (a.al == -400) {
            if (this.q != b) {
                this.v(b, 0);
            }
        }
        if (this.i.d(a.al)) {
            let c = this.i.item(a.al);
            if (!this.n(b, c)) {
                this.u(b, c);
            }
        }
    }
    y(a, b) {
        let c = this.s;
        if (b == null) {
            if (this.a.c2 != 1) {
                let d = this.a.da.getRowType(a);
                if (this.a.da.isRowSpanning(d) && this.s == -1) {
                    c = this.i.item(0);
                }
            }
        }
        else if (this.j.d(b)) {
            c = this.j.item(b);
        }
        if (c != -1) {
            if (this.q >= 0 && this.s >= 0) {
                if (a != this.q || c != this.s) {
                    this.ab(this.q, this.s, false);
                    this.u(a, c);
                }
            }
            else if (this.q == -1 && this.s == -1) {
                this.u(a, c);
            }
        }
    }
    v(a, b) {
        if (!this.i.d(b)) {
            return;
        }
        let c = this.i.item(b);
        if (a != this.q || c != this.s) {
            this.q = a;
            this.s = c;
            this.p = b;
            if (a >= 0 && b >= 0) {
                if (a >= 0 && a < this.a.da.getRowCount()) {
                    if (this.a.c2 != 1) {
                        let d = this.a.da.getRowType(a);
                        if (this.a.da.isRowSpanning(d)) {
                            b = -400;
                            c = -400;
                        }
                    }
                }
                this.b.aa(this.a, a, b, c);
            }
            this.a.mr(a, this.t(c));
        }
    }
    u(a, b) {
        if (!this.g.d(b)) {
            return;
        }
        let c = this.g.item(b);
        if (a != this.q || b != this.s) {
            this.q = a;
            this.s = b;
            this.p = c;
            if (a >= 0 && c >= 0) {
                if (a >= 0 && a < this.a.da.getRowCount()) {
                    if (this.a.c2 != 1) {
                        let d = this.a.da.getRowType(a);
                        if (this.a.da.isRowSpanning(d)) {
                            c = -400;
                            b = -400;
                        }
                    }
                }
                this.b.aa(this.a, a, c, b);
            }
            this.a.mr(a, this.t(b));
        }
    }
    ab(a, b, c) {
        if (this.n(a, b)) {
            this.s = -1;
            this.q = -1;
            this.p = -1;
            if (a >= 0) {
                if (this.g.d(b)) {
                    let d = this.g.item(b);
                    if (d >= 0) {
                        if (a >= 0 && a < this.a.da.getRowCount()) {
                            if (this.a.c2 != 1) {
                                let e = this.a.da.getRowType(a);
                                if (this.a.da.isRowSpanning(e)) {
                                    d = -400;
                                    b = -400;
                                }
                            }
                        }
                        this.b.ab(this.a, a, d, b);
                    }
                }
            }
            if (c) {
                this.a.mt(a, this.t(b));
            }
        }
    }
    ae() {
        this.q = -1;
        this.s = -1;
        this.p = -1;
    }
    af(a) {
    }
    ag(a) {
    }
    t(a) {
        if (!this.h.d(a)) {
            return null;
        }
        return this.h.item(a);
    }
    ah(a) {
    }
    ad() {
        this.k = true;
    }
    z() {
        this.c.u();
        this.e.u();
        this.d.u();
        this.f.u();
        for (let a = 0; a < this.a.actualColumns.count; a++) {
            this.c.s(this.a.actualColumns._inner[a].fj, a);
            this.e.s(a, this.a.actualColumns._inner[a].fj);
            this.d.s(this.a.actualColumns._inner[a].fj, this.a.actualColumns._inner[a].fu());
            this.f.s(this.a.actualColumns._inner[a].fu(), this.a.actualColumns._inner[a].fj);
        }
    }
    r() {
        if (this.g.d(this.s)) {
            return this.g.item(this.s);
        }
        if (this.p != -1) {
            return this.p;
        }
        return 0;
    }
}
ActivationManager.$t = markType(ActivationManager, 'ActivationManager');
/**
 * @hidden
 */
class SelectionManager extends Base {
    constructor(a, b) {
        super();
        this.a = null;
        this.b = null;
        this.f = new FastIterationDictionary$2(PrimaryKeyValue.$, Number_$type, 0);
        this.e = new FastIterationDictionary$2(PrimaryKeyValue.$, FastIterationDictionary$2.$.specialize(Number_$type, Number_$type), 0);
        this.c = new FastIterationDictionary$2(Number_$type, Number_$type, 0);
        this.d = new FastIterationDictionary$2(Number_$type, Number_$type, 0);
        this.i = false;
        this.r = new List$1(CellRange.$, 0);
        this.q = new List$1(CellRange.$, 0);
        this.j = false;
        this.a = a;
        this.b = b;
    }
    get g() {
        if (this.i) {
            this.v();
            this.i = false;
        }
        return this.c;
    }
    get h() {
        if (this.i) {
            this.v();
            this.i = false;
        }
        return this.d;
    }
    an(a) {
        if (!a.i.ab) {
            return;
        }
        if (this.o(a)) {
            this.aq(a);
        }
        else {
            this.aj(a);
        }
    }
    am(a) {
        if (!a.i.ab) {
            return;
        }
        this.j = true;
        this.aj(a);
        this.j = false;
    }
    o(a) {
        let b = this.a.da.getDataRow(a.i);
        if (b == -1) {
            return false;
        }
        if (this.a.da.isPlaceholderItem(b)) {
            return false;
        }
        let c = this.a.da.getRowKey(this.a.g(), b);
        if (c == null) {
            return false;
        }
        let d = this.f.d(c);
        if (d) {
            let e = this.f.item(c);
            if (e == -1) {
                this.f.item(c, b);
            }
            let f = this.a.da.resolveValueForRow(a.i);
            let g = this.a.ad.indexOf(c);
            if (g >= 0) {
                if (this.a.z.ae._inner[g] == null) {
                    this.a.n0(g, f, c);
                }
            }
        }
        if (!d) {
            if (this.h.d(a.i.al)) {
                let h = this.h.item(a.i.al);
                if (h >= 0) {
                    d = this.k(c, h);
                    if (d && this.e.item(c).item(h) == -1) {
                        this.e.item(c).item(h, b);
                    }
                }
            }
        }
        if (!d) {
            for (let i = 0; i < this.q.count; i++) {
                if (this.q._inner[i].b(a.i.s, a.i.al)) {
                    d = true;
                    break;
                }
            }
        }
        if (!d) {
            if (this.a.da.isRowPinned(b)) {
                let j = typeCast(DataSourceSpecialRow.$, c.value[0]);
                if (j != null) {
                    let k = this.a.da.getItemKey(this.a.g(), j.targetRow);
                    d = this.f.d(k);
                    if (!d) {
                        if (this.h.d(a.i.al)) {
                            let l = this.h.item(a.i.al);
                            if (l >= 0) {
                                d = this.k(k, l);
                            }
                        }
                    }
                }
            }
        }
        return d;
    }
    m(a) {
        return this.f.d(a);
    }
    k(a, b) {
        return this.e.d(a) && this.e.item(a).d(b);
    }
    n() {
        return this.a.cz == 1 || this.a.cz == 2;
    }
    l() {
        return this.a.cz == 3 || this.a.cz == 4;
    }
    aq(a) {
        let b = this.a.da.getDataRow(a.i);
        if (b == -1) {
            return;
        }
        if (this.a.da.isPlaceholderItem(b)) {
            return;
        }
        let c = this.a.da.getRowKey(this.a.g(), b);
        if (this.m(c)) {
            this.ar(c, b, false);
        }
        if (this.h.d(a.i.al)) {
            let d = this.h.item(a.i.al);
            if (this.k(c, d)) {
                this.ao(c, b, d);
            }
        }
    }
    aj(a) {
        if (this.a.cz == 0) {
            return;
        }
        if (this.a.cz == 1 || this.j) {
            let b = this.f.o;
            let c = this.f.p;
            let d = new List$1(PrimaryKeyValue.$, 0);
            let e = new List$1(Number_$type, 0);
            for (let f = 0; f < b.count; f++) {
                if (c._inner[f]) {
                    continue;
                }
                d.add(b._inner[f]);
                e.add(this.f.q._inner[f]);
            }
            for (let g = 0; g < d.count; g++) {
                this.ar(d._inner[g], e._inner[g], false);
            }
        }
        if (this.a.cz == 3 || this.j) {
            let h = this.e.o;
            let i = this.e.p;
            let j = new List$1(PrimaryKeyValue.$, 0);
            let k = new List$1(Number_$type, 0);
            let l = new List$1(Number_$type, 0);
            for (let m = 0; m < h.count; m++) {
                if (i._inner[m]) {
                    continue;
                }
                let n = h._inner[m];
                let o = this.e.item(n).o;
                let p = this.e.item(n).q;
                let q = this.e.item(n).p;
                for (let r = 0; r < o.count; r++) {
                    if (q._inner[r]) {
                        continue;
                    }
                    let s = o._inner[r];
                    let t = p._inner[r];
                    if (this.h.d(a.i.al) && this.h.item(a.i.al) == s && a.i.s == t) {
                        continue;
                    }
                    j.add(n);
                    k.add(s);
                    l.add(t);
                }
            }
            for (let u = 0; u < j.count; u++) {
                this.ao(j._inner[u], l._inner[u], k._inner[u]);
            }
        }
        let v = this.a.da.getDataRow(a.i);
        if (v == -1) {
            return;
        }
        if (this.a.da.isPlaceholderItem(v)) {
            return;
        }
        let w = this.a.da.getRowKey(this.a.g(), v);
        if (w == null) {
            return;
        }
        if (this.n()) {
            this.ak(w, v, false);
        }
        else if (this.l()) {
            this.ai(w, v, a.i.al);
        }
    }
    ak(a, b, c) {
        let d = true;
        let e = false;
        if (!c) {
            if (this.a.da.getRowType(b) == 3) {
                let f = typeCast(DataSourceSpecialRow.$, a.value[0]);
                if (f.targetRow != null) {
                    let g = this.a.da.getItemKey(this.a.g(), f.targetRow);
                    let h = this.a.da.indexOfVisibleItemByKey(this.a.g(), g, this.a.ic(), this.a.ig());
                    this.al(g, h, f.targetRow, true);
                }
                e = true;
                d = false;
            }
        }
        let i = null;
        if (!e) {
            i = this.a.da.resolveValueForDataRow(b);
            if (this.a.ac.contains(a)) {
                let j = this.s(a);
                if (j >= 0) {
                    let k = this.a.da.getRowKey(this.a.g(), j);
                    if (!this.m(k)) {
                        this.al(k, j, null, false);
                    }
                }
            }
        }
        this.al(a, b, i, d);
    }
    al(a, b, c, d) {
        if (!this.f.d(a)) {
            this.f.s(a, b);
            if (b >= 0) {
                this.b.an(this.a, b);
            }
        }
        if (d && c != null) {
            this.a.nx(c, a);
        }
    }
    as(a, b, c, d) {
        if (this.f.d(a)) {
            this.f.f(a);
            if (b >= 0) {
                let e = this.a.da.getRowKey(this.a.g(), b);
                if (e != null && e.equals(a) && b >= 0) {
                    this.b.ao(this.a, b);
                }
            }
        }
        if (d && c != null) {
            this.a.ny(c, a);
        }
    }
    ar(a, b, c) {
        let d = true;
        let e = false;
        if (!c) {
            if (this.a.da.getRowType(b) == 3) {
                let f = typeCast(DataSourceSpecialRow.$, a.value[0]);
                if (f.targetRow != null) {
                    let g = this.a.da.getItemKey(this.a.g(), f.targetRow);
                    let h = this.a.da.indexOfVisibleItemByKey(this.a.g(), g, this.a.ic(), this.a.ig());
                    this.as(g, h, f.targetRow, true);
                }
                e = true;
                d = false;
            }
        }
        let i = null;
        if (!e) {
            i = this.a.da.resolveValueForDataRow(b);
            if (this.a.ac.contains(a)) {
                let j = this.s(a);
                if (j >= 0) {
                    let k = this.a.da.getRowKey(this.a.g(), j);
                    if (this.m(k)) {
                        this.as(k, j, null, false);
                    }
                }
            }
        }
        this.as(a, b, i, d);
    }
    ai(a, b, c) {
        if (!this.h.d(c)) {
            return;
        }
        let d = this.h.item(c);
        let e = true;
        if (this.a.da.getRowType(b) == 3) {
            let f = typeCast(DataSourceSpecialRow.$, a.value[0]);
            if (f.targetRow != null) {
                let g = this.a.da.getItemKey(this.a.g(), f.targetRow);
                let h = this.a.da.indexOfVisibleItemByKey(this.a.g(), g, this.a.ic(), this.a.ig());
                this.ag(g, d, c, h, true);
            }
            e = false;
        }
        else {
            if (this.a.ac.contains(a)) {
                let i = this.s(a);
                if (i >= 0) {
                    let j = this.a.da.getRowKey(this.a.g(), i);
                    if (!this.k(j, d)) {
                        this.ag(j, d, c, i, false);
                    }
                }
            }
        }
        this.ag(a, d, c, b, e);
    }
    ah(a, b, c) {
        if (!this.g.d(c)) {
            return;
        }
        let d = this.g.item(c);
        if (!this.e.d(a)) {
            let e = new FastIterationDictionary$2(Number_$type, Number_$type, 0);
            e.s(c, b);
            this.e.s(a, e);
            if (b >= 0 && d >= 0) {
                this.b.ae(this.a, b, d, c);
            }
            this.a.m1(a, c);
        }
        else {
            if (!this.e.item(a).d(c)) {
                this.e.item(a).s(c, b);
                if (b >= 0) {
                    this.b.ae(this.a, b, d, c);
                }
                this.a.m1(a, c);
            }
        }
    }
    ag(a, b, c, d, e) {
        if (!this.e.d(a)) {
            if (b >= 0) {
                let f = new FastIterationDictionary$2(Number_$type, Number_$type, 0);
                f.s(b, d);
                this.e.s(a, f);
                if (d >= 0) {
                    this.b.ae(this.a, d, c, b);
                }
                if (e) {
                    this.a.m1(a, b);
                }
            }
        }
        else {
            if (!this.e.item(a).d(b)) {
                this.e.item(a).s(b, d);
                if (d >= 0) {
                    this.b.ae(this.a, d, c, b);
                }
                if (e) {
                    this.a.m1(a, b);
                }
            }
        }
    }
    ap(a, b, c, d) {
        if (this.k(a, c)) {
            this.e.item(a).f(c);
            if (this.e.item(a).r == 0) {
                this.e.f(a);
            }
            if (b >= 0) {
                let e = this.a.da.getRowKey(this.a.g(), b);
                if (e != null && e.equals(a) && b >= 0) {
                    if (this.g.d(c)) {
                        let f = this.g.item(c);
                        if (f >= 0) {
                            this.b.af(this.a, b, f, c);
                        }
                    }
                }
            }
            if (d) {
                this.a.m2(a, c);
            }
        }
    }
    ao(a, b, c) {
        let d = true;
        if (this.a.da.getRowType(b) == 3) {
            let e = typeCast(DataSourceSpecialRow.$, a.value[0]);
            if (e.targetRow != null) {
                let f = this.a.da.getItemKey(this.a.g(), e.targetRow);
                let g = this.a.da.indexOfVisibleItemByKey(this.a.g(), f, this.a.ic(), this.a.ig());
                this.ap(f, g, c, true);
            }
            d = false;
        }
        else {
            if (this.a.ac.contains(a)) {
                let h = this.s(a);
                if (h >= 0) {
                    let i = this.a.da.getRowKey(this.a.g(), h);
                    if (this.k(i, c)) {
                        this.ap(i, h, c, false);
                    }
                }
            }
        }
        this.ap(a, b, c, d);
    }
    s(a) {
        let b = -1;
        let c = this.a.da.getStickyRows();
        if (c != null) {
            for (let d = 0; d < c.length; d++) {
                let e = typeCast(DataSourceSpecialRow.$, this.a.actualDataSource.getItemAtIndex(c[d]));
                if (e != null && e.rowType == 3) {
                    let f = this.a.da.getItemKey(this.a.g(), e.targetRow);
                    if (f != null && f.equals(a)) {
                        b = c[d];
                        break;
                    }
                }
            }
        }
        return b;
    }
    av() {
        let a = this.p();
        let b = new Dictionary$2(PrimaryKeyValue.$, Number_$type, 0);
        for (let c = 0; c < a.count; c++) {
            let d = a.item(c);
            let e = -1;
            if (this.f.d(d)) {
                e = this.f.item(d);
            }
            if (e == -1) {
                e = this.a.da.indexOfVisibleItemByKey(this.a.g(), d, this.a.ic(), this.a.ig());
            }
            if (this.a.ac.contains(d)) {
                let f = this.s(d);
                if (f >= 0) {
                    let g = this.a.da.getRowKey(this.a.g(), f);
                    if (!b.containsKey(g)) {
                        b.addItem(g, f);
                    }
                    if (!this.m(g)) {
                        this.ak(g, f, true);
                    }
                }
            }
            if (!b.containsKey(d)) {
                b.addItem(d, e);
            }
            if (!this.m(d)) {
                this.ak(d, e, true);
            }
        }
        let h = this.f.o;
        let i = this.f.p;
        let j = new List$1(PrimaryKeyValue.$, 0);
        let k = new List$1(Number_$type, 0);
        for (let l = 0; l < h.count; l++) {
            if (i._inner[l]) {
                continue;
            }
            let m = h._inner[l];
            if (!b.containsKey(m)) {
                j.add(m);
                k.add(this.f.q._inner[l]);
            }
        }
        for (let n = 0; n < k.count; n++) {
            this.ar(j._inner[n], k._inner[n], false);
        }
        for (let o = 0; o < this.a.z.ae.count; o++) {
            let p = this.a.da.getItemKey(this.a.g(), this.a.z.ae._inner[o]);
            if (p != null && !b.containsKey(p)) {
                let q = -1;
                if (this.f.d(p)) {
                    q = this.f.item(p);
                }
                if (q == -1) {
                    q = this.a.da.fastGetItemIndexForKey(this.a.g(), p, this.a.ic(), this.a.ig());
                }
                this.ar(p, q, false);
            }
        }
    }
    au() {
        let a = this.a.ct.am;
        let b = new Dictionary$2(PrimaryKeyValue.$, IList$1_$type.specialize(Number_$type), 0);
        for (let c = 0; c < a.count; c++) {
            let d = a.item(c).primaryKey;
            if (d == null) {
                continue;
            }
            if (a.item(c).b == null) {
                continue;
            }
            let e = a.item(c).b.fj;
            let f = -1;
            if (this.k(d, e)) {
                f = this.e.item(d).item(e);
            }
            if (f == -1) {
                let g = this.a.ic();
                let h = this.a.ig();
                if (g != -1 && h != -1) {
                    f = this.a.da.indexOfVisibleItemByKey(this.a.g(), d, g, h);
                }
            }
            if (this.a.ac.contains(d)) {
                let i = this.s(d);
                if (i >= 0) {
                    let j = this.a.da.getRowKey(this.a.g(), i);
                    if (!b.containsKey(j)) {
                        b.addItem(j, ((() => {
                            let $ret = new List$1(Number_$type, 0);
                            $ret.add(e);
                            return $ret;
                        })()));
                    }
                    else if (!b.item(j).contains(e)) {
                        b.item(j).add(e);
                    }
                    if (!this.k(j, e)) {
                        this.ah(j, f, e);
                    }
                }
            }
            if (!b.containsKey(d)) {
                b.addItem(d, ((() => {
                    let $ret = new List$1(Number_$type, 0);
                    $ret.add(e);
                    return $ret;
                })()));
            }
            else if (!b.item(d).contains(e)) {
                b.item(d).add(e);
            }
            if (!this.k(d, e)) {
                this.ah(d, f, e);
            }
        }
        let k = this.e.o;
        let l = this.e.p;
        let m = new List$1(PrimaryKeyValue.$, 0);
        let n = new List$1(Number_$type, 0);
        let o = new List$1(Number_$type, 0);
        for (let p = 0; p < k.count; p++) {
            if (l._inner[p]) {
                continue;
            }
            let q = k._inner[p];
            for (let r = 0; r < this.e.item(q).r; r++) {
                let s = this.e.item(q).o._inner[r];
                let t = this.e.item(q).q._inner[r];
                if (!b.containsKey(q) || !b.item(q).contains(s)) {
                    m.add(q);
                    n.add(s);
                    o.add(t);
                }
            }
        }
        for (let u = 0; u < m.count; u++) {
            this.ao(m._inner[u], o._inner[u], n._inner[u]);
        }
    }
    at() {
        let a = this.a.cq.ae;
        this.r.clear();
        this.r = this.q;
        this.q = new List$1(CellRange.$, 0);
        for (let b = 0; b < a.count; b++) {
            this.q.add(a.item(b).a());
        }
        let c = this.a.model.bw;
        let d = this.a.model.by;
        let e = this.a.da.getStickyRows();
        if (e != null) {
            for (let f = 0; f < e.length; f++) {
                let g = this.a.da.getRowType(e[f]);
                if (g == 3) {
                    for (let h = c; h <= d; h++) {
                        this.u(e[f], h);
                    }
                }
            }
        }
        let i = this.a.ic();
        let j = this.a.ig();
        for (let k = i; k <= j; k++) {
            for (let l = c; l <= d; l++) {
                this.u(k, l);
            }
        }
    }
    u(a, b) {
        let c = false;
        let d = false;
        for (let e = 0; e < this.r.count; e++) {
            let f = this.r._inner[e];
            if (f.b(a, b)) {
                c = true;
            }
        }
        for (let g = 0; g < this.q.count; g++) {
            let h = this.q._inner[g];
            if (h.b(a, b)) {
                d = true;
            }
        }
        if (c && !d) {
            this.a.b1.ad(this.a, a, b);
        }
        else if (!c && d) {
            this.a.b1.ac(this.a, a, b);
        }
    }
    p() {
        return this.a.ad.ae;
    }
    z() {
        this.y();
        this.x();
    }
    ad(a) {
        for (let b = 0; b < this.f.o.count; b++) {
            if (this.f.p._inner[b]) {
                continue;
            }
            let c = this.f.o._inner[b];
            let d = this.f.q._inner[b];
            if (d >= a) {
                this.f.item(c, d + 1);
            }
        }
        for (let e = 0; e < this.e.o.count; e++) {
            if (this.e.p._inner[e]) {
                continue;
            }
            let f = this.e.o._inner[e];
            let g = this.e.q._inner[e];
            for (let h = 0; h < g.o.count; h++) {
                if (this.e.item(f).p._inner[h]) {
                    continue;
                }
                let i = g.o._inner[h];
                let j = this.e.item(f).item(i);
                if (j >= a) {
                    this.e.item(f).item(i, j + 1);
                }
            }
        }
    }
    ae(a) {
        let b = new List$1(PrimaryKeyValue.$, 0);
        let c = new List$1(Number_$type, 0);
        for (let d = 0; d < this.f.o.count; d++) {
            if (this.f.p._inner[d]) {
                continue;
            }
            let e = this.f.o._inner[d];
            let f = this.f.q._inner[d];
            if (f == a) {
                b.add(e);
                c.add(f);
            }
            if (f > a) {
                this.f.item(e, f - 1);
            }
        }
        for (let g = 0; g < b.count; g++) {
            this.ar(b._inner[g], c._inner[g], true);
        }
        for (let h = 0; h < this.e.o.count; h++) {
            if (this.e.p._inner[h]) {
                continue;
            }
            let i = this.e.o._inner[h];
            let j = this.e.q._inner[h];
            for (let k = 0; k < j.o.count; k++) {
                if (this.e.item(i).p._inner[k]) {
                    continue;
                }
                let l = j.o._inner[k];
                let m = this.e.item(i).item(l);
                if (m == a) {
                    this.e.item(i).item(l, -1);
                }
                if (m > a) {
                    this.e.item(i).item(l, m - 1);
                }
            }
        }
    }
    ac(a, b) {
        let c = this.a.ic();
        let d = this.a.ig();
        let e = new List$1(Number_$type, 0);
        for (let f = 0; f < this.q.count; f++) {
            let g = this.q._inner[f];
            if (g.l > d || g.j < c) {
                continue;
            }
            if (a < g.k) {
                this.t(e, g.k - 1);
            }
            if (a <= g.i) {
                this.t(e, g.i);
            }
        }
        for (let h = 0; h < e.count; h++) {
            if (e._inner[h] >= 0 && e._inner[h] <= this.a.actualColumns.count) {
                this.a.b1.ag(this.a, c, d, e._inner[h], true);
            }
        }
    }
    aa(a, b) {
        let c = this.a.ic();
        let d = this.a.ig();
        let e = new List$1(Number_$type, 0);
        for (let f = 0; f < this.q.count; f++) {
            let g = this.q._inner[f];
            if (g.l > d || g.j < c) {
                continue;
            }
            if (a < g.k) {
                this.t(e, g.k);
            }
            if (a <= g.i) {
                this.t(e, g.i + 1);
            }
        }
        for (let h = 0; h < e.count; h++) {
            if (e._inner[h] >= 0 && e._inner[h] <= this.a.actualColumns.count) {
                this.a.b1.ag(this.a, c, d, e._inner[h], true);
            }
        }
    }
    ab(a, b, c) {
        let d = this.a.ic();
        let e = this.a.ig();
        let f = new List$1(Number_$type, 0);
        for (let g = 0; g < this.q.count; g++) {
            let h = this.q._inner[g];
            if (h.l > e || h.j < d) {
                continue;
            }
            if (h.c(a) && !h.c(b)) {
                this.t(f, b);
                if (b > h.i) {
                    this.t(f, h.i);
                }
                else if (b < h.k) {
                    this.t(f, h.k);
                }
            }
            else if (!h.c(a) && h.c(b)) {
                this.t(f, b);
                if (a > h.i) {
                    this.t(f, h.i + 1);
                }
                else if (a < h.k) {
                    this.t(f, h.k - 1);
                }
            }
            else if (!h.c(a) && !h.c(b)) {
                if (a < h.k && b > h.i) {
                    this.t(f, h.k - 1);
                    this.t(f, h.i);
                }
                if (a > h.i && b < h.k) {
                    this.t(f, h.k);
                    this.t(f, h.i + 1);
                }
            }
        }
        for (let i = 0; i < f.count; i++) {
            this.a.b1.ag(this.a, d, e, f._inner[i], true);
        }
    }
    t(a, b) {
        if (b < 0 || b >= this.a.actualColumns.count) {
            return;
        }
        if (!a.contains(b)) {
            a.add(b);
        }
    }
    af(a) {
        let b = new List$1(PrimaryKeyValue.$, 0);
        let c = new List$1(Number_$type, 0);
        for (let d = 0; d < this.f.o.count; d++) {
            if (this.f.p._inner[d]) {
                continue;
            }
            let e = this.f.o._inner[d];
            let f = this.f.q._inner[d];
            if (f == a) {
                b.add(e);
                c.add(f);
            }
        }
        for (let g = 0; g < b.count; g++) {
            this.ar(b._inner[g], c._inner[g], true);
        }
    }
    w() {
        this.i = true;
    }
    v() {
        this.c.u();
        this.d.u();
        for (let a = 0; a < this.a.actualColumns.count; a++) {
            this.c.s(this.a.actualColumns._inner[a].fj, a);
            this.d.s(a, this.a.actualColumns._inner[a].fj);
        }
    }
    y() {
        let a = new List$1(Number_$type, 0);
        let b = new HashSet$1(Number_$type, 0);
        for (let c = 0; c < this.f.o.count; c++) {
            if (this.f.p._inner[c]) {
                continue;
            }
            let d = this.f.o._inner[c];
            a.add(this.f.item(d));
            let e = this.a.da.indexOfVisibleItemByKey(this.a.g(), d, this.a.ic(), this.a.ig());
            b.add_1(e);
            this.f.item(d, -1);
        }
        for (let f = 0; f < a.count; f++) {
            if (!b.contains(a._inner[f])) {
                this.a.b1.ao(this.a, a._inner[f]);
            }
        }
    }
    x() {
        let a = new FastIterationDictionary$2(PrimaryKeyValue.$, Number_$type, 0);
        let b = new FastIterationDictionary$2(PrimaryKeyValue.$, Number_$type, 0);
        let c = new List$1(Number_$type, 0);
        for (let d = 0; d < this.e.q.count; d++) {
            let e = this.e.o._inner[d];
            let f = this.a.da.indexOfVisibleItemByKey(this.a.g(), e, this.a.ic(), this.a.ig());
            let g = this.e.q._inner[d];
            for (let h = 0; h < g.q.count; h++) {
                let i = g.o._inner[h];
                a.s(e, this.e.item(e).item(i));
                b.s(e, f);
                c.add(i);
                this.e.item(e).item(i, -1);
            }
        }
        for (let j = 0; j < a.q.count; j++) {
            let k = a.o._inner[j];
            let l = a.q._inner[j];
            let m = b.q._inner[j];
            if (l > -1 && l < this.a.da.getRowCount()) {
                let n = this.a.actualDataSource.getItemAtIndex(l);
                let o = typeCast(DataSourceSpecialRow.$, n);
                if (o != null && o.rowType == 3) {
                    let p = this.a.da.getItemKey(this.a.g(), o.targetRow);
                    if (p.equals(k)) {
                        continue;
                    }
                }
            }
            if (!b.q.contains(l)) {
                this.a.b1.af(this.a, l, this.c.item(c._inner[j]), c._inner[j]);
            }
        }
    }
}
SelectionManager.$t = markType(SelectionManager, 'SelectionManager');
/**
 * @hidden
 */
class SortManager extends Base {
    constructor(a) {
        super();
        this.c = null;
        this.e = false;
        this.c = a;
    }
    d(a) {
        if (null == a) {
            return false;
        }
        let b = a.gb;
        let c = this.c.bq;
        let d = this.a(b, c);
        let e = null == d ? 0 : d.c == 0 ? 1 : 2;
        let f = (this.c.c4 == 3 || this.c.c4 == 2);
        let g = this.b(e, f);
        this.f(a, g);
        return true;
    }
    f(a, b) {
        if (null == a) {
            return false;
        }
        let c = a.gb;
        let d = this.c.bq;
        let e = this.a(c, d);
        return this.g(c, b, e);
    }
    g(a, b, c) {
        if (this.e) {
            return false;
        }
        this.e = true;
        try {
            let d = this.c.bq;
            let e = d.j(c);
            let f = (this.c.c4 == 1 || this.c.c4 == 3);
            if (null != c) {
                d.h(c);
            }
            if (false == f) {
                d.m();
            }
            switch (b) {
                case 0: break;
                case 2:
                case 1:
                    {
                        let g = b == 1 ? 0 : 1;
                        let h = new ColumnSortDescription(2, a, g);
                        if (f && e >= 0) {
                            d.i.insert(e, h);
                        }
                        else {
                            d.g(h);
                        }
                    }
                    break;
            }
            return true;
        }
        finally {
            this.e = false;
        }
    }
    h() {
        let a = this.c.bq;
        let b = a.i.count;
        if (b > 1) {
            for (let c = b - 1; c > 0; c--) {
                a.i.removeAt(c);
            }
        }
    }
    a(a, b) {
        if (null == b || b.i.count < 1) {
            return null;
        }
        for (let c = 0; c < b.i.count; c++) {
            let d = b.i.item(c);
            if (d.f == a) {
                return d;
            }
        }
        return null;
    }
    b(a, b) {
        if (b) {
            switch (a) {
                case 0: return 1;
                case 1: return 2;
                case 2: return 0;
            }
        }
        else {
            switch (a) {
                case 0:
                case 2: return 1;
                default: return 2;
            }
        }
        return 0;
    }
}
SortManager.$t = markType(SortManager, 'SortManager');
/**
 * @hidden
 */
let IDataAdapter_$type = new Type(null, 'IDataAdapter');
/**
 * @hidden
 */
class DataAdapter extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.f = new Dictionary$2(Base.$, Number_$type, 0);
        this.g = new List$1(PrimaryKeyValue.$, 0);
        this.e = null;
        this.b = null;
        this.propertyChanged = null;
        this.h = 0;
        this.i = 0;
        this.e = a;
    }
    get c() {
        return this.b;
    }
    set c(a) {
        let b = this.b;
        this.b = a;
        if (this.b != b) {
            this.l("DataSource", b, this.b);
        }
    }
    setDataSource(a) {
        this.c = a;
    }
    getItemForKey(a) {
        let b = this.indexOfKey(a);
        if (b == -1) {
            if (a.value != null && a.value.length == 1) {
                return a.value[0];
            }
            return null;
        }
        return this.c.getItemAtIndex(b);
    }
    getItemKey(a, item_) {
        let b = (item_ != null && item_.$$isSpecialRow !== undefined);
        if (b || a == null) {
            if (item_ == null) {
                return null;
            }
            return PrimaryKeyValue.createIdentityKey(item_);
        }
        let c = new Array(a.length);
        for (let d = 0; d < a.length; d++) {
            c[d] = this.c.getItemProperty(item_, a[d]);
        }
        return new PrimaryKeyValue(a, c);
    }
    getRowKey(a, b) {
        if (this.c == null) {
            return null;
        }
        if (b < 0 || b > this.c.actualCount - 1) {
            return null;
        }
        let c = this.c.getItemAtIndex(b);
        if (c == null) {
            return null;
        }
        return this.getItemKey(a, c);
    }
    l(a, b, c) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
        this.m(a, b, c);
    }
    m(a, b, c) {
        switch (a) {
            case "DataSource":
                this.a = null;
                this.f.clear();
                if (this.c != null) {
                    if (this.a == null) {
                        this.a = new Array(1);
                        this.a[0] = new DefaultSectionInformation(0, this.b.actualCount, null, null, null);
                    }
                    for (let d = 0; d < this.a.length; d++) {
                        if (this.a[d].groupKeyValues != null) {
                            this.f.addItem(this.a[d].groupKeyValues, d);
                        }
                    }
                    for (let e = 0; e < this.g.count; e++) {
                        this.b.pinRow(this.g._inner[e].value);
                    }
                    this.g.clear();
                }
                break;
        }
    }
    getRowCount() {
        return this.j(0);
    }
    k(a, b) {
        if (this.b == null) {
            return -1;
        }
        if (this.b.actualPrimaryKey != null && this.b.isKeyIndexLookupSupported) {
            return this.indexOfKey(a);
        }
        if (this.b.isItemIndexLookupSupported) {
            return this.b.indexOfItem(b);
        }
        return -1;
    }
    indexOfKey(a) {
        if (this.b == null) {
            return -1;
        }
        if (this.b.actualPrimaryKey != null && this.b.isKeyIndexLookupSupported) {
            return this.b.indexOfKey(a.value);
        }
        return -1;
    }
    fastGetItemIndexForKey(a, b, c, d) {
        let e = this.indexOfVisibleItemByKey(a, b, c, d);
        if (e >= 0) {
            return e;
        }
        return this.indexOfKey(b);
    }
    indexOfVisibleItemByKey(a, b, c, d) {
        if (this.b == null) {
            return -1;
        }
        for (let e = c; e <= d; e++) {
            if (e > this.b.actualCount - 1) {
                break;
            }
            let f = this.b.getItemAtIndex(e);
            if (f == null) {
                continue;
            }
            let g = this.getItemKey(a, f);
            if (g == null) {
                continue;
            }
            if (g.value != null && g.value.length == 1 && getInstanceType(g.value[0]) == DataSourceSpecialRow.$ && b.value != null && b.value.length == 1 && getInstanceType(b.value[0]) == DataSourceSpecialRow.$) {
                let h = typeCast(DataSourceSpecialRow.$, g.value[0]);
                let i = typeCast(DataSourceSpecialRow.$, b.value[0]);
                if (h.rowType == i.rowType && h.targetRow == i.targetRow) {
                    return e;
                }
            }
            if (g.equals(b)) {
                return e;
            }
        }
        return -1;
    }
    j(a) {
        if (this.b == null) {
            return 0;
        }
        return this.b.actualCount;
    }
    getSectionCount() {
        if (this.a == null) {
            return 0;
        }
        return this.a.length;
    }
    d(a) {
        return a;
    }
    getDataRow(a) {
        if (a == null) {
            return -1;
        }
        a = this.d(a);
        if (this.a == null || this.a.length < 1) {
            if (this.b.actualCount > a.s) {
                return a.s;
            }
        }
        else {
            let b = this.a[a.t].startIndex;
            let c = b + a.s;
            if (c < 0 || c >= this.b.actualCount) {
                return -1;
            }
            return c;
        }
        return -1;
    }
    resolveValue(a, b) {
        if (a < 0 || a > this.b.actualCount - 1) {
            return null;
        }
        if (b != null && b.length == 1 && b.charAt(0) == '.') {
            return this.b.getItemAtIndex(a);
        }
        return this.b.getItemPropertyAtIndex(a, b);
    }
    resolveValueForPath(a, b) {
        let c = null;
        if (b.al == -400) {
            let d = this.b.getRowType(b.s);
            let e = this.b.getMainValuePath(d);
            c = e;
        }
        else {
            let f = a.as(b);
            c = f.gb;
        }
        return this.resolveValue(b.s, c);
    }
    resolveRow(a) {
        if (a < 0 || a > this.b.actualCount - 1) {
            return null;
        }
        return this.b.getItemAtIndex(a);
    }
    resolveValueForDataRow(a) {
        if (a < 0 || a > this.b.actualCount - 1) {
            return null;
        }
        return this.b.getItemAtIndex(a);
    }
    resolveValueForRow(a) {
        a = this.d(a);
        if (a == null) {
            return null;
        }
        let b = this.getDataRow(a);
        if (b < 0 || b > this.b.actualCount - 1) {
            return null;
        }
        return this.b.getItemAtIndex(b);
    }
    getSectionForRow(a) {
        if (this.a == null || this.a.length < 2) {
            return 0;
        }
        for (let b = 0; b < this.a.length; b++) {
            if (b < this.a.length - 1) {
                if (a > this.a[b + 1].startIndex) {
                    continue;
                }
            }
            return b;
        }
        return this.a.length - 1;
    }
    getRowPathForRow(a) {
        let b = this.getSectionForRow(a);
        return new RowPath(b, a - this.a[b].startIndex);
    }
    get firstVisibleIndexRequested() {
        return this.h = 0;
    }
    set firstVisibleIndexRequested(a) {
        this.h = a;
        if (this.b != null) {
            this.b.firstVisibleIndexRequested = this.h;
        }
    }
    get lastVisibleIndexRequested() {
        return this.i = 0;
    }
    set lastVisibleIndexRequested(a) {
        this.i = a;
        if (this.b != null) {
            this.b.lastVisibleIndexRequested = this.i;
        }
    }
    isPlaceholderValue(a) {
        if (this.b == null) {
            return false;
        }
        let b = this.getDataRow(a);
        if (b < 0 || b > this.b.actualCount - 1) {
            return false;
        }
        return this.b.isPlaceholderItem(b);
    }
    isPlaceholderItem(a) {
        if (this.b == null) {
            return false;
        }
        return this.b.isPlaceholderItem(a);
    }
    getRowType(a) {
        if (this.b == null) {
            return 0;
        }
        return this.b.getRowType(a);
    }
    getStickyRows() {
        if (this.b == null) {
            return null;
        }
        return this.b.getStickyRows();
    }
    getStickyRowsInRange(a, b) {
        if (this.b == null) {
            return null;
        }
        return this.b.getStickyRowsInRange(a, b);
    }
    getStickRowPriority(a) {
        if (this.b == null) {
            return -1;
        }
        return this.b.getStickyRowPriority(a);
    }
    isExclusivelySticky(a) {
        if (this.b == null) {
            return false;
        }
        return this.b.isExclusivelySticky(a);
    }
    isRowSpanning(a) {
        if (this.b == null) {
            return false;
        }
        return this.b.isRowSpanning(a);
    }
    pinRow(a) {
        if (this.b == null) {
            this.g.add(a);
            return;
        }
        this.b.pinRow(a.value);
    }
    unpinRow(a) {
        if (this.b == null) {
            for (let b = 0; b < this.g.count; b++) {
                if (this.g._inner[b].equals(a)) {
                    this.g.remove(this.g._inner[b]);
                    break;
                }
            }
            return;
        }
        this.b.unpinRow(a.value);
    }
    clearPinnedRows() {
        if (this.b == null) {
            return;
        }
        this.b.clearPinnedRows();
    }
    isRowPinned(a) {
        if (this.b == null) {
            return false;
        }
        return this.b.isRowPinned(a);
    }
    getRowIndent(a) {
        if (this.b == null) {
            return 0;
        }
        return this.b.getRowLevel(a);
    }
    getRootSummaryRowCount() {
        if (this.b == null) {
            return 0;
        }
        return this.b.getRootSummaryRowCount();
    }
}
DataAdapter.$t = markType(DataAdapter, 'DataAdapter', Base.$, [INotifyPropertyChanged_$type, IDataAdapter_$type]);
/**
 * @hidden
 */
class ColumnMovingSeparator extends DefinitionBase {
    constructor() {
        super(...arguments);
        this.d0 = truncate(DeviceUtils.g(2));
    }
    b8(a, b, c) {
        return "columnMovingSeparator";
    }
    l(a) {
        return new VerticalSeparatorCellModel();
    }
    dq() {
        return GridStyleRepository.y;
    }
    get d1() {
        return this.d0;
    }
    set d1(a) {
        let b = this.d0;
        this.d0 = a;
        if (this.d0 != b) {
            this.cm("SeparatorWidth", 6, b, this.d0);
        }
    }
    cl(a, b) {
        if (a != null) {
            a.propertyChanged = delegateRemove(a.propertyChanged, runOn(this, this.d3));
        }
        if (b != null) {
            b.propertyChanged = delegateCombine(b.propertyChanged, runOn(this, this.d3));
        }
        this.cs();
    }
    cs() {
        if (this.dm == null) {
            if (this.grid != null && this.grid.py != null) {
                this.dg = this.grid.py;
                return;
            }
            this.dg = this.dq();
        }
        else {
            this.dg = this.dm;
        }
    }
    d3(a, b) {
        switch (b.propertyName) {
            case "ColumnMovingSeparatorBackground":
                this.cs();
                break;
        }
    }
}
ColumnMovingSeparator.$t = markType(ColumnMovingSeparator, 'ColumnMovingSeparator', DefinitionBase.$);
/**
 * @hidden
 */
class DateTimeColumn extends Column {
    constructor() {
        super();
        this.gt = new DateTimeColumnValueFormatter();
        this.gu = 0;
        this.gz = null;
        this.gx = null;
    }
    get gv() {
        return this.gu;
    }
    set gv(a) {
        let b = this.gu;
        this.gu = a;
        if (this.gu != b) {
            this.cm("DateTimeFormat", 4, enumGetBox(DateTimeFormats_$type, b), enumGetBox(DateTimeFormats_$type, this.gu));
        }
    }
    get g2() {
        return this.gz;
    }
    set g2(a) {
        let b = this.gz;
        this.gz = a;
        if (this.gz != b) {
            this.cm("FormatString", 8, b, this.gz);
        }
    }
    get gy() {
        return this.gx;
    }
    set gy(a) {
        let b = this.gx;
        this.gx = a;
        if (this.gx != b) {
            this.cm("FormatOverride", 9, b, this.gx);
        }
    }
    cn(a, b, c, d) {
        super.cn(a, b, c, d);
        switch (a) {
            case "DateTimeFormat":
                this.gt.k();
                break;
        }
    }
    l(a) {
        return new DateTimeCellModel();
    }
    b8(a, b, c) {
        return "datetime";
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        let e = a;
        e.ip = this.gw(c);
        e.ii = this.gt;
        this.gt.j(e);
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
        let e = a;
        e.ik = this.gv;
        e.ix = this.gy;
    }
    gw(a) {
        if (a == null) {
            return dateMinValue();
        }
        if (typeCast(Date_$type, a) !== null) {
            return a;
        }
        return dateMinValue();
    }
}
DateTimeColumn.$t = markType(DateTimeColumn, 'DateTimeColumn', Column.$);
/**
 * @hidden
 */
let IExternalDefinitionBase_$type = new Type(null, 'IExternalDefinitionBase');
/**
 * @hidden
 */
class DataBindingEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._resolvedValue = null;
        this._rowObject = null;
        this._cellInfo = null;
    }
    get resolvedValue() {
        return this._resolvedValue;
    }
    set resolvedValue(a) {
        this._resolvedValue = a;
    }
    get rowObject() {
        return this._rowObject;
    }
    set rowObject(a) {
        this._rowObject = a;
    }
    get cellInfo() {
        return this._cellInfo;
    }
    set cellInfo(a) {
        this._cellInfo = a;
    }
}
DataBindingEventArgs.$t = markType(DataBindingEventArgs, 'DataBindingEventArgs', EventArgs.$);
/**
 * @hidden
 */
class Header extends DefinitionBase {
    constructor() {
        super();
        this.eo = null;
        this.en = null;
        this.d1 = 3;
        this.d0 = 3;
        this.d5 = truncate(DeviceUtils.g(10));
        this.d7 = truncate(DeviceUtils.g(5));
        this.d6 = truncate(DeviceUtils.g(10));
        this.d4 = truncate(DeviceUtils.g(5));
        this.ep = this.eq();
    }
    dv() {
        return GridStyleRepository.ak;
    }
    dq() {
        return GridStyleRepository.aj;
    }
    eq() {
        return GridStyleRepository.am;
    }
    af() {
        return GridStyleRepository.c;
    }
    cl(a, b) {
        if (a != null) {
            a.propertyChanged = delegateRemove(a.propertyChanged, runOn(this, this.ek));
        }
        if (b != null) {
            b.propertyChanged = delegateCombine(b.propertyChanged, runOn(this, this.ek));
        }
        this.cs();
        this.cy();
        this.cz();
        this.el();
        this.em();
    }
    cs() {
        if (this.dm == null) {
            if (this.grid != null && this.grid.p0 != null) {
                this.dg = this.grid.p0;
                return;
            }
            this.dg = this.dq();
        }
        else {
            this.dg = this.dm;
        }
    }
    cy() {
        if (this.dz == null) {
            if (this.grid != null && this.grid.p3 != null) {
                this.dl = this.grid.p3;
                return;
            }
            this.dl = this.dv();
        }
        else {
            this.dl = this.dz;
        }
    }
    cz() {
        if (this.textStyle == null) {
            if (this.grid != null && this.grid.ei != null) {
                this.ad = this.grid.ei;
                return;
            }
            this.ad = this.af();
        }
        else {
            this.ad = this.textStyle;
        }
    }
    el() {
        if (this.er == null) {
            if (this.grid != null && this.grid.p2 != null) {
                this.ep = this.grid.p2;
                return;
            }
            this.ep = this.eq();
        }
        else {
            this.ep = this.er;
        }
    }
    em() {
        if (this.d3 == 3) {
            if (this.grid != null) {
                this.d2 = this.grid.dz;
                return;
            }
            this.d2 = 0;
        }
        else {
            this.d2 = this.d3;
        }
    }
    ek(a, b) {
        switch (b.propertyName) {
            case "HeaderBackground":
                this.cs();
                break;
            case "HeaderTextColor":
                this.cy();
                break;
            case "HeaderTextStyle":
                this.cz();
                break;
            case "HeaderSortIndicatorColor":
                this.el();
                break;
            case "HeaderSortIndicatorStyle":
                this.em();
                break;
        }
    }
    get er() {
        return this.eo;
    }
    set er(a) {
        let b = this.eo;
        this.eo = a;
        if (this.eo != b) {
            this.cm("SortIndicatorColor", 10, b, this.eo);
        }
    }
    get ep() {
        return this.en;
    }
    set ep(a) {
        let b = this.en;
        this.en = a;
        if (this.en != b) {
            this.cm("ActualSortIndicatorColor", 2, b, this.en);
        }
    }
    get d3() {
        return this.d1;
    }
    set d3(a) {
        let b = this.d1;
        this.d1 = a;
        if (this.d1 != b) {
            this.cm("SortIndicatorStyle", 11, enumGetBox(SortIndicatorStyle_$type, b), enumGetBox(SortIndicatorStyle_$type, this.d1));
        }
    }
    get d2() {
        return this.d0;
    }
    set d2(a) {
        let b = this.d0;
        this.d0 = a;
        if (this.d0 != b) {
            this.cm("ActualSortIndicatorStyle", 11, enumGetBox(SortIndicatorStyle_$type, b), enumGetBox(SortIndicatorStyle_$type, this.d0));
        }
    }
    get d9() {
        return this.d5;
    }
    set d9(a) {
        let b = this.d5;
        this.d5 = a;
        if (this.d5 != b) {
            this.cm("PaddingLeft", 6, b, this.d5);
        }
    }
    get eb() {
        return this.d7;
    }
    set eb(a) {
        let b = this.d7;
        this.d7 = a;
        if (this.d7 != b) {
            this.cm("PaddingTop", 6, b, this.d7);
        }
    }
    get ea() {
        return this.d6;
    }
    set ea(a) {
        let b = this.d6;
        this.d6 = a;
        if (this.d6 != b) {
            this.cm("PaddingRight", 6, b, this.d6);
        }
    }
    get d8() {
        return this.d4;
    }
    set d8(a) {
        let b = this.d4;
        this.d4 = a;
        if (this.d4 != b) {
            this.cm("PaddingBottom", 6, b, this.d4);
        }
    }
    ak(a) {
        if (super.ak(a)) {
            return true;
        }
        if (stringStartsWith(a, "Actual")) {
            return false;
        }
        switch (a) {
            case "PaddingBottom":
                this.cm("PaddingBottom", 0, this.d8, this.d8);
                return true;
            case "PaddingLeft":
                this.cm("PaddingLeft", 0, this.d9, this.d9);
                return true;
            case "PaddingRight":
                this.cm("PaddingRight", 0, this.ea, this.ea);
                return true;
            case "PaddingTop":
                this.cm("PaddingTop", 0, this.eb, this.eb);
                return true;
            case "SortIndicatorColor":
                this.cm("ActualSortIndicatorColor", 2, this.ep, this.ep);
                return true;
        }
        return false;
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
        a.ed = this.d9;
        a.eh = this.eb;
        a.ef = this.ea;
        a.eb = this.d8;
        a.id = this.ep;
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        let e = b.as(a.i);
        if (e != null) {
            if (a.i.e && e.ew()) {
                let f = e.el;
                let g = f.o;
                let h = g.count;
                let i = f.p;
                let j = f.q;
                for (let k = 0; k < h; k++) {
                    if (i._inner[k]) {
                        continue;
                    }
                    a.hr(g._inner[k], j._inner[k]);
                }
            }
        }
    }
}
Header.$t = markType(Header, 'Header', DefinitionBase.$);
/**
 * @hidden
 */
class ColumnResizingSeparator extends DefinitionBase {
    constructor() {
        super(...arguments);
        this.d0 = truncate(DeviceUtils.g(5));
    }
    b8(a, b, c) {
        return "columnResizingSeparator";
    }
    l(a) {
        return new VerticalSeparatorCellModel();
    }
    dq() {
        return GridStyleRepository.al;
    }
    get d1() {
        return this.d0;
    }
    set d1(a) {
        let b = this.d0;
        this.d0 = a;
        if (this.d0 != b) {
            this.cm("SeparatorWidth", 6, b, this.d0);
        }
    }
    cl(a, b) {
        if (a != null) {
            a.propertyChanged = delegateRemove(a.propertyChanged, runOn(this, this.d3));
        }
        if (b != null) {
            b.propertyChanged = delegateCombine(b.propertyChanged, runOn(this, this.d3));
        }
        this.cs();
    }
    cs() {
        if (this.dm == null) {
            if (this.grid != null && this.grid.pz != null) {
                this.dg = this.grid.pz;
                return;
            }
            this.dg = this.dq();
        }
        else {
            this.dg = this.dm;
        }
    }
    d3(a, b) {
        switch (b.propertyName) {
            case "ColumnResizingSeparatorBackground":
                this.cs();
                break;
        }
    }
}
ColumnResizingSeparator.$t = markType(ColumnResizingSeparator, 'ColumnResizingSeparator', DefinitionBase.$);
/**
 * @hidden
 */
class HeaderSeparator extends DefinitionBase {
    b8(a, b, c) {
        return "headerSeparator";
    }
    l(a) {
        return new VerticalSeparatorCellModel();
    }
    dq() {
        return GridStyleRepository.al;
    }
    d0() {
        return truncate(DeviceUtils.g(1));
    }
    cl(a, b) {
        if (a != null) {
            a.propertyChanged = delegateRemove(a.propertyChanged, runOn(this, this.d1));
        }
        if (b != null) {
            b.propertyChanged = delegateCombine(b.propertyChanged, runOn(this, this.d1));
        }
        this.cs();
        this.d2();
    }
    d1(a, b) {
        switch (b.propertyName) {
            case "HeaderSeparatorBackground":
                this.cs();
                break;
        }
    }
    cs() {
        if (this.dm == null) {
            if (this.grid != null && this.grid.p1 != null) {
                this.dg = this.grid.p1;
                return;
            }
            this.dg = this.dq();
        }
        else {
            this.dg = this.dm;
        }
    }
    d2() {
        if (this.grid != null) {
            this.dh = ((() => {
                let $ret = new Brush();
                $ret.color = Color.u(0, 0, 0, 0);
                return $ret;
            })());
            let a = this.grid.h0(this.grid.ip);
            this.ba = a;
            this.bb = a;
        }
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
        a.c.isLeaveActionDesired = true;
    }
}
HeaderSeparator.$t = markType(HeaderSeparator, 'HeaderSeparator', DefinitionBase.$);
/**
 * @hidden
 */
class ImageColumn extends Column {
    constructor() {
        super();
        this.gv = 0;
        this.gt = 0;
        this.gw = 0;
        this.h = this.i();
        this.c = this.d();
    }
    get gw() {
        return this.gv;
    }
    set gw(a) {
        let b = this.gv;
        this.gv = a;
        if (this.gv != b) {
            this.cm("ImageStretchOption", 4, enumGetBox(ImageStretchOptions_$type, b), enumGetBox(ImageStretchOptions_$type, this.gv));
        }
    }
    get gu() {
        return this.gt;
    }
    set gu(a) {
        let b = this.gt;
        this.gt = a;
        if (this.gt != b) {
            this.cm("ImageResourceType", 11, enumGetBox(ImageResourceType_$type, b), enumGetBox(ImageResourceType_$type, this.gt));
        }
    }
    i() {
        if (this.j != 4) {
            return this.j;
        }
        return 3;
    }
    d2() {
        if (this.c == 3) {
            return 1;
        }
        return super.d2();
    }
    d3() {
        if (this.h == 3) {
            return 1;
        }
        return super.d3();
    }
    d() {
        if (this.e != 4) {
            return this.e;
        }
        return 3;
    }
    l(a) {
        return new ImageCellModel();
    }
    b8(a, b, c) {
        return "image";
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        let e = a;
        if (c != null) {
            e.gq = c.toString();
            e.ik = this.gw;
            e.ii = this.gu;
            e.iq = this.gx(c);
        }
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
    }
    gx(a) {
        if (a == null) {
            return "";
        }
        if (typeof a === 'string') {
            return a;
        }
        return a.toString();
    }
}
ImageColumn.$t = markType(ImageColumn, 'ImageColumn', Column.$);
/**
 * @hidden
 */
class NumericColumn extends Column {
    constructor() {
        super();
        this.g5 = null;
        this.g7 = null;
        this.g6 = null;
        this.g8 = "";
        this.gw = 10;
        this.gx = 0;
        this.gy = -1;
        this.gt = false;
        this.g4 = null;
        this.g2 = null;
        this.c = this.d();
    }
    d() {
        if (this.e != 4) {
            return this.e;
        }
        return 2;
    }
    get hf() {
        return this.g5;
    }
    set hf(a) {
        let b = this.g5;
        this.g5 = a;
        if (this.g5 != b) {
            this.cm("NegativePrefix", 8, b, this.g5);
        }
    }
    get hj() {
        return this.g7;
    }
    set hj(a) {
        let b = this.g7;
        this.g7 = a;
        if (this.g7 != b) {
            this.cm("PositivePrefix", 8, b, this.g7);
        }
    }
    get hh() {
        return this.g6;
    }
    set hh(a) {
        let b = this.g6;
        this.g6 = a;
        if (this.g6 != b) {
            this.cm("NegativeSuffix", 8, b, this.g6);
        }
    }
    get hl() {
        return this.g8;
    }
    set hl(a) {
        let b = this.g8;
        this.g8 = a;
        if (this.g8 != b) {
            this.cm("PositiveSuffix", 8, b, this.g8);
        }
    }
    get gz() {
        return this.gw;
    }
    set gz(a) {
        let b = this.gw;
        this.gw = a;
        if (this.gw != b) {
            this.cm("MaxFractionDigits", 6, b, this.gw);
        }
    }
    get g0() {
        return this.gx;
    }
    set g0(a) {
        let b = this.gx;
        this.gx = a;
        if (this.gx != b) {
            this.cm("MinFractionDigits", 6, b, this.gx);
        }
    }
    get g1() {
        return this.gy;
    }
    set g1(a) {
        let b = this.gy;
        this.gy = a;
        if (this.gy != b) {
            this.cm("MinIntegerDigits", 6, b, this.gy);
        }
    }
    get gu() {
        return this.gt;
    }
    set gu(a) {
        let b = this.gt;
        this.gt = a;
        if (this.gt != b) {
            this.cm("ShowGroupingSeparator", 5, b, this.gt);
        }
    }
    get ha() {
        return this.g4;
    }
    set ha(a) {
        let b = this.g4;
        this.g4 = a;
        if (this.g4 != b) {
            this.cm("FormatString", 8, b, this.g4);
        }
    }
    get g3() {
        return this.g2;
    }
    set g3(a) {
        let b = this.g2;
        this.g2 = a;
        if (this.g2 != b) {
            this.cm("FormatOverride", 9, b, this.g2);
        }
    }
    l(a) {
        return new NumericCellModel();
    }
    b8(a, b, c) {
        return "numeric";
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        let e = a;
        {
            e.ij = false;
            e.io = this.gv(c);
        }
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
        let e = a;
        e.iw = this.g0;
        e.iu = this.gz;
        e.iy = this.g1;
        e.jn = this.hj;
        e.ji = this.hf;
        e.jp = this.hl;
        e.jk = this.hh;
        e.i8 = this.g3;
        e.il = this.gu;
    }
    gv(a) {
        if (a == null) {
            return NaN;
        }
        if (typeof a === 'number') {
            return typeGetValue(a);
        }
        if (typeof a === 'number') {
            return a;
        }
        if (typeof a === 'number') {
            return a;
        }
        if (typeof a === 'number') {
            return typeGetValue(a);
        }
        if (typeof a === 'string') {
            let b;
            if (((() => { let c = tryParseNumber(a, b); b = c.p1; return c.ret; })())) {
                return b;
            }
        }
        if (typeof a === 'number') {
            return typeGetValue(a);
        }
        if (typeof a === 'number') {
            return typeGetValue(a);
        }
        if (typeof a === 'number') {
            return typeGetValue(a);
        }
        if (typeof a === 'number') {
            return typeGetValue(a);
        }
        if (typeof a === 'number') {
            return typeGetValue(a);
        }
        return NaN;
    }
}
NumericColumn.$t = markType(NumericColumn, 'NumericColumn', Column.$);
/**
 * @hidden
 */
class SectionFooter extends DefinitionBase {
    l(a) {
        return new TextCellModel();
    }
    b8(a, b, c) {
        return "sectionFooter";
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
    }
    ci(a, b, c, d) {
        this.dg = GridStyleRepository.ac;
        super.ci(a, b, c, d);
    }
}
SectionFooter.$t = markType(SectionFooter, 'SectionFooter', DefinitionBase.$);
/**
 * @hidden
 */
class SectionHeader extends DefinitionBase {
    constructor() {
        super();
        this.eq = null;
        this.ep = null;
        this.d7 = truncate(DeviceUtils.g(10));
        this.d9 = truncate(DeviceUtils.g(5));
        this.d8 = truncate(DeviceUtils.g(10));
        this.d6 = truncate(DeviceUtils.g(5));
        this.d4 = false;
        this.d1 = 4;
        this.sectionHeaderPropertyUpdating = null;
        this.er = this.dt();
    }
    get es() {
        return this.eq;
    }
    set es(a) {
        let b = this.eq;
        this.eq = a;
        if (this.eq != b) {
            this.cm("SelectedBackground", 10, b, this.eq);
        }
    }
    get er() {
        return this.ep;
    }
    set er(a) {
        let b = this.ep;
        this.ep = a;
        if (this.ep != b) {
            this.cm("ActualSelectedBackground", 2, b, this.ep);
        }
    }
    get eb() {
        return this.d7;
    }
    set eb(a) {
        let b = this.d7;
        this.d7 = a;
        if (this.d7 != b) {
            this.cm("PaddingLeft", 6, b, this.d7);
        }
    }
    get ed() {
        return this.d9;
    }
    set ed(a) {
        let b = this.d9;
        this.d9 = a;
        if (this.d9 != b) {
            this.cm("PaddingTop", 6, b, this.d9);
        }
    }
    get ec() {
        return this.d8;
    }
    set ec(a) {
        let b = this.d8;
        this.d8 = a;
        if (this.d8 != b) {
            this.cm("PaddingRight", 6, b, this.d8);
        }
    }
    get ea() {
        return this.d6;
    }
    set ea(a) {
        let b = this.d6;
        this.d6 = a;
        if (this.d6 != b) {
            this.cm("PaddingBottom", 6, b, this.d6);
        }
    }
    get d5() {
        return this.d4;
    }
    set d5(a) {
        let b = this.d4;
        this.d4 = a;
        if (this.d4 != b) {
            this.cm("IsCollapsable", 5, b, this.d4);
        }
    }
    get d2() {
        return this.d1;
    }
    set d2(a) {
        let b = this.d1;
        this.d1 = a;
        if (this.d1 != b) {
            this.cm("SummaryDisplayMode", 4, enumGetBox(GroupSummaryDisplayMode_$type, b), enumGetBox(GroupSummaryDisplayMode_$type, this.d1));
        }
    }
    b8(a, b, c) {
        return "sectionHeader";
    }
    l(a) {
        return new SectionHeaderCellModel();
    }
    dq() {
        return GridStyleRepository.ad;
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        let e = typeCast(Dictionary$2.$.specialize(String_$type, Base.$), c);
        if (e == null) {
            return;
        }
        let f = b.actualDataSource.actualSchema;
        let g = 0;
        let h = stringEmpty();
        let i = stringEmpty();
        let j = new Array(e.count);
        for (let k of fromEnum(e)) {
            let l = null;
            for (let m = 0; m < b.az.i.count; m++) {
                if (b.az.i.item(m).f == k.key) {
                    l = b.az.i.item(m);
                    break;
                }
            }
            if (!l.i) {
                b.og(l);
            }
            if (g > 0) {
                h += ", ";
            }
            j[g] = this.d0(k.key, k.value, l, l.g);
            h += j[g].b;
            g++;
        }
        let n = new Array(0);
        if (this.d2 == 0 && b.bt.i.count > 0) {
            let o = typeCast(DataSourceSpecialRow.$, d);
            if (o != null && o.summaryResults != null) {
                n = new Array(o.summaryResults.length);
                for (let p = 0; p < o.summaryResults.length; p++) {
                    if (o.summaryResults[p] != null) {
                        let q = o.summaryResults[p].summaryIndex;
                        let r = b.bt.i.item(q);
                        if (p > 0) {
                            i += ", ";
                        }
                        n[p] = this.u(r, o.summaryResults[p]);
                        i += n[p].c;
                    }
                }
            }
        }
        let s = typeCast(SectionHeaderCellModel.$, a);
        if (s != null) {
            s.ij = j;
            s.ik = n;
            s.iy = h;
            s.iw = i;
            s.im = this.d2;
            if (b.dx.o(s)) {
                s.bn = 1;
            }
            else {
                s.bn = 0;
            }
            if (b.af.m(s)) {
                s.bg = 1;
            }
            else {
                s.bg = 0;
            }
            s.ag = this.d5;
            s.am = b.actualDataSource.getIsRowExpandedAtIndex(a.i.s);
            s.dw = b.da.getRowIndent(a.i.s);
        }
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
        a.ic = this.er;
        a.ed = this.eb;
        a.eh = this.ed;
        a.ef = this.ec;
        a.eb = this.ea;
    }
    cl(a, b) {
        if (a != null) {
            a.propertyChanged = delegateRemove(a.propertyChanged, runOn(this, this.em));
        }
        if (b != null) {
            b.propertyChanged = delegateCombine(b.propertyChanged, runOn(this, this.em));
        }
        this.eo();
        this.cs();
        this.cy();
        this.cz();
        this.en();
    }
    em(a, b) {
        switch (b.propertyName) {
            case "SectionHeaderSelectedBackground":
                this.eo();
                break;
            case "SectionHeaderBackground":
                this.cs();
                break;
            case "SectionHeaderTextColor":
                this.cy();
                break;
            case "SectionHeaderTextStyle":
                this.cz();
                break;
            case "IsGroupCollapsable":
                this.en();
                break;
        }
    }
    eo() {
        if (this.es == null) {
            if (this.grid != null && this.grid.qb != null) {
                this.er = this.grid.qb;
            }
            else {
                this.er = this.dt();
            }
        }
        else {
            this.er = this.es;
        }
    }
    cs() {
        if (this.dm == null) {
            if (this.grid != null && this.grid.qa != null) {
                this.dg = this.grid.qa;
                return;
            }
            this.dg = this.dq();
        }
        else {
            this.dg = this.dm;
        }
    }
    cy() {
        if (this.dz == null) {
            if (this.grid != null && this.grid.qc != null) {
                this.dl = this.grid.qc;
                return;
            }
            this.dl = this.dv();
        }
        else {
            this.dl = this.dz;
        }
    }
    cz() {
        if (this.textStyle == null) {
            if (this.grid != null && this.grid.ej != null) {
                this.ad = this.grid.ej;
                return;
            }
            this.ad = this.af();
        }
        else {
            this.ad = this.textStyle;
        }
    }
    en() {
        if (this.grid != null) {
            this.d5 = this.grid.ft;
        }
    }
    cn(a, b, c, d) {
        super.cn(a, b, c, d);
        switch (a) {
            case "SelectedBackground":
                this.eo();
                break;
        }
        if (this.sectionHeaderPropertyUpdating != null) {
            this.sectionHeaderPropertyUpdating(this, a, b, c, d);
        }
    }
    d0(a, b, c, d) {
        let e = b != null ? b.toString() : stringEmpty();
        let f = a + ": " + e;
        let g = stringEmpty();
        if (c != null) {
            if (c.m == null) {
                g = a + ": ";
            }
            else if (c.m != stringEmpty()) {
                g = c.m + ": ";
            }
            if (b != null) {
                switch (d) {
                    case 10:
                        if (c.k != null) {
                            let override_ = c.k;
                            let val_ = typeGetValue(b);
                            e = (override_.format(val_));
                        }
                        else {
                            e = (typeGetValue(b)).toString();
                        }
                        break;
                    case 8:
                        if (c.k != null) {
                            let override_ = c.k;
                            let val_ = b;
                            e = (override_.format(val_));
                        }
                        else {
                            e = b.toString();
                        }
                        break;
                    case 5:
                        if (c.k != null) {
                            let override_ = c.k;
                            let val_ = b;
                            e = (override_.format(val_));
                        }
                        else {
                            e = b.toString();
                        }
                        break;
                    case 1:
                        if (c.k != null) {
                            let override_ = c.k;
                            let val_ = typeGetValue(b);
                            e = (override_.format(val_));
                        }
                        else {
                            e = (typeGetValue(b)).toString();
                        }
                        break;
                    case 3:
                        if (c.k != null) {
                            let override_ = c.k;
                            let val_ = typeGetValue(b);
                            e = (override_.format(val_));
                        }
                        else {
                            e = typeGetValue(b).toString();
                        }
                        break;
                    case 4:
                        if (c.k != null) {
                            let override_ = c.k;
                            let val_ = typeGetValue(b);
                            e = (override_.format(val_));
                        }
                        else {
                            e = typeGetValue(b).toString();
                        }
                        break;
                    case 7:
                        if (c.k != null) {
                            let override_ = c.k;
                            let val_ = b;
                            e = (override_.format(val_));
                        }
                        else {
                            e = b.toString();
                        }
                        break;
                    case 0:
                    case 6:
                    case 2:
                    case 11:
                        e = b.toString();
                        break;
                }
            }
            f = g + e;
            f = c.n(b, e, f);
        }
        return ((() => {
            let $ret = new GroupData();
            $ret.c = a;
            $ret.a = b;
            $ret.b = f;
            return $ret;
        })());
    }
}
SectionHeader.$t = markType(SectionHeader, 'SectionHeader', DefinitionBase.$);
/**
 * @hidden
 */
class RowSeparator extends DefinitionBase {
    b8(a, b, c) {
        if (a.e) {
            return "headerRowSeparator";
        }
        return "rowSeparator";
    }
    cl(a, b) {
        if (a != null) {
            a.propertyChanged = delegateRemove(a.propertyChanged, runOn(this, this.d0));
        }
        if (b != null) {
            b.propertyChanged = delegateCombine(b.propertyChanged, runOn(this, this.d0));
        }
        this.cs();
    }
    cs() {
        if (this.dm == null) {
            if (this.grid != null && this.grid.p6 != null) {
                this.dg = this.grid.p6;
                return;
            }
            this.dg = this.dq();
        }
        else {
            this.dg = this.dm;
        }
    }
    cv() {
        if (this.dx == null) {
            if (this.grid != null && this.grid.p8 != null) {
                this.dj = this.grid.p8;
                return;
            }
            this.dj = this.ds();
        }
        else {
            this.dj = this.dx;
        }
    }
    cx() {
        if (this.dy == null) {
            if (this.grid != null && this.grid.p9 != null) {
                this.dk = this.grid.p9;
                return;
            }
            this.dk = this.du();
        }
        else {
            this.dk = this.dy;
        }
    }
    cu() {
        if (this.dw == null) {
            if (this.grid != null && this.grid.p7 != null) {
                this.di = this.grid.p7;
                return;
            }
            this.di = this.dr();
        }
        else {
            this.di = this.dw;
        }
    }
    d0(a, b) {
        switch (b.propertyName) {
            case "RowSeparatorBackground":
                this.cs();
                break;
            case "RowSeparatorLastStickyRowBackground":
                this.cu();
                break;
            case "RowSeparatorPinnedRowBackground":
                this.cv();
                break;
            case "RowSeparatorStickyRowBackground":
                this.cx();
                break;
        }
    }
    l(a) {
        return new RowSeparatorModel();
    }
    dq() {
        return GridStyleRepository.al;
    }
    du() {
        return GridStyleRepository.ah;
    }
    dr() {
        return GridStyleRepository.z;
    }
    ds() {
        return this.dq();
    }
    av() {
        return 1;
    }
}
RowSeparator.$t = markType(RowSeparator, 'RowSeparator', DefinitionBase.$);
/**
 * @hidden
 */
class SummaryRow extends DefinitionBase {
    constructor() {
        super();
        this.el = null;
        this.ej = null;
        this.em = null;
        this.ek = null;
        this.d1 = truncate(DeviceUtils.g(10));
        this.d3 = truncate(DeviceUtils.g(5));
        this.d2 = truncate(DeviceUtils.g(10));
        this.d0 = truncate(DeviceUtils.g(5));
        this.en = this.dt();
    }
    get eq() {
        return this.el;
    }
    set eq(a) {
        let b = this.el;
        this.el = a;
        if (this.el != b) {
            this.cm("SelectedBackground", 10, b, this.el);
        }
    }
    get en() {
        return this.ej;
    }
    set en(a) {
        let b = this.ej;
        this.ej = a;
        if (this.ej != b) {
            this.cm("ActualSelectedBackground", 2, b, this.ej);
        }
    }
    get er() {
        return this.em;
    }
    set er(a) {
        let b = this.em;
        this.em = a;
        if (this.em != b) {
            this.cm("SummaryNameTextColor", 2, b, this.em);
        }
    }
    get eo() {
        return this.ek;
    }
    set eo(a) {
        let b = this.ek;
        this.ek = a;
        if (this.ek != b) {
            this.cm("ActualSummaryNameTextColor", 2, b, this.ek);
        }
    }
    get d5() {
        return this.d1;
    }
    set d5(a) {
        let b = this.d1;
        this.d1 = a;
        if (this.d1 != b) {
            this.cm("PaddingLeft", 6, b, this.d1);
        }
    }
    get d7() {
        return this.d3;
    }
    set d7(a) {
        let b = this.d3;
        this.d3 = a;
        if (this.d3 != b) {
            this.cm("PaddingTop", 6, b, this.d3);
        }
    }
    get d6() {
        return this.d2;
    }
    set d6(a) {
        let b = this.d2;
        this.d2 = a;
        if (this.d2 != b) {
            this.cm("PaddingRight", 6, b, this.d2);
        }
    }
    get d4() {
        return this.d0;
    }
    set d4(a) {
        let b = this.d0;
        this.d0 = a;
        if (this.d0 != b) {
            this.cm("PaddingBottom", 6, b, this.d0);
        }
    }
    b8(a, b, c) {
        return "summary";
    }
    l(a) {
        return new SummaryCellModel();
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        let e = typeCast(DataSourceSpecialRow.$, d);
        let f = stringEmpty();
        let g = stringEmpty();
        let h = b.as(a.i);
        if (h != null) {
            let i = e.getSummaryResults(h.gb);
            if (i.length > 0 && b.bt.i.count > 0) {
                let j = b.bt.i.item(i[0].summaryIndex);
                if (j.c != null) {
                    let k = this.u(j, i[0]);
                    f = j.r != null ? j.r : j.c.displayName;
                    g = k.d;
                }
            }
        }
        let l = typeCast(SummaryCellModel.$, a);
        if (l != null) {
            l.im = f;
            l.ip = g;
            l.dw = b.da.getRowIndent(a.i.s);
            if (b.dx.o(l)) {
                l.bn = 1;
            }
            else {
                l.bn = 0;
            }
            if (b.af.m(l)) {
                l.bg = 1;
            }
            else {
                l.bg = 0;
            }
        }
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
        let e = typeCast(SummaryCellModel.$, a);
        e.ic = this.en;
        e.h7 = this.dg;
        e.it = this.eo;
        e.ed = this.d5;
        e.eh = this.d7;
        e.ef = this.d6;
        e.eb = this.d4;
    }
    cl(a, b) {
        if (a != null) {
            a.propertyChanged = delegateRemove(a.propertyChanged, runOn(this, this.eg));
        }
        if (b != null) {
            b.propertyChanged = delegateCombine(b.propertyChanged, runOn(this, this.eg));
        }
        this.eh();
        this.ei();
        this.cs();
        this.cy();
        this.cz();
    }
    ep() {
        return GridStyleRepository.ai;
    }
    eg(a, b) {
        switch (b.propertyName) {
            case "SummaryRootSelectedBackground":
            case "SummarySectionSelectedBackground":
                this.eh();
                break;
            case "SummaryRootBackground":
            case "SummarySectionBackground":
                this.cs();
                break;
            case "SummaryRootTextColor":
            case "SummarySectionTextColor":
                this.cy();
                break;
            case "SummaryRootNameTextColor":
            case "SummarySectionNameTextColor":
                this.ei();
                break;
            case "SummaryTextStyle":
                this.cz();
                break;
        }
    }
    eh() {
        if (this.eq == null) {
            this.en = this.dt();
        }
        else {
            this.en = this.eq;
        }
    }
    ei() {
        if (this.er == null) {
            this.eo = this.ep();
        }
        else {
            this.eo = this.er;
        }
    }
    cz() {
        if (this.textStyle == null) {
            if (this.grid != null && this.grid.el != null) {
                this.ad = this.grid.el;
            }
            else {
                this.ad = this.af();
            }
        }
        else {
            this.ad = this.textStyle;
        }
    }
    cn(a, b, c, d) {
        super.cn(a, b, c, d);
        switch (a) {
            case "SelectedBackground":
                this.eh();
                break;
            case "SummaryNameTextColor":
                this.ei();
                break;
        }
    }
}
SummaryRow.$t = markType(SummaryRow, 'SummaryRow', DefinitionBase.$);
/**
 * @hidden
 */
class SummaryRowRoot extends SummaryRow {
    b8(a, b, c) {
        return "summaryRowRoot";
    }
    dq() {
        return GridStyleRepository.ab;
    }
    cs() {
        if (this.dm == null) {
            if (this.grid != null && this.grid.qe != null) {
                this.dg = this.grid.qe;
                return;
            }
            this.dg = this.dq();
        }
        else {
            this.dg = this.dm;
        }
    }
    eh() {
        if (this.eq == null) {
            if (this.grid != null && this.grid.qg != null) {
                this.en = this.grid.qg;
            }
            else {
                this.en = this.dt();
            }
        }
        else {
            this.en = this.eq;
        }
    }
    ei() {
        if (this.er == null) {
            if (this.grid != null && this.grid.qf != null) {
                this.eo = this.grid.qf;
            }
            else {
                this.eo = this.ep();
            }
        }
        else {
            this.eo = this.er;
        }
    }
    cy() {
        if (this.dz == null) {
            if (this.grid != null && this.grid.qh != null) {
                this.dl = this.grid.qh;
            }
            else {
                this.dl = this.dv();
            }
        }
        else {
            this.dl = this.dz;
        }
    }
}
SummaryRowRoot.$t = markType(SummaryRowRoot, 'SummaryRowRoot', SummaryRow.$);
/**
 * @hidden
 */
class SummaryRowSection extends SummaryRow {
    b8(a, b, c) {
        return "summaryRowSection";
    }
    dq() {
        return GridStyleRepository.ae;
    }
    cs() {
        if (this.dm == null) {
            if (this.grid != null && this.grid.qi != null) {
                this.dg = this.grid.qi;
                return;
            }
            this.dg = this.dq();
        }
        else {
            this.dg = this.dm;
        }
    }
    eh() {
        if (this.eq == null) {
            if (this.grid != null && this.grid.qk != null) {
                this.en = this.grid.qk;
            }
            else {
                this.en = this.dt();
            }
        }
        else {
            this.en = this.eq;
        }
    }
    ei() {
        if (this.er == null) {
            if (this.grid != null && this.grid.qj != null) {
                this.eo = this.grid.qj;
            }
            else {
                this.eo = this.ep();
            }
        }
        else {
            this.eo = this.er;
        }
    }
    cy() {
        if (this.dz == null) {
            if (this.grid != null && this.grid.ql != null) {
                this.dl = this.grid.ql;
            }
            else {
                this.dl = this.dv();
            }
        }
        else {
            this.dl = this.dz;
        }
    }
}
SummaryRowSection.$t = markType(SummaryRowSection, 'SummaryRowSection', SummaryRow.$);
/**
 * @hidden
 */
class TemplateColumn extends Column {
    constructor() {
        super(...arguments);
        this.cellUpdating = null;
    }
    l(a) {
        return new TemplateCellModel();
    }
    b8(a, b, c) {
        let d = "template-" + this.fj;
        return d;
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        let e = a;
        e.ij = c;
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
    }
    gu(a, b) {
        if (this.cellUpdating != null) {
            this.cellUpdating(this, ((() => {
                let $ret = new TemplateCellUpdatingEventArgs();
                $ret.cellInfo = a;
                $ret.content = b;
                return $ret;
            })()));
        }
    }
}
TemplateColumn.$t = markType(TemplateColumn, 'TemplateColumn', Column.$);
/**
 * @hidden
 */
class TemplateCellUpdatingEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._cellInfo = null;
        this._content = null;
    }
    get cellInfo() {
        return this._cellInfo;
    }
    set cellInfo(a) {
        this._cellInfo = a;
    }
    get content() {
        return this._content;
    }
    set content(a) {
        this._content = a;
    }
}
TemplateCellUpdatingEventArgs.$t = markType(TemplateCellUpdatingEventArgs, 'TemplateCellUpdatingEventArgs', EventArgs.$);
/**
 * @hidden
 */
class TextColumn extends Column {
    constructor() {
        super(...arguments);
        this.gt = null;
    }
    get gv() {
        return this.gt;
    }
    set gv(a) {
        let b = this.gt;
        this.gt = a;
        if (this.gt != b) {
            this.cm("FormatString", 8, b, this.gt);
        }
    }
    l(a) {
        return new TextCellModel();
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        let e = a;
        if (c != null) {
            e.ij = this.gu(c);
        }
        else {
            e.ij = null;
        }
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
        let e = a;
    }
    gu(a) {
        if (typeof a === 'string') {
            return a;
        }
        return null;
    }
    b8(a, b, c) {
        return "text";
    }
}
TextColumn.$t = markType(TextColumn, 'TextColumn', Column.$);
/**
 * @hidden
 */
class TextHeader extends Header {
    constructor() {
        super();
        this.c = 0;
        this.h = 1;
    }
    l(a) {
        let b = new TextHeaderCellModel();
        return b;
    }
    b8(a, b, c) {
        return "textHeader";
    }
    ci(a, b, c, d) {
        super.ci(a, b, c, d);
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        let e = a;
        let f = b.as(a.i);
        e.ij = f.fp;
        e.gq = e.ij;
        e.k = f.eb;
        e.ip = f.ez && b.fs;
        e.im = this.d2;
    }
}
TextHeader.$t = markType(TextHeader, 'TextHeader', Header.$);
/**
 * @hidden
 */
class GridEffect extends Base {
    constructor() {
        super();
        this.s = 0;
        this.u = 0;
        this.br = "";
        this.af = false;
        this.ac = false;
        this.onFinished = null;
        this.onCanceled = null;
        this.a3 = 0;
        this.a1 = 0;
        this.h = null;
        this.a7 = -1;
        this.a8 = -1;
        this.a2 = 300;
        this.j = null;
        this.a4 = 0;
        this.c = null;
        this.a = null;
        this.a6 = -1;
        this.ad = false;
        this.ab = false;
        this.bk = -1;
        this.bm = null;
        this.bn = null;
        this.w = null;
        this.p = null;
        this.aa = false;
        this.n = null;
        this.ae = false;
        this.ay = null;
        this.az = 1;
        this.a5 = -1;
        this.b = null;
        this.ax = new Dictionary$2(CellPath.$, Number_$type, 0);
    }
    bu() {
        if (this.onFinished != null) {
            this.onFinished(this);
        }
    }
    bt(a) {
        if (this.onCanceled != null) {
            this.onCanceled(this, a);
        }
    }
    get t() {
        return this.s;
    }
    set t(a) {
        this.s = a;
    }
    am(a) {
        if (a == null) {
            return false;
        }
        if (a.s != this.s) {
            return false;
        }
        if (!this.af) {
            return true;
        }
        if (a.u != this.u) {
            return false;
        }
        if (a.br != this.br) {
            return false;
        }
        return true;
    }
    get v() {
        return this.u;
    }
    set v(a) {
        this.u = a;
    }
    get bs() {
        return this.br;
    }
    set bs(a) {
        this.br = a;
    }
    get as() {
        return this.af;
    }
    set as(a) {
        this.af = a;
    }
    get ap() {
        return this.ac;
    }
    set ap(a) {
        this.ac = a;
    }
    get ba() {
        return this.a3;
    }
    set ba(a) {
        this.a3 = a;
        this.a1 = a;
    }
    get i() {
        return this.h;
    }
    set i(a) {
        this.h = a;
    }
    get bi() {
        return this.a7;
    }
    set bi(a) {
        this.a7 = a;
    }
    get bj() {
        return this.a8;
    }
    set bj(a) {
        this.a8 = a;
    }
    get a9() {
        return this.a2;
    }
    set a9(a) {
        this.a2 = a;
    }
    get k() {
        return this.j;
    }
    set k(a) {
        this.j = a;
    }
    get bg() {
        return this.a4;
    }
    set bg(a) {
        this.a4 = a;
    }
    get g() {
        return this.c;
    }
    set g(a) {
        this.c = a;
    }
    get e() {
        return this.a;
    }
    set e(a) {
        this.a = a;
    }
    get bh() {
        return this.a6;
    }
    set bh(a) {
        this.a6 = a;
    }
    get aq() {
        return this.ad;
    }
    set aq(a) {
        this.ad = a;
    }
    get ao() {
        return this.ab;
    }
    set ao(a) {
        this.ab = a;
    }
    get bl() {
        return this.bk;
    }
    set bl(a) {
        this.bk = a;
    }
    get bo() {
        return this.bm;
    }
    set bo(a) {
        this.bm = a;
    }
    get bq() {
        return this.bn;
    }
    set bq(a) {
        this.bn = a;
    }
    get x() {
        return this.w;
    }
    set x(a) {
        this.w = a;
    }
    get q() {
        return this.p;
    }
    set q(a) {
        this.p = a;
    }
    get al() {
        return this.aa;
    }
    set al(a) {
        this.aa = a;
    }
    get o() {
        return this.n;
    }
    set o(a) {
        this.n = a;
    }
    get ar() {
        return this.ae;
    }
    set ar(a) {
        this.ae = a;
    }
    bx(a) {
        this.ba = a.l;
        this.bg = a.m;
        this.bi = a.n;
        this.bj = a.o;
        this.aq = a.e;
        this.q = this.r(a.c);
    }
    r(a) {
        switch (a) {
            case 0: return null;
            case 1: return EasingFunctions.cubicEase;
            case 3: return EasingFunctions.circleEase;
            case 2: return EasingFunctions.exponentialEase;
        }
        return null;
    }
    au(a, b, c, d) {
        if (this.ar && this.an(d)) {
            return false;
        }
        let e = this.a0(d);
        let f = 1;
        if (this.a3 > 0) {
            f = e / this.a3;
        }
        let g = false;
        if (this.w == null) {
            return true;
        }
        if (f >= 1) {
            f = 1;
            g = true;
        }
        if (this.p != null) {
            f = this.p(f);
        }
        let h = this.bp(this.bm, b, a, a.m);
        this.w(f, h, this.bn, a, b);
        return g;
    }
    av(a, b, c, d) {
        if (this.ar && this.an(d)) {
            return false;
        }
        let e = this.a0(d);
        let f = 1;
        if (this.a3 > 0) {
            f = e / this.a3;
        }
        let g = false;
        if (this.w == null) {
            return true;
        }
        if (f >= 1) {
            f = 1;
            g = true;
        }
        if (this.p != null) {
            f = this.p(f);
        }
        let h = this.bp(this.bm, b, a, a);
        this.w(f, h, this.bn, a, b);
        return g;
    }
    a0(a) {
        let b = (a - this.bk);
        if (this.a4 > 0) {
            if (b < this.a4) {
                b = 0;
            }
            else {
                b -= this.a4;
            }
        }
        return b;
    }
    an(a) {
        let b = (a - this.bk);
        if (this.a4 > 0) {
            if (b < this.a4) {
                return true;
            }
        }
        return false;
    }
    bz(a, b, c, d) {
        let e = this.bb(b, a);
        if (this.f == null) {
            return;
        }
        let f = this.bb(b, this.f);
        let g = f / this.a6;
        if (g > 5) {
            g = 5;
        }
        if (g == this.az) {
            return;
        }
        let h = g / this.az;
        this.az = g;
        let i = truncate(Math.round(this.a1 * h));
        if (i <= 0) {
            let j = 0;
            j += 1;
        }
        {
            this.a1 = i;
        }
    }
    at(a, b, c, d) {
        let e = false;
        if (a.i.s == 15) {
            let f = 0;
            f += 1;
        }
        this.bz(a.i, b, c, d);
        if (this.ar && this.an(d)) {
            return false;
        }
        let g = this.a0(d);
        let h = this.bf(b, c, a.i, d);
        let i = this.bc(b, c, a.i, d);
        if (i < 300) {
            let j = 0;
            j += 1;
        }
        let k = g - h;
        if (k < 0) {
            k = 0;
        }
        let l = 1;
        if (i > 0) {
            l = k / i;
        }
        if (l >= 1) {
            l = 1;
            e = true;
        }
        if (this.p != null) {
            l = this.p(l);
        }
        let m = this.bp(this.bm, b, a, a.i);
        this.w(l, m, this.bn, a, b);
        return e;
    }
    by(a, b, c) {
        if (this.ay == null) {
            this.ay = new Dictionary$2(Base.$, Base.$, 0);
        }
        this.ay.item(c, a);
    }
    bp(a, b, c, d) {
        if (this.al) {
            if (this.ay == null) {
                this.ay = new Dictionary$2(Base.$, Base.$, 0);
            }
            if (this.ay.containsKey(d)) {
                return this.ay.item(d);
            }
            let e = this.o(c, b);
            this.ay.item(d, e);
            return e;
        }
        else {
            return this.bm;
        }
    }
    aw(a, b, c, d) {
        if (this.ar && this.an(d)) {
            return false;
        }
        let e = this.a0(d);
        let f = 1;
        if (this.a3 > 0) {
            f = e / this.a3;
        }
        let g = false;
        if (this.w == null) {
            return true;
        }
        if (f >= 1) {
            f = 1;
            g = true;
        }
        if (this.p != null) {
            f = this.p(f);
        }
        this.w(f, this.bm, this.bn, a, b);
        return g;
    }
    ag(a, b) {
        return false;
    }
    ah(a, b) {
        return false;
    }
    ai(a, b) {
        return false;
    }
    aj(a, b) {
        return false;
    }
    bv(a) {
    }
    bw(a) {
    }
    get f() {
        return this.b;
    }
    bf(a, b, c, d) {
        if (c == null) {
            return 0;
        }
        let e = this.bb(a, c);
        let f = this.bd(a, b, c, d);
        let g = this.a3;
        if (this.ad) {
            g = truncate(((f / this.a6) * g));
        }
        let h = this.a7;
        if (h == -1) {
            h = truncate((g / f));
            if ((g - truncate((f * h))) < this.a2) {
                h = truncate(((g - this.a2) / f));
            }
            if (h < 0) {
                h = 0;
            }
        }
        let i = h * e;
        if (this.h != null) {
            i = this.h(this.c, this.a6, c);
        }
        let j = this.a1;
        if (i < (j * -1)) {
            i = (j * -1);
        }
        if (i > (j)) {
            i = j - this.a2;
        }
        if (this.ad && this.a0(d) > i && c != null && !this.ax.containsKey(c)) {
            this.ax.addItem(c, f);
        }
        return i;
    }
    bd(a, b, c, d) {
        if (this.f == null || !this.ad) {
            return this.a6;
        }
        if (this.ax.containsKey(c)) {
            return this.ax.item(c);
        }
        let e = this.bb(a, this.f);
        return e;
    }
    bb(a, b) {
        if (b == null) {
            return 0;
        }
        let c = this.be(a, b);
        if (this.a6 == -1) {
            this.a6 = this.be(a, this.a) + 1;
        }
        if (this.ab) {
            c = ((this.a6 - 1) - c);
        }
        let d = c;
        if (d > this.a6 && d > this.a5) {
            this.a5 = d;
            this.b = b;
        }
        return d;
    }
    be(a, b) {
        return 0;
    }
    bc(a, b, c, d) {
        let e = this.a1;
        if (this.j != null) {
            if (this.a6 == -1) {
                this.a6 = this.be(a, this.a) + 1;
            }
            e = this.j(this.c, this.a6, c);
        }
        else {
            if (this.a8 == -1) {
                if (this.ad) {
                    let f = this.bd(a, b, c, d);
                    e = this.a3;
                    e = truncate(((f / this.a6) * e));
                    e = e - this.bf(a, b, c, d);
                }
                else {
                    if (this.ab) {
                        e = this.a3 - this.bf(a, b, this.d(a), d);
                    }
                    else {
                        e = this.a3 - this.bf(a, b, this.a, d);
                    }
                }
            }
            else {
                e = this.a8;
            }
        }
        return e;
    }
    d(a) {
        return this.c;
    }
    y(a, b) {
        if (b.t == a.t) {
            if (b.s <= a.s) {
                a = a.w();
                a.s += 1;
            }
        }
        return a;
    }
    z(a, b) {
        if (b.t == a.t) {
            if (b.s < a.s) {
                a = a.w();
                a.s -= 1;
            }
        }
        return a;
    }
    ak(a, b, c) {
        let d = this.a0(c);
        return d >= this.a1;
    }
}
GridEffect.$t = markType(GridEffect, 'GridEffect');
/**
 * @hidden
 */
class ColumnEffect extends GridEffect {
    constructor() {
        super(...arguments);
        this.b0 = 0;
    }
    ah(a, b) {
        if (this.b0 == a.m) {
            return true;
        }
        return false;
    }
}
ColumnEffect.$t = markType(ColumnEffect, 'ColumnEffect', GridEffect.$);
/**
 * @hidden
 */
class SpacerEffect extends GridEffect {
    constructor() {
        super(...arguments);
        this.b0 = 0;
    }
    aj(a, b) {
        return a.o == this.b0;
    }
}
SpacerEffect.$t = markType(SpacerEffect, 'SpacerEffect', GridEffect.$);
/**
 * @hidden
 */
class ColumnCellsEffect extends GridEffect {
    constructor() {
        super(...arguments);
        this.b2 = 0;
        this.b1 = 0;
        this.b0 = 0;
    }
    ag(a, b) {
        if (this.b2 == -300) {
            if (a.af) {
                return true;
            }
        }
        if (this.b2 == -400) {
            if (a.al == -400) {
                return true;
            }
        }
        if (this.b1 >= 0) {
            if (this.b1 == a.al && this.b0 == a.b) {
                return true;
            }
        }
        else {
            let c = b.f(this.b2);
            if (c == null) {
                return false;
            }
            if (a.al == c.l && c.c == a.b) {
                return true;
            }
        }
        return false;
    }
    d(a) {
        if (a.bs > 0) {
            let b = this.g;
            let c = new CellPath(0, b.b, b.al, -100, -100);
            return c;
        }
        else {
            return this.g;
        }
    }
    be(a, b) {
        let c = this.g;
        let d = this.e;
        let e = b;
        if (e == null) {
            return 0;
        }
        if (e.e) {
            return 0;
        }
        let f = 0;
        if (a.bs > 0) {
            f++;
        }
        if (c == null) {
            return 0;
        }
        if (e.ai && e.g) {
            if (d == null) {
                return 0;
            }
            return (d.s - c.s) + f - e.m;
        }
        if (e.t == c.t) {
            return (e.s - c.s) + f;
        }
        let g = f;
        let h = c.t;
        if (e.t > c.t) {
            while (h <= e.t) {
                if (h == c.t) {
                    g += (a.bf._inner[h].m - 1) - c.s;
                    if (a.bf._inner[h].d > 0) {
                        g++;
                    }
                }
                else if (h == e.t) {
                    if (a.bf._inner[h].g > 0) {
                        g++;
                    }
                    g += (e.s + 1);
                }
                else {
                    if (a.bf._inner[h].g > 0) {
                        g++;
                    }
                    g += a.bf._inner[h].m;
                    if (a.bf._inner[h].d > 0) {
                        g++;
                    }
                }
                h++;
            }
        }
        else if (e.t < c.t) {
            while (h >= e.t) {
                if (h == c.t) {
                    g -= c.s;
                    if (a.bf._inner[h].d > 0) {
                        g++;
                    }
                }
                else if (h == e.t) {
                    if (a.bf._inner[h].d > 0) {
                        g--;
                    }
                    g -= (a.bf._inner[h].m - e.s);
                }
                else {
                    if (a.bf._inner[h].g > 0) {
                        g--;
                    }
                    g -= a.bf._inner[h].m;
                    if (a.bf._inner[h].d > 0) {
                        g--;
                    }
                }
                h--;
            }
        }
        return g;
    }
}
ColumnCellsEffect.$t = markType(ColumnCellsEffect, 'ColumnCellsEffect', GridEffect.$);
/**
 * @hidden
 */
class CellEffect extends GridEffect {
    constructor() {
        super(...arguments);
        this.b4 = 0;
        this.b3 = 0;
        this.b1 = 0;
        this.b0 = null;
        this.b2 = false;
    }
    ag(a, b) {
        if (this.b0.s == a.s) {
            if (this.b4 == -400) {
                if (a.al == -400) {
                    return true;
                }
            }
            if (this.b3 >= 0) {
                if (this.b3 == a.al && this.b1 == a.b) {
                    return true;
                }
            }
            else {
                let c = b.f(this.b4);
                if (c == null) {
                    return false;
                }
                if (a.al == c.l && c.c == a.b) {
                    return true;
                }
            }
        }
        return false;
    }
    bv(a) {
        this.b0 = this.y(this.b0, a);
    }
    bw(a) {
        this.b0 = this.z(this.b0, a);
    }
}
CellEffect.$t = markType(CellEffect, 'CellEffect', GridEffect.$);
/**
 * @hidden
 */
class CellPositionEffect extends CellEffect {
    ag(a, b) {
        return this.b0.equals(a);
    }
    bv(a) {
        this.b0 = this.y(this.b0, a);
    }
    bw(a) {
        this.b0 = this.z(this.b0, a);
    }
}
CellPositionEffect.$t = markType(CellPositionEffect, 'CellPositionEffect', CellEffect.$);
/**
 * @hidden
 */
class RowEffect extends GridEffect {
    constructor() {
        super(...arguments);
        this.b0 = null;
    }
    ai(a, b) {
        if (this.b0.equals(a)) {
            return true;
        }
        return false;
    }
    bv(a) {
        this.b0 = this.y(this.b0, a);
    }
    bw(a) {
        this.b0 = this.z(this.b0, a);
    }
}
RowEffect.$t = markType(RowEffect, 'RowEffect', GridEffect.$);
/**
 * @hidden
 */
class RowCellsEffect extends GridEffect {
    constructor() {
        super(...arguments);
        this.b0 = null;
    }
    ag(a, b) {
        if (this.b0.t == a.t && this.b0.s == a.s && this.b0.b == a.b) {
            return true;
        }
        return false;
    }
    bv(a) {
        this.b0 = this.y(this.b0, a);
    }
    bw(a) {
        this.b0 = this.z(this.b0, a);
    }
    be(a, b) {
        if (this.g == null) {
            return 0;
        }
        return b.al - this.g.al;
    }
}
RowCellsEffect.$t = markType(RowCellsEffect, 'RowCellsEffect', GridEffect.$);
/**
 * @hidden
 */
class GridEffectManager extends Base {
    constructor(a, b) {
        super();
        this.b = null;
        this.k = new List$1(ColumnEffect.$, 0);
        this.j = new List$1(ColumnCellsEffect.$, 0);
        this.m = new List$1(RowEffect.$, 0);
        this.l = new List$1(RowCellsEffect.$, 0);
        this.i = new List$1(CellEffect.$, 0);
        this.n = new List$1(SpacerEffect.$, 0);
        this.q = -30;
        this.o = -1;
        this.a = null;
        this.b = a;
        this.a = b;
    }
    get c() {
        return this.b;
    }
    ae(a) {
        for (let b = 0; b < this.l.count; b++) {
            this.l._inner[b].bv(a);
        }
        for (let c = 0; c < this.m.count; c++) {
            this.m._inner[c].bv(a);
        }
        for (let d = 0; d < this.i.count; d++) {
            this.i._inner[d].bv(a);
        }
    }
    af(a) {
        for (let b = this.l.count - 1; b >= 0; b--) {
            if (a.equals(this.l._inner[b].b0)) {
                this.aj(this.l._inner[b].b0, false, this.l._inner[b]);
            }
            else {
                this.l._inner[b].bw(a);
            }
        }
        for (let c = this.m.count - 1; c >= 0; c--) {
            if (a.equals(this.m._inner[c].b0)) {
                this.ak(this.m._inner[c].b0, false, this.m._inner[c]);
            }
            else {
                this.m._inner[c].bw(a);
            }
        }
        for (let d = this.i.count - 1; d >= 0; d--) {
            if (a.equals(this.i._inner[d].b0)) {
                this.ag(this.i._inner[d].b0, false, this.i._inner[d]);
            }
            else {
                this.i._inner[d].bw(a);
            }
        }
    }
    ad() {
        let a = this.k.count > 0;
        this.a.gi = true;
        this.an(false);
        if (a) {
            this.a.d3.m(this.a, this.a.model, truncate(this.a.g8));
            this.d();
        }
        this.a.gi = false;
        this.a.renderingEngine.invalidateVisibility(() => this.a.d9.n(this.a));
        this.a.renderingEngine.refresh(this.a.model, true);
    }
    d() {
        let a = this.k.count > 0;
        let b = this.p();
        let c = this.a.model;
        let d = this.a.cn;
        this.f(b, c, d);
        return a;
    }
    ac() {
        let a = this.p();
        let b = this.a.model;
        let c = this.a.cn;
        this.g(a, b, c);
    }
    ab() {
        let a = this.p();
        let b = this.a.model;
        let c = this.a.cn;
        this.e(a, b, c);
    }
    an(a) {
        let b = this.p();
        if ((b - this.q < 15) && !a) {
            this.b.requestFrame(this.o);
            return;
        }
        let c = this.a.model;
        let d = this.a.cn;
        let e = true;
        if (!this.f(b, c, d)) {
            e = false;
        }
        if (!this.h(b, c, d)) {
            e = false;
        }
        if (!this.g(b, c, d)) {
            e = false;
        }
        if (!this.e(b, c, d)) {
            e = false;
        }
        if (e && this.k.count == 0 && this.j.count == 0 && this.i.count == 0 && this.m.count == 0 && this.l.count == 0 && this.n.count == 0) {
            this.am();
        }
        else {
            this.b.requestFrame(this.o);
        }
    }
    p() {
        let a = dateNow();
        return a.getTime();
    }
    am() {
        this.b.teardownTicking(this.o);
        this.o = -1;
    }
    aa() {
        if (this.o == -1) {
            this.o = this.b.setupTicking(runOn(this, this.ad));
            this.b.requestFrame(this.o);
        }
    }
    u(a, b) {
        b.b0 = a.m;
        b.bl = this.p();
        this.ai(a.m, true, b);
        this.k.add(b);
        this.aa();
    }
    ai(a, b, c) {
        for (let d = this.k.count - 1; d >= 0; d--) {
            if (this.k._inner[d].b0 == a && this.k._inner[d].am(c)) {
                if (b) {
                    this.k._inner[d].bt(c);
                }
                this.k.removeAt(d);
            }
        }
    }
    z(a, b) {
        b.b0 = a.o;
        b.bl = this.p();
        this.al(a, true, b);
        this.n.add(b);
        this.aa();
    }
    al(a, b, c) {
        for (let d = this.n.count - 1; d >= 0; d--) {
            if (this.n._inner[d].b0 == a.o && this.n._inner[d].am(c)) {
                if (b) {
                    this.n._inner[d].bt(c);
                }
                this.n.removeAt(d);
            }
        }
    }
    t(a, b) {
        b.b2 = a.m;
        b.bl = this.p();
        this.ah(a.m, true, b);
        this.j.add(b);
        this.aa();
    }
    x(a) {
        a.b2 = -300;
        a.bl = this.p();
        this.ah(-300, true, a);
        this.j.add(a);
        this.aa();
    }
    y(a) {
        a.b2 = -400;
        a.bl = this.p();
        this.ah(-400, true, a);
        this.j.add(a);
        this.aa();
    }
    ah(a, b, c) {
        for (let d = this.j.count - 1; d >= 0; d--) {
            if (this.j._inner[d].b2 == a && this.j._inner[d].am(c)) {
                if (b) {
                    this.j._inner[d].bt(c);
                }
                this.j.removeAt(d);
            }
        }
    }
    w(a, b) {
        b.b0 = a;
        b.bl = this.p();
        this.ak(a, true, b);
        this.m.add(b);
        this.aa();
    }
    ak(a, b, c) {
        for (let d = this.m.count - 1; d >= 0; d--) {
            if (this.m._inner[d].b0.equals(a) && this.m._inner[d].am(c)) {
                if (b) {
                    this.m._inner[d].bt(c);
                }
                this.m.removeAt(d);
            }
        }
    }
    v(a, b) {
        b.b0 = a;
        b.bl = this.p();
        this.aj(a, true, b);
        this.l.add(b);
        this.aa();
    }
    aj(a, b, c) {
        for (let d = this.l.count - 1; d >= 0; d--) {
            if (this.l._inner[d].b0.equals(a) && this.l._inner[d].am(c)) {
                if (b) {
                    this.l._inner[d].bt(c);
                }
                this.l.removeAt(d);
            }
        }
    }
    r(a, b, c) {
        b.b4 = c;
        b.b0 = a;
        b.bl = this.p();
        b.b2 = true;
        this.ag(a, true, b);
        this.i.add(b);
        this.aa();
    }
    s(a, b) {
        b.b0 = a;
        b.bl = this.p();
        b.b2 = false;
        this.ag(a, true, b);
        this.i.add(b);
        this.aa();
    }
    ag(a, b, c) {
        for (let d = this.i.count - 1; d >= 0; d--) {
            if (this.i._inner[d].b0.equals(a) && this.i._inner[d].am(c)) {
                if (b) {
                    this.i._inner[d].bt(c);
                }
                this.i.removeAt(d);
            }
        }
    }
    f(a, b, c) {
        let d = true;
        let e;
        let f;
        let g = new List$1(ColumnEffect.$, 0);
        for (let h = 0; h < this.k.count; h++) {
            if (b.f(this.k._inner[h].b0) == null) {
                this.ai(this.k._inner[h].b0, false, this.k._inner[h]);
            }
        }
        for (let i = 0; i < b.a9.count; i++) {
            e = b.a9._inner[i];
            for (let j = 0; j < this.k.count; j++) {
                f = this.k._inner[j];
                if (f.ah(e, b)) {
                    if (!f.au(e, b, c, a)) {
                        d = false;
                    }
                    else {
                        g.add(f);
                    }
                }
            }
        }
        for (let k = 0; k < g.count; k++) {
            this.ai(g._inner[k].b0, false, g._inner[k]);
            g._inner[k].bu();
        }
        return d;
    }
    h(a, b, c) {
        let d = true;
        let e = b.bg;
        let f = new List$1(GridColumnSpacer.$, 0);
        let g = new List$1(SpacerEffect.$, 0);
        for (let h = 0; h < e.count; h++) {
            let i = e._inner[h];
            for (let j = 0; j < i.count; j++) {
                let k = i._inner[j];
                for (let l = 0; l < this.n.count; l++) {
                    if (this.n._inner[l].aj(k, b)) {
                        if (!this.n._inner[l].av(k, b, c, a)) {
                            d = false;
                        }
                        else {
                            f.add(k);
                            g.add(this.n._inner[l]);
                        }
                    }
                }
            }
        }
        for (let m = 0; m < f.count; m++) {
            this.al(f._inner[m], false, g._inner[m]);
            g._inner[m].bu();
        }
        return d;
    }
    g(a, b, c) {
        let d = true;
        let e = new CellPath(1, 0, 0, 0);
        let f;
        for (let g = 0; g < this.m.count; g++) {
            f = this.m._inner[g];
            e.b = f.b0.b;
            e.s = f.b0.s;
            e.t = f.b0.t;
            if (!f.aw(b.bf._inner[e.t], b, c, a)) {
                d = false;
            }
        }
        return d;
    }
    e(a, b, c) {
        let d = true;
        if (this.j.count == 0 && this.l.count == 0 && this.i.count == 0) {
            return true;
        }
        for (let e = 0; e < this.j.count; e++) {
            this.j._inner[e].b1 = -1;
            let f = b.f(this.j._inner[e].b2);
            if (f != null) {
                this.j._inner[e].b1 = f.l;
                this.j._inner[e].b0 = f.c;
            }
            this.j._inner[e].ap = true;
        }
        for (let g = 0; g < this.l.count; g++) {
            this.l._inner[g].ap = true;
        }
        for (let h = 0; h < this.i.count; h++) {
            this.i._inner[h].b3 = -1;
            if (this.i._inner[h].b2) {
                let i = b.f(this.i._inner[h].b4);
                if (i != null) {
                    this.i._inner[h].b3 = i.l;
                    this.i._inner[h].b1 = i.c;
                }
            }
            this.i._inner[h].ap = true;
        }
        for (let j = 0; j < b.be.count; j++) {
            let k = b.be._inner[j];
            for (let l = 0; l < k.o.count; l++) {
                if (k.p._inner[l]) {
                    continue;
                }
                let m = k.o._inner[l];
                for (let n = 0; n < this.j.count; n++) {
                    let o = this.j._inner[n];
                    if (o.ag(m, b)) {
                        if (!o.at(k.q._inner[l], b, c, a)) {
                            o.ap = false;
                        }
                    }
                }
                for (let p = 0; p < this.l.count; p++) {
                    let q = this.l._inner[p];
                    if (q.ag(m, b)) {
                        if (!q.at(k.q._inner[l], b, c, a)) {
                            q.ap = false;
                        }
                    }
                }
                for (let r = 0; r < this.i.count; r++) {
                    let s = this.i._inner[r];
                    if (s.ag(m, b)) {
                        if (!s.at(k.q._inner[l], b, c, a)) {
                            s.ap = false;
                        }
                    }
                }
            }
        }
        let t = new List$1(ColumnCellsEffect.$, 0);
        for (let u = 0; u < this.j.count; u++) {
            if (this.j._inner[u].ak(b, c, a) && this.j._inner[u].ap) {
                t.add(this.j._inner[u]);
            }
            else {
                d = false;
            }
        }
        let v = new List$1(RowCellsEffect.$, 0);
        for (let w = 0; w < this.l.count; w++) {
            if (this.l._inner[w].ak(b, c, a) && this.l._inner[w].ap) {
                v.add(this.l._inner[w]);
            }
            else {
                d = false;
            }
        }
        let x = new List$1(CellEffect.$, 0);
        for (let y = 0; y < this.i.count; y++) {
            if (this.i._inner[y].ak(b, c, a) && this.i._inner[y].ap) {
                x.add(this.i._inner[y]);
            }
            else {
                d = false;
            }
        }
        for (let z = 0; z < t.count; z++) {
            this.ah(t._inner[z].b2, false, t._inner[z]);
            t._inner[z].bu();
        }
        for (let aa = 0; aa < v.count; aa++) {
            this.aj(v._inner[aa].b0, false, v._inner[aa]);
            v._inner[aa].bu();
        }
        for (let ab = 0; ab < x.count; ab++) {
            this.ag(x._inner[ab].b0, false, x._inner[ab]);
            x._inner[ab].bu();
        }
        return d;
    }
}
GridEffectManager.$t = markType(GridEffectManager, 'GridEffectManager');
/**
 * @hidden
 */
class GridLayerController extends Base {
    constructor() {
        super(...arguments);
        this.e = new RecyclingManager();
    }
    a(a, b) {
        let c = b.be;
        let d = c.count;
        for (let e = 0; e < d; e++) {
            let f = c._inner[e].b(a);
            if (f != undefined) {
                return f;
            }
        }
        return null;
    }
    b(a, b, c, d, e, f, g, h) {
        let i = this.a(a, c);
        if (i == null) {
            let j = null;
            let k = null;
            let l = false;
            let m = -1;
            if (a.ab) {
                m = b.da.getDataRow(a);
                k = b.da.resolveValueForPath(b, a);
                if (k == null && b.da.isPlaceholderValue(a)) {
                    l = true;
                }
            }
            let n = b.j1(a, b, k, m);
            j = this.e.a(n);
            if (j == null) {
                j = b.ak(a, n);
            }
            else {
                j.hp();
            }
            let o = a;
            if (j.i != null) {
                o = j.i;
            }
            if (c.ay.d(o)) {
                c.ay.item(o).remove(j);
                if (c.ay.item(o).count == 0) {
                    c.ay.f(o);
                }
            }
            d.s(a, j);
            j.o = d;
            j.i = a;
            j.t = e;
            j.dq = m;
            j.ar = f;
            j.as = g;
            j.an = h;
            let p = false;
            let q = false;
            let r = 0;
            if (j.i.s >= 0 && (j.i.al == 0 || j.i.al == -400)) {
                r = b.da.getRowIndent(j.i.s);
                let s = b.da.getRowType(j.i.s);
                if (s == 1 && b.ft) {
                    p = b.ft;
                    q = b.actualDataSource.getIsRowExpandedAtIndex(j.i.s);
                }
            }
            j.ag = p;
            j.am = q;
            j.dw = r;
            b.nr(j, k, b.da.resolveRow(m));
            if (l) {
                j.bq = 1;
            }
            return j;
        }
        else {
            this.g(a, c, d);
            i.t = e;
            i.i = a;
            i.ar = f;
            i.as = g;
            i.an = h;
            let t = false;
            let u = false;
            let v = 0;
            if (i.i.s >= 0 && (i.i.al == 0 || i.i.al == -400)) {
                v = b.da.getRowIndent(i.i.s);
                let w = b.da.getRowType(i.i.s);
                if (w == 1 && b.ft) {
                    t = b.ft;
                    u = b.actualDataSource.getIsRowExpandedAtIndex(i.i.s);
                }
            }
            i.ag = t;
            i.am = u;
            i.dw = v;
            return i;
        }
    }
    d(a, b) {
        for (let c = 0; c < b.be.count; c++) {
            if (b.be._inner[c].d(a)) {
                return b.be._inner[c];
            }
        }
        return null;
    }
    g(a, b, c) {
        let d = this.d(a, b);
        if (d == null || d == c) {
            return;
        }
        let e = d.item(a);
        d.f(a);
        c.s(a, e);
        e.o = c;
    }
    f(a, b, c) {
        if (c == null) {
            c = this.d(a, b);
        }
        if (c == null) {
            return;
        }
        let d = c.item(a);
        c.f(a);
        let e = null;
        if (b.ay.d(a)) {
            e = b.ay.item(a);
            if (e.count == 1) {
                let f = a.w();
                b.ay.f(a);
                b.ay.s(f, e);
            }
        }
        else {
            e = new List$1(CellModel.$, 0);
            b.ay.s(a, e);
        }
        e.add(d);
    }
    i(a, b) {
        let c = this.d(a, b);
        if (c == null) {
            return;
        }
        let d = this.c(a, b);
        this.f(a, b, c);
        this.e.c(d);
    }
    j(a, b, c) {
        if (b == null) {
            return;
        }
        let d = b.item(a);
        this.f(a, c, b);
        this.e.c(d);
    }
    c(a, b) {
        for (let c = 0; c < b.be.count; c++) {
            if (b.be._inner[c].d(a)) {
                return b.be._inner[c].item(a);
            }
        }
        return null;
    }
    h(a, b, c, d, e, f) {
        if (a.i.f) {
            a.br = c + a.bj + (a.bk * b.a9._inner[a.i.al].j);
        }
        else {
            a.br = c + a.bj + (a.bk * a.e2);
        }
        a.bs = d + a.bo + (a.bp * a.dt);
        a.ep = truncate(Math.round(a.br));
        a.er = truncate(Math.round(a.bs));
        a.e2 = truncate(e);
        a.dt = truncate(f);
    }
}
GridLayerController.$t = markType(GridLayerController, 'GridLayerController');
/**
 * @hidden
 */
class VisibilityEngine extends Base {
    constructor() {
        super();
        this.j = 0;
        this.k = 0;
        this.c = null;
        this.b = null;
        this.e = false;
        this.l = 0;
        this.d = false;
    }
    get m() {
        return this.l;
    }
    set m(a) {
        this.l = a;
    }
    w() {
        this.d = true;
    }
    n(a) {
        let b = false;
        if (this.d) {
            this.d = false;
            b = true;
        }
        this.o(a, a.model, a.d3, b);
    }
    o(a, b, c, d) {
        a.mb();
        let e = b.actualVisibleRegion;
        if (e.isEmpty) {
            return;
        }
        if (e.width == 0 || e.height == 0) {
            return;
        }
        if (b.a9.count == 0) {
            return;
        }
        if (a.da == null) {
            return;
        }
        let f = this.a(a, b, c, e);
        for (let g = 0; g < b.a9.count; g++) {
            if (g >= f.k && g <= f.l) {
                b.a9._inner[g].k = c.g(g, a, b);
            }
        }
        b.bx = 0;
        b.b1 = 0;
        b.aw = f.b;
        b.av = f.a;
        b.bw = f.k;
        b.by = f.l;
        a.n2();
        if (f.k == -1 || f.l == -1) {
            return;
        }
        if (!d && (this.j == f.k) && (this.k == f.l) && (this.c == f.b) && (this.b == f.a)) {
            return;
        }
        else {
            this.j = f.k;
            this.k = f.l;
            this.c = f.b;
            this.b = f.a;
        }
        let h = a.cn;
        a.gi = true;
        this.v(a, b, f, h);
        this.p(a, b, f, h);
        f.j += b.br;
        if (this.b.s == -1) {
            return;
        }
        this.h(a, b, b.actualVisibleRegion, f, false);
        a.ci.ab();
        a.gi = false;
    }
    a(a, b, c, d) {
        let e;
        e = new CalculationParameters();
        e.j = d.top;
        e.g = d.bottom;
        e.h = d.left;
        e.i = d.right;
        if (this.m > 0) {
            let f = this.m * a.ir;
            e.j = Math.max(e.j - f, 0);
            e.g = Math.min(e.g + f, b.absoluteHeight);
            e.h = Math.max(e.h - f, 0);
            e.i = Math.min(e.i + f, b.absoluteWidth);
        }
        e.m = a.inset;
        e.d = Math.max(e.h, a.inset.c);
        e.f = Math.min(e.i, b.absoluteWidth - a.inset.d);
        e.e = e.f - e.d;
        e.b = c.b(e.j + b.bu + b.bv, b);
        e.a = c.b(e.g, b);
        e.k = c.k(e.h, a, b);
        e.l = c.k(e.i, a, b);
        for (let g = 0; g < b.a9.count; g++) {
            if (b.a9._inner[g].a == 2 || b.a9._inner[g].a == 1 || b.a9._inner[g].a == 6) {
                e.k = Math.min(e.k, g);
                e.l = Math.max(e.l, g);
            }
        }
        return e;
    }
    v(a, b, c, d) {
        let e = this.c.t;
        let f = this.b.t;
        let g = this.c.s;
        let h = this.b.s;
        let i = this.j;
        let j = this.k;
        let k = 0;
        let l = 0;
        let m = 0;
        let n = false;
        let o = false;
        let p = false;
        let q = false;
        let r = false;
        let s = a.ik == 0;
        let t = a.it == 0;
        let u = null;
        let v = a.da.getStickyRows();
        if (v != null) {
            for (let w = 0; w < v.length; w++) {
                if (u == null) {
                    u = new HashSet$1(Number_$type, 0);
                }
                u.add_1(v[w]);
            }
        }
        for (let x = 0; x < b.be.count; x++) {
            let y = b.be._inner[x];
            y.g = true;
            for (let z = 0; z < y.o.count; z++) {
                if (y.p._inner[z]) {
                    continue;
                }
                let aa = y.o._inner[z];
                o = false;
                n = false;
                k = aa.t;
                l = aa.s;
                m = aa.al;
                o = aa.af || aa.h || aa.ah;
                r = aa.ad;
                q = aa.e;
                p = u != null && u.contains(l);
                if (aa.af && t) {
                    n = true;
                }
                if (aa.e && s) {
                    n = true;
                }
                if (aa.ad && !a.dragger.isDragActive) {
                    n = true;
                }
                if (!o && (m < i || m > j)) {
                    n = true;
                }
                else if (!q && (k < e || k > f)) {
                    n = true;
                }
                else {
                    if (!p && !r) {
                        if (k == e && l < g) {
                            n = true;
                        }
                        if (k == f && l > h) {
                            n = true;
                        }
                    }
                }
                if (!n) {
                    let ab = a.da.getRowType(l);
                    let ac = a.da.isRowSpanning(ab) && a.c2 != 1;
                    if (!aa.af && !aa.ad) {
                        if (b.a3 && (ab == 1 || ab == 2)) {
                            n = true;
                        }
                        else if ((ac && !o) || (o && !ac)) {
                            n = true;
                        }
                        else if ((aa.ag && ab != 5) || (aa.ae && ab != 4) || (!aa.ag && ab == 5) || (!aa.ae && ab == 4)) {
                            n = true;
                        }
                    }
                }
                if (n) {
                    a.cn.j(aa, y, b);
                }
            }
            y.g = false;
        }
        b.a3 = false;
    }
    u(a, b, c) {
        let d = c.b;
        let e = c.a;
        let f = e.t;
        let g = new CellPath(1, 0, 0, 0);
        for (let h = d.t; h <= f; h++) {
            this.r(h, a, b, c, g);
        }
    }
    r(a, b, c, d, e) {
        let f = d.b;
        let g = d.a;
        let h = c.bf;
        let i = b.cn;
        let j = g.t;
        let k = d.d;
        let l = d.f;
        let m = d.e;
        let n = h._inner[a];
        let o = a == j ? g.s : n.m - 1;
        if (o == -201) {
            o = n.m - 1;
        }
        let p = 0;
        if (f.t == a) {
            p = f.s == -200 ? 0 : f.s;
        }
        if (p == -201) {
            let q = new CellPath(1, 0, a, -200);
            this.ae(q, c, k, n.i + n.l() - n.d, m, a, false, b);
            e.t = a;
            e.s = -201;
            e.al = 0;
            return;
        }
        if (n.g > 0) {
            this.t(a, b, c, d, e, f, n, p);
        }
        if (n.d > 0) {
            this.s(a, b, c, d, e, i, j, n);
        }
        e.t = a;
    }
    i(a, b, c) {
        let d = this.a(a, b, a.d3, c);
        return this.h(a, b, c, d, true);
    }
    h(a, b, c, d, e) {
        let f = d.a;
        let g = d.b;
        let h = d.a.t;
        let i = d.b.t;
        let j = new CellPath(1, 0, 0, 0);
        let k = b.bf._inner[0];
        let l = a.da.getStickyRowsInRange(g.s, f.s);
        let m = -1;
        let n = -1;
        let o = -1;
        let p = -1;
        let q = false;
        let r = a.it;
        let s = a.c2 == 3;
        let t = new Dictionary$2(Number_$type, PinnedRowInfo.$, 0);
        let u = new List$1(PinnedRowInfo.$, 0);
        if (l != null && ((a.az.i.count > 0 && a.fv) || a.az.i.count == 0)) {
            let v = c.top + b.bs;
            let w = c.bottom;
            for (let x = 0; x < l.length; x++) {
                let y = l[x];
                let z = a.da.getRowType(y);
                let aa = y * k.k() + k.i;
                let ab = new PinnedRowInfo();
                ab.b = b;
                ab.a = z;
                ab.i = k.e(y);
                ab.g = k.j(y);
                ab.l = a.da.getStickRowPriority(y);
                ab.k = y;
                ab.j = aa;
                ab.d = (x == l.length - 1) || l[x + 1] != y + 1;
                ab.e = z == 5 && (x == l.length - 1);
                t.addItem(y, ab);
                if (x == 0) {
                    if (ab.a != 4) {
                        if (ab.j <= v) {
                            ab.j += (v - ab.j);
                            p = x;
                        }
                        else if (ab.h > c.bottom) {
                            ab.j += (c.bottom - ab.h);
                            q = true;
                        }
                    }
                    else {
                        ab.j += (c.bottom - ab.h);
                        ab.f = true;
                        q = true;
                    }
                    continue;
                }
                let ac = l[x - 1];
                let ad = a.da.getStickRowPriority(ac);
                let ae = a.da.getStickRowPriority(y);
                let af = t.item(ac);
                let ag = a.da.isExclusivelySticky(y);
                let ah = x - 1 == p;
                af.e = (z != 5 && af.a == 5) || (z == 5 && x == l.length - 1);
                if (ab.a != 4) {
                    if (ab.j <= af.h && ah) {
                        p = x;
                        if (!this.g(a, x - 1, x, x, l, t, true, ag)) {
                            ab.j = af.h;
                        }
                    }
                    if (ab.a == 2) {
                        let ai = a.da.getRootSummaryRowCount();
                        let aj = c.bottom - ai * k.k();
                        if (ab.h > aj) {
                            ab.j -= ab.h - aj;
                            ab.f = true;
                            q = true;
                            if (!this.g(a, x - 1, x, x, l, t, false, ag)) {
                                ab.j = af.h;
                            }
                        }
                    }
                    else if (s && ab.a == 5) {
                        let ak = a.da.getRootSummaryRowCount();
                        let al = c.bottom - ak * k.k();
                        if (ab.h > al) {
                            ab.j -= ab.h - al;
                            ab.f = true;
                            q = true;
                            if (!this.g(a, x - 1, x, x, l, t, false, ag)) {
                                ab.j = af.h;
                            }
                        }
                    }
                }
                if (z == 4) {
                    ab.j += (c.bottom - ab.h);
                    ab.f = true;
                    q = true;
                    this.z(a, x - 1, x, 4, l, t);
                }
            }
            for (let am = 0; am <= p; am++) {
                let an = l[am];
                let ao = t.item(an).j;
                let ap = t.item(an).h;
                let aq = t.item(an).i;
                m = an;
                let ar = false;
                let as = false;
                let at = false;
                if (t.item(an).a == 3) {
                    ar = true;
                    as = true;
                }
                if (t.item(an).a == 3 && t.item(an).d) {
                    at = true;
                }
                u.add(t.item(an));
                if (!e) {
                    this.q(a, b, d, j, a.cn, an, ao, aq, true, ar, as, at);
                }
            }
            if (q) {
                let au = 0;
                for (let av = 0; av < l.length; av++) {
                    let aw = l[av];
                    if (!t.item(aw).f) {
                        continue;
                    }
                    if (o == -1) {
                        o = aw;
                    }
                    let ax = t.item(aw).j;
                    let ay = t.item(aw).h;
                    let az = t.item(aw).i;
                    n = aw;
                    let a0 = t.item(aw).a == 3 && t.item(aw).d;
                    let a1 = t.item(aw).a == 3;
                    if (!e) {
                        j.g = true;
                        j.m = (b.bx - 1) - au;
                        this.q(a, b, d, j, a.cn, aw, ax, az, true, a1, a1, a0);
                        j.g = false;
                        j.m = -1;
                    }
                    au++;
                }
            }
        }
        for (let a2 = Math.max(m + 1, g.s); a2 <= f.s; a2++) {
            if (o != -1 && n != -1) {
                if (a2 >= o && a2 <= n) {
                    continue;
                }
            }
            let a3 = k.f(a2);
            a3 += k.i;
            let a4 = k.e(a2);
            let a5 = false;
            let a6 = false;
            let a7 = false;
            let a8 = a.da.getRowType(a2);
            if (a8 == 3) {
                a7 = true;
                a6 = true;
            }
            if (a8 == 0 && a.da.isRowPinned(a2)) {
                a6 = true;
            }
            if (a8 == 3) {
                if (t.containsKey(a2) && t.item(a2).d) {
                    a5 = true;
                }
            }
            if (!e) {
                this.q(a, b, d, j, a.cn, a2, a3, a4, false, a6, a7, a5);
            }
        }
        return u;
    }
    z(a, b, c, d, e, f) {
        if (b < 0) {
            return;
        }
        let g = e[b];
        let h = e[c];
        if (f.item(g).a == d) {
            if (f.item(g).h > f.item(h).j) {
                f.item(g).j -= f.item(g).h - f.item(h).j;
                f.item(g).f = true;
                this.z(a, b - 1, b, d, e, f);
            }
        }
    }
    g(a, b, c, d, e, f, g, h) {
        let i = e[b];
        let j = e[c];
        let k = e[d];
        let l = f.item(i).l;
        let m = f.item(j).l;
        let n = f.item(k).l;
        let o = a.p != 1;
        if (f.item(j).j < f.item(i).h) {
            if (m > l || (m == l && h)) {
                let p = f.item(j).j - f.item(i).h;
                return this.f(a, p, b, d, e, f, g, h);
            }
            else if (m == l && !h) {
                return false;
            }
            else if (m < l) {
                if (n >= l) {
                    if (!o) {
                        let q = f.item(j).j - f.item(i).h;
                        return this.f(a, q, b, d, e, f, g, h);
                    }
                    else {
                        if (f.item(k).j < f.item(i).h) {
                            let r = f.item(k).j - f.item(i).h;
                            return this.f(a, r, b, d, e, f, g, h);
                        }
                    }
                    return true;
                }
                return false;
            }
        }
        return true;
    }
    f(a, b, c, d, e, f, g, h) {
        let i = e[c];
        f.item(i).j += b;
        f.item(i).f = !g;
        if (c > 0) {
            let j = this.g(a, c - 1, c, d, e, f, g, h);
            if (!j) {
                let k = e[c - 1];
                f.item(i).j = f.item(k).h;
                return false;
            }
        }
        return true;
    }
    q(a, b, c, d, e, f, g, h, i, j, k, l) {
        d.s = f;
        let m = b.a9;
        let n = c.k;
        let o = c.l;
        let p = c.d;
        let q = c.f;
        let r = c.e;
        let s = a.it;
        let t = a.da.getRowType(f);
        let u = false;
        if (t != 0) {
            u = a.da.isRowSpanning(t) && a.c2 != 1;
        }
        if (u) {
            d.al = -400;
            this.aa(truncate(c.h), truncate(r), g, h, d.w(), b, c.h, c.i, a, i, j, k, l, t);
        }
        else {
            for (let v = n; v <= o; v++) {
                let w = m._inner[v];
                d.al = w.l;
                d.b = w.c;
                let x = d.w();
                x.ae = t == 4;
                x.ag = t == 5;
                this.aa(w.k, w.j, g, h, x, b, c.h, c.i, a, i, j, k, l, t);
            }
        }
        if (i) {
            b.b1 = truncate(Math.round((g + h + a.iu) - c.j));
        }
        if (s > 0) {
            if (i) {
                b.b1 = truncate(Math.round((g + h + a.iu + s) - c.j));
            }
            d.al = -300;
            this.ag(c, d.w(), b, p, r, g + h + a.iu, s, a, i, j, k, l, t);
        }
    }
    s(a, b, c, d, e, f, g, h) {
        let i = d.d;
        let j = d.f;
        let k = d.e;
        e.t = a;
        e.s = -201;
        e.al = 0;
        let l = new CellPath(1, e.al, e.t, e.s);
        let m = h.i + h.l() - h.d;
        let n = m;
        if (a == g) {
            n = d.g - h.d;
            if (n < (h.i + h.g)) {
                n = (h.i + h.g);
            }
            this.af(l, c, i, Math.min(m, n), k, a, false, true, b);
        }
        else {
            this.ae(l, c, i, Math.min(m, n), k, a, false, b);
        }
    }
    t(a, b, c, d, e, f, g, h) {
        let i = d.d;
        let j = d.f;
        let k = d.e;
        e.t = a;
        e.s = -200;
        e.al = 0;
        let l = new CellPath(1, e.al, e.t, e.s);
        if (a == f.t) {
            if (h == g.m - 1) {
                let m = g.j(h);
                let n = g.f(h) + g.i;
                let o = (n + m) - g.g;
                this.af(l, c, i, Math.min(o, d.j), k, a, true, true, b);
            }
            else {
                this.af(l, c, i, Math.max(g.i, d.j - b.inset.e), k, a, true, true, b);
            }
        }
        else {
            this.ae(l, c, i, g.i, k, a, true, b);
        }
    }
    p(a, b, c, d) {
        let e = c.k;
        let f = c.l;
        let g = b.a9;
        let h = a.inset;
        let i = h.e;
        if (b.bs > 0) {
            let j = Math.max(c.j, i);
            b.a0 = this.e;
            if (this.e) {
                j = i;
            }
            for (let k = e; k <= f; k++) {
                let l = g._inner[k];
                let m = new CellPath(1, l.l, -100, -100);
                m.b = l.c;
                this.ad(m, b, j, a);
                if (a.fw) {
                    let n = new CellPath(1, l.l, -100, -101);
                    let o = a.h0(a.ip);
                    let p = a.ip + o * 2;
                    let q = b.a9._inner[m.al].k + b.a9._inner[m.al].j - a.ip - o;
                    this.ah(n, b, j, q, p, b.bu, a);
                }
            }
            if (b.bv > 0) {
                let r = new CellPath(1, -300, -100, -100);
                this.ag(c, r, b, c.d, c.e, 0, b.bv, a, false, false, false, false, 0);
            }
        }
        if (a.bg == 0 && a.dragger != null && a.dragger.isDragActive && a.dragger.dragType == 1) {
            let s = new CellPath(1, -400, 0, -102);
            this.ah(s, b, Math.max(c.j, i), a.iq, a.h3, b.bh, a);
        }
        if (a.a7 != 1 && a.dragger != null && a.dragger.isDragActive && a.dragger.dragType == 2) {
            let t = new CellPath(1, -400, 0, -102);
            this.ah(t, b, c.j, a.iq, a.h1, b.bh, a);
        }
    }
    x(a, b, c, d, e, f, g, h, i) {
        this.y(a, b, c, d, e, f, g, h, i, false, false, false);
    }
    y(a, b, c, d, e, f, g, h, i, j, k, l) {
        let m = a.cn.b(c, a, b, d, e, j, k, l);
        a.cn.h(m, b, f, g, h, i);
    }
    aa(a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        let o = f.ab;
        let p = e.b;
        let q = i.d3;
        let r = 1;
        if (n == 1) {
            r = 2;
        }
        if (n == 2) {
            r = 3;
        }
        if (p == 0) {
            if (e.al == -400) {
                if (j) {
                    if (n == 1 || n == 2) {
                        o = f.ak;
                    }
                }
            }
            else {
                if (f.a9._inner[e.al].a == 1 || f.a9._inner[e.al].a == 2 || f.a9._inner[e.al].a == 3) {
                    if (j) {
                        o = n != 4 ? f.ai : f.aq;
                    }
                    else {
                        o = f.ao;
                    }
                }
                else if (f.a9._inner[e.al].a == 6) {
                    if (j) {
                        o = n != 4 ? f.aj : f.at;
                    }
                    else {
                        o = f.ar;
                    }
                }
                else {
                    if (j) {
                        o = n != 4 ? f.ah : f.ag;
                    }
                    else {
                        o = f.ab;
                    }
                }
            }
        }
        if (p == 1) {
            a = i.d3.h(e.al, g, i, f);
            o = f.ae;
            b = f.ba._inner[e.al].j;
        }
        if (p == 2) {
            a = i.d3.i(e.al, h, i, f);
            o = f.ae;
            b = f.bb._inner[e.al].j;
        }
        this.y(i, f, e, o, r, a, c, b, d, k, l, m);
    }
    ab(a, b, c, d, e) {
        let f = e.d3.h(a.al, truncate(d), e, b);
        this.x(e, b, a, b.ad, 0, f, c, b.ba._inner[a.al].j, b.bs);
    }
    ac(a, b, c, d, e) {
        let f = e.d3.i(a.al, truncate(d), e, b);
        this.x(e, b, a, b.ad, 0, f, c, b.bb._inner[a.al].j, b.bs);
    }
    ad(a, b, c, d) {
        let e = b.ag;
        if (b.a9._inner[a.al].a == 1 || b.a9._inner[a.al].a == 2 || b.a9._inner[a.al].a == 3) {
            e = b.aq;
        }
        if (b.a9._inner[a.al].a == 6) {
            e = b.at;
        }
        this.x(d, b, a, e, 0, b.a9._inner[a.al].k, c, b.a9._inner[a.al].j, b.bu);
    }
    ah(a, b, c, d, e, f, g) {
        let h = b.au;
        if (a.f) {
            h = b.af;
            if (b.a9._inner[a.al].a == 1 || b.a9._inner[a.al].a == 2 || b.a9._inner[a.al].a == 3) {
                h = b.ap;
            }
            if (b.a9._inner[a.al].a == 6) {
                h = b.as;
            }
        }
        this.x(g, b, a, h, 5, d, c, e, f);
    }
    ae(a, b, c, d, e, f, g, h) {
        this.af(a, b, c, d, e, f, g, false, h);
    }
    af(a, b, c, d, e, f, g, h, i) {
        let j = g ? b.bf._inner[f].g : b.bf._inner[f].d;
        let k = 3;
        let l = b.an;
        if (g) {
            k = 2;
        }
        if (h) {
            l = b.an;
        }
        this.x(i, b, a, l, k, c, d, e, j);
    }
    ag(a, b, c, d, e, f, g, h, i, j, k, l, m) {
        let n = 0;
        let o = c.ab;
        if (i) {
            if (m == 1 || m == 2) {
                o = c.ak;
            }
            else if (m == 4) {
                o = c.am;
            }
            else {
                o = c.ah;
            }
        }
        if (b.e) {
            let p = h.inset;
            let q = p.e;
            let r = Math.max(a.j, q);
            n = r + c.bu;
            if (this.e) {
                n = a.m.e + c.bu;
            }
            o = c.af;
        }
        else {
            let s = c.bf._inner[b.t];
            n = f;
        }
        this.y(h, c, b, o, 4, d, n, e, g, j, k, l);
    }
}
VisibilityEngine.$t = markType(VisibilityEngine, 'VisibilityEngine');
/**
 * @hidden
 */
class PinnedRowInfo extends Base {
    constructor() {
        super(...arguments);
        this.k = 0;
        this.m = null;
        this.j = 0;
        this.i = 0;
        this.g = 0;
        this.d = false;
        this.c = false;
        this.a = 0;
        this.e = false;
        this.l = 0;
        this.b = null;
    }
    get h() {
        return this.j + this.g;
    }
    get f() {
        return this.c;
    }
    set f(a) {
        let b = this.c;
        this.c = a;
        if (this.c != b) {
            if (this.b != null) {
                this.b.bx = Math.max(0, this.c ? this.b.bx + 1 : this.b.bx - 1);
            }
        }
    }
}
PinnedRowInfo.$t = markType(PinnedRowInfo, 'PinnedRowInfo');
/**
 * @hidden
 */
let ICellRenderingEngine_$type = new Type(null, 'ICellRenderingEngine');
/**
 * @hidden
 */
class SpatialEngine extends Base {
    constructor() {
        super(...arguments);
        this.d = new List$1(ColumnInfo.$, 0);
        this.c = new Dictionary$2(Number_$type, ColumnInfo.$, 0);
        this.a = new GridColumnSpacerCollection();
    }
    n(a, b, c) {
        b.absoluteHeight = 0;
        b.absoluteWidth = 0;
        b.absoluteHeight = truncate(a.inset.e);
        b.br = truncate(a.inset.e);
        b.bf.clear();
        this.c.clear();
        for (let d = 0; d < a.model.a9.count; d++) {
            this.c.addItem(a.model.a9._inner[d].m, a.model.a9._inner[d]);
        }
        b.b8();
        b.bp = 0;
        b.bq = 0;
        a.model.bo = a.h4;
        if (a.da == null) {
            return;
        }
        let e = a.da.getSectionCount();
        e = Math.max(1, e);
        a.model.bv = a.ik > 0 ? a.it : 0;
        a.model.bs = a.ik + a.model.bv;
        a.model.bu = a.ik;
        a.model.absoluteHeight += a.model.bs;
        a.model.br += a.model.bs;
        for (let f = 0; f < e; f++) {
            let g = new SectionInfo();
            g.h = f;
            g.i = b.absoluteHeight;
            g.m = a.da.getRowCount();
            g.g = a.ix;
            g.d = a.iv;
            g.o = a.it;
            g.p = a.iu;
            g.n = a.ir;
            g.q = g.m * g.n;
            a.model.absoluteHeight += g.l();
            a.model.bf.add(g);
        }
        let h = a.defaultColumnWidth;
        let i = 0;
        let j = a.defaultColumnWidth;
        let k = a.g9;
        this.d.clear();
        for (i = 0; i < a.actualColumns.count; i++) {
            let l = new ColumnInfo();
            if (this.c.containsKey(a.actualColumns._inner[i].fj)) {
                l = this.c.item(a.actualColumns._inner[i].fj);
            }
            l.l = i;
            let m = a.actualColumns._inner[i];
            l.n = m.gb;
            l.m = m.fj;
            if (m.ed == 3) {
                l.g = -1;
            }
            if (m.ed == 5) {
                l.g = 0;
            }
            l.a = m.ed;
            let n = null;
            h = m.width;
            if (n == null) {
                n = (h == null) ? j : h;
            }
            let o = 0;
            if (!isNaN_(k)) {
                o = k;
            }
            if (!isNaN_(n.e) && n.e > 0) {
                o = Math.max(o, n.e);
            }
            if (!isNaN_(m.e5)) {
                o = m.e5;
            }
            l.b = n;
            l.h = o;
            l.c = 0;
            a.model.b3(l);
        }
        this.c.clear();
        a.model.bp = 0;
        a.model.bq = 0;
        this.m(a, b, c);
        a.ci.ac();
        a.model.absoluteHeight += truncate(a.inset.b);
    }
    m(a, b, c) {
        a.model.absoluteWidth = 0;
        let d = a.model.bo;
        let e = a.model.bo;
        let f = 0;
        let g = new List$1(ColumnInfo.$, 0);
        let h = b.bg;
        for (let i of fromEnum(b.a9)) {
            if (i.b.c) {
                f += i.b.f * this.e(i);
                g.add(i);
            }
            else {
                i.j = truncate((Math.max(DeviceUtils.g(i.b.f), i.h)));
                if (i.a != 3) {
                    if (i.a == 6) {
                        e += i.j + a.model.bo;
                    }
                    else {
                        e += i.j + a.model.bo - truncate(Math.round(i.e(b)));
                    }
                }
                if (i.a == 6) {
                    d += i.j + a.model.bo;
                }
                else {
                    d += i.j + a.model.bo - truncate(Math.round(i.e(b)));
                }
            }
        }
        if (f > 0) {
            let j = e;
            e = SpatialEngine.l(a, b, c, d, e, f, g);
        }
        a.model.absoluteWidth = e;
        a.model.absoluteWidth += truncate((a.inset.c + a.inset.d));
    }
    e(a) {
        if (a.a == 6) {
            return 1;
        }
        if (a.a == 3) {
            return 0;
        }
        let b = 1 - Math.max(0, Math.min(1, Math.abs(a.g)));
        return b;
    }
    static l(a, b, c, d, e, f, g) {
        c -= d;
        c -= truncate((a.inset.c + a.inset.d));
        c -= (g.count * a.model.bo);
        c -= a.model.bz + a.model.b0;
        let h = 0;
        let i = (c) / f;
        if (i < 0) {
            i = 0;
        }
        if (c < 0) {
            c = 0;
        }
        let j = false;
        let k = new HashSet$1(ColumnInfo.$, 0);
        while (f > 0 && !j) {
            j = true;
            for (let l of fromEnum(g)) {
                if (k.contains(l)) {
                    continue;
                }
                if (l.h > i * l.b.f) {
                    j = false;
                    f--;
                    k.add_1(l);
                    l.j = truncate(l.h);
                    if (l.a != 6) {
                        if (l.a != 3) {
                            e += (l.j) + a.model.bo - truncate(Math.round(l.e(b)));
                        }
                        if (l.a == 6) {
                            let m = (l.j) + a.model.bo;
                            d += m;
                            c -= m;
                        }
                        else {
                            let n = (l.j) + a.model.bo - truncate(Math.round(l.e(b)));
                            d += n;
                            c -= n;
                        }
                    }
                }
            }
            i = (c) / f;
        }
        if (c < 0) {
            c = 0;
        }
        let o = 0;
        for (let p of fromEnum(g)) {
            if (k.contains(p)) {
                continue;
            }
            let q = Math.max(p.h, i * p.b.f);
            let r = o + q;
            o += q;
            if (Math.round(r) >= r) {
                p.j = truncate(Math.ceil(q));
            }
            else {
                p.j = truncate(Math.floor(q));
            }
            if (p.c == 1) {
                a.model.bp += p.j;
            }
            if (p.c == 2) {
                a.model.bq += p.j;
            }
            if (p.c == 0) {
                e += a.model.bo;
                d += a.model.bo;
                h += a.model.bo;
                o += a.model.bo;
            }
            if (p.a != 3) {
                if (p.a == 6) {
                    e += p.j;
                }
                else {
                    e += p.j - truncate(Math.round(p.e(b)));
                }
            }
            if (p.a == 6) {
                d += p.j;
                h += p.j;
            }
            else {
                d += p.j - truncate(Math.round(p.e(b)));
                h += p.j - truncate(Math.round(p.e(b)));
            }
        }
        if (h < c) {
            let s = (c - h - a.model.bo);
            g._inner[g.count - 1].j += s;
            e += s;
            d += s;
        }
        if (h > c) {
            let t = (c - h - a.model.bo);
            g._inner[g.count - 1].j += t;
            e += t;
            d += t;
        }
        return e;
    }
    h(a, b, c, d) {
        let e = 0;
        for (let f = 0; f < a; f++) {
            if (d.ba._inner[f].a != 6) {
                e += d.ba._inner[f].j + c.model.bo - truncate(Math.round(d.ba._inner[f].e(d)));
            }
        }
        let g = truncate(b) + e;
        g = (g + truncate(Math.round(d.ba._inner[a].d(d))));
        return g;
    }
    i(a, b, c, d) {
        b = Math.min(b, d.absoluteWidth);
        let e = d.bq;
        for (let f = 0; f < a; f++) {
            if (d.bb._inner[f].a != 6) {
                e -= d.bb._inner[f].j + c.model.bo - truncate(Math.round(d.bb._inner[f].e(d)));
            }
        }
        let g = truncate(b) - (e + truncate(c.inset.c));
        g = (g + truncate(Math.round(d.bb._inner[a].d(d))));
        return g;
    }
    g(a, b, c) {
        let d = c.a9._inner[a].m;
        let e = truncate(b.inset.c) + c.bp + c.bo;
        let f = c.bg;
        let g = c.a9;
        for (let h = 0; h < a; h++) {
            e += truncate(Math.round(f._inner[h].ad(d)));
            if (g._inner[h].a != 6) {
                e += (g._inner[h].j) + b.model.bo - truncate(Math.round(g._inner[h].e(c)));
            }
            e += truncate(Math.round(f._inner[h].af(d)));
        }
        e += truncate(Math.round(f._inner[a].ad(d)));
        return truncate((e + Math.round(g._inner[a].d(c))));
    }
    j(a, b, c) {
        let d = c.a9._inner[a].m;
        let e = truncate(b.inset.c) + c.bp + c.bo;
        let f = c.bg;
        let g = c.a9;
        for (let h = 0; h < a; h++) {
            e += truncate(Math.round(f._inner[h].ad(d)));
            if (g._inner[h].a != 6) {
                e += (g._inner[h].j) + b.model.bo - truncate(Math.round(g._inner[h].e(c)));
            }
            e += truncate(Math.round(f._inner[h].af(d)));
        }
        e += truncate(Math.round(f._inner[a].ad(d)));
        return (e);
    }
    k(a, b, c) {
        let d = 0;
        let e = 0;
        let f = c.bp + truncate(b.inset.c);
        e += f;
        let g = c.bg;
        let h = c.a9;
        let i = h.count;
        for (let j = 0; j < i; j++) {
            let k = h._inner[j];
            e += truncate(Math.round(g._inner[d].ad(-1)));
            if (k.a != 6) {
                e += (k.j) + b.model.bo - truncate(Math.round(k.e(c)));
            }
            if (a <= e) {
                return d;
            }
            e += truncate(Math.round(g._inner[d].af(-1)));
            d++;
        }
        let l = c.a9.count - 1;
        if (d > l) {
            d = l;
        }
        return d;
    }
    b(a, b) {
        let c = b.bf.count;
        for (let d = 0; d < c; d++) {
            let e = b.bf._inner[d];
            let f = e.i;
            let g = f + e.l();
            if (a <= g) {
                if (a < f) {
                    a = f;
                }
                return e.a(a);
            }
        }
        return new RowPath(b.bf.count - 1, b.bf._inner[b.bf.count - 1].m - 1);
    }
    q(a, b, c, d) {
        this.w(a, b, d, false);
        for (let e = b + 1; e < d.a9.count; e++) {
            this.v(e, d, false, b);
        }
    }
    o(a, b, c) {
        for (let d = c.a9.count - 1; d >= a; d--) {
            this.v(d, c, true, a);
        }
    }
    s(a, b) {
        for (let c = 0; c < b.be.count; c++) {
            let d = new List$1(CellModel.$, 0);
            let e = b.be._inner[c];
            for (let f = 0; f < e.o.count; f++) {
                if (e.p._inner[f]) {
                    continue;
                }
                let g = e.o._inner[f];
                if (g.t > a.t || (g.t == a.t && g.s >= a.s)) {
                    d.add(e.q._inner[f]);
                }
            }
            e.g = true;
            for (let h = 0; h < d.count; h++) {
                let i = d._inner[h];
                e.f(i.i);
                i.i.s = i.i.s + 1;
            }
            for (let j = 0; j < d.count; j++) {
                let k = d._inner[j];
                e.s(k.i, k);
            }
            e.g = false;
        }
    }
    t(a, b, c) {
        for (let d = 0; d < c.be.count; d++) {
            let e = new List$1(CellModel.$, 0);
            let f = c.be._inner[d];
            let g = new List$1(CellPath.$, 0);
            for (let h = 0; h < f.o.count; h++) {
                if (f.p._inner[h]) {
                    continue;
                }
                let i = f.o._inner[h];
                if (i.t > b.t || (i.t == b.t && i.s > b.s)) {
                    e.add(f.q._inner[h]);
                }
                if (i.t == b.t && i.s == b.s) {
                    g.add(i);
                }
            }
            f.g = true;
            for (let j = 0; j < g.count; j++) {
                let k = g._inner[j];
                a.j(k, f, c);
            }
            for (let l = 0; l < e.count; l++) {
                let m = e._inner[l];
                f.f(m.i);
                m.i.s = m.i.s - 1;
            }
            for (let n = 0; n < e.count; n++) {
                let o = e._inner[n];
                f.s(o.i, o);
            }
            f.g = false;
        }
    }
    v(a, b, c, d) {
        for (let e = 0; e < b.be.count; e++) {
            let f = new List$1(CellModel.$, 0);
            let g = b.be._inner[e];
            for (let h = 0; h < g.o.count; h++) {
                if (g.p._inner[h]) {
                    continue;
                }
                let i = g.o._inner[h];
                if (i.al == a && (i.ab || i.ac)) {
                    f.add(g.q._inner[h]);
                }
            }
            g.g = true;
            for (let j = 0; j < f.count; j++) {
                let k = f._inner[j];
                g.f(k.i);
                if (c) {
                    k.i.al = k.i.al + 1;
                }
                else {
                    k.i.al = k.i.al - 1;
                }
                g.s(k.i, k);
            }
            g.g = false;
        }
        let l = b.bg;
        if (c) {
            if (a == l.count - 1) {
                l.add(new GridColumnSpacerCollection());
            }
            for (let m = l._inner[a].count - 1; m >= 0; m--) {
                if (a != d || l._inner[a]._inner[m].d) {
                    l._inner[a + 1].add(l._inner[a]._inner[m]);
                    l._inner[a].removeAt(m);
                }
            }
        }
        else {
            for (let n = l._inner[a].count - 1; n >= 0; n--) {
                l._inner[a - 1].add(l._inner[a]._inner[n]);
                l._inner[a].removeAt(n);
            }
        }
    }
    w(a, b, c, d) {
        for (let e = 0; e < c.be.count; e++) {
            let f = new List$1(CellModel.$, 0);
            let g = c.be._inner[e];
            for (let h = 0; h < g.o.count; h++) {
                if (g.p._inner[h]) {
                    continue;
                }
                let i = g.o._inner[h];
                if (i.al == b && (i.ab || i.ac)) {
                    f.add(g.q._inner[h]);
                }
            }
            g.g = true;
            for (let j = 0; j < f.count; j++) {
                let k = f._inner[j];
                if (d) {
                    g.f(k.i);
                    k.i.al = -800;
                    g.s(k.i, k);
                }
                else {
                    a.j(k.i, g, c);
                }
            }
            g.g = false;
        }
        let l = c.bg;
        if (b < l.count) {
            for (let m = l._inner[b].count - 1; m >= 0; m--) {
                this.a.add(l._inner[b]._inner[m]);
                l._inner[b].removeAt(m);
            }
        }
    }
    u(a, b) {
        for (let c = 0; c < b.be.count; c++) {
            let d = new List$1(CellModel.$, 0);
            let e = b.be._inner[c];
            for (let f = 0; f < e.o.count; f++) {
                if (e.p._inner[f]) {
                    continue;
                }
                let g = e.o._inner[f];
                if (g.al == -800 && (g.ab || g.ac)) {
                    d.add(e.q._inner[f]);
                }
            }
            e.g = true;
            for (let h = 0; h < d.count; h++) {
                let i = d._inner[h];
                e.f(i.i);
                i.i.al = a;
                e.s(i.i, i);
            }
            e.g = false;
        }
    }
    r(a, b) {
        for (let c = 0; c < b.a9.count; c++) {
            this.w(a, c, b, false);
        }
    }
    p(a, b, c, d, e) {
        this.w(a, c, b, true);
        for (let f = c + 1; f < b.a9.count; f++) {
            this.v(f, b, false, c);
        }
        for (let g = b.a9.count - 1; g >= d; g--) {
            this.v(g, b, true, d);
        }
        this.u(d, b);
        let h = b.bg;
        for (let i = this.a.count - 1; i >= 0; i--) {
            h._inner[c].add(this.a._inner[i]);
            this.a.removeAt(i);
        }
    }
    f(a, b) {
        if (b == null) {
            return 0;
        }
        let c = 0;
        for (let d = 0; d < b.t; d++) {
            c += a.bf._inner[d].m;
        }
        c += b.s;
        return c;
    }
}
SpatialEngine.$t = markType(SpatialEngine, 'SpatialEngine');
/**
 * @hidden
 */
class ColumnExchanger extends Base {
    constructor(a, ..._rest) {
        super();
        this.c = null;
        this.a = null;
        this.b = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    let c = _rest[0];
                    let d = _rest[1];
                    this.a = c;
                    this.b = d;
                }
                break;
        }
    }
}
ColumnExchanger.$t = markType(ColumnExchanger, 'ColumnExchanger');
/**
 * @hidden
 */
class ColumnExchangersCollection extends ObservableCollection$1 {
    constructor() {
        super(ColumnExchanger.$, 0);
    }
}
ColumnExchangersCollection.$t = markType(ColumnExchangersCollection, 'ColumnExchangersCollection', ObservableCollection$1.$.specialize(ColumnExchanger.$));
/**
 * @hidden
 */
class ResponsiveEngine extends Base {
    constructor(a) {
        super();
        this.c = null;
        this.l = 500;
        this.m = 200;
        this.k = dateMinValue();
        this.h = false;
        this.i = false;
        this.j = null;
        this.a = null;
        this.f = null;
        this.b = null;
        this.d = null;
        this.a = a;
        this.g = new ResponsiveStatesCollection();
        this.j = new List$1(Number_$type, 0);
        this.h = true;
        this.d = null;
    }
    get g() {
        return this.f;
    }
    set g(a) {
        this.f = a;
    }
    x(a) {
        if (this.b == a) {
            return;
        }
        this.d = a;
        if (this.h) {
        }
        else {
            this.w();
        }
    }
    y(a, b) {
        this.k = dateNow();
        if (this.h) {
            this.q();
            this.h = false;
        }
        else {
            this.w();
        }
    }
    w() {
        if (this.i) {
            return;
        }
        let a = this.n();
        this.i = true;
        this.a.delayedExecutionManager.executeIn(() => {
            if (!this.i) {
                return;
            }
            this.i = false;
            if (this.n() < 1) {
                this.q();
            }
            else {
                this.w();
            }
        }, a);
    }
    q() {
        if (this.b != null) {
            return;
        }
        let a = null;
        if (this.g.count > 0) {
            a = this.e(this.a.g8);
        }
        if (a == this.c) {
            return;
        }
        if (this.c != null && a != null) {
            this.c.q();
            this.c = null;
        }
        if (a != null) {
            if (this.d != null) {
                this.d = null;
            }
            this.b = a;
            this.c = a;
            this.c.l = 0;
            this.c.p();
            this.t(this.c);
            this.c.o();
        }
    }
    t(a) {
        if (a.c.count == a.l) {
            this.b = null;
            let b = this.e(this.a.g8);
            {
                if (b != this.c) {
                    this.w();
                }
            }
            return;
        }
        if (this.h) {
            this.u(a);
            this.c.l = this.c.l + 1;
            this.t(a);
        }
        else {
            this.a.delayedExecutionManager.executeIn(() => {
                let c = this.a.b1;
                c.animationCompleted = delegateCombine(c.animationCompleted, runOn(this, this.p));
                let d = this.a.b1;
                d.animationCanceled = delegateCombine(d.animationCanceled, runOn(this, this.o));
                this.a.b1.aq();
                this.u(a);
                this.j = this.a.b1.m();
                if (this.j.count == 0) {
                    this.r(-1);
                }
            }, a.c._inner[0].i);
        }
    }
    u(a) {
        let b = a.c._inner[a.l];
        this.v(b.e);
        this.s(b.b);
    }
    o(a, b) {
        this.r(b.a);
    }
    p(a, b) {
        this.r(b.a);
    }
    r(a) {
        if (this.j.contains(a)) {
            this.j.remove(a);
        }
        if (this.j.count == 0) {
            let b = this.a.b1;
            b.animationCompleted = delegateRemove(b.animationCompleted, runOn(this, this.p));
            let c = this.a.b1;
            c.animationCanceled = delegateRemove(c.animationCanceled, runOn(this, this.o));
            this.c.l = this.c.l + 1;
            this.t(this.c);
        }
    }
    v(a) {
        for (let b = 0; b < a.count; b++) {
            let c = a._inner[b];
            let d = null;
            for (let e = 0; e < this.a.actualColumns.count; e++) {
                if (this.a.actualColumns._inner[e].f5 == c.c) {
                    d = this.a.actualColumns._inner[e];
                    break;
                }
            }
            if (d == null) {
                for (let f = 0; f < this.a.actualColumns.count; f++) {
                    if (this.a.actualColumns._inner[f].gb == c.c) {
                        d = this.a.actualColumns._inner[f];
                        break;
                    }
                }
            }
            if (d == null) {
                continue;
            }
            let g = d.externalObject;
            this.a.propertySetter.setProperty(g, c.d, c.b);
        }
    }
    s(a) {
        for (let b = 0; b < a.count; b++) {
            let c = a._inner[b];
            if (c.a == null) {
                continue;
            }
            if (c.b >= this.a.actualColumns.count) {
                continue;
            }
            let d = this.a.actualColumns._inner[c.b];
            this.a.l9(c.a, d);
        }
    }
    e(a) {
        if (this.d != null) {
            return this.d;
        }
        for (let b = 0; b < this.g.count; b++) {
            let c = this.g._inner[b];
            if (a >= c.k && a <= c.j && !c.i) {
                return c;
            }
        }
        return null;
    }
    n() {
        let a = timeSpanFromMilliseconds(this.m);
        let b = timeSpanFromMilliseconds(this.l);
        if (+(this.k) != +(dateMinValue())) {
            a = +(dateNow()) - +(this.k);
        }
        let c = truncate(timeSpanTotalMilliseconds(a));
        let d = (this.m - c);
        if (d < 1) {
            d = 0;
        }
        return d;
    }
}
ResponsiveEngine.$t = markType(ResponsiveEngine, 'ResponsiveEngine');
/**
 * @hidden
 */
class ResponsivePhase extends Base {
    constructor() {
        super(...arguments);
        this.j = null;
        this.k = null;
        this.i = 0;
        this.d = new ColumnPropertySettersCollection();
        this.a = new ColumnExchangersCollection();
    }
    get e() {
        return this.d;
    }
    get b() {
        return this.a;
    }
    g(a) {
        this.e.add(a);
        return this;
    }
    c() {
        let a = new ColumnPropertySetter(0);
        this.e.add(a);
        return a;
    }
    f(a) {
        this.b.add(a);
        return this;
    }
    h() {
        let a = new ColumnExchanger(0);
        this.b.add(a);
        return this;
    }
}
ResponsivePhase.$t = markType(ResponsivePhase, 'ResponsivePhase');
/**
 * @hidden
 */
class ResponsivePhasesCollection extends ObservableCollection$1 {
    constructor() {
        super(ResponsivePhase.$, 0);
    }
}
ResponsivePhasesCollection.$t = markType(ResponsivePhasesCollection, 'ResponsivePhasesCollection', ObservableCollection$1.$.specialize(ResponsivePhase.$));
/**
 * @hidden
 */
class ResponsiveState extends Base {
    constructor() {
        super(...arguments);
        this.m = null;
        this.n = null;
        this.k = 0;
        this.j = 0;
        this.stateEntering = null;
        this.stateEntered = null;
        this.stateExited = null;
        this.h = false;
        this.l = 0;
        this.b = new ResponsivePhasesCollection();
    }
    get i() {
        return this.h;
    }
    set i(a) {
        this.h = a;
    }
    get c() {
        return this.b;
    }
    d(a) {
        this.c.add(a);
        return this;
    }
    a() {
        let a = new ResponsivePhase();
        this.c.add(a);
        return a;
    }
    p() {
        if (this.stateEntering != null) {
            this.stateEntering(this, new ResponsiveStateEnteringEventArgs());
        }
    }
    o() {
        if (this.stateEntered != null) {
            this.stateEntered(this, new ResponsiveStateEnteredEventArgs());
        }
    }
    q() {
        if (this.stateExited != null) {
            this.stateExited(this, new ResponsiveStateExitedEventArgs());
        }
    }
}
ResponsiveState.$t = markType(ResponsiveState, 'ResponsiveState');
/**
 * @hidden
 */
class ResponsiveStatesCollection extends ObservableCollection$1 {
    constructor() {
        super(ResponsiveState.$, 0);
    }
}
ResponsiveStatesCollection.$t = markType(ResponsiveStatesCollection, 'ResponsiveStatesCollection', ObservableCollection$1.$.specialize(ResponsiveState.$));
/**
 * @hidden
 */
class GridLayer extends FastIterationDictionary$2 {
    constructor(a) {
        super(CellPath.$, CellModel.$, 0);
        this.v = null;
        this.v = a;
    }
}
GridLayer.$t = markType(GridLayer, 'GridLayer', FastIterationDictionary$2.$.specialize(CellPath.$, CellModel.$));
/**
 * @hidden
 */
class ColumnInfo extends Base {
    constructor() {
        super();
        this.l = 0;
        this.b = null;
        this.h = 0;
        this.j = 0;
        this.k = 0;
        this.n = null;
        this.m = 0;
        this.c = 0;
        this.f = 0;
        this.i = 0;
        this.g = 0;
        this.a = 0;
        this.f = 0;
        this.g = 0;
        this.i = 0;
        this.h = 0;
    }
    d(a) {
        let b = this.g;
        if (this.a != 6) {
            if (b > 0 && b < 1) {
                b = 0;
            }
            if (b >= 1) {
                b = b - 1;
            }
        }
        return this.f + b * (this.j + a.bo);
    }
    e(a) {
        let b = Math.abs(this.f + this.g * (this.j + a.bo));
        if (b < (-1 * (this.j + a.bo))) {
            b = (-1 * (this.j + a.bo));
        }
        if (b > (this.j + a.bo)) {
            b = (this.j + a.bo);
        }
        return b;
    }
}
ColumnInfo.$t = markType(ColumnInfo, 'ColumnInfo');
/**
 * @hidden
 */
class SectionInfo extends Base {
    constructor() {
        super(...arguments);
        this.h = 0;
        this.m = 0;
        this.q = 0;
        this.o = 0;
        this.g = 0;
        this.d = 0;
        this.n = 0;
        this.p = 0;
        this.i = 0;
        this.b = null;
        this.c = null;
    }
    l() {
        return this.q + this.g + this.d + ((this.o + this.p) * this.m);
    }
    e(a) {
        if (a == -200) {
            return this.g;
        }
        if (a == -201) {
            return this.d;
        }
        if (this.b == null) {
            return this.n;
        }
        else {
            return this.b._inner[a];
        }
    }
    f(a) {
        if (this.c == null) {
            if (a == -200) {
                return 0;
            }
            else if (a == -201) {
                return this.l() - this.g;
            }
            return (a * this.k()) + this.g;
        }
        else {
            if (a == -200) {
                return 0;
            }
            else if (a == -201) {
                return this.l() - this.d;
            }
            return this.c._inner[a];
        }
    }
    k() {
        return this.n + this.p + this.o;
    }
    j(a) {
        if (this.c == null) {
            return this.n + this.p + this.o;
        }
        else {
            return this.b._inner[a] + this.o + this.p;
        }
    }
    a(a) {
        a -= this.i;
        if (a < this.g) {
            return new RowPath(this.h, -200);
        }
        else if (a > this.l() - this.d) {
            return new RowPath(this.h, -201);
        }
        a -= this.g;
        if (this.b == null) {
            let b = this.k();
            let c = truncate((a / b));
            if (c >= this.m) {
                c = this.m - 1;
            }
            return new RowPath(this.h, c);
        }
        else {
            for (let d = 0; d < this.m; d++) {
                let e = this.c._inner[d];
                let f = this.j(d);
                if (a >= e && a <= e + f) {
                    return new RowPath(this.h, d);
                }
            }
        }
        return null;
    }
}
SectionInfo.$t = markType(SectionInfo, 'SectionInfo');
/**
 * @hidden
 */
class VisualModel extends Base {
    constructor() {
        super();
        this._actualVisibleRegion = null;
        this._absoluteWidth = 0;
        this._absoluteHeight = 0;
        this.bs = 0;
        this.bu = 0;
        this.bv = 0;
        this.br = 0;
        this.bp = 0;
        this.bq = 0;
        this.bo = 0;
        this.bz = 0;
        this.b0 = 0;
        this.bx = 0;
        this.u = null;
        this.h = null;
        this.x = null;
        this.k = null;
        this.i = null;
        this.w = null;
        this.v = null;
        this.m = null;
        this.l = null;
        this.z = null;
        this.y = null;
        this.j = null;
        this.n = null;
        this.o = null;
        this.p = null;
        this.q = null;
        this.r = null;
        this.s = null;
        this.t = null;
        this.aa = null;
        this.c = null;
        this.ax = null;
        this.bf = null;
        this.ba = null;
        this.a5 = null;
        this.bb = null;
        this.a6 = null;
        this.a9 = null;
        this.a1 = false;
        this.a3 = false;
        this.a8 = new List$1(GridColumnSpacerCollection.$, 0);
        this.a4 = null;
        this.aw = null;
        this.av = null;
        this.b2 = -1;
        this.e = null;
        this.a7 = null;
        this.bw = 0;
        this.by = 0;
        this.a0 = false;
        this.b1 = 0;
        this.actualVisibleRegion = Rect.empty;
        this.u = new GridLayer("SubContentLayer");
        this.h = new GridLayer("ContentLayer");
        this.x = new GridLayer("SuperContentLayer");
        this.k = new GridLayer("FixedLayer");
        this.i = new GridLayer("DecoratorLayer");
        this.n = new GridLayer("PinnedRowLayer");
        this.o = new GridLayer("PinnedRowsSubLayer");
        this.p = new GridLayer("PinnedRowsSuperLayer");
        this.q = new GridLayer("PinnedSectionLayer");
        this.r = new GridLayer("PinnedSectionSubLayer");
        this.s = new GridLayer("PinnedSectionSuperLayer");
        this.t = new GridLayer("SectionLayer");
        this.w = new GridLayer("SubHeaderLayer");
        this.m = new GridLayer("HeaderLayer");
        this.l = new GridLayer("HeaderDecoratorLayer");
        this.z = new GridLayer("SuperHeaderLayer");
        this.j = new GridLayer("FixedHeaderLayer");
        this.aa = new GridLayer("VerticalSeparatorLayer");
        this.v = new GridLayer("SubHeaderDecoratorLayer");
        this.y = new GridLayer("SuperHeaderDecoratorLayer");
        this.ax = new FastIterationDictionary$2(CellPath.$, List$1.$.specialize(CellModel.$), 0);
        this.b9();
        this.bf = new List$1(SectionInfo.$, 0);
        this.a9 = new List$1(ColumnInfo.$, 0);
        this.a4 = new Dictionary$2(Number_$type, Number_$type, 0);
        this.bb = new List$1(ColumnInfo.$, 0);
        this.a6 = new Dictionary$2(Number_$type, Number_$type, 0);
        this.ba = new List$1(ColumnInfo.$, 0);
        this.a5 = new Dictionary$2(Number_$type, Number_$type, 0);
    }
    get actualVisibleRegion() {
        return this._actualVisibleRegion;
    }
    set actualVisibleRegion(a) {
        this._actualVisibleRegion = a;
    }
    get absoluteWidth() {
        return this._absoluteWidth;
    }
    set absoluteWidth(a) {
        this._absoluteWidth = a;
    }
    get absoluteHeight() {
        return this._absoluteHeight;
    }
    set absoluteHeight(a) {
        this._absoluteHeight = a;
    }
    get bk() {
        return truncate(this.actualVisibleRegion.top);
    }
    get bi() {
        return truncate(this.actualVisibleRegion.left);
    }
    get bj() {
        return truncate(this.actualVisibleRegion.right);
    }
    get bh() {
        return truncate(this.actualVisibleRegion.height);
    }
    get bl() {
        return truncate(this.actualVisibleRegion.width);
    }
    get ao() {
        return this.u;
    }
    set ao(a) {
        this.u = a;
        this.b9();
    }
    get ab() {
        return this.h;
    }
    set ab(a) {
        this.h = a;
        this.b9();
    }
    get ar() {
        return this.x;
    }
    set ar(a) {
        this.x = a;
        this.b9();
    }
    get ae() {
        return this.k;
    }
    set ae(a) {
        this.k = a;
        this.b9();
    }
    get ac() {
        return this.i;
    }
    set ac(a) {
        this.i = a;
        this.b9();
    }
    get aq() {
        return this.w;
    }
    set aq(a) {
        this.w = a;
        this.b9();
    }
    get ap() {
        return this.v;
    }
    set ap(a) {
        this.v = a;
        this.b9();
    }
    get ag() {
        return this.m;
    }
    set ag(a) {
        this.m = a;
        this.b9();
    }
    get af() {
        return this.l;
    }
    set af(a) {
        this.l = a;
        this.b9();
    }
    get at() {
        return this.z;
    }
    set at(a) {
        this.z = a;
        this.b9();
    }
    get as() {
        return this.y;
    }
    set as(a) {
        this.y = a;
        this.b9();
    }
    get ad() {
        return this.j;
    }
    set ad(a) {
        this.j = a;
        this.b9();
    }
    get ah() {
        return this.n;
    }
    set ah(a) {
        this.n = a;
        this.b9();
    }
    get ai() {
        return this.o;
    }
    set ai(a) {
        this.o = a;
        this.b9();
    }
    get aj() {
        return this.p;
    }
    set aj(a) {
        this.p = a;
        this.b9();
    }
    get ak() {
        return this.q;
    }
    set ak(a) {
        this.q = a;
        this.b9();
    }
    get al() {
        return this.r;
    }
    set al(a) {
        this.r = a;
        this.b9();
    }
    get am() {
        return this.s;
    }
    set am(a) {
        this.s = a;
        this.b9();
    }
    get an() {
        return this.t;
    }
    set an(a) {
        this.t = a;
        this.b9();
    }
    get au() {
        return this.aa;
    }
    set au(a) {
        this.aa = a;
    }
    d(a, b) {
        a += this.actualVisibleRegion.left;
        b += this.actualVisibleRegion.top;
        let c = this.be;
        let d = c.count;
        for (let e = d - 1; e >= 0; e--) {
            if (c._inner[e] == this.ab) {
                break;
            }
            let f = c._inner[e].q;
            let g = c._inner[e].q.count;
            let h = c._inner[e].p;
            for (let i = 0; i < g; i++) {
                if (h._inner[i]) {
                    continue;
                }
                let j = f._inner[i];
                if (a >= j.br && a <= j.br + j.e2 && b >= j.bs && b <= j.bs + j.dt) {
                    this.c = j;
                    return j;
                }
            }
        }
        if (this.c != null) {
            let k = this.c;
            if (a >= k.br && a <= k.br + k.e2 && b >= k.bs && b <= k.bs + k.dt) {
                this.c = k;
                return k;
            }
        }
        c = this.be;
        d = c.count;
        for (let l = d - 1; l >= 0; l--) {
            let m = c._inner[l].q;
            let n = c._inner[l].q.count;
            let o = c._inner[l].p;
            for (let p = 0; p < n; p++) {
                if (o._inner[p]) {
                    continue;
                }
                let q = m._inner[p];
                if (a >= q.br && a <= q.br + q.e2 && b >= q.bs && b <= q.bs + q.dt) {
                    this.c = q;
                    return q;
                }
            }
        }
        return null;
    }
    get ay() {
        return this.ax;
    }
    set ay(a) {
        this.ax = a;
    }
    get bg() {
        while (this.a8.count < this.a9.count) {
            this.a8.add(new GridColumnSpacerCollection());
        }
        return this.a8;
    }
    set bg(a) {
        this.a8 = a;
    }
    a2() {
        if (this.aw != null && this.av != null && this.aw.s >= 0 && this.av.s >= 0) {
            return true;
        }
        return false;
    }
    f(a) {
        if (a == this.b2) {
            return this.e;
        }
        let b = null;
        if (this.a4.containsKey(a)) {
            b = this.a9._inner[this.a4.item(a)];
        }
        else if (this.a5.containsKey(a)) {
            b = this.ba._inner[this.a5.item(a)];
        }
        else if (this.a6.containsKey(a)) {
            b = this.bb._inner[this.a6.item(a)];
        }
        this.b2 = a;
        this.e = b;
        return b;
    }
    b3(a) {
        this.a9.add(a);
        this.a4.addItem(a.m, this.a9.count - 1);
    }
    b4(a) {
        this.ba.add(a);
        this.a5.addItem(a.m, this.ba.count - 1);
    }
    b5(a) {
        this.bb.add(a);
        this.a6.addItem(a.m, this.ba.count - 1);
    }
    b9() {
        this.a7 = new List$1(GridLayer.$, 0);
        this.a7.add(this.ao);
        this.a7.add(this.ab);
        this.a7.add(this.ar);
        this.a7.add(this.ac);
        this.a7.add(this.ai);
        this.a7.add(this.ah);
        this.a7.add(this.aj);
        this.a7.add(this.al);
        this.a7.add(this.ak);
        this.a7.add(this.am);
        this.a7.add(this.an);
        this.a7.add(this.ae);
        this.a7.add(this.aq);
        this.a7.add(this.ap);
        this.a7.add(this.ag);
        this.a7.add(this.af);
        this.a7.add(this.at);
        this.a7.add(this.as);
        this.a7.add(this.ad);
        this.a7.add(this.au);
    }
    get be() {
        return this.a7;
    }
    az() {
        for (let a = 0; a < this.a7.count; a++) {
            for (let b = 0; b < this.a7._inner[a].o.count; b++) {
                if (this.a7._inner[a].p._inner[b]) {
                    continue;
                }
                let c = this.a7._inner[a].o._inner[b];
                let d = this.a7._inner[a].q._inner[b];
                if (c != d.i) {
                    return false;
                }
            }
        }
        return true;
    }
    b8() {
        this.e = null;
        this.b2 = -1;
        this.a9.clear();
        this.a4.clear();
        this.ba.clear();
        this.bb.clear();
    }
    b7() {
        this.b8();
        this.bf.clear();
        this.ab.u();
        this.ae.u();
        this.ac.u();
        this.ag.u();
        this.ad.u();
    }
    b() {
        let a = new VisualModelExport();
        a.k = new RectData(this.actualVisibleRegion.x, this.actualVisibleRegion.y, this.actualVisibleRegion.width, this.actualVisibleRegion.height);
        a.n = this.absoluteWidth;
        a.m = this.absoluteHeight;
        a.aa = this.bu;
        a.t = this.bs;
        a.s = this.br;
        a.q = this.bp;
        a.r = this.bq;
        a.o = this.bo;
        a.w = this.bz;
        a.x = this.b0;
        a.y = this.bk;
        a.v = this.bi;
        a.u = this.bh;
        a.z = this.bl;
        a.j = this.a(this.ao);
        a.a = this.a(this.ab);
        a.b = this.a(this.ac);
        a.d = this.a(this.ae);
        a.f = this.a(this.ag);
        a.e = this.a(this.af);
        a.c = this.a(this.ad);
        a.h = this.a(this.ah);
        a.i = this.a(this.ak);
        a.ad();
        return a;
    }
    a(a) {
        let b = new GridLayerExport(a.v);
        let c = a == this.ag;
        for (let d of fromEnum(a.n)) {
            let e = d.b(null);
            if (this.a0 && c) {
                e.q += this.bk;
            }
            b.e(e);
        }
        return b;
    }
    g(a, b, c, d, e) {
        let f = new GridColumnSpacer();
        f.i = c;
        f.j = c;
        f.f = d;
        f.n = b.m;
        f.d = e;
        this.bg._inner[a].add(f);
        return f;
    }
    b6(a) {
        let b = this.bg;
        for (let c = 0; c < b.count; c++) {
            let d = b._inner[c];
            for (let e = d.count - 1; e >= 0; e--) {
                if (d._inner[e].o == a.o) {
                    d.removeAt(e);
                }
            }
        }
    }
    bd(a) {
        let b = new List$1(GridColumnSpacer.$, 0);
        let c = this.bg;
        for (let d = 0; d < c.count; d++) {
            let e = c._inner[d];
            for (let f = e.count - 1; f >= 0; f--) {
                if (e._inner[f].n == a.m) {
                    b.add(e._inner[f]);
                }
            }
        }
        return b;
    }
    bc(a) {
        let b = new List$1(CellModel.$, 0);
        for (let c = 0; c < this.be.count; c++) {
            let d = new List$1(CellModel.$, 0);
            let e = this.be._inner[c];
            for (let f = 0; f < e.o.count; f++) {
                if (e.p._inner[f]) {
                    continue;
                }
                let g = e.q._inner[f];
                if (g.i.al == a.l && g.i.b == a.c) {
                    b.add(g);
                }
            }
        }
        return b;
    }
    bt() {
        let a = 0;
        for (let b = 0; b < this.bf.count; b++) {
            a += this.bf._inner[b].m;
        }
        return a;
    }
}
VisualModel.$t = markType(VisualModel, 'VisualModel');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Represents info about the current cell.
*/
class IgxCellInfo {
    constructor() {
        this._onChanged = [];
        this._changed = false;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return null;
    }
    get i() {
        return this._implementation;
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    onImplementationCreated() {
    }
    addOnChangedListener(listener) {
        if (this._onChanged.length == 0) {
            this.i.propertyChanged = delegateCombine(this.i.propertyChanged, runOn(this, this._implementation_propertyChanged));
            this.i.cellReconciling = delegateCombine(this.i.cellReconciling, runOn(this, this._implementation_cellReconciling));
        }
        this._onChanged.push(listener);
    }
    removeOnChangedListener(listener) {
        let ind = this._onChanged.indexOf(listener);
        if (ind < 0) {
            return;
        }
        this._onChanged.splice(ind, 1);
        if (this._onChanged.length == 0) {
            this.i.propertyChanged = delegateRemove(this.i.propertyChanged, runOn(this, this._implementation_propertyChanged));
            this.i.cellReconciling = delegateRemove(this.i.cellReconciling, runOn(this, this._implementation_cellReconciling));
        }
    }
    _implementation_propertyChanged(sender, args) {
        this._changed = true;
    }
    _implementation_cellReconciling(model) {
        if (this._changed && this._onChanged !== null && this._onChanged.length > 0) {
            this._changed = false;
            for (let i = 0; i < this._onChanged.length; i++) {
                this._onChanged[i]();
            }
        }
        this._changed = false;
    }
    get resolvedTextAlign() {
        switch (this.horizontalAlignment) {
            case CellContentHorizontalAlignment.Center:
                return "center";
            case CellContentHorizontalAlignment.Left:
                return "left";
            case CellContentHorizontalAlignment.Right:
                return "right";
            case CellContentHorizontalAlignment.Stretch:
                return "center";
        }
        return "left";
    }
    get resolvedContentOpacity() {
        let virtualPercent = Math.min(1.0, Math.max(0.0, this.virtualizationPercentage));
        let opacity = this.contentOpacity * (1.0 - virtualPercent);
        return opacity;
    }
    /**
 * Gets the style key of the current cell, used for recycling.
*/
    get styleKey() {
        return this.i.g1;
    }
    set styleKey(v) {
        this.i.g1 = v;
    }
    /**
     * Gets the absolute data row for the current cell.
    */
    get dataRow() {
        return this.i.dq;
    }
    set dataRow(v) {
        this.i.dq = +v;
    }
    /**
     * Gets if the position of the cell is dirty.
    */
    get isPositionDirty() {
        return this.i.aq;
    }
    set isPositionDirty(v) {
        this.i.aq = ensureBool(v);
    }
    /**
     * Gets if the size of the cell is dirty.
    */
    get isSizeDirty() {
        return this.i.av;
    }
    set isSizeDirty(v) {
        this.i.av = ensureBool(v);
    }
    /**
     * Gets if the content of the cell is dirty.
    */
    get isContentDirty() {
        return this.i.ah;
    }
    set isContentDirty(v) {
        this.i.ah = ensureBool(v);
    }
    /**
     * Gets if the content of the cell is dirty.
    */
    get isBorderDirty() {
        return this.i.af;
    }
    set isBorderDirty(v) {
        this.i.af = ensureBool(v);
    }
    /**
     * Gets if the layer of the cell is dirty.
    */
    get isLayerDirty() {
        return this.i.ao;
    }
    set isLayerDirty(v) {
        this.i.ao = ensureBool(v);
    }
    /**
     * Gets if the layer of the cell is dirty.
    */
    get isStateDirty() {
        return this.i.aw;
    }
    set isStateDirty(v) {
        this.i.aw = ensureBool(v);
    }
    /**
     * Gets if the data of the cell is dirty.
    */
    get isDataDirty() {
        return this.i.aj;
    }
    set isDataDirty(v) {
        this.i.aj = ensureBool(v);
    }
    /**
     * Gets if placeholder content is needed when virtualized.
    */
    get isPlaceholdContentNeeded() {
        return this.i.ap;
    }
    set isPlaceholdContentNeeded(v) {
        this.i.ap = ensureBool(v);
    }
    /**
     * Gets the action manager to propagate actions back to the grid.
    */
    get actionManager() {
        return this.i.c;
    }
    set actionManager(v) {
        this.i.c = v;
    }
    /**
     * Gets if this cell belongs to a row that has been marked as pinned.
    */
    get isRowPinned() {
        return this.i.ar;
    }
    set isRowPinned(v) {
        this.i.ar = ensureBool(v);
    }
    /**
     * Gets if this cell belongs to a row that will stick to the top of the grid.
    */
    get isRowSticky() {
        return this.i.as;
    }
    set isRowSticky(v) {
        this.i.as = ensureBool(v);
    }
    /**
     * Gets if this cell is the last row that can stick to the top of the grid.
    */
    get isLastStickyRow() {
        return this.i.an;
    }
    set isLastStickyRow(v) {
        this.i.an = ensureBool(v);
    }
    /**
     * Gets the indent level of the cell.
    */
    get indent() {
        return this.i.dw;
    }
    set indent(v) {
        this.i.dw = +v;
    }
    get rowItem() {
        return this.i.fc;
    }
    set rowItem(v) {
        this.i.fc = v;
    }
    /**
     * Gets the X position of the cell within the content.
    */
    get x() {
        return this.i.br;
    }
    set x(v) {
        this.i.br = +v;
    }
    /**
     * Gets the Y position of the cell within the content.
    */
    get y() {
        return this.i.bs;
    }
    set y(v) {
        this.i.bs = +v;
    }
    /**
     * Gets the pixel snapped X position of the cell within the content.
    */
    get snappedX() {
        return this.i.ep;
    }
    set snappedX(v) {
        this.i.ep = +v;
    }
    /**
     * Gets the snapped Y position of the cell within the content.
    */
    get snappedY() {
        return this.i.er;
    }
    set snappedY(v) {
        this.i.er = +v;
    }
    /**
     * Gets or sets the opacity of the content of the cell.
    */
    get contentOpacity() {
        return this.i.bi;
    }
    set contentOpacity(v) {
        this.i.bi = +v;
    }
    /**
     * Gets or sets the opacity of the cell.
    */
    get opacity() {
        return this.i.bl;
    }
    set opacity(v) {
        this.i.bl = +v;
    }
    /**
     * Gets the actual opacity of the cell.
    */
    get actualOpacity() {
        return this.i.bh;
    }
    set actualOpacity(v) {
        this.i.bh = +v;
    }
    /**
     * Gets the height of the cell.
    */
    get height() {
        return this.i.dt;
    }
    set height(v) {
        this.i.dt = +v;
    }
    /**
     * Gets the width of the cell.
    */
    get width() {
        return this.i.e2;
    }
    set width(v) {
        this.i.e2 = +v;
    }
    /**
     * Gets if the cell is selected.
    */
    get isSelected() {
        return this.i.au;
    }
    set isSelected(v) {
        this.i.au = ensureBool(v);
    }
    /**
     * Gets the amount that the cell is selected. This is a value between 0 and 1.
    */
    get selectedStatus() {
        return this.i.bn;
    }
    set selectedStatus(v) {
        this.i.bn = +v;
    }
    /**
     * Gets the amount that the cell is activated. This is a value between 0 and 1.
    */
    get activationStatus() {
        return this.i.bg;
    }
    set activationStatus(v) {
        this.i.bg = +v;
    }
    /**
     * Gets or sets the horiztonal alignment of the cell content.
    */
    get horizontalAlignment() {
        return this.i.e;
    }
    set horizontalAlignment(v) {
        this.i.e = ensureEnum(CellContentHorizontalAlignment_$type, v);
    }
    /**
     * Gets or sets the vertical alignment of the cell content.
    */
    get verticalAlignment() {
        return this.i.g;
    }
    set verticalAlignment(v) {
        this.i.g = ensureEnum(CellContentVerticalAlignment_$type, v);
    }
    /**
     * Gets or sets the background color of the cell.
    */
    get background() {
        return brushToString(this.i.h7);
    }
    set background(v) {
        this.i.h7 = stringToBrush(v);
    }
    /**
     * Gets or sets the border color of the cell.
    */
    get border() {
        return brushToString(this.i.h8);
    }
    set border(v) {
        this.i.h8 = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the cell
    */
    get actualBackground() {
        return brushToString(this.i.h5);
    }
    set actualBackground(v) {
        this.i.h5 = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the cell
    */
    get actualBorder() {
        return brushToString(this.i.h6);
    }
    set actualBorder(v) {
        this.i.h6 = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the cell
    */
    get activationBorder() {
        return brushToString(this.i.h4);
    }
    set activationBorder(v) {
        this.i.h4 = stringToBrush(v);
    }
    /**
     * Gets or sets the selected background color of the cell.
    */
    get selectedBackground() {
        return brushToString(this.i.ic);
    }
    set selectedBackground(v) {
        this.i.ic = stringToBrush(v);
    }
    /**
     * Gets or sets the color for the sort indicator icon.
    */
    get sortIndicatorColor() {
        return brushToString(this.i.id);
    }
    set sortIndicatorColor(v) {
        this.i.id = stringToBrush(v);
    }
    /**
     * Gets or sets the background color for the cell when it is stuck to the top of the grid as a pinned row.
    */
    get stickyRowBackground() {
        return brushToString(this.i.ie);
    }
    set stickyRowBackground(v) {
        this.i.ie = stringToBrush(v);
    }
    /**
     * Gets or sets the background color for the cell that has been marked as pinned.
    */
    get pinnedRowBackground() {
        return brushToString(this.i.ib);
    }
    set pinnedRowBackground(v) {
        this.i.ib = stringToBrush(v);
    }
    /**
     * Gets or sets the color for the last row in the sticky row area.
    */
    get lastStickyRowBackground() {
        return brushToString(this.i.ia);
    }
    set lastStickyRowBackground(v) {
        this.i.ia = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for displaying text.
    */
    get pinnedRowOpacity() {
        return this.i.bm;
    }
    set pinnedRowOpacity(v) {
        this.i.bm = +v;
    }
    /**
     * Gets or sets the original value for the cell, before processing.
    */
    get originalValue() {
        return this.i.fb;
    }
    set originalValue(v) {
        this.i.fb = v;
    }
    /**
     * Gets or sets the text value, if any, which was rendered by a text cell.
    */
    get renderValue() {
        return this.i.gq;
    }
    set renderValue(v) {
        this.i.gq = v;
    }
    /**
     * Gets or sets the color of the text for the cell, if any.
    */
    get textColor() {
        return brushToString(this.i.ig);
    }
    set textColor(v) {
        this.i.ig = stringToBrush(v);
    }
    get font() {
        if (this.i.x == null) {
            return null;
        }
        return this.i.x.fontString;
    }
    set font(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.x = fi;
    }
    /**
     * Gets or sets the line break mode to use if text is present in the cell.
    */
    get lineBreakMode() {
        return this.i.v;
    }
    set lineBreakMode(v) {
        this.i.v = ensureEnum(TextCellLineBreakMode_$type, v);
    }
    /**
     * Gets or sets the virtualization percentage value. This is between 0 an 1, and indicates how virtual the content is at present.
    */
    get virtualizationPercentage() {
        return this.i.bq;
    }
    set virtualizationPercentage(v) {
        this.i.bq = +v;
    }
    /**
     * Gets or sets the left padding to use for the content.
    */
    get paddingLeft() {
        return this.i.ed;
    }
    set paddingLeft(v) {
        this.i.ed = +v;
    }
    /**
     * Gets or sets the top padding to use for the content.
    */
    get paddingTop() {
        return this.i.eh;
    }
    set paddingTop(v) {
        this.i.eh = +v;
    }
    /**
     * Gets or sets the right padding to use for the content.
    */
    get paddingRight() {
        return this.i.ef;
    }
    set paddingRight(v) {
        this.i.ef = +v;
    }
    /**
     * Gets or sets the bottom padding to use for the content.
    */
    get paddingBottom() {
        return this.i.eb;
    }
    set paddingBottom(v) {
        this.i.eb = +v;
    }
    /**
     * Gets or sets the left padding to use for the content.
    */
    get actualPaddingLeft() {
        return this.i.c8;
    }
    set actualPaddingLeft(v) {
        this.i.c8 = +v;
    }
    /**
     * Gets or sets the top padding to use for the content.
    */
    get actualPaddingTop() {
        return this.i.dc;
    }
    set actualPaddingTop(v) {
        this.i.dc = +v;
    }
    /**
     * Gets or sets the right padding to use for the content.
    */
    get actualPaddingRight() {
        return this.i.da;
    }
    set actualPaddingRight(v) {
        this.i.da = +v;
    }
    /**
     * Gets or sets the bottom padding to use for the content.
    */
    get actualPaddingBottom() {
        return this.i.c6;
    }
    set actualPaddingBottom(v) {
        this.i.c6 = +v;
    }
    /**
     * Gets or sets the left border to use for the content.
    */
    get borderLeftWidth() {
        return this.i.dh;
    }
    set borderLeftWidth(v) {
        this.i.dh = +v;
    }
    /**
     * Gets or sets the top border to use for the content.
    */
    get borderTopWidth() {
        return this.i.dm;
    }
    set borderTopWidth(v) {
        this.i.dm = +v;
    }
    /**
     * Gets or sets the right border to use for the content.
    */
    get borderRightWidth() {
        return this.i.dk;
    }
    set borderRightWidth(v) {
        this.i.dk = +v;
    }
    /**
     * Gets or sets the bottom border to use for the content.
    */
    get borderBottomWidth() {
        return this.i.df;
    }
    set borderBottomWidth(v) {
        this.i.df = +v;
    }
    /**
     * Gets or sets the left activation border to use for the content.
    */
    get activationBorderLeftWidth() {
        return this.i.cn;
    }
    set activationBorderLeftWidth(v) {
        this.i.cn = +v;
    }
    /**
     * Gets or sets the top activation border to use for the content.
    */
    get activationBorderTopWidth() {
        return this.i.cs;
    }
    set activationBorderTopWidth(v) {
        this.i.cs = +v;
    }
    /**
     * Gets or sets the right activation border to use for the content.
    */
    get activationBorderRightWidth() {
        return this.i.cq;
    }
    set activationBorderRightWidth(v) {
        this.i.cq = +v;
    }
    /**
     * Gets or sets the bottom activation border to use for the content.
    */
    get activationBorderBottomWidth() {
        return this.i.cl;
    }
    set activationBorderBottomWidth(v) {
        this.i.cl = +v;
    }
    /**
     * Gets or sets the actual left border to use for the content.
    */
    get actualBorderLeftWidth() {
        return this.i.cy;
    }
    set actualBorderLeftWidth(v) {
        this.i.cy = +v;
    }
    /**
     * Gets or sets the actual top border to use for the content.
    */
    get actualBorderTopWidth() {
        return this.i.c3;
    }
    set actualBorderTopWidth(v) {
        this.i.c3 = +v;
    }
    /**
     * Gets or sets the actual right border to use for the content.
    */
    get actualBorderRightWidth() {
        return this.i.c1;
    }
    set actualBorderRightWidth(v) {
        this.i.c1 = +v;
    }
    /**
     * Gets or sets the actual bottom border to use for the content.
    */
    get actualBorderBottomWidth() {
        return this.i.cw;
    }
    set actualBorderBottomWidth(v) {
        this.i.cw = +v;
    }
    /**
     * Gets the current sort direction for the column containing the cell.
    */
    get sortDirection() {
        return this.i.k;
    }
    set sortDirection(v) {
        this.i.k = ensureEnum(ColumnSortDirection_$type, v);
    }
    /**
     * Gets the expansion state of the cell.
    */
    get isExpanded() {
        return this.i.am;
    }
    set isExpanded(v) {
        this.i.am = ensureBool(v);
    }
    /**
     * Gets if the cell needs to display an expansion indicator.
    */
    get isCollapsable() {
        return this.i.ag;
    }
    set isCollapsable(v) {
        this.i.ag = ensureBool(v);
    }
    isCustomFieldDirty(propertyName) {
        let iv = this.i.ai(propertyName);
        return (iv);
    }
    /**
     * Gets if a named property is dirty.
    
    * @param propertyId  * The property id to check.
    */
    isDirtyById(propertyId_) {
        let iv = this.i.al(propertyId_);
        return (iv);
    }
    /**
     * Gets if a named property is dirty.
    
    * @param propertyName  * The property name to check.
    */
    isDirty(propertyName) {
        let iv = this.i.ak(propertyName);
        return (iv);
    }
    setNamedValue(valueName, value) {
        this.i.hr(valueName, value);
    }
    /**
     * Returns if there is a named value stored for the cell.
    
    * @param valueName  * The name of the value to check.
    */
    hasNamedValue(valueName) {
        let iv = this.i.ae(valueName);
        return (iv);
    }
    /**
     * Removes a named value from the cell.
    
    * @param valueName  * The name of the value to remove.
    */
    removeNamedValue(valueName) {
        this.i.ho(valueName);
    }
    /**
     * Gets a named value from the cell.
    
    * @param valueName  * The name of the value to get.
    */
    getNamedValue(valueName) {
        let iv = this.i.e9(valueName);
        return (iv);
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Backing information about a date time cell for the grid.
*/
class IgxDateTimeCellInfo extends IgxCellInfo {
    createImplementation() {
        return new DateTimeCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets the DateTime value for the cell.
    */
    get dateTimeValue() {
        return this.i.ip;
    }
    set dateTimeValue(v) {
        this.i.ip = v;
    }
    /**
     * The format options to apply to the value
    */
    get formatOverride() {
        return this.i.ix;
    }
    set formatOverride(v) {
        this.i.ix = v;
    }
    /**
     * Sets or gets the simple DateTimeFormat to use for the cell.
    */
    get dateTimeFormat() {
        return this.i.ik;
    }
    set dateTimeFormat(v) {
        this.i.ik = ensureEnum(DateTimeFormats_$type, v);
    }
    /**
     * Sets or gets whether the value to use is a DateTimeOffset value.
    */
    get isOffsetValue() {
        return this.i.im;
    }
    set isOffsetValue(v) {
        this.i.im = ensureBool(v);
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Backing information for an image cell in the grid.
*/
class IgxImageCellInfo extends IgxCellInfo {
    createImplementation() {
        return new ImageCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets the resource path to use to get the image for the cell.
    */
    get imagePath() {
        return this.i.iq;
    }
    set imagePath(v) {
        this.i.iq = v;
    }
    /**
     * Sets or gets the image stretching behavior for the image.
    */
    get imageStretchOption() {
        return this.i.ik;
    }
    set imageStretchOption(v) {
        this.i.ik = ensureEnum(ImageStretchOptions_$type, v);
    }
    /**
     * Sets or gets the image resource type. Indicates which type of resource should be fetched and how ImagePath should be interpreted.
    */
    get imageResourceType() {
        return this.i.ii;
    }
    set imageResourceType(v) {
        this.i.ii = ensureEnum(ImageResourceType_$type, v);
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Backing information for a numeric cell in the grid.
*/
class IgxNumericCellInfo extends IgxCellInfo {
    createImplementation() {
        return new NumericCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets the numeric value to use for the cell.
    */
    get numericValue() {
        return this.i.io;
    }
    set numericValue(v) {
        this.i.io = +v;
    }
    /**
     * Sets or gets whether there is a decimal numeric value to use for the cell.
    */
    get hasDecimalValue() {
        return this.i.ij;
    }
    set hasDecimalValue(v) {
        this.i.ij = ensureBool(v);
    }
    /**
     * The format options to apply to the value
    */
    get formatOverride() {
        return this.i.i8;
    }
    set formatOverride(v) {
        this.i.i8 = v;
    }
    /**
     * Sets or gets the text prepended to a negative numeric value
    */
    get negativePrefix() {
        return this.i.ji;
    }
    set negativePrefix(v) {
        this.i.ji = v;
    }
    /**
     * Sets or gets the text prepended to a positive numeric value
    */
    get positivePrefix() {
        return this.i.jn;
    }
    set positivePrefix(v) {
        this.i.jn = v;
    }
    /**
     * Sets or gets the text appended to a negative numeric value
    */
    get negativeSuffix() {
        return this.i.jk;
    }
    set negativeSuffix(v) {
        this.i.jk = v;
    }
    /**
     * Sets or gets the text appended to a positive numeric value
    */
    get positiveSuffix() {
        return this.i.jp;
    }
    set positiveSuffix(v) {
        this.i.jp = v;
    }
    /**
     * The maximum number of decimal places to display when formatting
    */
    get maxFractionDigits() {
        return this.i.iu;
    }
    set maxFractionDigits(v) {
        this.i.iu = +v;
    }
    /**
     * The minimum number of decimal places to display when formatting
    */
    get minFractionDigits() {
        return this.i.iw;
    }
    set minFractionDigits(v) {
        this.i.iw = +v;
    }
    /**
     * The minimum number of integer digits to display when formatting
    */
    get minIntegerDigits() {
        return this.i.iy;
    }
    set minIntegerDigits(v) {
        this.i.iy = +v;
    }
    /**
     * Sets or gets if the grouping separator is shown
    */
    get showGroupingSeparator() {
        return this.i.il;
    }
    set showGroupingSeparator(v) {
        this.i.il = ensureBool(v);
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Represents backing information for the row separators.
*/
class IgxRowSeparatorInfo extends IgxCellInfo {
    createImplementation() {
        return new RowSeparatorModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Backing information for a section header cell in the grid.
*/
class IgxSectionHeaderCellInfo extends IgxCellInfo {
    createImplementation() {
        return new SectionHeaderCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets the resolved text for the section header cell.
    */
    get resolvedText() {
        return this.i.iy;
    }
    set resolvedText(v) {
        this.i.iy = v;
    }
    /**
     * Sets or gets the resolved summary text for the section header cell.
    */
    get resolvedSummaryText() {
        return this.i.iw;
    }
    set resolvedSummaryText(v) {
        this.i.iw = v;
    }
    /**
     * Sets or gets how summaries are displayed in the section header cell.
    */
    get summaryDisplayMode() {
        return this.i.im;
    }
    set summaryDisplayMode(v) {
        this.i.im = ensureEnum(GroupSummaryDisplayMode_$type, v);
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Represents backing information for a template cell.
*/
class IgxTemplateCellInfo extends IgxCellInfo {
    createImplementation() {
        return new TemplateCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets the value to provide to the template.
    */
    get value() {
        return this.i.ij;
    }
    set value(v) {
        this.i.ij = v;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateHeaderCellModelExport extends CellModelExport {
    constructor() {
        super(...arguments);
        this.ac = null;
    }
    get_aa() {
        return "TemplateHeaderCell";
    }
    ab(a) {
        super.ab(a);
    }
}
TemplateHeaderCellModelExport.$t = markType(TemplateHeaderCellModelExport, 'TemplateHeaderCellModelExport', CellModelExport.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateHeaderCellModel extends TemplateCellModel {
    constructor() {
        super(...arguments);
        this.il = false;
    }
    get im() {
        return this.il;
    }
    set im(a) {
        let b = this.il;
        this.il = a;
        if (this.il != b) {
            this.hl("IsFilterUIVisible", TemplateHeaderCellModel.io, b, this.il);
        }
    }
    hs(a, b) {
        super.hs(a, b);
        if (a == "IsFilterUIVisible") {
            this.im = b;
        }
    }
    fa(a) {
        if (a == "IsFilterUIVisible") {
            return this.im;
        }
        return super.fa(a);
    }
    b(a) {
        if (a == null) {
            a = new TemplateHeaderCellModelExport();
        }
        a = super.b(a);
        let b = a;
        b.ac = this.ij;
        return b;
    }
}
TemplateHeaderCellModel.$t = markType(TemplateHeaderCellModel, 'TemplateHeaderCellModel', TemplateCellModel.$);
TemplateHeaderCellModel.io = CellModel.ds("IsFilterUIVisible");

/**
 * Backing information for the template header cells.
*/
class IgxTemplateHeaderCellInfo extends IgxTemplateCellInfo {
    createImplementation() {
        return new TemplateHeaderCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets whether the filter UI should be visible in the header.
    */
    get isFilterUIVisible() {
        return this.i.im;
    }
    set isFilterUIVisible(v) {
        this.i.im = ensureBool(v);
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateSectionHeaderCellModel extends SectionHeaderCellModel {
}
TemplateSectionHeaderCellModel.$t = markType(TemplateSectionHeaderCellModel, 'TemplateSectionHeaderCellModel', SectionHeaderCellModel.$);

/**
 * Backing information for a template section header cell in the grid.
*/
class IgxTemplateSectionHeaderCellInfo extends IgxSectionHeaderCellInfo {
    createImplementation() {
        return new TemplateSectionHeaderCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Backing information for a text cell in the grid.
*/
class IgxTextCellInfo extends IgxCellInfo {
    createImplementation() {
        return new TextCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets the text value for the cell.
    */
    get textValue() {
        return this.i.ij;
    }
    set textValue(v) {
        this.i.ij = v;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Backing information for a text header cell.
*/
class IgxTextHeaderCellInfo extends IgxTextCellInfo {
    createImplementation() {
        return new TextHeaderCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets whether the filter UI should be visible in the header.
    */
    get isFilterUIVisible() {
        return this.i.ip;
    }
    set isFilterUIVisible(v) {
        this.i.ip = ensureBool(v);
    }
    get sortIndicatorStyle() {
        return this.i.im;
    }
    set sortIndicatorStyle(v) {
        this.i.im = ensureEnum(SortIndicatorStyle_$type, v);
    }
}

/**
 * Information about the data binding taking place.
*/
class IgxDataBindingEventArgs {
    createImplementation() {
        return new DataBindingEventArgs();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The backing information for the current cell.
    */
    get cellInfo() {
        if (this.i.cellInfo == null) {
            return null;
        }
        if (!this.i.cellInfo.externalObject) {
            let ext = null;
            switch (this.i.cellInfo.$type.name) {
                case "DateTimeCellModel":
                    ext = new IgxDateTimeCellInfo();
                    break;
                case "ImageCellModel":
                    ext = new IgxImageCellInfo();
                    break;
                case "NumericCellModel":
                    ext = new IgxNumericCellInfo();
                    break;
                case "RowSeparatorModel":
                    ext = new IgxRowSeparatorInfo();
                    break;
                case "SectionHeaderCellModel":
                    ext = new IgxSectionHeaderCellInfo();
                    break;
                case "TemplateCellModel":
                    ext = new IgxTemplateCellInfo();
                    break;
                case "TemplateHeaderCellModel":
                    ext = new IgxTemplateHeaderCellInfo();
                    break;
                case "TemplateSectionHeaderCellModel":
                    ext = new IgxTemplateSectionHeaderCellInfo();
                    break;
                case "TextCellModel":
                    ext = new IgxTextCellInfo();
                    break;
                case "TextHeaderCellModel":
                    ext = new IgxTextHeaderCellInfo();
                    break;
            }
            ext._implementation = this.i.cellInfo;
            this.i.cellInfo.externalObject = ext;
        }
        return this.i.cellInfo.externalObject;
    }
    /**
 * The resolved value for the cell.
*/
    get resolvedValue() {
        return this.i.resolvedValue;
    }
    set resolvedValue(v) {
        this.i.resolvedValue = v;
    }
    /**
     * The data for the row in which the cell is contained.
    */
    get rowObject() {
        return this.i.rowObject;
    }
    set rowObject(v) {
        this.i.rowObject = v;
    }
}

/**
 * Information about the style request for a cell.
*/
class IgxCellStyleRequestedEventArgs {
    createImplementation() {
        return new CellStyleRequestedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The proposed style key for the cell. Used for recycling the cell.
    */
    get styleKey() {
        return this.i.styleKey;
    }
    set styleKey(v) {
        this.i.styleKey = v;
    }
    /**
     * The resolved value for the cell.
    */
    get resolvedValue() {
        return this.i.resolvedValue;
    }
    set resolvedValue(v) {
        this.i.resolvedValue = v;
    }
    /**
     * The row number for the cell.
    */
    get rowNumber() {
        return this.i.rowNumber;
    }
    set rowNumber(v) {
        this.i.rowNumber = +v;
    }
}

/**
 * Base class for various definition types for the grid.
*/
class IgxDefinitionBaseComponent {
    constructor() {
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._renderer = null;
        this._dataBinding = null;
        this._dataBound = null;
        this._cellStyleKeyRequested = null;
        this._zoneRunner = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return null;
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igx" + name + "Component";
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    ngOnInit() {
    }
    onImplementationCreated() {
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        this._stylingContainer = container;
        this._stylingParent = component;
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        let grid = component._grid;
        var prev;
        if (grid) {
            prev = grid.columnPropertyUpdatingAnimationMode;
            grid.columnPropertyUpdatingAnimationMode = ColumnPropertyUpdatingAnimationMode.None;
        }
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        let lowerTypeName = typeName.toLowerCase();
        if (lowerTypeName.indexOf("column") >= 0) {
            genericPrefix = "column";
        }
        else if (lowerTypeName.indexOf("sectionheader") >= 0) {
            genericPrefix = "section-header";
        }
        else if (lowerTypeName.indexOf("sectionfooter") >= 0) {
            genericPrefix = "section-footer";
        }
        else if (lowerTypeName.indexOf("rowseparator") >= 0) {
            genericPrefix = "row-separator";
        }
        else {
            genericPrefix = "header";
        }
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName == "Grid") {
                parentTypeName = "LiveGrid";
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (grid) {
            grid.columnPropertyUpdatingAnimationMode = prev;
        }
        this._inStyling = false;
    }
    _provideRenderer(renderer) {
        this._renderer = renderer;
        this._zoneRunner = (act) => renderer._ngZone.run(act);
    }
    /**
 * Gets or sets the background color to use.
*/
    get background() {
        return brushToString(this.i.dm);
    }
    set background(v) {
        this.i.dm = stringToBrush(v);
    }
    /**
     * Gets or sets the background color to use.
    */
    get border() {
        return brushToString(this.i.dn);
    }
    set border(v) {
        this.i.dn = stringToBrush(v);
    }
    /**
     * Gets or sets the background color to use.
    */
    get activationBorder() {
        return brushToString(this.i.de);
    }
    set activationBorder(v) {
        this.i.de = stringToBrush(v);
    }
    /**
     * Gets the actual border color that will be used.
    */
    get actualBorder() {
        return brushToString(this.i.dh);
    }
    set actualBorder(v) {
        this.i.dh = stringToBrush(v);
    }
    /**
     * Gets or sets the amount of left border to use for the cell content for this column.
    */
    get borderLeftWidth() {
        return this.i.ba;
    }
    set borderLeftWidth(v) {
        this.i.ba = +v;
    }
    /**
     * Gets or sets the amount of top border to use for the cell content for this column.
    */
    get borderTopWidth() {
        return this.i.bc;
    }
    set borderTopWidth(v) {
        this.i.bc = +v;
    }
    /**
     * Gets or sets the amount of right border to use for the cell content of this column.
    */
    get borderRightWidth() {
        return this.i.bb;
    }
    set borderRightWidth(v) {
        this.i.bb = +v;
    }
    /**
     * Gets or sets the amount of bottom border to use for the cell content of this column.
    */
    get borderBottomWidth() {
        return this.i.a9;
    }
    set borderBottomWidth(v) {
        this.i.a9 = +v;
    }
    /**
     * Gets or sets the amount of left activation border to use for the cell content for this column.
    */
    get activationBorderLeftWidth() {
        return this.i.a6;
    }
    set activationBorderLeftWidth(v) {
        this.i.a6 = +v;
    }
    /**
     * Gets or sets the amount of top activation border to use for the cell content for this column.
    */
    get activationBorderTopWidth() {
        return this.i.a8;
    }
    set activationBorderTopWidth(v) {
        this.i.a8 = +v;
    }
    /**
     * Gets or sets the amount of right activation border to use for the cell content of this column.
    */
    get activationBorderRightWidth() {
        return this.i.a7;
    }
    set activationBorderRightWidth(v) {
        this.i.a7 = +v;
    }
    /**
     * Gets or sets the amount of bottom activation border to use for the cell content of this column.
    */
    get activationBorderBottomWidth() {
        return this.i.a5;
    }
    set activationBorderBottomWidth(v) {
        this.i.a5 = +v;
    }
    /**
     * Gets the actual background color that will be used.
    */
    get actualBackground() {
        return brushToString(this.i.dg);
    }
    set actualBackground(v) {
        this.i.dg = stringToBrush(v);
    }
    /**
     * Gets the actual background color that will be used.
    */
    get actualActivationBorder() {
        return brushToString(this.i.df);
    }
    set actualActivationBorder(v) {
        this.i.df = stringToBrush(v);
    }
    /**
     * Gets or sets the background color for content that sticks to the top of the grid.
    */
    get stickyRowBackground() {
        return brushToString(this.i.dy);
    }
    set stickyRowBackground(v) {
        this.i.dy = stringToBrush(v);
    }
    /**
     * Gets the actual background color for content that sticks to the top of the grid.
    */
    get actualStickyRowBackground() {
        return brushToString(this.i.dk);
    }
    set actualStickyRowBackground(v) {
        this.i.dk = stringToBrush(v);
    }
    /**
     * Gets or sets the background color for cells belonging to rows marked as pinned.
    */
    get pinnedRowBackground() {
        return brushToString(this.i.dx);
    }
    set pinnedRowBackground(v) {
        this.i.dx = stringToBrush(v);
    }
    /**
     * Gets the actual background color for cells belonging to rows marked as pinned.
    */
    get actualPinnedRowBackground() {
        return brushToString(this.i.dj);
    }
    set actualPinnedRowBackground(v) {
        this.i.dj = stringToBrush(v);
    }
    /**
     * Gets or sets the color for the last row in the sticky row area.
    */
    get lastStickyRowBackground() {
        return brushToString(this.i.dw);
    }
    set lastStickyRowBackground(v) {
        this.i.dw = stringToBrush(v);
    }
    /**
     * Gets the actual color for the last row in the sticky row area.
    */
    get actualLastStickyRowBackground() {
        return brushToString(this.i.di);
    }
    set actualLastStickyRowBackground(v) {
        this.i.di = stringToBrush(v);
    }
    /**
     * Gets or sets the opacity of the content.
    */
    get contentOpacity() {
        return this.i.au;
    }
    set contentOpacity(v) {
        this.i.au = +v;
    }
    /**
     * Gets or sets the horizontal alignment to use for the cell content.
    */
    get horizontalAlignment() {
        return this.i.e;
    }
    set horizontalAlignment(v) {
        this.i.e = ensureEnum(CellContentHorizontalAlignment_$type, v);
    }
    /**
     * Gets or sets the vertical alignment to use for the cell content.
    */
    get verticalAlignment() {
        return this.i.j;
    }
    set verticalAlignment(v) {
        this.i.j = ensureEnum(CellContentVerticalAlignment_$type, v);
    }
    /**
     * Gets or sets the line breaking mode to use if text is present in the cell.
    */
    get lineBreakMode() {
        return this.i.y;
    }
    set lineBreakMode(v) {
        this.i.y = ensureEnum(TextCellLineBreakMode_$type, v);
    }
    /**
     * Gets the actual line break mode which will be used if text is present in the cell.
    */
    get actualLineBreakMode() {
        return this.i.x;
    }
    set actualLineBreakMode(v) {
        this.i.x = ensureEnum(TextCellLineBreakMode_$type, v);
    }
    /**
     * Gets or sets the color to use for displaying text.
    */
    get textColor() {
        return brushToString(this.i.dz);
    }
    set textColor(v) {
        this.i.dz = stringToBrush(v);
    }
    /**
     * Gets the actual color used for displaying text.
    */
    get actualTextColor() {
        return brushToString(this.i.dl);
    }
    set actualTextColor(v) {
        this.i.dl = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for displaying text.
    */
    get pinnedRowOpacity() {
        return this.i.aw;
    }
    set pinnedRowOpacity(v) {
        this.i.aw = +v;
    }
    /**
     * Gets or sets the color to use for displaying text.
    */
    get actualPinnedRowOpacity() {
        return this.i.at;
    }
    set actualPinnedRowOpacity(v) {
        this.i.at = +v;
    }
    get textStyle() {
        if (this.i.textStyle == null) {
            return null;
        }
        return this.i.textStyle.fontString;
    }
    set textStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.textStyle = fi;
    }
    setNamedValue(valueName, animationType, value) {
        this.i.cq(valueName, (animationType == null ? null : animationType), value);
    }
    /**
     * Returns if this definition has named value.
    
    */
    hasNamedValues() {
        let iv = this.i.ai();
        return (iv);
    }
    /**
     * Returns if this definition has a named value with a given name.
    
    * @param valueName  * The named value name to check for.
    */
    hasNamedValue(valueName) {
        let iv = this.i.ah(valueName);
        return (iv);
    }
    /**
     * Removes the named value from this definition by name.
    
    * @param valueName  * The named value name to remove.
    */
    removeNamedValue(valueName) {
        this.i.co(valueName);
    }
    /**
     * Gets the value for a named value from this definition.
    
    * @param valueName  * The named value name to check for.
    */
    getNamedValue(valueName) {
        let iv = this.i.bf(valueName);
        return (iv);
    }
    /**
     * Called when a cell is data binding.
    */
    get dataBinding() {
        if (this._dataBinding == null) {
            this._dataBinding = new EventEmitter();
            this.i.dataBinding = delegateCombine(this.i.dataBinding, (o, e) => {
                let outerArgs = new IgxDataBindingEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeDataBinding) {
                    this.beforeDataBinding(this, outerArgs);
                }
                this._dataBinding.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._dataBinding;
    }
    /**
     * Called when a cell has been data bound.
    */
    get dataBound() {
        if (this._dataBound == null) {
            this._dataBound = new EventEmitter();
            this.i.dataBound = delegateCombine(this.i.dataBound, (o, e) => {
                let outerArgs = new IgxDataBindingEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeDataBound) {
                    this.beforeDataBound(this, outerArgs);
                }
                this._dataBound.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._dataBound;
    }
    /**
     * Called when the style key for a cell is needed. Used for recycling the cell.
    */
    get cellStyleKeyRequested() {
        if (this._cellStyleKeyRequested == null) {
            this._cellStyleKeyRequested = new EventEmitter();
            this.i.cellStyleKeyRequested = delegateCombine(this.i.cellStyleKeyRequested, (o, e) => {
                let outerArgs = new IgxCellStyleRequestedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCellStyleKeyRequested) {
                    this.beforeCellStyleKeyRequested(this, outerArgs);
                }
                this._cellStyleKeyRequested.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._cellStyleKeyRequested;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "background", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "border", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "activationBorder", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualBorder", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "borderLeftWidth", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "borderTopWidth", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "borderRightWidth", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "borderBottomWidth", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "activationBorderLeftWidth", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "activationBorderTopWidth", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "activationBorderRightWidth", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "activationBorderBottomWidth", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualActivationBorder", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "stickyRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualStickyRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "pinnedRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualPinnedRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "lastStickyRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualLastStickyRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "contentOpacity", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "horizontalAlignment", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "verticalAlignment", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "lineBreakMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "actualLineBreakMode", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "textColor", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "actualTextColor", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "pinnedRowOpacity", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDefinitionBaseComponent.prototype, "actualPinnedRowOpacity", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxDefinitionBaseComponent.prototype, "textStyle", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxDefinitionBaseComponent.prototype, "dataBinding", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxDefinitionBaseComponent.prototype, "dataBound", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxDefinitionBaseComponent.prototype, "cellStyleKeyRequested", null);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxSectionHeaderComponent_1;
/**
 * Used to configure the appearance of the section header cells.
*/
const IgxSectionHeaderComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxSectionHeaderComponent) }];
let IgxSectionHeaderComponent = IgxSectionHeaderComponent_1 = class IgxSectionHeaderComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new SectionHeader();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    get selectedBackground() {
        return brushToString(this.i.es);
    }
    set selectedBackground(v) {
        this.i.es = stringToBrush(v);
    }
    get actualSelectedBackground() {
        return brushToString(this.i.er);
    }
    set actualSelectedBackground(v) {
        this.i.er = stringToBrush(v);
    }
    /**
     * Gets or sets the amount of left padding to use for the cell content for this column.
    */
    get paddingLeft() {
        return this.i.eb;
    }
    set paddingLeft(v) {
        this.i.eb = +v;
    }
    /**
     * Gets or sets the amount of top padding to use for the cell content for this column.
    */
    get paddingTop() {
        return this.i.ed;
    }
    set paddingTop(v) {
        this.i.ed = +v;
    }
    /**
     * Gets or sets the amount of right padding to use for the cell content of this column.
    */
    get paddingRight() {
        return this.i.ec;
    }
    set paddingRight(v) {
        this.i.ec = +v;
    }
    /**
     * Gets or sets the amount of bottom padding to use for the cell content of this column.
    */
    get paddingBottom() {
        return this.i.ea;
    }
    set paddingBottom(v) {
        this.i.ea = +v;
    }
    get isCollapsable() {
        return this.i.d5;
    }
    set isCollapsable(v) {
        this.i.d5 = ensureBool(v);
    }
    get summaryDisplayMode() {
        return this.i.d2;
    }
    set summaryDisplayMode(v) {
        this.i.d2 = ensureEnum(GroupSummaryDisplayMode_$type, v);
    }
};
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxSectionHeaderComponent.prototype, "selectedBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxSectionHeaderComponent.prototype, "actualSelectedBackground", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxSectionHeaderComponent.prototype, "paddingLeft", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxSectionHeaderComponent.prototype, "paddingTop", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxSectionHeaderComponent.prototype, "paddingRight", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxSectionHeaderComponent.prototype, "paddingBottom", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxSectionHeaderComponent.prototype, "isCollapsable", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxSectionHeaderComponent.prototype, "summaryDisplayMode", null);
IgxSectionHeaderComponent = IgxSectionHeaderComponent_1 = __decorate([
    Component({
        selector: 'igx-section-header',
        template: ``,
        providers: [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxSectionHeaderComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxSectionHeaderComponent);

const IgxSummaryRowComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxSummaryRowComponent) }];
class IgxSummaryRowComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    get selectedBackground() {
        return brushToString(this.i.eq);
    }
    set selectedBackground(v) {
        this.i.eq = stringToBrush(v);
    }
    get actualSelectedBackground() {
        return brushToString(this.i.en);
    }
    set actualSelectedBackground(v) {
        this.i.en = stringToBrush(v);
    }
    get summaryNameTextColor() {
        return brushToString(this.i.er);
    }
    set summaryNameTextColor(v) {
        this.i.er = stringToBrush(v);
    }
    get actualSummaryNameTextColor() {
        return brushToString(this.i.eo);
    }
    set actualSummaryNameTextColor(v) {
        this.i.eo = stringToBrush(v);
    }
    /**
     * Gets or sets the amount of left padding to use for the cell content for this column.
    */
    get paddingLeft() {
        return this.i.d5;
    }
    set paddingLeft(v) {
        this.i.d5 = +v;
    }
    /**
     * Gets or sets the amount of top padding to use for the cell content for this column.
    */
    get paddingTop() {
        return this.i.d7;
    }
    set paddingTop(v) {
        this.i.d7 = +v;
    }
    /**
     * Gets or sets the amount of right padding to use for the cell content of this column.
    */
    get paddingRight() {
        return this.i.d6;
    }
    set paddingRight(v) {
        this.i.d6 = +v;
    }
    /**
     * Gets or sets the amount of bottom padding to use for the cell content of this column.
    */
    get paddingBottom() {
        return this.i.d4;
    }
    set paddingBottom(v) {
        this.i.d4 = +v;
    }
}
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxSummaryRowComponent.prototype, "selectedBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxSummaryRowComponent.prototype, "actualSelectedBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxSummaryRowComponent.prototype, "summaryNameTextColor", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxSummaryRowComponent.prototype, "actualSummaryNameTextColor", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxSummaryRowComponent.prototype, "paddingLeft", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxSummaryRowComponent.prototype, "paddingTop", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxSummaryRowComponent.prototype, "paddingRight", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxSummaryRowComponent.prototype, "paddingBottom", null);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxSummaryRowRootComponent_1;
const IgxSummaryRowRootComponent_PROVIDERS = [{ provide: IgxSummaryRowComponent, useExisting: forwardRef(() => IgxSummaryRowRootComponent) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxSummaryRowRootComponent) }];
let IgxSummaryRowRootComponent = IgxSummaryRowRootComponent_1 = class IgxSummaryRowRootComponent extends IgxSummaryRowComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new SummaryRowRoot();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
};
IgxSummaryRowRootComponent = IgxSummaryRowRootComponent_1 = __decorate([
    Component({
        selector: 'igx-summary-row-root',
        template: ``,
        providers: [{ provide: IgxSummaryRowComponent, useExisting: forwardRef(() => IgxSummaryRowRootComponent_1) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxSummaryRowRootComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxSummaryRowRootComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxSummaryRowSectionComponent_1;
const IgxSummaryRowSectionComponent_PROVIDERS = [{ provide: IgxSummaryRowComponent, useExisting: forwardRef(() => IgxSummaryRowSectionComponent) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxSummaryRowSectionComponent) }];
let IgxSummaryRowSectionComponent = IgxSummaryRowSectionComponent_1 = class IgxSummaryRowSectionComponent extends IgxSummaryRowComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new SummaryRowSection();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
};
IgxSummaryRowSectionComponent = IgxSummaryRowSectionComponent_1 = __decorate([
    Component({
        selector: 'igx-summary-row-section',
        template: ``,
        providers: [{ provide: IgxSummaryRowComponent, useExisting: forwardRef(() => IgxSummaryRowSectionComponent_1) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxSummaryRowSectionComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxSummaryRowSectionComponent);

/**
 * Represents a width of a column.
*/
class IgxColumnWidth {
    createImplementation() {
        return new ColumnWidth();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * Gets or sets whether to use star sizing for the column's width
    */
    get isStarSized() {
        return this.i.c;
    }
    set isStarSized(v) {
        this.i.c = ensureBool(v);
    }
    /**
     * Gets or sets the fixed width or the proportional width of the column, depending on whether this width is a star width.
    */
    get value() {
        return this.i.f;
    }
    set value(v) {
        this.i.f = +v;
    }
    /**
     * Gets or sets a minimum width to use when star sizing.
    */
    get minimumWidth() {
        return this.i.e;
    }
    set minimumWidth(v) {
        this.i.e = +v;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Information about the cell in context.
*/
class IgxGridCellEventArgs {
    createImplementation() {
        return new GridCellEventArgs();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The backing information for the current cell.
    */
    get cellInfo() {
        if (this.i.cellInfo == null) {
            return null;
        }
        if (!this.i.cellInfo.externalObject) {
            let ext = null;
            switch (this.i.cellInfo.$type.name) {
                case "DateTimeCellModel":
                    ext = new IgxDateTimeCellInfo();
                    break;
                case "ImageCellModel":
                    ext = new IgxImageCellInfo();
                    break;
                case "NumericCellModel":
                    ext = new IgxNumericCellInfo();
                    break;
                case "RowSeparatorModel":
                    ext = new IgxRowSeparatorInfo();
                    break;
                case "SectionHeaderCellModel":
                    ext = new IgxSectionHeaderCellInfo();
                    break;
                case "TemplateCellModel":
                    ext = new IgxTemplateCellInfo();
                    break;
                case "TemplateHeaderCellModel":
                    ext = new IgxTemplateHeaderCellInfo();
                    break;
                case "TemplateSectionHeaderCellModel":
                    ext = new IgxTemplateSectionHeaderCellInfo();
                    break;
                case "TextCellModel":
                    ext = new IgxTextCellInfo();
                    break;
                case "TextHeaderCellModel":
                    ext = new IgxTextHeaderCellInfo();
                    break;
            }
            ext._implementation = this.i.cellInfo;
            this.i.cellInfo.externalObject = ext;
        }
        return this.i.cellInfo.externalObject;
    }
    /**
 * Gets the grid owning the cell.
*/
    get grid() {
        if (this.i.grid == null) {
            return null;
        }
        return this.i.grid.externalObject;
    }
    set grid(v) {
        v == null ? this.i.grid = null : this.i.grid = v.i;
    }
}

/**
 * Information about the generated columns.
*/
class IgxGridColumnsAutoGeneratedEventArgs {
    createImplementation() {
        return new GridColumnsAutoGeneratedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
}

/**
 * Information about the changing selected items in the grid.
*/
class IgxGridSelectedItemsChangedEventArgs {
    createImplementation() {
        return new GridSelectedItemsChangedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
}

/**
 * A primary key value.
*/
class IgxPrimaryKeyValue {
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor(primaryKey = null, primaryKeyValue = null) {
        this._implementation = new PrimaryKeyValue(primaryKey, primaryKeyValue);
        this._implementation.externalObject = this;
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    static createIdentityKey(item) {
        let int = PrimaryKeyValue.createIdentityKey(item);
        let ext = new IgxPrimaryKeyValue(null, null);
        ext._provideImplementation(int);
        return ext;
    }
    /**
 * The primary key associated with this value.
*/
    get key() {
        return this.i.key;
    }
    /**
     * The value of the keys for this primary key value.
    */
    get value() {
        return this.i.value;
    }
    /**
 * Determines if two primary key values are equal.

* @param other  * The other key value to check against.
*/
    equals(other) {
        let iv = this.i.equals(other);
        return (iv);
    }
}

class IgxGridSelectedKeysCollection extends IgCollection {
    constructor(list) {
        super();
        if (!IgxPrimaryKeyValue.$type) {
            IgxPrimaryKeyValue.$type = markType(IgxPrimaryKeyValue, "IgxPrimaryKeyValue");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxPrimaryKeyValue.$type) {
            IgxPrimaryKeyValue.$type = markType(IgxPrimaryKeyValue, "IgxPrimaryKeyValue");
        }
        let coll = new SyncableObservableCollection$2(IgxPrimaryKeyValue.$type, PrimaryKeyValue.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = new IgxPrimaryKeyValue();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

/**
 * Information about the change to the selected keys in the grid.
*/
class IgxGridSelectedKeysChangedEventArgs {
    constructor() {
        this._addedKeys = null;
        this._removedKeys = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridSelectedKeysChangedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The keys added to the selection.
    */
    get addedKeys() {
        if (this._addedKeys === null) {
            let coll = new IgxGridSelectedKeysCollection();
            let innerColl = this.i.addedKeys;
            if (!innerColl) {
                innerColl = new GridSelectedKeysCollection();
            }
            this._addedKeys = coll._fromInner(innerColl);
            this.i.addedKeys = innerColl;
        }
        return this._addedKeys;
    }
    set addedKeys(v) {
        if (this._addedKeys !== null) {
            this._addedKeys._setSyncTarget(null);
            this._addedKeys = null;
        }
        let coll = new IgxGridSelectedKeysCollection();
        this._addedKeys = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PrimaryKeyValue.$type);
        let innerColl = this.i.addedKeys;
        if (!innerColl) {
            innerColl = new GridSelectedKeysCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._addedKeys._setSyncTarget(syncColl);
        this.i.addedKeys = innerColl;
    }
    /**
     * The keys removed from the selection.
    */
    get removedKeys() {
        if (this._removedKeys === null) {
            let coll = new IgxGridSelectedKeysCollection();
            let innerColl = this.i.removedKeys;
            if (!innerColl) {
                innerColl = new GridSelectedKeysCollection();
            }
            this._removedKeys = coll._fromInner(innerColl);
            this.i.removedKeys = innerColl;
        }
        return this._removedKeys;
    }
    set removedKeys(v) {
        if (this._removedKeys !== null) {
            this._removedKeys._setSyncTarget(null);
            this._removedKeys = null;
        }
        let coll = new IgxGridSelectedKeysCollection();
        this._removedKeys = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PrimaryKeyValue.$type);
        let innerColl = this.i.removedKeys;
        if (!innerColl) {
            innerColl = new GridSelectedKeysCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._removedKeys._setSyncTarget(syncColl);
        this.i.removedKeys = innerColl;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Column animation settings for the grid.
*/
class IgxGridColumnAnimationSettings {
    constructor() {
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridColumnAnimationSettings();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}

/**
 * Represents a base class used to configure the appearance of the column header cells.
*/
const IgxHeaderComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxHeaderComponent) }];
class IgxHeaderComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the color to use for the sort indicator icon
    */
    get sortIndicatorColor() {
        return brushToString(this.i.er);
    }
    set sortIndicatorColor(v) {
        this.i.er = stringToBrush(v);
    }
    /**
     * Gets the actual background color that is used for the cells when they are selected
    */
    get actualSortIndicatorColor() {
        return brushToString(this.i.ep);
    }
    set actualSortIndicatorColor(v) {
        this.i.ep = stringToBrush(v);
    }
    get sortIndicatorStyle() {
        return this.i.d3;
    }
    set sortIndicatorStyle(v) {
        this.i.d3 = ensureEnum(SortIndicatorStyle_$type, v);
    }
    get actualSortIndicatorStyle() {
        return this.i.d2;
    }
    set actualSortIndicatorStyle(v) {
        this.i.d2 = ensureEnum(SortIndicatorStyle_$type, v);
    }
    /**
     * Gets or sets the amount of left padding to use for the cell content.
    */
    get paddingLeft() {
        return this.i.d9;
    }
    set paddingLeft(v) {
        this.i.d9 = +v;
    }
    /**
     * Gets or sets the amount of top padding to use for the cell content.
    */
    get paddingTop() {
        return this.i.eb;
    }
    set paddingTop(v) {
        this.i.eb = +v;
    }
    /**
     * Gets or sets the amount of right padding to use for the cell content.
    */
    get paddingRight() {
        return this.i.ea;
    }
    set paddingRight(v) {
        this.i.ea = +v;
    }
    /**
     * Gets or sets the amount of bottom padding to use for the cell content.
    */
    get paddingBottom() {
        return this.i.d8;
    }
    set paddingBottom(v) {
        this.i.d8 = +v;
    }
}
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxHeaderComponent.prototype, "sortIndicatorColor", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxHeaderComponent.prototype, "actualSortIndicatorColor", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "sortIndicatorStyle", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "actualSortIndicatorStyle", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "paddingLeft", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "paddingTop", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "paddingRight", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxHeaderComponent.prototype, "paddingBottom", null);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnFilterCondition extends Base {
    b() {
        return false;
    }
    a(a, b) {
        return null;
    }
}
ColumnFilterCondition.$t = markType(ColumnFilterCondition, 'ColumnFilterCondition');

/**
 * A column in the data grid.
*/
const IgxColumnComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxColumnComponent) }];
class IgxColumnComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the amount of left padding to use for the cell content for this column.
    */
    get paddingLeft() {
        return this.i.ff;
    }
    set paddingLeft(v) {
        this.i.ff = +v;
    }
    /**
     * Gets or sets the amount of top padding to use for the cell content for this column.
    */
    get paddingTop() {
        return this.i.fh;
    }
    set paddingTop(v) {
        this.i.fh = +v;
    }
    /**
     * Gets or sets the amount of right padding to use for the cell content of this column.
    */
    get paddingRight() {
        return this.i.fg;
    }
    set paddingRight(v) {
        this.i.fg = +v;
    }
    /**
     * Gets or sets the amount of bottom padding to use for the cell content of this column.
    */
    get paddingBottom() {
        return this.i.fe;
    }
    set paddingBottom(v) {
        this.i.fe = +v;
    }
    /**
     * Gets or sets an unique name of the Column
    */
    get name() {
        return this.i.f5;
    }
    set name(v) {
        this.i.f5 = v;
    }
    /**
     * Gets or sets the key used for the column binding
    */
    get propertyPath() {
        return this.i.gb;
    }
    set propertyPath(v) {
        this.i.gb = v;
    }
    /**
     * Gets or sets the text displayed in the header of the column
    */
    get headerText() {
        return this.i.fw;
    }
    set headerText(v) {
        this.i.fw = v;
    }
    /**
     * Gets the actual text displayed in the header of the column
    */
    get actualHeaderText() {
        return this.i.fp;
    }
    set actualHeaderText(v) {
        this.i.fp = v;
    }
    /**
     * Gets or sets the background color to use for the cells when they are selected
    */
    get selectedBackground() {
        return brushToString(this.i.gs);
    }
    set selectedBackground(v) {
        this.i.gs = stringToBrush(v);
    }
    /**
     * Gets the actual background color that is used for the cells when they are selected
    */
    get actualSelectedBackground() {
        return brushToString(this.i.gq);
    }
    set actualSelectedBackground(v) {
        this.i.gq = stringToBrush(v);
    }
    /**
     * Gets or sets the animation settings to use for this column.
    */
    get animationSettings() {
        if (this.i.eh == null) {
            return null;
        }
        if (!this.i.eh.externalObject) {
            let e = new IgxGridColumnAnimationSettings();
            e._implementation = this.i.eh;
            this.i.eh.externalObject = e;
        }
        return this.i.eh.externalObject;
    }
    set animationSettings(v) {
        v == null ? this.i.eh = null : this.i.eh = v.i;
    }
    /**
     * Gets or sets the width to use for this column.
    */
    get width() {
        if (this.i.width == null) {
            return null;
        }
        if (!this.i.width.externalObject) {
            let e = new IgxColumnWidth();
            e._implementation = this.i.width;
            this.i.width.externalObject = e;
        }
        return this.i.width.externalObject;
    }
    set width(v) {
        if (typeof v == "string") {
            let int = ColumnWidth.parse(v);
            let ext = new IgxColumnWidth();
            ext._implementation = int;
            v = ext;
        }
        v == null ? this.i.width = null : this.i.width = v.i;
    }
    /**
     * Gets or sets the minimum width to use for this column. Overrides the DefaultColumnMinWidth from the grid, if set.
    */
    get minWidth() {
        return this.i.e5;
    }
    set minWidth(v) {
        this.i.e5 = +v;
    }
    /**
     * Gets whether this column was projected from markup/templates and is constrained.
    */
    get isFromMarkup() {
        return this.i.e0;
    }
    set isFromMarkup(v) {
        this.i.e0 = ensureBool(v);
    }
    /**
     * Gets whether this column was auto generated.
    */
    get isAutoGenerated() {
        return this.i.ey;
    }
    set isAutoGenerated(v) {
        this.i.ey = ensureBool(v);
    }
    /**
     * Gets or sets a filter to apply on the values of this column
    */
    get filter() {
        return this.i.d1;
    }
    set filter(v) {
        this.i.d1 = v;
    }
    /**
     * Gets or sets the header definition for this column.
    */
    get header() {
        if (this.i.header == null) {
            return null;
        }
        if (!this.i.header.externalObject) {
            let e = IgxHeaderComponent._createFromInternal(this.i.header);
            if (e) {
                e._implementation = this.i.header;
            }
            this.i.header.externalObject = e;
        }
        return this.i.header.externalObject;
    }
    set header(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.header = null : this.i.header = v.i;
    }
    /**
     * Gets or sets whether filtering is enabled for this column.
    */
    get isFilteringEnabled() {
        return this.i.ez;
    }
    set isFilteringEnabled(v) {
        this.i.ez = ensureBool(v);
    }
    /**
     * Gets or sets whether resizing is enabled for this column.
    */
    get isResizingEnabled() {
        return this.i.e2;
    }
    set isResizingEnabled(v) {
        this.i.e2 = ensureBool(v);
    }
    /**
     * Gets or sets whether or not a column is hidden from the grid
    */
    get isHidden() {
        return this.i.e1;
    }
    set isHidden(v) {
        this.i.e1 = ensureBool(v);
    }
    /**
     * Gets or sets if a column should be removed from the grid when it is fully hidden
    */
    get shouldRemoveWhenHidden() {
        return this.i.e3;
    }
    set shouldRemoveWhenHidden(v) {
        this.i.e3 = ensureBool(v);
    }
    /**
     * Gets the current sort direction (None, Ascending, Descending) for this column.
    */
    get sortDirection() {
        return this.i.eb;
    }
    set sortDirection(v) {
        this.i.eb = ensureEnum(ColumnSortDirection_$type, v);
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.header && this.header._styling) {
            this.header._styling(container, component, this);
        }
        this._inStyling = false;
    }
    /**
     * Get the unique key used to identify this column.
    
    */
    getUniqueKey() {
        let iv = this.i.fu();
        return (iv);
    }
    setNamedHeaderValue(valueName, animationType, value) {
        this.i.gk(valueName, (animationType == null ? null : animationType), value);
    }
    /**
     * Returns if the column has named header values.
    
    */
    hasNamedHeaderValues() {
        let iv = this.i.ew();
        return (iv);
    }
    /**
     * Returns if there is a named header value with a given name.
    
    * @param valueName  * The named value to check for.
    */
    hasNamedHeaderValue(valueName) {
        let iv = this.i.ev(valueName);
        return (iv);
    }
    /**
     * Removes a named header value with the given name from the named header values for this column.
    
    * @param valueName  * The named header value to remove.
    */
    removeNamedHeaderValue(valueName) {
        this.i.gj(valueName);
    }
    /**
     * Gets the value of a named header value for this column by name.
    
    * @param valueName  * Name of the named header value to retrieve.
    */
    getNamedHeaderValue(valueName) {
        let iv = this.i.fk(valueName);
        return (iv);
    }
}
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "paddingLeft", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "paddingTop", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "paddingRight", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "paddingBottom", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "name", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "propertyPath", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "headerText", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "actualHeaderText", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "selectedBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxColumnComponent.prototype, "actualSelectedBackground", null);
__decorate([
    Input(),
    __metadata("design:type", IgxGridColumnAnimationSettings),
    __metadata("design:paramtypes", [IgxGridColumnAnimationSettings])
], IgxColumnComponent.prototype, "animationSettings", null);
__decorate([
    Input(),
    __metadata("design:type", IgxColumnWidth),
    __metadata("design:paramtypes", [IgxColumnWidth])
], IgxColumnComponent.prototype, "width", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "minWidth", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "isFromMarkup", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "isAutoGenerated", null);
__decorate([
    Input(),
    __metadata("design:type", ColumnFilterCondition),
    __metadata("design:paramtypes", [ColumnFilterCondition])
], IgxColumnComponent.prototype, "filter", null);
__decorate([
    Input(),
    __metadata("design:type", IgxHeaderComponent),
    __metadata("design:paramtypes", [IgxHeaderComponent])
], IgxColumnComponent.prototype, "header", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "isFilteringEnabled", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "isResizingEnabled", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "isHidden", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxColumnComponent.prototype, "shouldRemoveWhenHidden", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxColumnComponent.prototype, "sortDirection", null);

/**
 * An indentifier for a specific cell in the grid.
*/
class IgxCellKey {
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = new CellKey();
        this._implementation.externalObject = this;
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * Gets or sets the primary key of the row associated with the cell.
    */
    get primaryKey() {
        if (this.i.primaryKey == null) {
            return null;
        }
        if (!this._primaryKey) {
            this._primaryKey = new IgxPrimaryKeyValue(this.i.primaryKey.key, this.i.primaryKey.value);
        }
        return this._primaryKey;
    }
    set primaryKey(v) {
        this.i.primaryKey = v.i;
    }
    /**
 * Gets or sets the row data object associated with the cell.
*/
    get rowItem() {
        return this.i.h;
    }
    set rowItem(v) {
        this.i.h = v;
    }
    /**
     * Gets or sets the column name associated with the cell.
     * All columns in the grid must have a unique name. That unique name is what is used for this property.
    */
    get columnUniqueKey() {
        return this.i.j;
    }
    set columnUniqueKey(v) {
        this.i.j = v;
    }
    /**
     * Gets or sets the resolved column object associated with this cell.
    */
    get resolvedColumn() {
        if (this.i.b == null) {
            return null;
        }
        if (!this.i.b.externalObject) {
            let e = IgxColumnComponent._createFromInternal(this.i.b);
            if (e) {
                e._implementation = this.i.b;
            }
            this.i.b.externalObject = e;
        }
        return this.i.b.externalObject;
    }
}

class IgxGridSelectedCellsCollection extends IgCollection {
    constructor(list) {
        super();
        if (!IgxCellKey.$type) {
            IgxCellKey.$type = markType(IgxCellKey, "IgxCellKey");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxCellKey.$type) {
            IgxCellKey.$type = markType(IgxCellKey, "IgxCellKey");
        }
        let coll = new SyncableObservableCollection$2(IgxCellKey.$type, CellKey.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = new IgxCellKey();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Information about the change to the selected cells in the grid.
*/
class IgxGridSelectedCellsChangedEventArgs {
    constructor() {
        this._addedCells = null;
        this._removedCells = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridSelectedCellsChangedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The cells added to the selection.
    */
    get addedCells() {
        if (this._addedCells === null) {
            let coll = new IgxGridSelectedCellsCollection();
            let innerColl = this.i.addedCells;
            if (!innerColl) {
                innerColl = new GridSelectedCellsCollection();
            }
            this._addedCells = coll._fromInner(innerColl);
            this.i.addedCells = innerColl;
        }
        return this._addedCells;
    }
    set addedCells(v) {
        if (this._addedCells !== null) {
            this._addedCells._setSyncTarget(null);
            this._addedCells = null;
        }
        let coll = new IgxGridSelectedCellsCollection();
        this._addedCells = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(CellKey.$type);
        let innerColl = this.i.addedCells;
        if (!innerColl) {
            innerColl = new GridSelectedCellsCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._addedCells._setSyncTarget(syncColl);
        this.i.addedCells = innerColl;
    }
    /**
     * The cells removed from the selection.
    */
    get removedCells() {
        if (this._removedCells === null) {
            let coll = new IgxGridSelectedCellsCollection();
            let innerColl = this.i.removedCells;
            if (!innerColl) {
                innerColl = new GridSelectedCellsCollection();
            }
            this._removedCells = coll._fromInner(innerColl);
            this.i.removedCells = innerColl;
        }
        return this._removedCells;
    }
    set removedCells(v) {
        if (this._removedCells !== null) {
            this._removedCells._setSyncTarget(null);
            this._removedCells = null;
        }
        let coll = new IgxGridSelectedCellsCollection();
        this._removedCells = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(CellKey.$type);
        let innerColl = this.i.removedCells;
        if (!innerColl) {
            innerColl = new GridSelectedCellsCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._removedCells._setSyncTarget(syncColl);
        this.i.removedCells = innerColl;
    }
}

/**
 * An indentifier for a specific cell in the grid.
*/
class IgxCellRange {
    createImplementation() {
        return new CellRange();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * Gets or sets the start column of the range.
    */
    get startColumn() {
        return this.i.k;
    }
    set startColumn(v) {
        this.i.k = +v;
    }
    /**
     * Gets or sets the end column of the range.
    */
    get endColumn() {
        return this.i.i;
    }
    set endColumn(v) {
        this.i.i = +v;
    }
    /**
     * Gets or sets the start row of the range.
    */
    get startRow() {
        return this.i.l;
    }
    set startRow(v) {
        this.i.l = +v;
    }
    /**
     * Gets or sets the end row of the range.
    */
    get endRow() {
        return this.i.j;
    }
    set endRow(v) {
        this.i.j = +v;
    }
}

class IgxGridSelectedCellRangesCollection extends IgCollection {
    constructor(list) {
        super();
        if (!IgxCellRange.$type) {
            IgxCellRange.$type = markType(IgxCellRange, "IgxCellRange");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxCellRange.$type) {
            IgxCellRange.$type = markType(IgxCellRange, "IgxCellRange");
        }
        let coll = new SyncableObservableCollection$2(IgxCellRange.$type, CellRange.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = new IgxCellRange();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

/**
 * Information about the change to the selected cell ranges in the grid.
*/
class IgxGridSelectedCellRangesChangedEventArgs {
    constructor() {
        this._addedRanges = null;
        this._removedRanges = null;
        this._updatedRanges = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridSelectedCellRangesChangedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The cell ranges added to the selection.
    */
    get addedRanges() {
        if (this._addedRanges === null) {
            let coll = new IgxGridSelectedCellRangesCollection();
            let innerColl = this.i.addedRanges;
            if (!innerColl) {
                innerColl = new GridSelectedCellRangesCollection();
            }
            this._addedRanges = coll._fromInner(innerColl);
            this.i.addedRanges = innerColl;
        }
        return this._addedRanges;
    }
    set addedRanges(v) {
        if (this._addedRanges !== null) {
            this._addedRanges._setSyncTarget(null);
            this._addedRanges = null;
        }
        let coll = new IgxGridSelectedCellRangesCollection();
        this._addedRanges = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(CellRange.$type);
        let innerColl = this.i.addedRanges;
        if (!innerColl) {
            innerColl = new GridSelectedCellRangesCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._addedRanges._setSyncTarget(syncColl);
        this.i.addedRanges = innerColl;
    }
    /**
     * The cell ranges removed from the selection.
    */
    get removedRanges() {
        if (this._removedRanges === null) {
            let coll = new IgxGridSelectedCellRangesCollection();
            let innerColl = this.i.removedRanges;
            if (!innerColl) {
                innerColl = new GridSelectedCellRangesCollection();
            }
            this._removedRanges = coll._fromInner(innerColl);
            this.i.removedRanges = innerColl;
        }
        return this._removedRanges;
    }
    set removedRanges(v) {
        if (this._removedRanges !== null) {
            this._removedRanges._setSyncTarget(null);
            this._removedRanges = null;
        }
        let coll = new IgxGridSelectedCellRangesCollection();
        this._removedRanges = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(CellRange.$type);
        let innerColl = this.i.removedRanges;
        if (!innerColl) {
            innerColl = new GridSelectedCellRangesCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._removedRanges._setSyncTarget(syncColl);
        this.i.removedRanges = innerColl;
    }
    /**
     * The cell ranges that have been updated by the grid.
    */
    get updatedRanges() {
        if (this._updatedRanges === null) {
            let coll = new IgxGridSelectedCellRangesCollection();
            let innerColl = this.i.updatedRanges;
            if (!innerColl) {
                innerColl = new GridSelectedCellRangesCollection();
            }
            this._updatedRanges = coll._fromInner(innerColl);
            this.i.updatedRanges = innerColl;
        }
        return this._updatedRanges;
    }
    set updatedRanges(v) {
        if (this._updatedRanges !== null) {
            this._updatedRanges._setSyncTarget(null);
            this._updatedRanges = null;
        }
        let coll = new IgxGridSelectedCellRangesCollection();
        this._updatedRanges = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(CellRange.$type);
        let innerColl = this.i.updatedRanges;
        if (!innerColl) {
            innerColl = new GridSelectedCellRangesCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._updatedRanges._setSyncTarget(syncColl);
        this.i.updatedRanges = innerColl;
    }
}

/**
 * Represents an element in the current sort applied to a data source or provider. Changes to this object are not observed or expected after it is initially assigned to a collection.
*/
class IgxColumnSortDescription {
    createImplementation() {
        return new ColumnSortDescription(0);
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * Gets or sets the property being sorted.
    */
    get propertyPath() {
        return this.i.f;
    }
    set propertyPath(v) {
        this.i.f = v;
    }
    /**
     * Gets or sets the direction to sort based on the property.
    */
    get sortDirection() {
        return this.i.c;
    }
    set sortDirection(v) {
        this.i.c = v;
    }
    /**
     * Returns if the SortDescription is equal to another.
    
    * @param other  * The SortDescription to compare to.
    */
    equals(other) {
        let iv = this.i.equals(other);
        return (iv);
    }
    /**
     * Returns the hash code for the SortDescription.
    
    */
    getHashCode() {
        let iv = this.i.getHashCode();
        return (iv);
    }
}

/**
 * Represents a collection of sort elements that are applied to a data source or provider.
*/
class IgxColumnSortDescriptionCollection {
    createImplementation() {
        return new ColumnSortDescriptionCollection();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    item(index, value) {
        let int = null;
        if (value !== undefined) {
            int = this.i.set(index, value == null ? null : value.i);
        }
        else {
            int = this.i.get(index);
        }
        let ext = null;
        if (int != null) {
            ext = int.externalObject;
            if (!ext) {
                ext = new IgxColumnSortDescription();
                ext._implementation = int;
                int.externalObject = ext;
            }
        }
        return ext;
    }
    get count() {
        return this.i.size();
    }
    toArray() {
        let arr = [];
        for (let i = 0; i < this.count; i++) {
            arr[i] = this.item(i);
        }
        return arr;
    }
    *[Symbol.iterator]() {
        for (let i = 0; i < this.count; i++) {
            let item = this.item(i);
            if (item.externalObject) {
                item = item.externalObject;
            }
            yield item;
        }
    }
    add(item) {
        let iv = this.i.g((item == null ? null : item.i));
        return (iv);
    }
    insert(index, item) {
        this.i.n(index, (item == null ? null : item.i));
    }
    clear() {
        this.i.m();
    }
    indexOf(item) {
        let iv = this.i.j((item == null ? null : item.i));
        return (iv);
    }
    remove(item) {
        let iv = this.i.h((item == null ? null : item.i));
        return (iv);
    }
    removeAt(index) {
        let iv = this.i.d(index);
        return (iv == null ? null : iv.externalObject);
    }
}

/**
 * Information about the current sorting applied to the grid.
*/
class IgxGridSortDescriptionsChangedEventArgs {
    createImplementation() {
        return new GridSortDescriptionsChangedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get sortDescriptions() {
        if (this.i.sortDescriptions == null) {
            return null;
        }
        if (!this.i.sortDescriptions.externalObject) {
            let e = new IgxColumnSortDescriptionCollection();
            e._implementation = this.i.sortDescriptions;
            this.i.sortDescriptions.externalObject = e;
        }
        return this.i.sortDescriptions.externalObject;
    }
    set sortDescriptions(v) {
        v == null ? this.i.sortDescriptions = null : this.i.sortDescriptions = v.i;
    }
}

class IgxFormatGroupTextEventArgs {
    createImplementation() {
        return new FormatGroupTextEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * Gets the group name.
    */
    get groupName() {
        return this.i.d;
    }
    set groupName(v) {
        this.i.d = v;
    }
    /**
     * Gets the original value before formatting.
    */
    get groupValue() {
        return this.i.a;
    }
    set groupValue(v) {
        this.i.a = v;
    }
    /**
     * Gets the group value as text, formatted based on the GroupDescription's ValueFormat.
    */
    get formattedValue() {
        return this.i.c;
    }
    set formattedValue(v) {
        this.i.c = v;
    }
    /**
     * Gets or sets the final text that will be displayed in the group header.
    */
    get formattedText() {
        return this.i.b;
    }
    set formattedText(v) {
        this.i.b = v;
    }
}

/**
 * Represents an element in the current grouping applied to a data source or provider. Changes to this object are not observed or expected after it is initially assigned to a collection.
*/
class IgxColumnGroupDescription extends IgxColumnSortDescription {
    constructor() {
        super();
        this._formatText = null;
        this._zoneRunner = null;
    }
    createImplementation() {
        return new ColumnGroupDescription(0);
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets an INTL.DateTimeFormat or INTL.NumericFormat to use to format the value.
    */
    get formatOverride() {
        return this.i.k;
    }
    set formatOverride(v) {
        this.i.k = v;
    }
    /**
     * Gets or sets the display text for the group name.
    */
    get displayName() {
        return this.i.m;
    }
    set displayName(v) {
        this.i.m = v;
    }
    /**
     * Called when the value is being formatted.
    */
    get formatText() {
        if (this._formatText == null) {
            this._formatText = new EventEmitter();
            this.i.formatText = delegateCombine(this.i.formatText, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxFormatGroupTextEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeFormatText) {
                        this.beforeFormatText(this, outerArgs);
                    }
                    this._formatText.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._formatText;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxColumnGroupDescription.prototype, "formatText", null);

/**
 * Represents a collection of grouping elements that are applied to a data source or provider.
*/
class IgxColumnGroupDescriptionCollection {
    createImplementation() {
        return new ColumnGroupDescriptionCollection();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    item(index, value) {
        let int = null;
        if (value !== undefined) {
            int = this.i.set(index, value == null ? null : value.i);
        }
        else {
            int = this.i.get(index);
        }
        let ext = null;
        if (int != null) {
            ext = int.externalObject;
            if (!ext) {
                ext = new IgxColumnGroupDescription();
                ext._implementation = int;
                int.externalObject = ext;
            }
        }
        return ext;
    }
    get count() {
        return this.i.size();
    }
    toArray() {
        let arr = [];
        for (let i = 0; i < this.count; i++) {
            arr[i] = this.item(i);
        }
        return arr;
    }
    *[Symbol.iterator]() {
        for (let i = 0; i < this.count; i++) {
            let item = this.item(i);
            if (item.externalObject) {
                item = item.externalObject;
            }
            yield item;
        }
    }
    add(item) {
        let iv = this.i.g((item == null ? null : item.i));
        return (iv);
    }
    insert(index, item) {
        this.i.n(index, (item == null ? null : item.i));
    }
    clear() {
        this.i.m();
    }
    indexOf(item) {
        let iv = this.i.j((item == null ? null : item.i));
        return (iv);
    }
    remove(item) {
        let iv = this.i.h((item == null ? null : item.i));
        return (iv);
    }
    removeAt(index) {
        let iv = this.i.d(index);
        return (iv == null ? null : iv.externalObject);
    }
}

/**
 * Information about the current grouping applied to the grid.
*/
class IgxGridGroupDescriptionsChangedEventArgs {
    createImplementation() {
        return new GridGroupDescriptionsChangedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get groupDescriptions() {
        if (this.i.groupDescriptions == null) {
            return null;
        }
        if (!this.i.groupDescriptions.externalObject) {
            let e = new IgxColumnGroupDescriptionCollection();
            e._implementation = this.i.groupDescriptions;
            this.i.groupDescriptions.externalObject = e;
        }
        return this.i.groupDescriptions.externalObject;
    }
    set groupDescriptions(v) {
        v == null ? this.i.groupDescriptions = null : this.i.groupDescriptions = v.i;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CurrentRendererSettings extends Base {
    constructor() {
        super(...arguments);
        this.a = null;
        this.c = 0;
        this.d = 0;
        this.b = false;
    }
}
CurrentRendererSettings.$t = markType(CurrentRendererSettings, 'CurrentRendererSettings');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DataGridCellLayoutPanel extends Base {
    constructor(a, b, c) {
        super();
        this.e = null;
        this.k = false;
        this.q = null;
        this._element = null;
        this.f = null;
        this.i = false;
        this.m = false;
        this.g = null;
        this.l = false;
        this._requestAnimationFrame = null;
        this.s = 0;
        this.o = -1;
        this.n = -1;
        this.j = false;
        this.p = 0;
        this.c = null;
        this.a = null;
        this.d = null;
        this.b = null;
        this.p = c;
        this.q = a;
        this.requestAnimationFrame = this.q.getRequestAnimationFrame();
        this.element = this.q.createElement("div");
        this.element.setRawStyleProperty("position", "relative");
        this.element.setRawStyleProperty("box-sizing", "border-box");
        this.refresh(this.e, false);
        this.f = b;
        this.i = false;
    }
    get element() {
        return this._element;
    }
    set element(a) {
        this._element = a;
    }
    refresh(a, b) {
        this.e = a;
        this.ah(b);
    }
    viewportChanged() {
        this.ah(true);
    }
    invalidateVisibility(a) {
        this.g = a;
        this.m = true;
    }
    get initialRefreshFinished() {
        return this.i;
    }
    z(a, b, c, d) {
        this.ah(true);
    }
    ag(a) {
        let b = this.f.b(this.q, a);
        if (b.isCanvasBased) {
            let c = b.nativeCell.ab = false;
        }
        else {
            let d = b.nativeCell.x;
            d.setRawStyleProperty("top", "-1000px");
        }
    }
    ah(a) {
        if (a) {
            this.k = true;
            this.t();
            return;
        }
        if (this.l) {
            return;
        }
        if (this.k) {
            return;
        }
        this.k = true;
        this.v(runOn(this, this.t));
    }
    get requestAnimationFrame() {
        return this._requestAnimationFrame;
    }
    set requestAnimationFrame(a) {
        this._requestAnimationFrame = a;
    }
    v(a) {
        this.requestAnimationFrame(a);
    }
    t() {
        if (!this.k) {
            return;
        }
        this.k = false;
        if (this.m) {
            this.m = false;
            this.g();
        }
        if (this.e == null) {
            return;
        }
        if (Rect.l_op_Equality(this.e.actualVisibleRegion, null) || this.e.actualVisibleRegion.isEmpty) {
            return;
        }
        this.i = true;
        if (this.o != this.e.absoluteWidth) {
            this.element.setRawStyleProperty("width", this.e.absoluteWidth + "px");
        }
        if (this.n != this.e.absoluteHeight) {
            this.element.setRawStyleProperty("height", this.e.absoluteHeight + "px");
        }
        this.o = this.e.absoluteWidth;
        this.n = this.e.absoluteHeight;
        let a = this.e.actualVisibleRegion.top;
        let b = this.e.actualVisibleRegion.left;
        let c = this.e.be;
        let d = c.count;
        let e = this.e.ay;
        let f = this.e.ay.o;
        let g = f.count;
        let h = this.e.ay.p;
        for (let i = 0; i < g; i++) {
            if (h._inner[i]) {
                continue;
            }
            let j = e.item(f._inner[i]);
            for (let k = 0; k < j.count; k++) {
                let l = j._inner[k];
                this.ag(l);
            }
        }
        e.u();
        let m = false;
        let n = this.s;
        let o = true;
        let p = false;
        for (let q = 0; q < d; q++) {
            let r = c._inner[q].q;
            let s = c._inner[q].q.count;
            let t = c._inner[q].p;
            for (let u = 0; u < s; u++) {
                if (t._inner[u]) {
                    continue;
                }
                let v = r._inner[u];
                let w = this.f.b(this.q, v);
                if (!w.isCanvasBased) {
                    o = false;
                }
                else {
                    p = true;
                }
                if (v.ao) {
                    m = true;
                }
                if (v.r == 1 && v.e6 != n) {
                    m = true;
                }
            }
        }
        if (p) {
            this.u();
        }
        if (m) {
            if (this.s == 0x7FFFFFFFFFFFFFFF - 1) {
                this.s = 0;
            }
            else {
                this.s++;
            }
            n = this.s;
        }
        let x = 0;
        let y = new CurrentRendererSettings();
        let z = this.p;
        this.l = true;
        for (let aa = 0; aa < d; aa++) {
            let ab = c._inner[aa].q;
            let ac = c._inner[aa].q.count;
            let ad = c._inner[aa].p;
            for (let ae = 0; ae < ac; ae++) {
                if (ad._inner[ae]) {
                    continue;
                }
                let af = ab._inner[ae];
                let ag = this.f.b(this.q, af);
                if (ag.isCanvasBased) {
                    let ah = y.a;
                    this.al(y, aa, af, this.e, x, m, o);
                    if (y.a != ah && m) {
                        x++;
                    }
                }
                let ai = ag.isCanvasBased;
                let aj = null;
                if (!ai) {
                    aj = ag.nativeCell.x;
                    if (af.r == 0) {
                        this.element.append(aj);
                    }
                }
                if (af.r == 1) {
                    if (ai) {
                        let ak = af.p.nativeCell;
                        ak.ab = true;
                    }
                }
                af.r = 2;
                let al = (af.ep + intDivide(af.e2, 2));
                let am = (af.er + intDivide(af.dt, 2));
                let an = (al - b) / this.e.actualVisibleRegion.width;
                let ao = (am - a) / this.e.actualVisibleRegion.height;
                if (af.aq) {
                    if (!ai) {
                        aj.setRawPosition(af.br, af.bs);
                    }
                }
                af.hh();
                if (ai) {
                    let ap = af.p.nativeCell;
                    ap.cg(z);
                }
                af.p.modelUpdated(af);
                if (ai && y.b) {
                    let aq = af.p.nativeCell;
                    aq.by(y.a, y.c, y.d, af.br, af.bs, z);
                }
                af.ha();
                if (m) {
                    af.e6 = n;
                    if (!ai) {
                        aj.setRawStyleProperty("z-index", x.toString());
                    }
                    x++;
                }
            }
        }
        this.l = false;
        if (y.a != null && this.p != 1) {
            y.a.y();
        }
    }
    u() {
        if (!this.j) {
            this.j = true;
            let a = this.q.rootWrapper;
            let b = (window.navigator.msPointerEnabled && MSGesture !== undefined);
            let c = (window.PointerEvent || window.navigator.pointerEnabled);
            let d = (window.TouchEvent);
            if ((b || c)) {
                a.listen("pointerdown", runOn(this, this.ad));
                a.listen("pointerup", runOn(this, this.af));
                a.listen("pointermove", runOn(this, this.ae));
            }
            else {
                a.listen("mousedown", runOn(this, this.w));
                a.listen("mouseup", runOn(this, this.y));
                a.listen("mousemove", runOn(this, this.x));
                a.listen("touchstart", runOn(this, this.ai));
                a.listen("touchend", runOn(this, this.ak));
                a.listen("touchmove", runOn(this, this.aj));
            }
        }
    }
    w(a) {
        this.ac(a, false);
    }
    y(a) {
        this.aa(a, false);
    }
    x(a) {
        this.ab(a, false);
    }
    ad(e_) {
        let a = (e_.originalEvent.pointerType);
        if (a == "touch") {
            this.ai(e_);
        }
        else {
            this.w(e_);
        }
    }
    ae(e_) {
        let a = (e_.originalEvent.pointerType);
        if (a == "touch") {
            this.aj(e_);
        }
        else {
            this.x(e_);
        }
    }
    af(e_) {
        let a = (e_.originalEvent.pointerType);
        if (a == "touch") {
            this.ak(e_);
        }
        else {
            this.y(e_);
        }
    }
    ai(a) {
        this.ac(a, true);
    }
    ac(a, b) {
        if (this.e == null) {
            return;
        }
        let c = this.q.rootWrapper.getOffset();
        let d = this.e.d(a.pageX - c.left, a.pageY - c.top);
        if (d == null) {
            return;
        }
        if (d.p != null) {
            if (d.p.isCanvasBased && d.p.nativeCell != null) {
                d.p.nativeCell.onContactStarted(a, b);
            }
        }
    }
    aj(a) {
        this.ab(a, true);
    }
    ab(a, b) {
        if (this.e == null) {
            return;
        }
        let c = this.q.rootWrapper.getOffset();
        let d = this.e.d(a.pageX - c.left, a.pageY - c.top);
        if (d == null) {
            return;
        }
        if (d.p != null) {
            if (d.p.isCanvasBased && d.p.nativeCell != null) {
                d.p.nativeCell.onContactMoved(a, b);
            }
        }
    }
    ak(a) {
        this.aa(a, true);
    }
    aa(a, b) {
        if (this.e == null) {
            return;
        }
        let c = this.q.rootWrapper.getOffset();
        let d = this.e.d(a.pageX - c.left, a.pageY - c.top);
        if (d == null) {
            return;
        }
        if (d.p != null) {
            if (d.p.isCanvasBased && d.p.nativeCell != null) {
                d.p.nativeCell.onContactCompleted(a, b);
            }
        }
    }
    al(a, b, c, d, e, f, g) {
        if (g) {
            b = 0;
        }
        if (this.c == null) {
            this.c = new Array(d.be.count);
            this.a = new Array(d.be.count);
            this.d = new Array(d.be.count);
            this.b = new Array(d.be.count);
            for (let h = 0; h < d.be.count; h++) {
                this.c[h] = null;
                this.a[h] = null;
                this.d[h] = -1;
                this.b[h] = -1;
            }
        }
        if (this.c[b] == null) {
            let i = this.q.createElement("canvas");
            this.a[b] = i;
            i.setRawStyleProperty("position", "absolute");
            i.setRawStyleProperty("z-index", e.toString());
            this.element.append(i);
            let j = this.q.get2DCanvasContext(i);
            let k = ((() => {
                let $ret = new CanvasViewRenderer();
                $ret.h$d = j;
                return $ret;
            })());
            this.c[b] = new RenderingContext(k, j);
        }
        if (a.a != this.c[b]) {
            a.a = this.c[b];
            a.b = true;
            a.c = d.actualVisibleRegion.left;
            a.d = d.actualVisibleRegion.top;
            let l = d.actualVisibleRegion.width * this.p;
            let m = d.actualVisibleRegion.height * this.p;
            if (l != this.d[b] || m != this.b[b]) {
                this.a[b].setRawSize(d.actualVisibleRegion.width, d.actualVisibleRegion.height);
                this.a[b].setAttribute("width", l + "px");
                this.a[b].setAttribute("height", m + "px");
                this.d[b] = l;
                this.b[b] = m;
            }
            if (f) {
                this.a[b].setRawStyleProperty("z-index", e.toString());
            }
            a.a.k(0, 0, d.actualVisibleRegion.width, d.actualVisibleRegion.height);
            this.a[b].setRawPosition(a.c, a.d);
        }
    }
}
DataGridCellLayoutPanel.$t = markType(DataGridCellLayoutPanel, 'DataGridCellLayoutPanel', Base.$, [ICellRenderingEngine_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridExternalWrapper extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.a = a;
    }
    get renderer() {
        let grid_ = this.a;
        return (grid_._renderer);
    }
    onContentSizeChanged() {
        let grid_ = this.a;
        grid_.refreshContentSize();
    }
    createLocalDataSource(a) {
        let b = new LocalDataSource();
        b.itemsSource = a;
        return b;
    }
    createTextColumn(a) {
        if (TypeRegistrar.isRegistered("IgxTextColumnComponent")) {
            let column_ = TypeRegistrar.create("IgxTextColumnComponent");
            let b = (column_._implementation);
            b.gb = a;
            return b;
        }
        return null;
    }
    createNumericColumn(a) {
        if (TypeRegistrar.isRegistered("IgxNumericColumnComponent")) {
            let column_ = TypeRegistrar.create("IgxNumericColumnComponent");
            let b = (column_._implementation);
            b.gb = a;
            return b;
        }
        return null;
    }
    createDateTimeColumn(a) {
        if (TypeRegistrar.isRegistered("IgxDateTimeColumnComponent")) {
            let column_ = TypeRegistrar.create("IgxDateTimeColumnComponent");
            let b = (column_._implementation);
            b.gb = a;
            return b;
        }
        return null;
    }
    createImageColumn(a) {
        if (TypeRegistrar.isRegistered("IgxImageColumnComponent")) {
            let column_ = TypeRegistrar.create("IgxImageColumnComponent");
            let b = (column_._implementation);
            b.gb = a;
            return b;
        }
        return null;
    }
    createTemplateColumn(a) {
        if (TypeRegistrar.isRegistered("IgxTemplateColumnComponent")) {
            let column_ = TypeRegistrar.create("IgxTemplateColumnComponent");
            let b = (column_._implementation);
            b.gb = a;
            return b;
        }
        return null;
    }
    focusScroller() {
        let grid_ = this.a;
        grid_._focusScroller();
    }
    insertExternalColumnAtIndex(index_, column_) {
        let grid_ = this.a;
        grid_._insertExternalColumnAtIndex(index_, column_);
    }
    removeExternalColumn(column_) {
        let grid_ = this.a;
        grid_._removeExternalColumn(column_);
    }
    setDefaultCursor() {
        let grid_ = this.a;
        grid_._setDefaultCursor();
    }
    setResizeCursor() {
        let grid_ = this.a;
        grid_._setResizeCursor();
    }
    setHandCursor() {
        let grid_ = this.a;
        grid_._setHandCursor();
    }
    ensureColumnsAreManual() {
        let grid_ = this.a;
        grid_._ensureColumnsAreManual();
    }
}
GridExternalWrapper.$t = markType(GridExternalWrapper, 'GridExternalWrapper', Base.$, [IExternalGrid_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class BrowserTickProvider extends Base {
    constructor(a) {
        super();
        this.e = 0;
        this.c = null;
        this._requestAnimationFrame = null;
        this.d = new List$1(Delegate_$type, 0);
        this.b = false;
        this.requestAnimationFrame = a.getRequestAnimationFrame();
        this.c = new Dictionary$2(Number_$type, Delegate_$type, 0);
    }
    get requestAnimationFrame() {
        return this._requestAnimationFrame;
    }
    set requestAnimationFrame(a) {
        this._requestAnimationFrame = a;
    }
    f() {
        this.b = false;
        this.d.clear();
        for (let a of fromEnum(this.c.values)) {
            this.d.add(a);
        }
        for (let b = 0; b < this.d.count; b++) {
            this.d._inner[b]();
        }
        this.d.clear();
    }
    setupTicking(a) {
        let b = this.e;
        this.e++;
        this.c.item(b, a);
        return b;
    }
    requestFrame(a) {
        if (this.b) {
            return;
        }
        this.b = true;
        this.requestAnimationFrame(runOn(this, this.f));
    }
    teardownTicking(a) {
        if (this.c.containsKey(a)) {
            this.c.removeItem(a);
        }
    }
}
BrowserTickProvider.$t = markType(BrowserTickProvider, 'BrowserTickProvider', Base.$, [ITickProvider_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class BrowserPixelConverter extends Base {
    devicePixelsToPixel(a) {
        return a;
    }
}
BrowserPixelConverter.$t = markType(BrowserPixelConverter, 'BrowserPixelConverter', Base.$, [IPlatformPixelConverter_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let INativeCell_$type = new Type(null, 'INativeCell');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasPlaceholderView extends Base {
    constructor() {
        super();
        this.f = null;
        this.j = new Color();
        this.g = 1;
        this.a = true;
        this.c = 0;
        this.b = 0;
        this.k = new Color();
    }
    get l() {
        return this.j;
    }
    set l(a) {
        this.j = a;
        this.i();
    }
    get h() {
        return this.g;
    }
    set h(a) {
        this.a = true;
        this.g = a;
        this.i();
    }
    get e() {
        return this.c;
    }
    set e(a) {
        this.c = a;
        this.i();
    }
    get d() {
        return this.b;
    }
    set d(a) {
        this.b = a;
        this.i();
    }
    i() {
        let a = this.e;
        let b = this.d;
        this.k = Color.u(truncate((this.j.l * this.g)), this.j.o, this.j.n, this.j.m);
    }
}
CanvasPlaceholderView.$t = markType(CanvasPlaceholderView, 'CanvasPlaceholderView');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasGridCellBase extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.q = true;
        this.o = true;
        this.k = null;
        this.bj = null;
        this.bw = null;
        this.l = false;
        this.an = 1;
        this.ar = 5;
        this.at = 5;
        this.as = 5;
        this.aq = 5;
        this.cs = null;
        this.af = 0;
        this.ah = 0;
        this.ag = 0;
        this.ae = 0;
        this.cz = new Rectangle();
        this.cw = new Line();
        this.cy = new Line();
        this.cx = new Line();
        this.cv = new Line();
        this.ax = 0;
        this.az = 0;
        this.a0 = 0;
        this.a1 = 0;
        this.bl = null;
        this.j = null;
        this.aj = 0;
        this.ai = 0;
        this.al = 0;
        this.ak = 0;
        this.s = true;
        this.ay = NaN;
        this.cr = new TextBlock();
        this.cu = Color.u(255, 0, 0, 0);
        this.r = true;
        this.ap = 0;
        this.a2 = 0;
        this.ct = Color.u(255, 255, 255, 255);
        this.m = false;
        this.g = null;
        this.c = 0;
        this.e = 0;
        this.bv = 1;
        this.aw = 0;
        this.av = 0;
        this.i = ((() => {
            let $ret = new FontInfo();
            $ret.n = "Verdana";
            $ret.d = 12;
            return $ret;
        })());
        this.p = true;
        this.bo = -1;
        this.bt = 0;
        this.bu = 0;
        this.n = false;
        this.bm = 0;
        this.b = 0;
        this.ao = NaN;
        this.h = null;
        this.bq = -1;
        this.am = NaN;
        this.f = 1;
        this.au = 1;
        this.bj = a;
    }
    get x() {
        return this.o;
    }
    set x(a) {
        this.o = a;
    }
    ch(a) {
        this.k = a;
    }
    b2() {
        this.o = true;
        if (this.k != null) {
            this.k();
        }
    }
    get isCanvasBased() {
        return true;
    }
    get bk() {
        return this.bj;
    }
    ci(a) {
        this.bw = a;
        this.o = true;
        this.q = true;
    }
    get templateContext() {
        return this.j.g();
    }
    get t() {
        return this.l;
    }
    set t(a) {
        this.l = a;
    }
    get_z() {
        return false;
    }
    get z() {
        return this.get_z();
    }
    b9(a, b, c, d, e) {
        this.o = true;
        this.cs = a;
        this.af = b;
        this.ah = c;
        this.ag = d;
        this.ae = e;
        this.q = true;
    }
    ca(a) {
        this.o = true;
        this.an = a;
        this.cr._opacity = this.an;
    }
    get a9() {
        return this.ar;
    }
    get bb() {
        return this.at;
    }
    get ba() {
        return this.as;
    }
    get a8() {
        return this.aq;
    }
    get a4() {
        return this.af;
    }
    get a6() {
        return this.ah;
    }
    get a5() {
        return this.ag;
    }
    get a3() {
        return this.ae;
    }
    get bd() {
        return this.ax;
    }
    get bf() {
        return this.az;
    }
    get bg() {
        return this.a1;
    }
    get_aa() {
        return false;
    }
    get aa() {
        return this.get_aa();
    }
    by(a, b, c, d, e, f) {
        let g = true;
        let h = true;
        let i = false;
        if (this.aa) {
            g = false;
            h = false;
            i = false;
        }
        this.bz(a, b, c, d, e, f, g, h, i);
    }
    get resized() {
        return this.s;
    }
    ensureCorrectSize() {
        this.s = this.u(this.au);
        return this.s;
    }
    bz(a, b, c, d, e, f, g, h, i) {
        if (!this.r) {
            return;
        }
        if (this.bv != 1) {
            a.ad(this.bv);
        }
        this.au = f;
        if (!i) {
            this.b0();
            this.ensureCorrectSize();
        }
        if (this.x || this.s || i) {
            this.x = false;
            let j = this.j;
            if (this.p || this.s || (this.i != null && this.i.g != this.bo)) {
                this.p = false;
                this.bo = this.i.g;
                j.ac(this.i);
            }
            if (f != 1) {
                this.j.z();
                this.j.aa(f, f);
            }
            if (g) {
                this.b3();
            }
            if (h) {
                this.b4(this.j);
            }
            if (f != 1) {
                this.j.y();
            }
        }
        if (!i) {
            let k = Math.round((d - b) * f);
            let l = Math.round((e - c) * f);
            if (this.aj == this.al && this.ai == this.ak) {
                a.m(this.bl.getNativeElement(), 1, k, l, this.aj, this.ai);
            }
            else {
                a.n(this.bl.getNativeElement(), 1, 0, 0, this.aj, this.ai, k, l, this.aj, this.ai);
            }
        }
        if (this.bv != 1) {
            a.ad(1);
        }
    }
    b3() {
        if (!this.m) {
            this.j.k(0, 0, this.al, this.ak);
        }
        this.cz.n = 0;
        this.cz.o = 0;
        this.cz.width = this.a2;
        this.cz.height = this.ap;
        this.j.v(this.cz);
        if (this.cs != null) {
            if (this.af > 0) {
                this.cw.am = 0;
                this.cw.ak = this.af / 2;
                this.cw.an = this.ap;
                this.cw.al = this.af / 2;
                this.cw._stroke = this.cs;
                this.cw.ac = this.af;
                this.j.r(this.cw);
            }
            if (this.ag > 0) {
                this.cx.am = 0;
                this.cx.ak = Math.max(0, (this.a2 - (this.ag / 2)));
                this.cx.an = this.ap;
                this.cx.al = Math.max(0, (this.a2 - (this.ag / 2)));
                this.cx._stroke = this.cs;
                this.cx.ac = this.ag;
                this.j.r(this.cx);
            }
            if (this.ah > 0) {
                this.cy.am = this.ah / 2;
                this.cy.ak = this.af;
                this.cy.an = this.ah / 2;
                this.cy.al = Math.max(0, (this.a2 - (this.ag / 2)));
                this.cy._stroke = this.cs;
                this.cy.ac = this.ah;
                this.j.r(this.cy);
            }
            if (this.ae > 0) {
                this.cv.am = Math.max(0, this.ap - (this.ae / 2));
                this.cv.ak = this.af;
                this.cv.an = Math.max(0, this.ap - (this.ae / 2));
                this.cv.al = Math.max(0, (this.a2 - (this.ag / 2)));
                this.cv._stroke = this.cs;
                this.cv.ac = this.ae;
                this.j.r(this.cv);
            }
        }
    }
    cg(a) {
        this.au = a;
    }
    renderStandardContent() {
        this.bz(this.j, 0, 0, 0, 0, this.au, false, true, true);
    }
    renderStandardBackground() {
        this.bz(this.j, 0, 0, 0, 0, this.au, true, false, true);
    }
    b4(a) {
        if (this.q) {
            this.cq();
            this.q = false;
        }
        if (this.cr.ak != null) {
            this.cr.n = this.ax;
            this.cr.o = this.a0;
            this.j.w(this.cr);
        }
    }
    b0() {
        if (this.bl == null) {
            this.bl = this.bj.createElement("canvas");
            let a = this.bj.get2DCanvasContext(this.bl);
            let b = ((() => {
                let $ret = new CanvasViewRenderer();
                $ret.h$d = a;
                return $ret;
            })());
            this.j = new RenderingContext(b, a);
            this.q = true;
        }
    }
    u(a) {
        let b = Math.round(this.a2 * a);
        let c = Math.round(this.ap * a);
        this.aj = b;
        this.ai = c;
        let d = this.bc(b);
        let e = this.bc(c);
        if (d != this.al || e != this.ak) {
            this.bl.setAttribute("width", d + "px");
            this.bl.setAttribute("height", e + "px");
            this.al = d;
            this.ak = e;
            this.aj = b;
            this.ai = c;
            return true;
        }
        return false;
    }
    bc(a) {
        return a;
    }
    cf(a, b, c, d) {
        this.o = true;
        this.ar = a;
        this.at = b;
        this.as = c;
        this.aq = d;
        this.q = true;
    }
    get be() {
        return this.ay;
    }
    set be(a) {
        this.ay = a;
    }
    cj(a) {
        this.o = true;
        this.cu = a;
        this.cr.am = ((() => {
            let $ret = new Brush();
            $ret.color = this.cu;
            return $ret;
        })());
    }
    get_y() {
        return false;
    }
    get y() {
        return this.get_y();
    }
    get ab() {
        return this.r;
    }
    set ab(a) {
        this.o = true;
        this.r = a;
    }
    get a7() {
        return this.ap;
    }
    get bi() {
        return this.a2;
    }
    cc(a) {
        this.o = true;
        this.ap = a;
        this.cz.height = this.ap;
    }
    cl(a) {
        this.o = true;
        this.a2 = a;
        this.cz.width = this.a2;
        this.q = true;
    }
    bx() {
        if (!this.z) {
            return;
        }
        this.l = true;
        this.g = new CanvasPlaceholderView();
        this.c = 0;
        this.e = 1;
        this.g.l = Color.u(120, 120, 120, 120);
        this.g.h = 0;
    }
    b8(a) {
        this.o = true;
        this.ct = a;
        this.m = this.ct.l == 255;
        this.cz._fill = ((() => {
            let $ret = new Brush();
            $ret.color = this.ct;
            return $ret;
        })());
    }
    ce(a) {
        this.o = true;
        this.bv = a;
    }
    cp(a) {
        if (!this.z) {
            return;
        }
        this.o = true;
        this.g.h = (a * 0.20000000298023224);
    }
    b1(a, b, c, d) {
        if (this.g != null) {
            let e = this.aw;
            let f = this.av;
            if (this.e == 1) {
                b = truncate((b + (d / 2) - (f / 2)));
            }
            else if (this.e == 2) {
                b = truncate((b + (d) - (f)));
            }
            if (this.c == 1) {
                a = truncate((a + (c / 2) - (e / 2)));
            }
            else if (this.c == 2) {
                a = truncate((a + (c) - (e)));
            }
        }
    }
    cb(a) {
        this.i = a;
        this.p = true;
        this.o = true;
        this.q = true;
    }
    co(a) {
        if (!this.z) {
            return;
        }
        this.o = true;
        let b = DeviceUtils.f(12);
        if (a.x != null && !isNaN_(a.x.d)) {
            b = a.x.d;
        }
        if (this.av != b) {
            this.av = b;
        }
        let c = a.e2 * 0.2;
        let d = a.dt * 0.6;
        if (this.aw >= c && this.aw <= d) {
            return;
        }
        let e = (CanvasGridCellBase.bs.nextDouble() * (d - c) + c);
        if (this.aw != e) {
            this.aw = e;
        }
    }
    cm(a, b) {
        if (!this.z) {
            return;
        }
        this.o = true;
        this.c = a;
        this.e = b;
    }
    cn(a) {
        if (!this.z) {
            return;
        }
        this.o = true;
    }
    b7(a) {
        this.a = a;
    }
    get d() {
        return this.b;
    }
    cd(a) {
        this.b = a;
        this.o = true;
        this.q = true;
    }
    cq() {
        if (this.bw == null) {
            return;
        }
        if (this.j == null) {
            return;
        }
        if (this.p || (this.i != null && this.i.g != this.bo)) {
            this.p = false;
            this.bo = this.i.g;
            this.j.ac(this.i);
        }
        let a;
        if (this.h != this.i || this.bq != this.i.g) {
            this.h = this.i;
            this.bq = this.i.g;
            this.ao = FontUtil.getCurrentFontHeight(this.bj, this.i);
        }
        a = this.ao;
        let b = 0;
        let c = 0;
        let d = this.a2;
        let e = this.ap;
        d -= (this.af + this.ar + this.ag + this.as);
        e -= (this.ah + this.at + this.ae + this.aq);
        d = Math.max(d, 0);
        e = Math.max(e, 0);
        let f = d;
        if (!isNaN_(this.ay) && this.ay < d) {
            f = this.ay;
        }
        let g = this.bh(this.cr, this.bw, f, this.j);
        switch (this.b) {
            case 0:
                b = this.ar + this.af;
                break;
            case 3:
            case 1:
                b = this.ar + this.af + ((d / 2) - (g / 2));
                break;
            case 2:
                b = Math.max(0, (this.a2 - (this.as + this.ag))) - g;
                break;
        }
        switch (this.f) {
            case 0:
                c = this.at + this.ah;
                break;
            case 3:
            case 1:
                c = this.at + this.ah + ((e / 2) - (a / 2));
                break;
            case 2:
                c = Math.max(0, (this.ap - (this.aq + this.ae))) - a;
                break;
        }
        this.ax = b;
        this.az = this.ax + g;
        this.a0 = c;
        this.a1 = this.a0 + (a / 2);
        this.o = true;
    }
    bh(a, b, c, d) {
        let e = b;
        let f = e.length;
        let g = ("\u2026");
        if (isNaN_(this.am)) {
            this.am = d.f(g);
        }
        if (c <= this.am) {
            a.ak = g;
            return this.am;
        }
        let h = d.f(e);
        if (h <= c) {
            a.ak = b;
            return h;
        }
        let i = c / h;
        let j = truncate(Math.ceil(f * i));
        let k = e.substr(0, j) + g;
        let l = d.f(k);
        if (l > c) {
            f = j;
        }
        else {
            j = j + 1;
            k = e.substr(0, j) + g;
            l = d.f(k);
            if (l > c) {
                f = j;
            }
        }
        while (h > c && f > 0) {
            f--;
            e = e.substr(0, f) + g;
            h = d.f(e);
        }
        a.ak = e;
        return h;
    }
    ck(a) {
        this.f = a;
        this.o = true;
        this.q = true;
    }
    ad(a) {
        return a.isClickActionDesired;
    }
    onContactStarted(a, b) {
        if (this.a != null && this.ad(this.a)) {
            this.bt = a.pageX;
            this.bu = a.pageY;
            this.a.mouseDownCell(this.bt, this.bu);
        }
    }
    onContactMoved(a, b) {
        if (this.a != null && this.ad(this.a)) {
            let c = a.pageX;
            let d = a.pageY;
            if (this.a.isMouseDown) {
                if (b) {
                    if (PointUtil.equals(this.a.mousePosition, null) || Math.abs(c - this.a.mousePosition.x) > CanvasGridCellBase.bp || Math.abs(d - this.a.mousePosition.y) > CanvasGridCellBase.bp) {
                        this.a.mouseUpCell(c, d);
                    }
                    else {
                        a.stopPropagation();
                    }
                }
                else {
                    if (PointUtil.equals(this.a.mousePosition, null)) {
                        this.a.mouseUpCell(c, d);
                    }
                    else {
                        if (Math.abs(c - this.a.mousePosition.x) > CanvasGridCellBase.bn || Math.abs(d - this.a.mousePosition.y) > CanvasGridCellBase.bn) {
                            this.a.isControlPressed = a.ctrlKey;
                            this.a.dragStarted();
                        }
                    }
                }
            }
        }
    }
    onContactCompleted(a, b) {
        if (this.a != null && this.ad(this.a)) {
            let c = a.pageX;
            let d = a.pageY;
            if (PointUtil.equals(this.a.mousePosition, null) || Math.abs(c - this.a.mousePosition.x) > CanvasGridCellBase.bp || Math.abs(d - this.a.mousePosition.y) > CanvasGridCellBase.bp || this.a.isDrag) {
                this.a.mouseUpCell(c, d);
            }
            if (this.a.isCellDown()) {
                this.a.isControlPressed = a.ctrlKey;
                this.a.isShiftPressed = a.shiftKey;
                this.a.clickCell();
                this.a.mouseUpCell(a.pageX, a.pageY);
            }
        }
    }
}
CanvasGridCellBase.$t = markType(CanvasGridCellBase, 'CanvasGridCellBase', Base.$, [INativeCell_$type]);
CanvasGridCellBase.bs = new Random(0);
CanvasGridCellBase.bp = 10;
CanvasGridCellBase.bn = 3;

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasTextCell extends CanvasGridCellBase {
    constructor(a) {
        super(a);
        this.cd(0);
        this.ck(1);
    }
    get_z() {
        return true;
    }
}
CanvasTextCell.$t = markType(CanvasTextCell, 'CanvasTextCell', CanvasGridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasCellPresenterBase extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.a = a;
    }
    modelUpdated(a) {
        this.b(a);
    }
    b(a) {
        this.a.b7(a.c);
        if (a.al(CellModel.c9) || a.al(CellModel.dd) || a.al(CellModel.db) || a.al(CellModel.c7)) {
            this.a.cf(a.c8, a.dc, a.da, a.c6);
        }
        if (a.af) {
            this.a.b9(a.h6, a.cy, a.c3, a.c1, a.cw);
        }
        if (a.av) {
            this.a.cc(a.dt);
            this.a.cl(a.e2);
        }
        if (a.ah) {
            if (a.ap && !this.a.t) {
                this.a.bx();
            }
            if (a.al(CellModel.cv)) {
                this.a.b8(a.h5.color);
            }
            if (a.al(CellModel.c5)) {
                this.a.ce(a.bh);
            }
        }
        if (a.av && a.ap) {
            this.a.co(a);
        }
    }
    c(a, b, c) {
        if (c == 0) {
            return a.color;
        }
        if (c == 1) {
            return b.color;
        }
        let d = BrushUtil.g(a, c, b, 0);
        return d.color;
    }
    get nativeCell() {
        return this.a;
    }
    get isCanvasBased() {
        return true;
    }
}
CanvasCellPresenterBase.$t = markType(CanvasCellPresenterBase, 'CanvasCellPresenterBase', Base.$, [ICellPresenter_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasContentCellModelHelper extends Base {
    static c(a) {
        if (a == null) {
            return CanvasContentCellModelHelper.b;
        }
        return a.color;
    }
    static a(a, b, c) {
        if (b.ah) {
            if (b.al(CellModel.dp) || b.al(CellModel.e1)) {
                let d = Math.min(1, Math.max(0, b.bq));
                let e = b.bi * (1 - d);
                c.ca(e);
                if (b.ap) {
                    c.cp(b.bi * d);
                }
            }
            if (b.al(CellModel.ex)) {
                let f = CanvasContentCellModelHelper.c((b).ig);
                c.cj(f);
                if (b.ap) {
                    c.cn(b.ig);
                }
            }
            if (b.al(CellModel.d7)) {
            }
            if (b.al(CellModel.dv) || b.al(CellModel.e0)) {
                let g = b.e;
                let h = b.g;
                c.cd(g);
                c.ck(h);
                if (b.ap) {
                    c.cm(g, h);
                }
            }
            if (b.al(CellModel.dr)) {
                let i = b.x;
                if (i == null) {
                    i = FontUtil.getDefaultFont(a);
                }
                c.cb(i);
            }
        }
    }
}
CanvasContentCellModelHelper.$t = markType(CanvasContentCellModelHelper, 'CanvasContentCellModelHelper');
CanvasContentCellModelHelper.b = Color.u(0, 0, 0, 0);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasTextCellPresenter extends CanvasCellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(TextCellModel.ih) || a.al(CellModel.ea)) {
                if (b.ij != null) {
                    b.gq = b.ij;
                }
                else {
                    if (b.fb == null) {
                        b.gq = "";
                    }
                    else {
                        b.gq = b.fb.toString();
                    }
                }
                this.d.ci(b.gq);
            }
            CanvasContentCellModelHelper.a(this.a.bk, b, this.a);
        }
    }
}
CanvasTextCellPresenter.$t = markType(CanvasTextCellPresenter, 'CanvasTextCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasNumericCell extends CanvasTextCell {
    constructor(a) {
        super(a);
        this.cd(2);
        this.ck(1);
    }
}
CanvasNumericCell.$t = markType(CanvasNumericCell, 'CanvasNumericCell', CanvasTextCell.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class NumericCellFormatter extends Base {
    static c() {
        if (NumericCellFormatter.a != null) {
            return NumericCellFormatter.a;
        }
        let a = "";
        let b = 1.1;
        let c = b.toLocaleString();
        let d = false;
        for (let e = 0; e < c.length; e++) {
            if (c.charAt(e) == '1') {
                d = !d;
            }
            if (c.charAt(e) != '1' && d) {
                a += c.charAt(e);
            }
        }
        NumericCellFormatter.a = a;
        return NumericCellFormatter.a;
    }
    static b(a) {
        let b = a.io;
        let c = a.io;
        let d = 10;
        let e = 0;
        let f = "0";
        if (isNaN_(a.io)) {
            return "";
        }
        let g = 0;
        if (a.io >= 0) {
            g = a.io - Math.floor(a.io);
        }
        else {
            g = Math.abs(a.io - Math.ceil(a.io));
        }
        let h = 0;
        if (a.io >= 0) {
            h = a.io - g;
        }
        else {
            h = a.io + g;
        }
        let i = Math.abs(h);
        let j = g.toString();
        if (g == 0) {
            j = "";
        }
        else {
            j = j.substr(2);
        }
        let k = Math.round(i).toString();
        d = a.iu;
        e = a.iw;
        if (e < 0) {
            e = 0;
        }
        if (d < 0) {
            d = 10;
        }
        if (e > d) {
            d = e;
        }
        if (j.length > d) {
            let l = Math.round(g * (Math.pow(10, d))) / (Math.pow(10, d));
            j = (l).toString();
            if (l == 1) {
                if (a.io >= 0) {
                    h += 1;
                    i += 1;
                }
                else {
                    h -= 1;
                    i += 1;
                }
                j = "";
                k = Math.round(i).toString();
            }
            else if (l == 0) {
                j = "";
            }
            else {
                j = j.substr(2);
            }
        }
        let m = k.length;
        let n = Math.max(0, a.iy - k.length);
        let o = Math.max(0, a.iw - j.length);
        let p = false;
        if (k.charAt(0) == '1') {
            p = true;
        }
        for (let q = 0; q < n; q++) {
            let r = "0";
            if (a.il) {
                if (p) {
                    r = "9";
                }
                else {
                    r = "1";
                }
            }
            k = r + k;
        }
        for (let s = 0; s < o; s++) {
            j = j + "0";
        }
        if (d == 0) {
            j = "";
        }
        if (a.il && k.length > 0) {
            let t = parseInt(k);
            let u = t.toLocaleString();
            let v = '1';
            if (p) {
                v = '9';
            }
            let w = true;
            let x = "";
            for (let y = 0; y < u.length; y++) {
                if (u.charAt(y) == v && w) {
                    x += "0";
                }
                else {
                    x += u.charAt(y);
                    if (isDigit(u.charAt(y)) && u.charAt(y) != v) {
                        w = false;
                    }
                }
            }
            k = x;
        }
        if (h < 0) {
            k = "-" + k;
        }
        let z = k;
        if (j.length > 0) {
            z += NumericCellFormatter.c() + j;
        }
        if (b >= 0) {
            if (!stringIsNullOrEmpty(a.jn)) {
                z = a.jn + z;
            }
            if (!stringIsNullOrEmpty(a.jp)) {
                z += a.jp;
            }
        }
        else {
            if (!stringIsNullOrEmpty(a.ji)) {
                z = a.ji + z;
            }
            if (!stringIsNullOrEmpty(a.jk)) {
                z += a.jk;
            }
        }
        return z;
    }
}
NumericCellFormatter.$t = markType(NumericCellFormatter, 'NumericCellFormatter');
NumericCellFormatter.a = null;

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasNumericCellPresenter extends CanvasCellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(NumericCellModel.i2) || b.ik()) {
                b.gq = this.e(b);
                this.d.ci(b.gq);
            }
            CanvasContentCellModelHelper.a(this.a.bk, b, this.a);
        }
    }
    e(a) {
        if (a.i8 != null) {
            let val_ = a.io;
            let override_ = a.i8;
            return (override_.format(val_));
        }
        return NumericCellFormatter.b(a);
    }
}
CanvasNumericCellPresenter.$t = markType(CanvasNumericCellPresenter, 'CanvasNumericCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasDateTimeCell extends CanvasTextCell {
    constructor(a) {
        super(a);
    }
}
CanvasDateTimeCell.$t = markType(CanvasDateTimeCell, 'CanvasDateTimeCell', CanvasTextCell.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasDateTimeCellPresenter extends CanvasCellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(DateTimeCellModel.ir) || a.al(DateTimeCellModel.is) || a.al(DateTimeCellModel.iq)) {
                this.e(b);
                this.d.ci(b.gq);
            }
            CanvasContentCellModelHelper.a(this.a.bk, b, this.a);
        }
    }
    e(a) {
        a.gq = a.i0(a.ip);
        if (a.gq == stringEmpty() && a.fb != null) {
            a.gq = a.fb.toString();
        }
    }
}
CanvasDateTimeCellPresenter.$t = markType(CanvasDateTimeCellPresenter, 'CanvasDateTimeCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class SortIndicatorRenderCompletedEventArgs extends EventArgs {
}
SortIndicatorRenderCompletedEventArgs.$t = markType(SortIndicatorRenderCompletedEventArgs, 'SortIndicatorRenderCompletedEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridSortIndicatorView extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.d = new List$1(Path.$, 0);
        this.i = 0;
        this.h = 0;
        this.b = 0;
        this.m = null;
        this.c = null;
        this.l = null;
        this.f = 0;
        this.e = 0;
        this.g = 1;
        this.k = 0;
        this.j = 0;
        this.a = a;
    }
    s() {
        if (this.m == null || this.c == null) {
            return;
        }
        if (this.i != this.k || this.h != this.j || this.b != this.a.f) {
            this.d.clear();
            switch (this.a.f) {
                case 0:
                    this.n();
                    break;
                case 1:
                    this.o();
                    break;
                case 2:
                    this.p();
                    break;
            }
            this.i = this.k;
            this.h = this.j;
            this.b = this.a.f;
        }
        switch (this.a.f) {
            case 0:
                this.u();
                break;
            case 1:
                this.v();
                break;
            case 2:
                this.w();
                break;
        }
        let a = Math.round(this.k * this.g);
        let b = Math.round(this.j * this.g);
        if (this.f != a || this.e != b) {
            this.m.setAttribute("width", a.toString());
            this.m.setAttribute("height", b.toString());
            this.m.setStyleProperty("width", this.k.toString() + "px");
            this.m.setStyleProperty("height", this.j.toString() + "px");
            this.m.setStyleProperty("top", "0px");
            this.m.setStyleProperty("left", "0px");
            this.f = truncate(Math.round(a));
            this.e = truncate(Math.round(b));
        }
        if (this.c.d && this.g != 1) {
            this.c.z();
            this.c.aa(this.g, this.g);
        }
        this.c.k(0, 0, this.k, this.j);
        this.c.z();
        this.c.aa(this.a.u(), this.a.u());
        for (let c = 0; c < this.d.count; c++) {
            this.c.j(this.d._inner[c].j);
            let d = this.x();
            if (this.a.ax != null) {
                d = this.a.ax;
            }
            this.d._inner[c]._stroke = d;
            this.c.s(this.d._inner[c]);
        }
        this.c.y();
        if (this.c.d && this.g != 1) {
            this.c.y();
        }
        this.a.aq();
    }
    t() {
        this.s();
    }
    n() {
        this.a.al(this.k, this.j, this.d);
    }
    u() {
        if (this.d.count != 1) {
            return;
        }
        this.d._inner[0]._opacity = this.a.q;
        let a = { $type: Point_$type, x: this.k / 2, y: this.j / 2 };
        let b = new TransformGroup();
        b.j.add(((() => {
            let $ret = new TranslateTransform();
            $ret.j = -a.x;
            $ret.k = -a.y;
            return $ret;
        })()));
        b.j.add(((() => {
            let $ret = new RotateTransform();
            $ret.j = this.a.p;
            return $ret;
        })()));
        b.j.add(((() => {
            let $ret = new TranslateTransform();
            $ret.j = a.x;
            $ret.k = a.y;
            return $ret;
        })()));
        this.d._inner[0].j = b;
    }
    o() {
        this.a.am(this.k, this.j, this.d);
    }
    v() {
        if (this.d.count != 4) {
            return;
        }
        this.d._inner[0]._opacity = this.a.q;
        this.d._inner[1]._opacity = this.a.q;
        this.d._inner[2]._opacity = this.a.w;
        this.d._inner[3]._opacity = this.a.w;
    }
    p() {
        this.a.an(this.k, this.j, this.d);
    }
    w() {
        this.d._inner[0]._opacity = this.a.q;
        this.d._inner[1]._opacity = this.a.w;
    }
    q(a) {
        if (a == null) {
            this.m = null;
            this.l = null;
            this.c = null;
            return;
        }
        this.g = (isNaN_(this.a.v) ? this.a.o : this.a.v);
        let b = a;
        this.l = b;
        this.a.j.u(this.l);
        this.a.i.u(this.l);
        this.l.rootWrapper.addClass("ui-radialgauge-container");
        let c = this.g;
        let d = Math.round(b.rootWrapper.width());
        let e = Math.round(b.rootWrapper.height());
        let f = d * c;
        let g = e * c;
        this.l.rootWrapper.setStyleProperty("position", "relative");
        let h = this.l.createElement("canvas");
        h.setStyleProperty("position", "absolute");
        this.l.append(h);
        this.f = truncate(Math.round(f));
        this.e = truncate(Math.round(g));
        h.setAttribute("width", f.toString());
        h.setAttribute("height", g.toString());
        h.setStyleProperty("width", d.toString() + "px");
        h.setStyleProperty("height", e.toString() + "px");
        this.k = d;
        this.j = e;
        this.m = h;
        let i = this.l.get2DCanvasContext(this.m);
        this.c = new RenderingContext(new CanvasViewRenderer(), i);
        if (isNaN_(this.a.v)) {
            this.a.o = window.devicePixelRatio;
            this.g = this.a.o;
        }
        this.s();
    }
    r(a, b) {
        if (isNaN_(this.a.v)) {
            this.a.o = window.devicePixelRatio;
            this.g = this.a.o;
        }
        this.k = a;
        this.j = b;
        this.s();
    }
    x() {
        return ((() => {
            let $ret = new Brush();
            $ret.color = Color.u(138, 0, 0, 0);
            return $ret;
        })());
    }
}
GridSortIndicatorView.$t = markType(GridSortIndicatorView, 'GridSortIndicatorView');
/**
 * @hidden
 */
class GridSortIndicator extends Base {
    constructor() {
        super();
        this.aa = null;
        this.a = 0;
        this.aw = null;
        this.k = true;
        this.propertyChanged = null;
        this.g = null;
        this.h = null;
        this.n = NaN;
        this.m = 1;
        this.e = 0;
        this.q = 0;
        this.p = 0;
        this.w = 0;
        this.s = 0;
        this.r = 0;
        this.y = 0;
        this.x = 0;
        this.t = 0;
        this.z = 0;
        this.c = null;
        this.renderCompleted = null;
        this.q = 0;
        this.w = 0.5;
        this.p = 180;
        this.c = new GridSortIndicatorView(this);
        this.g = new DoubleAnimator(0, 1, 400);
        this.h = new DoubleAnimator(0, 1, 400);
        this.g.b = EasingFunctions.cubicEase;
        this.h.b = EasingFunctions.cubicEase;
        let a = this.g;
        a.propertyChanged = delegateCombine(a.propertyChanged, runOn(this, this.aj));
        let b = this.h;
        b.propertyChanged = delegateCombine(b.propertyChanged, runOn(this, this.ak));
    }
    get ab() {
        return this.aa;
    }
    set ab(a) {
        this.aa = a;
    }
    get b() {
        return this.a;
    }
    set b(a) {
        let b = this.a;
        this.a = a;
        if (b != this.a) {
            this.ap("SortDirection", enumGetBox(ColumnSortDirection_$type, b), enumGetBox(ColumnSortDirection_$type, this.a));
        }
    }
    get ax() {
        return this.aw;
    }
    set ax(a) {
        let b = this.aw;
        this.aw = a;
        if (b != this.aw) {
            this.ap("IconColor", b, this.aw);
        }
    }
    get l() {
        return this.k;
    }
    set l(a) {
        let b = this.k;
        this.k = a;
        if (b != this.k) {
            this.ap("IsAnimationEnabled", b, this.k);
        }
    }
    get i() {
        return this.g;
    }
    get j() {
        return this.h;
    }
    get v() {
        return this.n;
    }
    set v(a) {
        let b = this.n;
        this.n = a;
        this.ap("PixelScalingRatio", b, this.n);
    }
    get o() {
        return this.m;
    }
    set o(a) {
        let b = this.m;
        this.m = a;
        this.ap("ActualPixelScalingRatio", b, this.m);
    }
    get f() {
        return this.e;
    }
    set f(a) {
        let b = this.e;
        this.e = a;
        if (b != this.e) {
            this.ap("SortIndicatorStyle", enumGetBox(SortIndicatorStyle_$type, b), enumGetBox(SortIndicatorStyle_$type, this.e));
        }
    }
    ap(a, b, c) {
        this.at(a, b, c);
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
    }
    at(a, b, c) {
        switch (a) {
            case "PixelScalingRatio":
                this.o = this.v;
                break;
            case "ActualPixelScalingRatio":
                this.c.t();
                break;
            case "IconColor":
                this.c.t();
                break;
            case "SortIndicatorStyle":
                switch (this.f) {
                    case 0:
                        this.ar(this.b, false);
                        break;
                    case 1:
                    case 2:
                        this.as(this.b, false);
                        break;
                }
                break;
            case "SortDirection":
                switch (this.f) {
                    case 0:
                        this.ar(EnumUtil.getEnumValue(ColumnSortDirection_$type, c), this.l);
                        break;
                    case 1:
                    case 2:
                        this.as(EnumUtil.getEnumValue(ColumnSortDirection_$type, c), this.l);
                        break;
                }
                break;
        }
    }
    ak(a, b) {
        switch (this.f) {
            case 0:
                this.q = this.s + this.h.o * (this.y - this.s);
                break;
            case 1:
            case 2:
                this.q = this.s + this.h.o * (this.y - this.s);
                this.w = this.t + this.h.o * (this.z - this.t);
                break;
        }
        this.c.t();
    }
    aj(a, b) {
        this.p = this.r + this.g.o * (this.x - this.r);
        this.c.t();
    }
    ar(a, b) {
        this.s = this.q;
        this.r = this.p;
        if (this.l || this.g.f() || this.h.f()) {
            this.g.w();
            this.h.w();
        }
        if (a == 0) {
            this.y = 0;
            this.x = 180;
        }
        else {
            this.y = 1;
            if (a == 1) {
                this.x = 180;
            }
            else {
                this.x = 0;
            }
        }
        if (b) {
            this.g.v();
            this.h.v();
        }
        else {
            this.p = this.x;
            this.q = this.y;
            this.c.t();
        }
    }
    as(a, b) {
        this.s = this.q;
        this.t = this.w;
        if (this.l || this.h.f()) {
            this.h.w();
        }
        switch (a) {
            case 0:
                this.y = 0.4;
                this.z = 0.4;
                break;
            case 1:
                this.y = 1;
                this.z = 0.2;
                break;
            case 2:
                this.y = 0.2;
                this.z = 1;
                break;
        }
        if (b) {
            this.h.v();
        }
        else {
            this.q = this.y;
            this.w = this.z;
            this.c.t();
        }
    }
    u() {
        switch (this.f) {
            case 0: return 1;
            case 1: return 0.71;
            case 2: return 1;
        }
        return 1;
    }
    au(a) {
        this.c.q(a);
    }
    av(a) {
        this.j.u(a);
        this.i.u(a);
    }
    ac() {
        return this.c.m.getNativeElement();
    }
    ao(a, b) {
        this.c.r(a, b);
    }
    al(a, b, c) {
        let d = Math.min(a, b);
        let e = { $type: Point_$type, x: a / 2, y: b / 2 };
        let f = d * 0.8;
        let g = f / 2;
        let h = g / 2;
        let i = new PathFigure();
        i._startPoint = { $type: Point_$type, x: e.x, y: e.y - g };
        let j = new LineSegment(1);
        j.c = { $type: Point_$type, x: e.x, y: e.y + g };
        i._segments.add(j);
        let k = new PathFigure();
        k._startPoint = { $type: Point_$type, x: e.x - g, y: (e.y + g) - g };
        let l = new LineSegment(1);
        l.c = { $type: Point_$type, x: e.x, y: e.y + g };
        let m = new LineSegment(1);
        m.c = { $type: Point_$type, x: e.x + g, y: (e.y + g) - g };
        k._segments.add(l);
        k._segments.add(m);
        let n = new PathGeometry();
        n.c.add(i);
        n.c.add(k);
        let o = new Path();
        o.ak = n;
        o._stroke = this.c.x();
        o.ac = 1;
        c.add(o);
    }
    am(a, b, c) {
        let d = Geometry.a("M3.792172, 7.800278 L7.983785, 3.635676 L12.148387, 7.800278L12.148387, 7.800278");
        let e = Geometry.a("M7.97027972,4.10930186 L7.97027972,13.8116223 L7.97027972,4.10930186 Z");
        let f = Geometry.a("M11.851613, 16.199722 L16.043224, 20.364325  L20.207829, 16.199722");
        let g = Geometry.a("M16.043224,10.1883777 L16.043224,19.8906981 L16.043224,10.1883777 Z");
        c.add(((() => {
            let $ret = new Path();
            $ret.ak = d;
            $ret.aj = 2;
            $ret.stroke = this.c.x();
            $ret.ac = 2;
            return $ret;
        })()));
        c.add(((() => {
            let $ret = new Path();
            $ret.ak = e;
            $ret.aj = 2;
            $ret.stroke = this.c.x();
            $ret.ac = 2;
            return $ret;
        })()));
        c.add(((() => {
            let $ret = new Path();
            $ret.ak = f;
            $ret.aj = 2;
            $ret.stroke = this.c.x();
            $ret.ac = 2;
            return $ret;
        })()));
        c.add(((() => {
            let $ret = new Path();
            $ret.ak = g;
            $ret.aj = 2;
            $ret.stroke = this.c.x();
            $ret.ac = 2;
            return $ret;
        })()));
    }
    an(a, b, c) {
        let d = { $type: Point_$type, x: a / 2, y: b / 2 };
        let e = { $type: Point_$type, x: d.x - 3.5, y: d.y - 1.5 };
        let f = { $type: Point_$type, x: d.x - 3.5, y: d.y + 1.5 };
        let g = Geometry.a("M" + e.x.toString() + ", " + e.y.toString() + " l 3.5,-3.5 3.5,3.5");
        let h = Geometry.a("M" + f.x.toString() + ", " + f.y.toString() + " l 3.5,3.5 3.5,-3.5");
        c.add(((() => {
            let $ret = new Path();
            $ret.ak = g;
            $ret.aj = 2;
            $ret.stroke = this.c.x();
            $ret.ac = 2;
            return $ret;
        })()));
        c.add(((() => {
            let $ret = new Path();
            $ret.ak = h;
            $ret.aj = 2;
            $ret.stroke = this.c.x();
            $ret.ac = 2;
            return $ret;
        })()));
    }
    aq() {
        if (this.renderCompleted != null) {
            this.renderCompleted(this, new SortIndicatorRenderCompletedEventArgs());
        }
    }
}
GridSortIndicator.$t = markType(GridSortIndicator, 'GridSortIndicator', Base.$, [INotifyPropertyChanged_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasTextHeaderCell extends CanvasGridCellBase {
    constructor(a) {
        super(a);
        this.c0 = null;
        this.c3 = null;
        this.c2 = null;
        this.cd(0);
        this.ck(1);
        this.c0 = new GridSortIndicator();
        let b = a.createElement("div");
        b.setRawStyleProperty("display", "inline-block");
        b.setRawStyleProperty("width", "16px");
        b.setRawStyleProperty("height", "16px");
        this.c3 = b;
        let c = a.getSubRenderer(this.c3);
        this.c0.au(c);
        this.c0.v = window.devicePixelRatio;
        let d = this.c0;
        d.renderCompleted = delegateCombine(d.renderCompleted, (d, e) => this.b2());
        this.c0.ao(16, 16);
        this.c2 = this.c0.ac();
    }
    get c1() {
        return this.c0;
    }
    c4(a) {
        this.c1.b = a;
        this.b2();
    }
    b4(a) {
        super.b4(a);
        let b = this.bf + 5;
        if (this.d == 2) {
            b = this.bd - 21;
        }
        a.m(this.c2, 1, b, this.bg - 8, 16, 16);
    }
    get_y() {
        return true;
    }
}
CanvasTextHeaderCell.$t = markType(CanvasTextHeaderCell, 'CanvasTextHeaderCell', CanvasGridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasTextHeaderCellPresenter extends CanvasCellPresenterBase {
    constructor(a) {
        super(a);
        this.e = null;
    }
    get d() {
        return this.a;
    }
    f() {
        if (this.e != null) {
            this.e();
        }
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(TextCellModel.ih)) {
                b.gq = b.ij;
                this.d.ci(b.gq);
            }
            if (a.al(CellModel.et)) {
                if (a.aw) {
                    this.d.c1.l = false;
                }
                if (this.e == null) {
                    let c = a.m;
                    this.e = () => c.n9();
                }
                this.d.c4(a.k);
                this.d.ch(runOn(this, this.f));
                if (a.aw) {
                    this.d.c1.l = true;
                }
            }
            if (a.al(CellModel.eu)) {
                if (a.aw) {
                    this.d.c1.l = false;
                }
                this.d.c1.ax = a.id;
                if (a.aw) {
                    this.d.c1.l = true;
                }
            }
            if (a.ak("SortIndicatorStyle")) {
                this.d.c1.f = b.im;
            }
            CanvasContentCellModelHelper.a(this.a.bk, b, this.a);
        }
    }
}
CanvasTextHeaderCellPresenter.$t = markType(CanvasTextHeaderCellPresenter, 'CanvasTextHeaderCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasRowSeparatorCell extends CanvasGridCellBase {
    constructor(a) {
        super(a);
    }
}
CanvasRowSeparatorCell.$t = markType(CanvasRowSeparatorCell, 'CanvasRowSeparatorCell', CanvasGridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasRowSeparatorCellPresenter extends CanvasCellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
}
CanvasRowSeparatorCellPresenter.$t = markType(CanvasRowSeparatorCellPresenter, 'CanvasRowSeparatorCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasImageCell extends CanvasGridCellBase {
    constructor(a) {
        super(a);
        this.c0 = 1;
        this.c1 = 3;
        this.c5 = null;
        this.c2 = 1;
        this.c4 = null;
        this.c4 = a.createElement("img");
    }
    get c3() {
        return this.c2;
    }
    set c3(a) {
        this.c2 = a;
    }
    c8(a, b) {
        this.c6();
        this.c4.setRawStyleProperty("opacity", "0");
        if (a == null || a.length == 0) {
            this.c7(this.c4);
            return;
        }
        if (Base.equalsStatic(a, this.c5)) {
            return;
        }
        this.db(a, b);
    }
    c7(a) {
        a.setAttribute("src", "");
    }
    db(a, b) {
        this.c5 = a;
        this.c4.setAttribute("src", a);
    }
    c6() {
        this.c7(this.c4);
        this.c5 = "";
    }
    c9(a) {
        this.x = true;
        this.c0 = a;
    }
    da(a) {
        this.x = true;
        this.c1 = a;
    }
    get_z() {
        return true;
    }
}
CanvasImageCell.$t = markType(CanvasImageCell, 'CanvasImageCell', CanvasGridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasImageCellPresenter extends CanvasCellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(CellModel.dp) || a.al(CellModel.e1)) {
                let c = Math.min(1, Math.max(0, a.bq));
                let d = a.bi * (1 - c);
                this.d.c3 = d;
            }
            if (b.al(ImageCellModel.il) || b.al(ImageCellModel.im)) {
                this.e(b.iq, b.ii);
            }
            if (b.al(ImageCellModel.io) || b.al(ImageCellModel.dv) || b.al(ImageCellModel.e0)) {
                this.f(b.ik, b.e, b.g);
            }
            if (b.al(ImageCellModel.ev)) {
                if (a.r == 1) {
                    this.d.c6();
                }
                else if (a.r == 2) {
                    this.e(b.iq, b.ii);
                }
            }
        }
    }
    f(a, b, c) {
    }
    e(a, b) {
        let c = a.toLowerCase();
        if (b == 0) {
            b = 4;
        }
        if (stringStartsWith(c, "http") || b == 4) {
            this.d.c8(a, 4);
        }
        if (stringStartsWith(c, "asset") || b == 2) {
            let d = a;
            if (stringStartsWith(c, "asset")) {
                d = a.substr(8);
            }
            this.d.c8(d, 2);
        }
        if (stringStartsWith(c, "drawable") || b == 1) {
            let e = a;
            if (stringStartsWith(c, "drawable")) {
                e = a.substr(11);
            }
            this.d.c8(e, 1);
        }
        if (stringStartsWith(c, "nativeresource") || b == 1) {
            let f = a;
            if (stringStartsWith(c, "nativeresource")) {
                f = a.substr(17);
            }
            this.d.c8(f, 1);
        }
        if (stringStartsWith(c, "embeddedresource") || b == 3) {
            let g = a;
            if (stringStartsWith(c, "embeddedresource")) {
                g = a.substr(19);
            }
            this.d.c8(g, 3);
        }
    }
}
CanvasImageCellPresenter.$t = markType(CanvasImageCellPresenter, 'CanvasImageCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasTemplateCellContainer extends Base {
    constructor(a) {
        super();
        this.d = null;
        this.c = null;
        this._opacity = 0;
        this.c = a;
    }
    get isCanvasBased() {
        return true;
    }
    get opacity() {
        return this._opacity;
    }
    set opacity(a) {
        this._opacity = a;
    }
}
CanvasTemplateCellContainer.$t = markType(CanvasTemplateCellContainer, 'CanvasTemplateCellContainer');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasTemplateCell extends CanvasGridCellBase {
    constructor(a) {
        super(a);
        this.c0 = null;
        this.c0 = new CanvasTemplateCellContainer(a);
    }
    get c1() {
        return this.c0;
    }
    get_z() {
        return true;
    }
    c2() {
        this.b0();
    }
}
CanvasTemplateCell.$t = markType(CanvasTemplateCell, 'CanvasTemplateCell', CanvasGridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasTemplateCellPresenter extends CanvasCellPresenterBase {
    constructor(a, b) {
        super(a);
        this.d = null;
        this.d = b;
    }
    get e() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        let c = this.d.actualColumns._inner[a.i.al];
        if (a.al(CellModel.dp) || a.al(CellModel.e1)) {
            let d = Math.min(1, Math.max(0, a.bq));
            let e = a.bi * (1 - d);
            this.e.c1.opacity = e;
        }
        this.e.c2();
        c.gu(a, this.e);
    }
}
CanvasTemplateCellPresenter.$t = markType(CanvasTemplateCellPresenter, 'CanvasTemplateCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasTemplateHeaderCell extends CanvasGridCellBase {
    constructor(a) {
        super(a);
        this.c0 = null;
        this.c0 = new CanvasTemplateCellContainer(a);
    }
    get c1() {
        return this.c0;
    }
    get_y() {
        return true;
    }
    c2() {
        this.b0();
    }
}
CanvasTemplateHeaderCell.$t = markType(CanvasTemplateHeaderCell, 'CanvasTemplateHeaderCell', CanvasGridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasTemplateHeaderCellPresenter extends CanvasCellPresenterBase {
    constructor(a, b) {
        super(a);
        this.d = null;
        this.d = b;
    }
    get e() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = this.d.actualColumns._inner[a.i.al];
        let c = b.header;
        if (a.al(CellModel.dp) || a.al(CellModel.e1)) {
            let d = Math.min(1, Math.max(0, a.bq));
            let e = a.bi * (1 - d);
        }
        let f = a;
        this.e.c2();
        c.et(f, this.e);
    }
}
CanvasTemplateHeaderCellPresenter.$t = markType(CanvasTemplateHeaderCellPresenter, 'CanvasTemplateHeaderCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasSectionHeaderCell extends CanvasGridCellBase {
    constructor(a) {
        super(a);
        this.cd(0);
        this.ck(1);
    }
    get_z() {
        return true;
    }
}
CanvasSectionHeaderCell.$t = markType(CanvasSectionHeaderCell, 'CanvasSectionHeaderCell', CanvasGridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasSectionHeaderCellPresenter extends CanvasCellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(SectionHeaderCellModel.io) || a.al(SectionHeaderCellModel.iq)) {
                if (b.ij == null || (b.ij.length == 0 && b.iy == null)) {
                    if (b.fb == null) {
                        b.gq = "";
                    }
                    else {
                        b.gq = b.fb.toString();
                    }
                }
                else {
                    if (b.iw != null && b.im == 0) {
                        b.gq = b.iy + "    " + b.iw;
                    }
                    else {
                        b.gq = b.iy;
                    }
                }
                this.d.ci(b.gq);
            }
            CanvasContentCellModelHelper.a(this.a.bk, b, this.a);
        }
    }
}
CanvasSectionHeaderCellPresenter.$t = markType(CanvasSectionHeaderCellPresenter, 'CanvasSectionHeaderCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasVerticalSeparatorCell extends CanvasGridCellBase {
    constructor(a) {
        super(a);
    }
}
CanvasVerticalSeparatorCell.$t = markType(CanvasVerticalSeparatorCell, 'CanvasVerticalSeparatorCell', CanvasGridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasVerticalSeparatorCellPresenter extends CanvasCellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
}
CanvasVerticalSeparatorCellPresenter.$t = markType(CanvasVerticalSeparatorCellPresenter, 'CanvasVerticalSeparatorCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasSummaryCell extends CanvasGridCellBase {
    constructor(a) {
        super(a);
        this.c8 = null;
        this.dd = new TextBlock();
        this.c4 = 0;
        this.c5 = 0;
        this.c3 = 0;
        this.c0 = null;
        this.c7 = 0;
        this.c1 = false;
        this.c2 = true;
        this.c6 = 0;
        this.cd(2);
    }
    cl(a) {
        super.cl(a);
        this.be = intDivide(a, 2);
        this.c2 = true;
    }
    db(a) {
        this.c0 = a;
        this.c1 = true;
        this.x = true;
        this.c2 = true;
    }
    c9(a) {
        this.c8 = a;
        this.dd.ak = this.c8;
        this.x = true;
        this.c2 = true;
    }
    da(a) {
        this.x = true;
        this.dd.am = ((() => {
            let $ret = new Brush();
            $ret.color = a;
            return $ret;
        })());
    }
    dc(a) {
        if (this.dd.ak == null) {
            return;
        }
        if (a == null) {
            return;
        }
        if (this.c1 || (this.c0 != null && this.c0.g != this.c7)) {
            this.c1 = false;
            this.c7 = this.c0.g;
            a.ac(this.c0);
            this.c3 = FontUtil.getCurrentFontHeight(this.bk, this.c0);
        }
        let b = this.bi;
        let c = this.a7;
        b -= (this.a4 + this.a9 + this.a5 + this.ba);
        c -= (this.a6 + this.bb + this.a3 + this.a8);
        b = Math.max(b, 0);
        c = Math.max(c, 0);
        this.c6 = this.bh(this.dd, this.c8, b / 2, a);
        this.c4 = this.a9 + this.a4;
        this.c5 = this.bb + this.a6 + ((c / 2) - (this.c3 / 2));
    }
    b4(a) {
        if (this.dd.ak != null) {
            if (this.c2) {
                this.dc(a);
                this.c2 = false;
            }
            this.dd.n = this.c4;
            this.dd.o = this.c5;
            a.w(this.dd);
        }
        super.b4(a);
    }
    get_z() {
        return false;
    }
}
CanvasSummaryCell.$t = markType(CanvasSummaryCell, 'CanvasSummaryCell', CanvasGridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CanvasSummaryCellPresenter extends CanvasCellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.ak("ResolvedSummaryText") || a.ak("ResolvedSummaryValue")) {
                this.d.c9(b.im);
                this.d.ci(b.ip);
            }
            if (a.ak("SummaryNameTextColor")) {
                let c = CanvasContentCellModelHelper.c(b.it);
                this.d.da(c);
            }
            if (a.ak("FontInfo")) {
                this.d.db(b.x);
            }
            CanvasContentCellModelHelper.a(this.a.bk, b, this.a);
        }
    }
}
CanvasSummaryCellPresenter.$t = markType(CanvasSummaryCellPresenter, 'CanvasSummaryCellPresenter', CanvasCellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridExpansionIndicatorView extends Base {
    constructor(a) {
        super();
        this.k = null;
        this.f = 1;
        this.e = 0;
        this.d = 0;
        this.c = new List$1(Path.$, 0);
        this.m = null;
        this.b = null;
        this.l = null;
        this.j = 0;
        this.g = 0;
        this.i = 0;
        this.h = 0;
        this.a = null;
        this.a = a;
    }
    o(a) {
        if (a == null) {
            this.m = null;
            this.l = null;
            this.b = null;
            if (this.k != null) {
                window.removeEventListener("resize", this.k, false);
                this.k = null;
            }
            return;
        }
        this.f = (isNaN_(this.a.m) ? this.a.j : this.a.m);
        let b = a;
        this.l = b;
        this.a.c.u(this.l);
        this.l.rootWrapper.addClass("ui-expansion-indicator-container");
        let c = this.f;
        let d = Math.round(b.rootWrapper.width());
        let e = Math.round(b.rootWrapper.height());
        let f = d * c;
        let g = e * c;
        let h = this.l.createElement("canvas");
        h.setStyleProperty("position", "absolute");
        this.l.append(h);
        this.e = truncate(Math.round(f));
        this.d = truncate(Math.round(g));
        h.setAttribute("width", f.toString());
        h.setAttribute("height", g.toString());
        h.setStyleProperty("width", d.toString() + "px");
        h.setStyleProperty("height", e.toString() + "px");
        this.j = d;
        this.g = e;
        this.m = h;
        let i = this.l.get2DCanvasContext(this.m);
        this.b = new RenderingContext(new CanvasViewRenderer(), i);
        if (isNaN_(this.a.m)) {
            this.a.j = window.devicePixelRatio;
            this.f = this.a.j;
        }
        this.q();
    }
    p(a, b) {
        this.j = a;
        this.g = b;
        this.q();
    }
    s() {
        if (this.a.ae != null) {
            return this.a.ae;
        }
        return ((() => {
            let $ret = new Brush();
            $ret.color = Color.u(138, 0, 0, 0);
            return $ret;
        })());
    }
    r() {
        this.q();
    }
    n() {
        this.c.clear();
        this.a.x(this.j, this.g, this.c);
    }
    q() {
        if (this.m == null || this.b == null) {
            return;
        }
        if (this.i != this.j || this.h != this.g) {
            this.n();
            this.i = this.j;
            this.h = this.g;
        }
        if (this.c.count > 0) {
            let a = { $type: Point_$type, x: this.j / 2, y: this.g / 2 };
            let b = new TransformGroup();
            b.j.add(((() => {
                let $ret = new TranslateTransform();
                $ret.j = -a.x;
                $ret.k = -a.y;
                return $ret;
            })()));
            b.j.add(((() => {
                let $ret = new RotateTransform();
                $ret.j = this.a.k;
                return $ret;
            })()));
            b.j.add(((() => {
                let $ret = new TranslateTransform();
                $ret.j = a.x;
                $ret.k = a.y;
                return $ret;
            })()));
            this.c._inner[0].j = b;
        }
        let c = Math.round(this.j * this.f);
        let d = Math.round(this.g * this.f);
        if (this.e != c || this.d != d) {
            this.m.setAttribute("width", c.toString());
            this.m.setAttribute("height", d.toString());
            this.m.setStyleProperty("width", this.j.toString() + "px");
            this.m.setStyleProperty("height", this.g.toString() + "px");
            this.m.setStyleProperty("top", "0px");
            this.m.setStyleProperty("left", "0px");
            this.e = truncate(Math.round(c));
            this.d = truncate(Math.round(d));
        }
        if (this.b.d && this.f != 1) {
            this.b.z();
            this.b.aa(this.f, this.f);
        }
        this.b.k(0, 0, this.j, this.g);
        this.b.z();
        for (let e = 0; e < this.c.count; e++) {
            this.b.j(this.c._inner[e].j);
            let f = this.s();
            if (this.a.ae != null) {
                f = this.a.ae;
            }
            this.c._inner[e]._stroke = f;
            this.b.s(this.c._inner[e]);
        }
        this.b.y();
        if (this.b.d && this.f != 1) {
            this.b.y();
        }
    }
}
GridExpansionIndicatorView.$t = markType(GridExpansionIndicatorView, 'GridExpansionIndicatorView');
/**
 * @hidden
 */
class GridExpansionIndicator extends Base {
    constructor() {
        super();
        this.a = null;
        this.o = null;
        this.e = false;
        this.ad = null;
        this.d = false;
        this.propertyChanged = null;
        this.b = null;
        this.i = NaN;
        this.h = 1;
        this.k = 0;
        this.l = 0;
        this.n = 0;
        this.k = 0;
        this.a = new GridExpansionIndicatorView(this);
        this.b = new DoubleAnimator(0, 1, 400);
        this.b.b = EasingFunctions.cubicEase;
        let a = this.b;
        a.propertyChanged = delegateCombine(a.propertyChanged, runOn(this, this.w));
    }
    get p() {
        return this.o;
    }
    set p(a) {
        this.o = a;
    }
    get g() {
        return this.e;
    }
    set g(a) {
        let b = this.e;
        this.e = a;
        if (b != this.e) {
            this.z("IsExpanded", b, this.e);
        }
    }
    get ae() {
        return this.ad;
    }
    set ae(a) {
        let b = this.ad;
        this.ad = a;
        if (b != this.ad) {
            this.z("IconColor", b, this.ad);
        }
    }
    get f() {
        return this.d;
    }
    set f(a) {
        let b = this.d;
        this.d = a;
        if (b != this.d) {
            this.z("IsAnimationEnabled", b, this.d);
        }
    }
    get c() {
        return this.b;
    }
    get m() {
        return this.i;
    }
    set m(a) {
        let b = this.i;
        this.i = a;
        this.z("PixelScalingRatio", b, this.i);
    }
    get j() {
        return this.h;
    }
    set j(a) {
        let b = this.h;
        this.h = a;
        this.z("ActualPixelScalingRatio", b, this.h);
    }
    z(a, b, c) {
        this.aa(a, b, c);
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
    }
    aa(a, b, c) {
        switch (a) {
            case "PixelScalingRatio":
                this.j = this.m;
                break;
            case "ActualPixelScalingRatio":
                this.a.r();
                break;
            case "IconColor":
                this.a.r();
                break;
            case "IsExpanded":
                if (this.f || this.b.f()) {
                    this.b.w();
                }
                this.l = this.k;
                this.n = this.g ? 90 : 0;
                if (this.f) {
                    this.b.v();
                }
                else {
                    this.k = this.n;
                    this.a.r();
                }
                break;
        }
    }
    w(a, b) {
        this.k = this.l + this.b.o * (this.n - this.l);
        this.a.r();
    }
    x(a, b, c) {
        let d = Geometry.a("M 10.18 6.343 l 5.64 5.675 -5.64 5.639");
        c.add(((() => {
            let $ret = new Path();
            $ret.ak = d;
            $ret.aj = 2;
            $ret.stroke = this.a.s();
            $ret.ac = 2;
            return $ret;
        })()));
    }
    ab(a) {
        this.a.o(a);
    }
    ac(a) {
        this.c.u(a);
    }
    q() {
        return this.a.m.getNativeElement();
    }
    y(a, b) {
        this.a.p(a, b);
    }
}
GridExpansionIndicator.$t = markType(GridExpansionIndicator, 'GridExpansionIndicator', Base.$, [INotifyPropertyChanged_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class PlaceholderView extends Base {
    constructor(a) {
        super();
        this.f = null;
        this.k = new Color();
        this.h = 1;
        this.a = true;
        this.c = 0;
        this.b = 0;
        this.g = null;
        this.f = a;
        this.g = this.f.createElement("div");
        this.g.setRawStyleProperty("position", "absolute");
    }
    get l() {
        return this.k;
    }
    set l(a) {
        this.k = a;
        this.j();
    }
    get i() {
        return this.h;
    }
    set i(a) {
        this.a = true;
        this.h = a;
        this.j();
    }
    get e() {
        return this.c;
    }
    set e(a) {
        this.c = a;
        this.j();
    }
    get d() {
        return this.b;
    }
    set d(a) {
        this.b = a;
        this.j();
    }
    j() {
        let a = this.e;
        let b = this.d;
        let c = Color.u(truncate((this.k.l * this.h)), this.k.o, this.k.n, this.k.m);
        this.g.setRawStyleProperty("background-color", c.colorString);
        this.g.setRawStyleProperty("width", a + "px");
        this.g.setRawStyleProperty("height", b + "px");
    }
}
PlaceholderView.$t = markType(PlaceholderView, 'PlaceholderView');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridCellBase extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.t = null;
        this.v = null;
        this.w = null;
        this.e = null;
        this.ah = 0;
        this.ae = 24;
        this.ag = 0;
        this.af = 0;
        this.ak = 0;
        this.i = false;
        this.j = false;
        this.g = false;
        this.am = 0;
        this.ao = 0;
        this.an = 0;
        this.al = 0;
        this.aa = 0;
        this.ac = 0;
        this.ab = 0;
        this.z = 0;
        this.bw = null;
        this.ai = 0;
        this.aq = 0;
        this.aj = 0;
        this.f = null;
        this.c = 0;
        this.d = 0;
        this.s = 0;
        this.r = 0;
        this.k = false;
        this.aw = 0;
        this.ax = 0;
        this.y = 0;
        this.h = false;
        this.t = a;
        this.v = this.t.createElement("div");
        this.v.setRawStyleProperty("position", "absolute");
        this.v.setRawStyleProperty("overflow", "hidden");
        this.v.setRawStyleProperty("box-sizing", "border-box");
        let b = (window.navigator.msPointerEnabled && MSGesture !== undefined);
        let c = (window.PointerEvent || window.navigator.pointerEnabled);
        let d = (window.TouchEvent);
        if ((b || c)) {
            this.v.listen("pointerdown", runOn(this, this.ba));
            this.v.listen("pointerup", runOn(this, this.bd));
            this.v.listen("pointermove", runOn(this, this.bc));
            this.v.listen("pointerleave", runOn(this, this.bb));
        }
        else {
            this.v.listen("mousedown", runOn(this, this.a3));
            this.v.listen("mouseup", runOn(this, this.a6));
            this.v.listen("mousemove", runOn(this, this.a5));
            this.v.listen("mouseleave", runOn(this, this.a4));
            this.v.listen("touchstart", runOn(this, this.bo));
            this.v.listen("touchend", runOn(this, this.bq));
            this.v.listen("touchmove", runOn(this, this.bp));
        }
    }
    get b() {
        return this.a;
    }
    get u() {
        return this.t;
    }
    get x() {
        return this.v;
    }
    get at() {
        return this.ah;
    }
    get ar() {
        return this.af;
    }
    get as() {
        return this.ag;
    }
    get au() {
        return this.ak;
    }
    set au(a) {
        let b = this.ak;
        this.ak = a;
        if (b != this.ak) {
            this.a9("Indent", b, this.ak);
        }
    }
    get m() {
        return this.i;
    }
    set m(a) {
        let b = this.i;
        this.i = a;
        if (b != this.i) {
            this.a9("IsCollapsable", b, this.i);
        }
    }
    get n() {
        return this.j;
    }
    set n(a) {
        let b = this.j;
        this.j = a;
        if (b != this.j) {
            this.a9("IsExpanded", b, this.j);
        }
    }
    a2() {
        this.ag = 10;
        this.af = this.au * 24;
        this.ah = 24;
        if (this.w == null) {
            this.w = this.t.createElement("div");
            this.w.setRawStyleProperty("display", "inline-block");
            this.w.setRawStyleProperty("vertical-align", "middle");
            this.w.setRawStyleProperty("width", this.ah + "px");
            this.w.setRawStyleProperty("height", this.ah + "px");
            this.w.setRawStyleProperty("cursor", "pointer");
            this.w.setRawStyleProperty("position", "absolute");
            this.w.setRawXPosition(this.am + this.af);
            this.w.setRawYPosition(intDivide(this.ai, 2) - intDivide(this.ae, 2));
        }
        if (this.e == null) {
            let a = this.t.getSubRenderer(this.w);
            this.e = new GridExpansionIndicator();
            this.e.ab(a);
            this.e.y(24, 24);
        }
        if (this.w.parent() == null) {
            this.v.append(this.w);
        }
    }
    be() {
        this.ah = 0;
        this.ag = 0;
        if (this.w != null) {
            if (this.w.parent() != null) {
                this.w.remove();
            }
        }
    }
    get l() {
        return this.g;
    }
    set l(a) {
        this.g = a;
    }
    get_p() {
        return false;
    }
    get p() {
        return this.get_p();
    }
    bl(a, b, c, d) {
        this.am = a;
        this.ao = b;
        this.an = c;
        this.al = d;
        this.v.setRawStyleProperty("padding-left", a.toString() + "px");
        this.v.setRawStyleProperty("padding-top", b.toString() + "px");
        this.v.setRawStyleProperty("padding-right", c.toString() + "px");
        this.v.setRawStyleProperty("padding-bottom", d.toString() + "px");
    }
    bh(a, b, c, d, e) {
        this.aa = b;
        this.ac = c;
        this.ab = d;
        this.z = e;
        this.bw = a;
        if (a == null) {
            this.v.setRawStyleProperty("border", "");
        }
        else {
            this.v.setRawStyleProperty("border-color", a._fill);
            this.v.setRawStyleProperty("border-left-width", b.toString() + "px");
            this.v.setRawStyleProperty("border-top-width", c.toString() + "px");
            this.v.setRawStyleProperty("border-right-width", d.toString() + "px");
            this.v.setRawStyleProperty("border-bottom-width", e.toString() + "px");
            this.v.setRawStyleProperty("border-style", "solid");
        }
    }
    get_o() {
        return false;
    }
    get o() {
        return this.get_o();
    }
    bi(a, b) {
        if (this.ai != a || this.aj != b) {
            this.ai = a;
            this.aj = b;
            let c = Math.max(0, this.ai - this.aj);
            this.v.setRawStyleProperty("height", a.toString() + "px");
            this.v.setRawStyleProperty("line-height", c.toString() + "px");
            if (this.w != null) {
                this.w.setRawYPosition(intDivide(this.ai, 2) - intDivide(this.ah, 2));
            }
        }
    }
    bn(a, b) {
        if (this.aq != a) {
            this.aq = a;
            this.v.setRawStyleProperty("width", a.toString() + "px");
        }
    }
    a1() {
        if (!this.p) {
            return;
        }
        this.g = true;
        this.f = new PlaceholderView(this.t);
        this.c = 0;
        this.d = 1;
        this.f.l = Color.u(120, 120, 120, 120);
        this.f.i = 0;
        this.v.append(this.f.g);
    }
    bg(a) {
        this.v.setRawStyleProperty("background-color", a.colorString);
    }
    bk(a) {
        this.v.setRawStyleProperty("opacity", a.toString());
    }
    bv(a) {
        if (!this.p) {
            return;
        }
        this.f.i = (a * 0.20000000298023224);
    }
    bt(a, b, c, d) {
        if (this.f != null) {
            let e = this.s;
            let f = this.r;
            if (this.d == 1) {
                b = truncate((b + (d / 2) - (f / 2)));
            }
            else if (this.d == 2) {
                b = truncate((b + (d) - (f)));
            }
            if (this.c == 1) {
                a = truncate((a + (c / 2) - (e / 2)));
            }
            else if (this.c == 2) {
                a = truncate((a + (c) - (e)));
            }
            this.f.g.setRawXPosition(a);
            this.f.g.setRawYPosition(b);
        }
    }
    a8(a, b, c) {
    }
    bu(a) {
        if (!this.p) {
            return;
        }
        let b = DeviceUtils.f(12);
        if (a.x != null && !isNaN_(a.x.d)) {
            b = a.x.d;
        }
        if (this.r != b) {
            this.r = b;
            this.f.d = (b);
        }
        let c = a.e2 * 0.2;
        let d = a.dt * 0.6;
        if (this.s >= c && this.s <= d && !this.k) {
            return;
        }
        this.k = false;
        let e = (GridCellBase.av.nextDouble() * (d - c) + c);
        if (this.s != e) {
            this.s = e;
            this.f.e = e;
        }
        this.bt(this.am + this.af + this.ah, this.ao, this.aq - (this.am + this.an), this.ai - (this.ao + this.al));
    }
    br(a, b) {
        if (!this.p) {
            return;
        }
        this.c = a;
        this.d = b;
        this.k = true;
    }
    bs(a) {
        if (!this.p) {
            return;
        }
        if (a != null) {
            this.f.l = a.color;
        }
    }
    bf(a) {
        this.a = a;
    }
    bj(a, b) {
        switch (b) {
            case 0:
                this.x.setRawStyleProperty("text-align", "left");
                break;
            case 1:
                this.x.setRawStyleProperty("text-align", "center");
                break;
            case 2:
                this.x.setRawStyleProperty("text-align", "right");
                break;
            case 3:
                this.x.setRawStyleProperty("text-align", "center");
                break;
        }
    }
    bm(a, b) {
        switch (b) {
            case 0:
                a.setRawStyleProperty("vertical-align", "top");
                break;
            case 1:
                a.setRawStyleProperty("vertical-align", "center");
                break;
            case 2:
                a.setRawStyleProperty("vertical-align", "bottom");
                break;
            case 3:
                a.setRawStyleProperty("vertical-align", "center");
                break;
        }
    }
    q(a) {
        return a.isClickActionDesired;
    }
    a3(a) {
        this.onContactStarted(a, false);
    }
    a6(a) {
        this.onContactCompleted(a, false);
    }
    a5(a) {
        this.onContactMoved(a, false);
    }
    a4(a) {
        this.a7(a, false);
    }
    ba(e_) {
        let a = (e_.originalEvent.pointerType);
        if (a == "touch") {
            this.bo(e_);
        }
        else {
            this.a3(e_);
        }
    }
    bc(e_) {
        let a = (e_.originalEvent.pointerType);
        if (a == "touch") {
            this.bp(e_);
        }
        else {
            this.a5(e_);
        }
    }
    bd(e_) {
        let a = (e_.originalEvent.pointerType);
        if (a == "touch") {
            this.bq(e_);
        }
        else {
            this.a6(e_);
        }
    }
    bb(e_) {
        let a = (e_.originalEvent.pointerType);
        if (a != "touch") {
            this.a4(e_);
        }
    }
    bo(a) {
        this.onContactStarted(a, true);
    }
    bp(a) {
        this.onContactMoved(a, true);
    }
    bq(a) {
        this.onContactCompleted(a, true);
    }
    onContactStarted(e_, a) {
        let b = false;
        if (this.m) {
            let indicator_ = this.e.q();
            b = (e_.originalEvent.srcElement === indicator_ || e_.originalEvent.target === indicator_);
        }
        this.h = false;
        if (b) {
            this.h = true;
        }
        else {
            if (this.a != null && this.q(this.a)) {
                this.aw = e_.pageX;
                this.ax = e_.pageY;
                this.a.mouseDownCell(this.aw, this.ax);
            }
        }
    }
    onContactMoved(a, b) {
        if (this.a != null) {
            let c = a.pageX;
            let d = a.pageY;
            if (this.q(this.a)) {
                if (this.a.isMouseDown) {
                    if (b) {
                        if (PointUtil.equals(this.a.mousePosition, null) || Math.abs(c - this.a.mousePosition.x) > GridCellBase.ap || Math.abs(d - this.a.mousePosition.y) > GridCellBase.ap) {
                            this.a.mouseUpCell(c, d);
                        }
                        else {
                            a.stopPropagation();
                        }
                    }
                    else {
                        if (PointUtil.equals(this.a.mousePosition, null)) {
                            this.a.mouseUpCell(c, d);
                        }
                        else {
                            if (Math.abs(c - this.a.mousePosition.x) > GridCellBase.ad || Math.abs(d - this.a.mousePosition.y) > GridCellBase.ad) {
                                this.a.isControlPressed = a.ctrlKey;
                                this.a.dragStarted();
                            }
                        }
                    }
                }
            }
            if (this.a.isHoverActionDesired) {
                this.a.mouseIsOver(c, d);
            }
        }
    }
    onContactCompleted(e_, a) {
        let b = false;
        if (this.m) {
            let indicator_ = this.e.q();
            b = (e_.originalEvent.srcElement === indicator_ || e_.originalEvent.target === indicator_);
        }
        if (this.h && b) {
            this.b.clickExpansionIndicator();
        }
        else {
            if (this.a != null && this.q(this.a)) {
                let c = e_.pageX;
                let d = e_.pageY;
                if (PointUtil.equals(this.a.mousePosition, null) || Math.abs(c - this.a.mousePosition.x) > GridCellBase.ap || Math.abs(d - this.a.mousePosition.y) > GridCellBase.ap || this.a.isDrag) {
                    this.a.mouseUpCell(c, d);
                }
                if (this.a.isCellDown()) {
                    this.a.isControlPressed = e_.ctrlKey;
                    this.a.isShiftPressed = e_.shiftKey;
                    this.a.clickCell();
                    this.a.mouseUpCell(e_.pageX, e_.pageY);
                }
            }
        }
        this.h = false;
    }
    a7(a, b) {
        if (this.a != null && this.a.isLeaveActionDesired) {
            let c = a.pageX;
            let d = a.pageY;
            this.a.mouseLeaveCell(c, d);
        }
    }
    a9(a, b, c) {
        switch (a) {
            case "Indent":
                this.af = this.au * 24;
                this.ag = this.au > 0 ? 10 : 0;
                if (this.w != null) {
                    this.w.setRawXPosition(this.am + this.af);
                    this.w.setRawYPosition(intDivide(this.ai, 2) - intDivide(this.ae, 2));
                }
                break;
            case "IsCollapsable":
                if (this.m) {
                    this.a2();
                }
                else {
                    this.be();
                }
                break;
            case "IsExpanded":
                if (this.e != null) {
                    this.e.g = this.n;
                }
                break;
        }
    }
}
GridCellBase.$t = markType(GridCellBase, 'GridCellBase', Base.$, [INativeCell_$type]);
GridCellBase.av = new Random(0);
GridCellBase.ap = 10;
GridCellBase.ad = 3;

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TextCell extends GridCellBase {
    constructor(a) {
        super(a);
        this.bx = null;
        this.b0 = -1;
        this.bz = -1;
        this.bx = a.createElement("span");
        this.x.setRawStyleProperty("text-align", "left");
        this.bx.setRawStyleProperty("display", "inline-block");
        this.bx.setRawStyleProperty("line-height", "normal");
        this.bx.setRawStyleProperty("vertical-align", "middle");
        this.bx.setRawStyleProperty("overflow", "hidden");
        this.bx.setRawStyleProperty("white-space", "nowrap");
        this.bx.setRawStyleProperty("text-overflow", "ellipsis");
        this.x.setRawStyleProperty("vertical-align", "middle");
        this.x.append(this.bx);
    }
    get by() {
        return this.bx;
    }
    bn(a, b) {
        super.bn(a, b);
        let c = Math.max(0, a - b - (this.ar + this.at + this.as));
        if (this.b0 != c) {
            this.b0 = c;
            this.bx.setRawStyleProperty("max-width", c.toString() + "px");
        }
    }
    bi(a, b) {
        super.bi(a, b);
        let c = Math.max(0, a - b);
        if (this.bz != c) {
            this.bz = c;
            this.bx.setRawStyleProperty("max-height", c.toString() + "px");
        }
    }
    get_p() {
        return true;
    }
    a9(a, b, c) {
        super.a9(a, b, c);
        if (a == "Indent" || a == "IsCollapsable") {
            this.bx.setRawStyleProperty("margin-left", this.ar + this.at + this.as + "px");
        }
    }
}
TextCell.$t = markType(TextCell, 'TextCell', GridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class CellPresenterBase extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.a = a;
    }
    modelUpdated(a) {
        this.b(a);
    }
    b(a) {
        this.a.bf(a.c);
        if (a.al(CellModel.c9) || a.al(CellModel.dd) || a.al(CellModel.db) || a.al(CellModel.c7)) {
            this.a.bl(a.c8, a.dc, a.da, a.c6);
        }
        if (a.af) {
            this.a.bh(a.h6, a.cy, a.c3, a.c1, a.cw);
        }
        if (a.av) {
            this.a.bi(a.dt, (a.dc + a.c6 + a.c3 + a.cw));
            this.a.bn(a.e2, (a.c8 + a.da + a.cy + a.c1));
        }
        if (a.ah) {
            if (a.ap && !this.a.l) {
                this.a.a1();
            }
            if (a.al(CellModel.cv)) {
                this.a.bg(a.h5.color);
            }
            if (a.al(CellModel.c5)) {
                this.a.bk(a.bh);
            }
            if (a.ak("IsCollapsable")) {
                this.a.m = a.ag;
                this.a.au = a.dw;
                this.a.n = a.am;
                this.a.bn(a.e2, (a.c8 + a.da + a.cy + a.c1));
            }
            if (a.ak("Indent")) {
                this.a.au = a.dw;
                this.a.bn(a.e2, (a.c8 + a.da + a.cy + a.c1));
            }
            if (a.ak("IsExpanded")) {
                this.a.n = a.am;
            }
        }
        if (a.av && a.ap) {
            this.a.bu(a);
        }
    }
    c(a, b, c) {
        if (c == 0) {
            return a.color;
        }
        if (c == 1) {
            return b.color;
        }
        let d = BrushUtil.g(a, c, b, 0);
        return d.color;
    }
    get nativeCell() {
        return this.a;
    }
    get isCanvasBased() {
        return false;
    }
}
CellPresenterBase.$t = markType(CellPresenterBase, 'CellPresenterBase', Base.$, [ICellPresenter_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ContentCellModelHelper extends Base {
    static e(a) {
        if (a == null) {
            return ContentCellModelHelper.d;
        }
        return a.color;
    }
    static b(a, b, c) {
        switch (c) {
            case 0:
                a.setRawStyleProperty("text-align", "left");
                break;
            case 1:
                a.setRawStyleProperty("text-align", "center");
                break;
            case 2:
                a.setRawStyleProperty("text-align", "right");
                break;
            case 3:
                a.setRawStyleProperty("text-align", "center");
                break;
        }
    }
    static c(a, b, c) {
        switch (c) {
            case 0:
                b.setRawStyleProperty("vertical-align", "top");
                break;
            case 1:
                b.setRawStyleProperty("vertical-align", "center");
                break;
            case 2:
                b.setRawStyleProperty("vertical-align", "bottom");
                break;
            case 3:
                b.setRawStyleProperty("vertical-align", "center");
                break;
        }
    }
    static a(a, b, c, d, e) {
        if (b.ah) {
            if (b.al(CellModel.dp) || b.al(CellModel.e1)) {
                let f = Math.min(1, Math.max(0, b.bq));
                let g = b.bi * (1 - f);
                d.setRawStyleProperty("opacity", g.toString());
                if (b.ap) {
                    e.bv(b.bi * f);
                }
            }
            if (b.al(CellModel.ex)) {
                let h = ContentCellModelHelper.e((b).ig);
                d.setRawStyleProperty("color", h.colorString);
                if (b.ap) {
                    e.bs(b.ig);
                }
            }
            if (b.al(CellModel.d7)) {
                switch (b.v) {
                    case 0:
                        d.setRawStyleProperty("white-space", "nowrap");
                        d.setRawStyleProperty("text-overflow", "ellipsis");
                        break;
                    case 3:
                    case 2:
                        d.setRawStyleProperty("white-space", "pre-wrap");
                        d.setRawStyleProperty("text-overflow", "ellipsis");
                        break;
                    case 1:
                        d.setRawStyleProperty("white-space", "nowrap");
                        d.setRawStyleProperty("text-overflow", "clip");
                        break;
                }
            }
            if (b.al(CellModel.dv) || b.al(CellModel.e0)) {
                let i = b.e;
                let j = b.g;
                ContentCellModelHelper.b(c, d, i);
                e.a8(c, d, i);
                ContentCellModelHelper.c(c, d, j);
                if (b.ap) {
                    e.br(i, j);
                }
            }
            if (b.al(CellModel.dr)) {
                let k = b.x;
                if (k == null) {
                    k = FontUtil.getDefaultFont(a);
                }
                d.setRawStyleProperty("font", k.fontString);
            }
        }
    }
}
ContentCellModelHelper.$t = markType(ContentCellModelHelper, 'ContentCellModelHelper');
ContentCellModelHelper.d = Color.u(0, 0, 0, 0);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TextCellPresenter extends CellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(TextCellModel.ih) || a.al(CellModel.ea)) {
                if (b.ij != null) {
                    b.gq = b.ij;
                }
                else {
                    if (b.fb == null) {
                        b.gq = "";
                    }
                    else {
                        b.gq = b.fb.toString();
                    }
                }
                this.d.by.setRawText(b.gq);
            }
            ContentCellModelHelper.a(this.a.u, b, this.a.x, this.d.by, this.a);
        }
    }
}
TextCellPresenter.$t = markType(TextCellPresenter, 'TextCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class NumericCell extends TextCell {
    constructor(a) {
        super(a);
        this.bj(this.by, 2);
        this.bm(this.by, 1);
    }
    a9(a, b, c) {
        super.a9(a, b, c);
        if (a == "Indent" || a == "IsCollapsable") {
            this.by.setRawStyleProperty("margin-left", this.ar + this.at + this.as + "px");
        }
    }
}
NumericCell.$t = markType(NumericCell, 'NumericCell', TextCell.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class NumericCellPresenter extends CellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(NumericCellModel.i2) || b.ik()) {
                b.gq = this.e(b);
                this.d.by.setRawText(b.gq);
            }
            ContentCellModelHelper.a(this.a.u, b, this.a.x, this.d.by, this.a);
        }
    }
    e(a) {
        if (a.i8 != null) {
            let val_ = a.io;
            let override_ = a.i8;
            return (override_.format(val_));
        }
        return NumericCellFormatter.b(a);
    }
}
NumericCellPresenter.$t = markType(NumericCellPresenter, 'NumericCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DateTimeCell extends TextCell {
    constructor(a) {
        super(a);
    }
}
DateTimeCell.$t = markType(DateTimeCell, 'DateTimeCell', TextCell.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DateTimeCellPresenter extends CellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(DateTimeCellModel.ir) || a.al(DateTimeCellModel.is) || a.al(DateTimeCellModel.iq)) {
                this.e(b);
                this.d.by.setRawText(b.gq);
            }
            ContentCellModelHelper.a(this.a.u, b, this.a.x, this.d.by, this.a);
        }
    }
    e(a) {
        a.gq = a.i0(a.ip);
        if (a.gq == stringEmpty() && a.fb != null) {
            a.gq = a.fb.toString();
        }
    }
}
DateTimeCellPresenter.$t = markType(DateTimeCellPresenter, 'DateTimeCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridFilterDialogViewModelRow extends Base {
    constructor() {
        super(...arguments);
        this.c = null;
        this.b = null;
        this.k = null;
        this.a = null;
        this.g = null;
        this.h = null;
        this.propertyChanged = null;
    }
    get f() {
        return this.c;
    }
    set f(a) {
        let b = this.c;
        this.c = a;
        if (b != this.c) {
            this.m("OperatorTypes");
        }
    }
    m(a) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
    }
    get e() {
        return this.b;
    }
    set e(a) {
        let b = this.b;
        this.b = a;
        if (b != this.b) {
            this.m("Operators");
        }
    }
    get l() {
        return this.k;
    }
    set l(a) {
        let b = this.k;
        this.k = a;
        if (b != this.k) {
            this.m("CurrentOperator");
        }
    }
    get d() {
        return this.a;
    }
    set d(a) {
        let b = this.a;
        this.a = a;
        if (b != this.a) {
            this.m("OperandNumber");
        }
    }
    get i() {
        return this.g;
    }
    set i(a) {
        let b = this.g;
        this.g = a;
        if (b != this.g) {
            this.m("Operand1");
        }
    }
    get j() {
        return this.h;
    }
    set j(a) {
        let b = this.h;
        this.h = a;
        if (b != this.h) {
            this.m("Operand2");
        }
    }
}
GridFilterDialogViewModelRow.$t = markType(GridFilterDialogViewModelRow, 'GridFilterDialogViewModelRow', Base.$, [INotifyPropertyChanged_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridFilterDialogOpeningEventArgs extends Base {
    constructor() {
        super(...arguments);
        this.a = null;
        this.b = 0;
    }
}
GridFilterDialogOpeningEventArgs.$t = markType(GridFilterDialogOpeningEventArgs, 'GridFilterDialogOpeningEventArgs');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * Identifies the operator type of a column comparison condition.
 */
var ColumnComparisonConditionOperatorType;
(function (ColumnComparisonConditionOperatorType) {
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["Contains"] = 0] = "Contains";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["DoesNotContain"] = 1] = "DoesNotContain";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["DoesNotEndWith"] = 2] = "DoesNotEndWith";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["DoesNotStartWith"] = 3] = "DoesNotStartWith";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["EndsWith"] = 4] = "EndsWith";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["Equals"] = 5] = "Equals";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["GreaterThan"] = 6] = "GreaterThan";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["GreaterThanOrEqualTo"] = 7] = "GreaterThanOrEqualTo";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["LessThan"] = 8] = "LessThan";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["LessThanOrEqualTo"] = 9] = "LessThanOrEqualTo";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["NotEquals"] = 10] = "NotEquals";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["StartsWith"] = 11] = "StartsWith";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["IsNotNull"] = 12] = "IsNotNull";
    ColumnComparisonConditionOperatorType[ColumnComparisonConditionOperatorType["IsNull"] = 13] = "IsNull";
})(ColumnComparisonConditionOperatorType || (ColumnComparisonConditionOperatorType = {}));
/**
 * @hidden
 */
let ColumnComparisonConditionOperatorType_$type = markEnum('ColumnComparisonConditionOperatorType', 'Contains,0|DoesNotContain,1|DoesNotEndWith,2|DoesNotStartWith,3|EndsWith,4|Equals,5|GreaterThan,6|GreaterThanOrEqualTo,7|LessThan,8|LessThanOrEqualTo,9|NotEquals,10|StartsWith,11|IsNotNull,12|IsNull,13');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnComparisonFilterCondition extends ColumnFilterCondition {
    constructor() {
        super();
        this.e = 0;
        this.i = null;
        this.f = false;
        this.f = true;
    }
    static c(a) {
        let b = new List$1(ColumnComparisonConditionOperatorType_$type, 0);
        switch (a) {
            case 11: break;
            case 2: break;
            case 10:
            case 6:
            case 5:
            case 1:
            case 3:
            case 8:
                b.add(6);
                b.add(7);
                b.add(8);
                b.add(9);
                break;
            case 0:
                b.add(11);
                b.add(3);
                b.add(4);
                b.add(2);
                b.add(0);
                b.add(1);
                b.add(6);
                b.add(7);
                b.add(8);
                b.add(9);
                break;
        }
        b.add(5);
        b.add(10);
        b.add(12);
        b.add(13);
        return b.toArray();
    }
    equals(a) {
        if (a == null) {
            return false;
        }
        if (!(typeCast(ColumnComparisonFilterCondition.$, a) !== null)) {
            return false;
        }
        let b = a;
        if (b.e != this.e) {
            return false;
        }
        if (!Base.equalsStatic(b.i, this.i)) {
            return false;
        }
        if (!Base.equalsStatic(b.f, this.f)) {
            return false;
        }
        return true;
    }
    a(a, b) {
        switch (this.e) {
            case 0:
                {
                    if (b != 0 || this.i == null) {
                        return null;
                    }
                    let c = FilterFactory.instance.property(a);
                    let d = FilterFactory.instance.literal(this.i);
                    if (!this.f) {
                        c = c.toLower();
                        d = d.toLower();
                    }
                    return c.contains(d);
                }
            case 1:
                {
                    if (b != 0 || this.i == null) {
                        return null;
                    }
                    let e = FilterFactory.instance.property(a);
                    let f = FilterFactory.instance.literal(this.i);
                    if (!this.f) {
                        e = e.toLower();
                        f = f.toLower();
                    }
                    return e.contains(f).not();
                }
            case 2:
                {
                    if (b != 0 || this.i == null) {
                        return null;
                    }
                    let g = FilterFactory.instance.property(a);
                    let h = FilterFactory.instance.literal(this.i);
                    if (!this.f) {
                        g = g.toLower();
                        h = h.toLower();
                    }
                    return g.endsWith(h).not();
                }
            case 3:
                {
                    if (b != 0 || this.i == null) {
                        return null;
                    }
                    let i = FilterFactory.instance.property(a);
                    let j = FilterFactory.instance.literal(this.i);
                    if (!this.f) {
                        i = i.toLower();
                        j = j.toLower();
                    }
                    return i.startsWith(j).not();
                }
            case 4:
                {
                    if (b != 0 || this.i == null) {
                        return null;
                    }
                    let k = FilterFactory.instance.property(a);
                    let l = FilterFactory.instance.literal(this.i);
                    if (!this.f) {
                        k = k.toLower();
                        l = l.toLower();
                    }
                    return k.endsWith(l);
                }
            case 5:
                {
                    let m = FilterFactory.instance.property(a);
                    let n = FilterFactory.instance.literal(this.h(this.i, b));
                    if (b == 0 && !this.f) {
                        m = m.toLower();
                        n = n.toLower();
                    }
                    return m.isEqualTo(n);
                }
            case 6:
                {
                    let o = FilterFactory.instance.property(a);
                    let p = FilterFactory.instance.literal(this.h(this.i, b));
                    if (b == 0 && !this.f) {
                        o = o.toLower();
                        p = p.toLower();
                    }
                    return o.isGreaterThan(p);
                }
            case 7:
                {
                    let q = FilterFactory.instance.property(a);
                    let r = FilterFactory.instance.literal(this.h(this.i, b));
                    if (b == 0 && !this.f) {
                        q = q.toLower();
                        r = r.toLower();
                    }
                    return q.isGreaterThanOrEqualTo(r);
                }
            case 8:
                {
                    let s = FilterFactory.instance.property(a);
                    let t = FilterFactory.instance.literal(this.h(this.i, b));
                    if (b == 0 && !this.f) {
                        s = s.toLower();
                        t = t.toLower();
                    }
                    return s.isLessThan(t);
                }
            case 9:
                {
                    let u = FilterFactory.instance.property(a);
                    let v = FilterFactory.instance.literal(this.h(this.i, b));
                    if (b == 0 && !this.f) {
                        u = u.toLower();
                        v = v.toLower();
                    }
                    return u.isLessThanOrEqualTo(v);
                }
            case 10:
                {
                    let w = FilterFactory.instance.property(a);
                    let x = FilterFactory.instance.literal(this.h(this.i, b));
                    if (b == 0 && !this.f) {
                        w = w.toLower();
                        x = x.toLower();
                    }
                    return w.isNotEqualTo(x);
                }
            case 11:
                {
                    if (b != 0 || this.i == null) {
                        return null;
                    }
                    let y = FilterFactory.instance.property(a);
                    let z = FilterFactory.instance.literal(this.i);
                    if (!this.f) {
                        y = y.toLower();
                        z = z.toLower();
                    }
                    return y.startsWith(z);
                }
            case 12:
                {
                    let aa = FilterFactory.instance.property(a);
                    let ab = FilterFactory.instance.literal(null);
                    return aa.isNotEqualTo(ab);
                }
            case 13:
                {
                    let ac = FilterFactory.instance.property(a);
                    let ad = FilterFactory.instance.literal(null);
                    return ac.isEqualTo(ad);
                }
        }
        return null;
    }
    static g(a) {
        if (a == 12 || a == 13) {
            return 0;
        }
        else {
            return 1;
        }
    }
    static d(a) {
        let b = new Array(a.length);
        for (let c = 0; c < a.length; c++) {
            b[c] = ColumnComparisonFilterCondition.g(a[c]);
        }
        return b;
    }
    h(value_, a) {
        switch (a) {
            case 2: return (!!value_);
            case 10: return (+value_);
            case 8:
                if (typeCast(Date_$type, value_) !== null) {
                    return value_;
                }
                if (typeof value_ === 'string') {
                    let b;
                    if (((() => { let c = dateTryParse(value_, b); b = c.p1; return c.ret; })())) {
                        return b;
                    }
                    else {
                        return null;
                    }
                }
                return (new Date(+value_));
            case 6: return (+value_);
            case 5: return (+value_);
            case 1: return (+value_);
            case 3: return (+value_);
            case 11: return value_;
            case 4: return (+value_);
            case 7: return (+value_);
            case 0: return value_ != null ? value_.toString() : value_;
        }
        return value_;
    }
}
ColumnComparisonFilterCondition.$t = markType(ColumnComparisonFilterCondition, 'ColumnComparisonFilterCondition', ColumnFilterCondition.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridFilterDialogFilterChangeEventArgs extends Base {
    constructor() {
        super(...arguments);
        this.a = null;
    }
}
GridFilterDialogFilterChangeEventArgs.$t = markType(GridFilterDialogFilterChangeEventArgs, 'GridFilterDialogFilterChangeEventArgs');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnFilterConditionCollection extends ObservableCollection$1 {
    constructor() {
        super(ColumnFilterCondition.$, 0);
    }
}
ColumnFilterConditionCollection.$t = markType(ColumnFilterConditionCollection, 'ColumnFilterConditionCollection', ObservableCollection$1.$.specialize(ColumnFilterCondition.$));

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ColumnFilterConditionGroup extends ColumnFilterCondition {
    constructor() {
        super();
        this.f = false;
        this.e = null;
        this.e = new ColumnFilterConditionCollection();
        this.f = false;
    }
    b() {
        return true;
    }
    equals(a) {
        if (a == null) {
            return false;
        }
        if (!(typeCast(ColumnFilterConditionGroup.$, a) !== null)) {
            return false;
        }
        let b = a;
        if (b.g != this.g) {
            return false;
        }
        for (let c = 0; c < this.g; c++) {
            if (!Base.equalsStatic(this.item(c), b.item(c))) {
                return false;
            }
        }
        return true;
    }
    get g() {
        return this.e.count;
    }
    h(a) {
        this.e.add(a);
    }
    j(a) {
        this.e.remove(a);
    }
    k(a) {
        this.e.removeAt(a);
    }
    item(a, b) {
        if (arguments.length === 2) {
            this.e._inner[a] = b;
            return b;
        }
        else {
            return this.e._inner[a];
        }
    }
    i() {
        this.e.clear();
    }
    c() {
        let a = new Array(this.e.count);
        for (let b = 0; b < this.e.count; b++) {
            a[b] = this.e._inner[b];
        }
        return a;
    }
    a(a, b) {
        if (this.e.count == 0) {
            return null;
        }
        let c = this.e._inner[this.e.count - 1].a(a, b);
        for (let d = this.e.count - 2; d >= 0; d--) {
            if (this.f) {
                c = FilterFactory.instance.or(this.e._inner[d].a(a, b), c);
            }
            else {
                c = FilterFactory.instance.and(this.e._inner[d].a(a, b), c);
            }
        }
        return c;
    }
}
ColumnFilterConditionGroup.$t = markType(ColumnFilterConditionGroup, 'ColumnFilterConditionGroup', ColumnFilterCondition.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridFilterDialogViewModelGrouping extends Base {
    constructor() {
        super(...arguments);
        this.c = 0;
        this.b = 0;
        this.a = false;
    }
}
GridFilterDialogViewModelGrouping.$t = markType(GridFilterDialogViewModelGrouping, 'GridFilterDialogViewModelGrouping');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridFilterDialogViewModelGroupingLevel extends ObservableCollection$1 {
    constructor() {
        super(GridFilterDialogViewModelGrouping.$, 0);
    }
}
GridFilterDialogViewModelGroupingLevel.$t = markType(GridFilterDialogViewModelGroupingLevel, 'GridFilterDialogViewModelGroupingLevel', ObservableCollection$1.$.specialize(GridFilterDialogViewModelGrouping.$));

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridFilterDialogViewModelGroupingLevelCollection extends ObservableCollection$1 {
    constructor() {
        super(GridFilterDialogViewModelGroupingLevel.$, 0);
    }
}
GridFilterDialogViewModelGroupingLevelCollection.$t = markType(GridFilterDialogViewModelGroupingLevelCollection, 'GridFilterDialogViewModelGroupingLevelCollection', ObservableCollection$1.$.specialize(GridFilterDialogViewModelGroupingLevel.$));

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class GridFilterDialogView extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.x = new Path();
        this.i = 0;
        this.h = 0;
        this.m = null;
        this.c = null;
        this.l = null;
        this.f = 0;
        this.e = 0;
        this.g = 1;
        this.k = 0;
        this.j = 0;
        this.d = false;
        this.b = null;
        this.a = a;
    }
    t() {
        if (this.i != this.k || this.h != this.j) {
            this.q();
            this.i = this.k;
            this.h = this.j;
        }
        let a = Math.min(this.k, this.j);
        let b = { $type: Point_$type, x: this.k / 2, y: this.j / 2 };
        let c = Math.round(this.k * this.g);
        let d = Math.round(this.j * this.g);
        if (this.f != c || this.e != d) {
            this.m.setAttribute("width", c.toString());
            this.m.setAttribute("height", d.toString());
            this.m.setStyleProperty("width", this.k.toString() + "px");
            this.m.setStyleProperty("height", this.j.toString() + "px");
            this.m.setStyleProperty("top", "0px");
            this.m.setStyleProperty("left", "0px");
            this.f = truncate(Math.round(c));
            this.e = truncate(Math.round(d));
        }
        if (this.c.d && this.g != 1) {
            this.c.z();
            this.c.aa(this.g, this.g);
        }
        this.c.k(0, 0, this.k, this.j);
        this.c.s(this.x);
        if (this.c.d && this.g != 1) {
            this.c.y();
        }
    }
    q() {
        this.a.ah(this.k, this.j, this.x);
    }
    r(a) {
        if (a == null) {
            if (this.m != null) {
                this.m.destroy();
            }
            this.m = null;
            this.l = null;
            this.c = null;
            return;
        }
        this.g = (isNaN_(this.a.u) ? this.a.t : this.a.u);
        let b = a;
        this.l = b;
        this.l.rootWrapper.addClass("ui-radialgauge-container");
        let c = this.g;
        let d = Math.round(b.rootWrapper.width());
        let e = Math.round(b.rootWrapper.height());
        let f = d * c;
        let g = e * c;
        this.l.rootWrapper.setStyleProperty("position", "relative");
        let h = this.l.createElement("canvas");
        h.setStyleProperty("position", "absolute");
        this.l.append(h);
        this.f = truncate(Math.round(f));
        this.e = truncate(Math.round(g));
        h.setAttribute("width", f.toString());
        h.setAttribute("height", g.toString());
        h.setStyleProperty("width", d.toString() + "px");
        h.setStyleProperty("height", e.toString() + "px");
        h.listen("mousedown", runOn(this, this.n));
        h.listen("mouseup", runOn(this, this.o));
        this.k = d;
        this.j = e;
        this.m = h;
        let i = this.l.get2DCanvasContext(this.m);
        this.c = new RenderingContext(new CanvasViewRenderer(), i);
        if (isNaN_(this.a.u)) {
            this.a.t = window.devicePixelRatio;
            this.g = this.a.t;
        }
        this.t();
    }
    n(a) {
        a.preventDefault();
        a.stopPropagation();
    }
    o(a) {
        a.preventDefault();
        a.stopPropagation();
        if (!this.d) {
            this.a.am();
        }
        else {
            this.a.ag(this.b.b, false);
        }
    }
    u() {
        this.t();
    }
    s(a, b) {
        if (isNaN_(this.a.u)) {
            this.a.t = window.devicePixelRatio;
            this.g = this.a.t;
        }
        this.k = a;
        this.j = b;
        this.t();
    }
    w() {
        return ((() => {
            let $ret = new Brush();
            $ret.color = Color.u(138, 0, 0, 0);
            return $ret;
        })());
    }
    v(a) {
        this.d = true;
        let b = new GridFilterDialogPanel(this.m, this.l);
        b.a = this.a;
        b.x(a);
        this.b = b;
    }
    p() {
        this.d = false;
        if (this.b != null) {
            this.b.o();
            this.b.p();
            this.b = null;
        }
    }
}
GridFilterDialogView.$t = markType(GridFilterDialogView, 'GridFilterDialogView');
/**
 * @hidden
 */
class GridFilterDialogPanel extends Base {
    constructor(a, b) {
        super();
        this.a = null;
        this.i = null;
        this.d = null;
        this.h = null;
        this.k = null;
        this.b = null;
        this.g = null;
        this.f = null;
        this.j = null;
        this.e = null;
        this.c = false;
        let c = b.createElement("div");
        let d = b.getSubRenderer(c);
        c.setStyleProperty("position", "absolute");
        c.setStyleProperty("top", "0px");
        c.setStyleProperty("left", "0px");
        c.setStyleProperty("display", "none");
        c.setStyleProperty("z-index", "10000");
        c.setStyleProperty("opacity", ".9");
        c.setStyleProperty("background-color", "#aaa");
        c.setStyleProperty("border-radius", "3px");
        c.setStyleProperty("boxShadow", "0 19px 38px rgba(0,0,0,0.30), 0 15px 12px rgba(0,0,0,0.22)");
        this.i = a;
        this.d = d;
        this.h = c;
        this.k = d.createElement("div");
        this.h.append(this.k);
        this.g = d.createElement("div");
        this.h.append(this.g);
        this.e = d.createElement("input");
        this.e.setAttribute("type", "button");
        this.e.setProperty("value", "add condition");
        this.f = d.createElement("input");
        this.f.setAttribute("type", "button");
        this.f.setProperty("value", "apply");
        this.j = d.createElement("input");
        this.j.setAttribute("type", "button");
        this.j.setProperty("value", "reset");
        this.g.append(this.e);
        this.g.append(this.f);
        this.g.append(this.j);
        this.e.listen("click", runOn(this, this.r));
        this.f.listen("click", runOn(this, this.s));
        this.j.listen("click", runOn(this, this.v));
        this.e.setStyleProperty("opacity", ".9");
        this.e.setStyleProperty("margin", "3px");
        this.f.setStyleProperty("opacity", ".9");
        this.f.setStyleProperty("margin", "3px");
        this.j.setStyleProperty("opacity", ".9");
        this.j.setStyleProperty("margin", "3px");
    }
    r(a) {
        this.b.n();
    }
    v(a) {
        this.a.ag(this.b, true);
    }
    s(a) {
        this.a.ag(this.b, false);
    }
    x(a) {
        a.onModified = delegateCombine(a.onModified, runOn(this, this.aa));
        this.b = a;
        this.z();
        this.h.setStyleProperty("left", this.i.getOffset().left + "px");
        this.h.setStyleProperty("top", (this.i.getOffset().top + this.i.outerHeight()) + "px");
        this.h.setStyleProperty("display", "block");
        this.d.appendToBody(this.h);
    }
    o() {
        let a = this.b;
        a.onModified = delegateRemove(a.onModified, runOn(this, this.aa));
        this.b = null;
        this.h.setStyleProperty("display", "none");
        this.h.remove();
    }
    p() {
        this.d.destroy();
        this.h = null;
        this.k = null;
        this.f = null;
        this.g = null;
        this.j = null;
        if (this.b != null) {
            let a = this.b;
            a.onModified = delegateRemove(a.onModified, runOn(this, this.aa));
        }
        this.b = null;
    }
    aa(a) {
        if (this.c) {
            return;
        }
        this.z();
    }
    z() {
        for (let a = 0; a < this.b.f.count; a++) {
            let b = null;
            if (a < this.k.getChildCount()) {
                b = this.k.getChildAt(a);
            }
            else {
                b = this.d.createElement("div");
                this.k.append(b);
            }
            this.y(a, b, this.b.f._inner[a]);
        }
        while (this.k.getChildCount() > this.b.f.count) {
            let c = this.k.getChildAt(this.k.getChildCount() - 1);
            c.remove();
        }
    }
    y(a, b, c) {
        let d = false;
        let e = false;
        let f = false;
        let g = false;
        let h = this.l(c) > 0;
        if (b.getChildCount() == 0) {
            d = true;
            e = h;
            f = true;
        }
        else {
            if (h && b.getChildCount() == 2) {
                e = true;
            }
            if (!h && b.getChildCount() == 3) {
                g = true;
            }
        }
        let i = null;
        let j = null;
        let k = null;
        if (d) {
            i = this.d.createElement("select");
            this.q(i, c);
            i.listen("change", runOn(this, this.w));
            i.setStyleProperty("opacity", ".9");
            i.setStyleProperty("margin", "3px");
            b.append(i);
        }
        else {
            i = b.getChildAt(0);
        }
        if (e) {
            j = this.d.createElement("input");
            j.setAttribute("type", "text");
            j.listen("input", runOn(this, this.u));
            j.setStyleProperty("opacity", ".9");
            j.setStyleProperty("margin", "3px");
            if (b.getChildCount() == 2) {
                let l = b.getChildAt(b.getChildCount() - 1);
                l.before(j);
            }
            else {
                b.append(j);
            }
        }
        else {
            j = b.getChildAt(1);
        }
        if (g) {
            let m = b.getChildAt(1);
            m.remove();
        }
        if (f) {
            k = this.d.createElement("input");
            k.setAttribute("type", "button");
            k.setProperty("value", "X");
            k.listen("click", runOn(this, this.t));
            k.setStyleProperty("opacity", ".9");
            k.setStyleProperty("margin", "3px");
            b.append(k);
        }
        else {
            k = b.getChildAt(b.getChildCount() - 1);
        }
        this.c = true;
        i.setAttribute("data-index", a.toString());
        if (!stringIsNullOrEmpty(c.l)) {
            i.setProperty("value", c.l);
        }
        if (b.getChildCount() > 2) {
            j.setAttribute("data-index", a.toString());
            if (c.i != null) {
                j.setProperty("value", c.i);
            }
        }
        k.setAttribute("data-index", a.toString());
        this.c = false;
    }
    q(a, b) {
        a.removeChildren();
        for (let c = 0; c < b.e.length; c++) {
            let d = this.d.createElement("option");
            d.setAttribute("value", b.e[c]);
            d.setText(b.e[c]);
            a.append(d);
        }
    }
    t(a) {
        let b = this.n(a);
        this.b.f.removeAt(b);
    }
    n(a) {
        let originalEvent_ = a.originalEvent;
        let currentTarget_ = originalEvent_.currentTarget;
        return parseInt((currentTarget_.getAttribute('data-index')));
    }
    u(a) {
        this.c = true;
        let b = this.n(a);
        let c = this.k.getChildAt(b).getChildAt(1).getProperty("value");
        this.b.f._inner[b].i = c;
        this.c = false;
    }
    w(a) {
        this.c = true;
        let b = this.n(a);
        let c = this.k.getChildAt(b).getChildAt(0).getProperty("value");
        this.b.f._inner[b].l = c;
        this.c = false;
    }
    l(a) {
        return a.d[this.m(a)];
    }
    m(a) {
        for (let b = 0; b < a.e.length; b++) {
            if (a.e[b] == a.l) {
                return b;
            }
        }
        return 0;
    }
}
GridFilterDialogPanel.$t = markType(GridFilterDialogPanel, 'GridFilterDialogPanel');
/**
 * @hidden
 */
class GridFilterDialog extends Base {
    constructor() {
        super();
        this.x = null;
        this.o = true;
        this.propertyChanged = null;
        this.s = NaN;
        this.r = 1;
        this.f = null;
        this.dialogOpening = null;
        this.filterChanging = null;
        this.filterChanged = null;
        this.l = null;
        this.l = new GridFilterDialogView(this);
    }
    get y() {
        return this.x;
    }
    set y(a) {
        this.x = a;
    }
    get p() {
        return this.o;
    }
    set p(a) {
        let b = this.o;
        this.o = a;
        if (b != this.o) {
            this.ak("IsAnimationEnabled", b, this.o);
        }
    }
    get u() {
        return this.s;
    }
    set u(a) {
        let b = this.s;
        this.s = a;
        this.ak("PixelScalingRatio", b, this.s);
    }
    get t() {
        return this.r;
    }
    set t(a) {
        let b = this.r;
        this.r = a;
        this.ak("ActualPixelScalingRatio", b, this.r);
    }
    ak(a, b, c) {
        this.an(a, b, c);
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
    }
    an(a, b, c) {
        switch (a) {
            case "PixelScalingRatio":
                this.t = this.u;
                break;
            case "ActualPixelScalingRatio":
                this.l.u();
                break;
        }
    }
    ao(a) {
        this.l.r(a);
    }
    am() {
        let a = null;
        let b = 0;
        if (this.dialogOpening != null) {
            let c = new GridFilterDialogOpeningEventArgs();
            this.dialogOpening(this, c);
            a = c.a;
            b = c.b;
        }
        this.as(a, b);
    }
    as(a, b) {
        this.f = a;
        let c = ColumnComparisonFilterCondition.c(b);
        let d = this.m(a, c);
        d.m = 1;
        d.a = b;
        d.onModified = delegateCombine(d.onModified, runOn(this, this.al));
        this.l.v(d);
    }
    aj(a, b) {
        a.onModified = delegateRemove(a.onModified, runOn(this, this.al));
        if (b) {
            this.aq();
        }
        else {
            this.ap(a, true);
        }
        this.f = null;
    }
    ar() {
        if (this.filterChanged != null) {
            this.filterChanged(this, ((() => {
                let $ret = new GridFilterDialogFilterChangeEventArgs();
                $ret.a = this.f;
                return $ret;
            })()));
        }
    }
    aq() {
        if (this.filterChanged != null) {
            this.filterChanged(this, ((() => {
                let $ret = new GridFilterDialogFilterChangeEventArgs();
                $ret.a = null;
                return $ret;
            })()));
        }
    }
    ap(a, b) {
        let c = this.e(a);
        if (b) {
            if (this.filterChanged != null) {
                this.filterChanged(this, ((() => {
                    let $ret = new GridFilterDialogFilterChangeEventArgs();
                    $ret.a = c;
                    return $ret;
                })()));
            }
        }
        else {
            if (this.filterChanging != null) {
                this.filterChanging(this, ((() => {
                    let $ret = new GridFilterDialogFilterChangeEventArgs();
                    $ret.a = c;
                    return $ret;
                })()));
            }
        }
    }
    e(a) {
        let b = new ColumnFilterConditionGroup();
        b.f = a.k;
        let c = new Stack$1(ColumnFilterConditionGroup.$);
        let d = 0;
        let e = b;
        for (let f = 0; f < a.f.count; f++) {
            let g = this.h(d, c, a, f);
            while (g != null) {
                e.h(g);
                e = g;
                d++;
                g = this.h(d, c, a, f);
            }
            g = this.g(d, c, a, f);
            while (g != null) {
                e = g;
                d--;
                g = this.g(d, c, a, f);
            }
            if (e == null) {
                e = b;
            }
            if (this.q(a, a.f._inner[f])) {
                continue;
            }
            e.h(this.d(a.f._inner[f]));
        }
        if (b.g == 0) {
            return null;
        }
        return b;
    }
    q(a, b) {
        let c = 0;
        for (let d = 0; d < b.e.length; d++) {
            if (b.e[d] == b.l) {
                c = d;
                break;
            }
        }
        if (b.d[c] > 0 && b.i == null) {
            return true;
        }
        if (a.a != 0 && b.d[c] > 0 && typeof b.i === 'string' && stringIsNullOrEmpty(b.i)) {
            return true;
        }
        return false;
    }
    g(a, b, c, d) {
        let e = this.w(c, d);
        if (a > e) {
            b.e();
            return b.d();
        }
        return null;
    }
    w(a, b) {
        let c = a.c(b);
        if (c == null) {
            return 0;
        }
        return a.e.indexOf(c);
    }
    h(a, b, c, d) {
        let e = this.w(c, d);
        if (a < e) {
            let f = c.b(d);
            let g = new ColumnFilterConditionGroup();
            g.f = f.a;
            b.h(g);
            return g;
        }
        return null;
    }
    d(a) {
        let b = new ColumnComparisonFilterCondition();
        b.e = this.c(a.l);
        b.i = a.i;
        return b;
    }
    c(a) {
        return EnumUtil.getEnumValue(ColumnComparisonConditionOperatorType_$type, EnumUtil.parse(ColumnComparisonConditionOperatorType_$type, a, true));
    }
    al(a) {
        this.ap(a, false);
    }
    m(a, b) {
        let c = new GridFilterDialogViewModel();
        if (a != null) {
            this.af(c, a, b);
        }
        else {
            let d = new GridFilterDialogViewModelRow();
            d.f = b;
            d.e = GridFilterDialog.a(b);
            d.d = GridFilterDialog.b(b);
            d.l = GridFilterDialog.ac(b[0]);
            c.f.add(d);
        }
        return c;
    }
    af(a, b, c) {
        if (b.b()) {
            let d = b;
            for (let e = 0; e < d.g; e++) {
                let f = d.item(e);
                this.af(a, f, c);
            }
        }
        else {
            a.f.add(this.n(b, c));
        }
    }
    n(a, b) {
        let c = new GridFilterDialogViewModelRow();
        c.l = GridFilterDialog.ac(a.e);
        c.f = b;
        c.e = GridFilterDialog.a(b);
        c.i = GridFilterDialog.z(GridFilterDialog.v(a.e), a.e, a);
        c.j = GridFilterDialog.aa(GridFilterDialog.v(a.e), a.e, a);
        c.d = GridFilterDialog.b(b);
        return c;
    }
    static v(a) {
        return ColumnComparisonFilterCondition.g(a);
    }
    static z(a, b, c) {
        if (a == 0) {
            return "";
        }
        return c.i != null ? c.i.toString() : "";
    }
    static aa(a, b, c) {
        return "";
    }
    static b(a) {
        return ColumnComparisonFilterCondition.d(a);
    }
    static a(a) {
        let b = new Array(a.length);
        for (let c = 0; c < a.length; c++) {
            b[c] = EnumUtil.getName(ColumnComparisonConditionOperatorType_$type, a[c]);
        }
        return b;
    }
    static ac(a) {
        return EnumUtil.getName(ColumnComparisonConditionOperatorType_$type, a);
    }
    ai(a, b) {
        this.l.s(a, b);
    }
    ah(a, b, c) {
        let d = Math.min(a, b);
        let e = { $type: Point_$type, x: a / 2, y: b / 2 };
        let f = d * 0.8;
        let g = f / 2;
        let h = g / 2;
        let i = h / 2;
        let j = i / 2;
        let k = new PathFigure();
        k._startPoint = { $type: Point_$type, x: e.x - g, y: e.y - g };
        let l = new LineSegment(1);
        l.c = { $type: Point_$type, x: e.x + g, y: e.y - g };
        k._segments.add(l);
        let m = new PathFigure();
        m._startPoint = { $type: Point_$type, x: e.x - h, y: e.y };
        let n = new LineSegment(1);
        n.c = { $type: Point_$type, x: e.x + h, y: e.y };
        m._segments.add(n);
        let o = new PathFigure();
        o._startPoint = { $type: Point_$type, x: e.x - i, y: e.y + g };
        let p = new LineSegment(1);
        p.c = { $type: Point_$type, x: e.x + i, y: e.y + g };
        o._segments.add(p);
        let q = new PathGeometry();
        q.c.add(k);
        q.c.add(m);
        q.c.add(o);
        c.ak = q;
        c._stroke = this.l.w();
        c.ac = 1;
    }
    ag(a, b) {
        this.l.p();
        this.aj(a, b);
    }
}
GridFilterDialog.$t = markType(GridFilterDialog, 'GridFilterDialog', Base.$, [INotifyPropertyChanged_$type]);
/**
 * @hidden
 */
class GridFilterDialogViewModel extends Base {
    constructor() {
        super();
        this.a = 0;
        this.e = null;
        this.k = false;
        this.m = 0;
        this.f = null;
        this.onModified = null;
        this.k = false;
        this.f = new GridFilterDialogViewModelRowCollection();
        this.f.ae = this;
        this.e = new GridFilterDialogViewModelGroupingLevelCollection();
        this.f.ag = runOn(this, this.u);
        let a = this.f;
        a.collectionChanged = delegateCombine(a.collectionChanged, runOn(this, this.t));
    }
    n() {
        let a = new GridFilterDialogViewModelRow();
        let b = ColumnComparisonFilterCondition.c(this.a);
        a.f = b;
        a.e = GridFilterDialog.a(b);
        a.d = GridFilterDialog.b(b);
        a.l = GridFilterDialog.ac(b[0]);
        this.f.add(a);
    }
    u(a) {
        if (this.onModified != null) {
            this.onModified(this);
        }
    }
    t(a, b) {
        switch (b.action) {
            case 0:
                if (b.newItems != null) {
                    for (let c = 0; c < b.newItems.count; c++) {
                        let d = b.newItems.item(c);
                        this.q(c + b.newStartingIndex, d);
                    }
                }
                break;
            case 1:
                if (b.oldItems != null) {
                    for (let e = 0; e < b.oldItems.count; e++) {
                        this.r(b.oldStartingIndex);
                    }
                }
                break;
            case 2:
                if (b.oldItems != null) {
                    for (let f = 0; f < b.oldItems.count; f++) {
                        this.r(b.oldStartingIndex);
                    }
                }
                if (b.newItems != null) {
                    for (let g = 0; g < b.newItems.count; g++) {
                        let h = b.newItems.item(g);
                        this.q(g + b.newStartingIndex, b.newItems.item(g));
                    }
                }
                break;
            case 4:
                this.s();
                break;
        }
        if (this.onModified != null) {
            this.onModified(this);
        }
    }
    r(a) {
        let b = this.c(a);
        if (b == null) {
            return;
        }
        let c = this.b(a);
        if (c == null) {
            return;
        }
        this.w(c, a);
        for (let d = b.indexOf(c) + 1; d < b.count; d++) {
            this.v(b._inner[d], -1);
        }
    }
    w(a, b) {
        a.b--;
    }
    s() {
        this.e.clear();
    }
    q(a, b) {
        let c = this.c(a);
        if (c == null) {
            return;
        }
        let d = this.b(a);
        if (d == null) {
            return;
        }
        this.p(d, a);
        for (let e = c.indexOf(d) + 1; e < c.count; e++) {
            this.v(c._inner[e], +1);
        }
    }
    v(a, b) {
        a.c += b;
        a.b -= b;
    }
    p(a, b) {
        a.b++;
    }
    b(a) {
        for (let b = this.e.count - 1; b >= 0; b--) {
            for (let c = 0; c < this.e._inner[b].count; c--) {
                if (this.e._inner[b]._inner[c].c <= a && this.e._inner[b]._inner[c].b >= a) {
                    return this.e._inner[b]._inner[c];
                }
            }
        }
        return null;
    }
    c(a) {
        for (let b = this.e.count - 1; b >= 0; b--) {
            for (let c = 0; c < this.e._inner[b].count; c--) {
                if (this.e._inner[b]._inner[c].c <= a && this.e._inner[b]._inner[c].b >= a) {
                    return this.e._inner[b];
                }
            }
        }
        return null;
    }
    h(a, b) {
        let c = this.d(a, b);
        if (this.i(c, a, b)) {
            if (this.e.count < this.m) {
                return true;
            }
            else {
                return false;
            }
        }
        return true;
    }
    i(a, b, c) {
        if (a == null) {
            return false;
        }
        for (let d = 0; d < a.count; d++) {
            if (this.j(a._inner[d], b, c)) {
                return true;
            }
        }
        return false;
    }
    j(a, b, c) {
        if (c > a.c || b > a.b) {
            return false;
        }
        return true;
    }
    d(a, b) {
        if (this.e.count == 0) {
            return null;
        }
        for (let c = 0; c < this.e.count; c++) {
            if (!this.i(this.e._inner[c], a, b)) {
                return this.e._inner[c];
            }
        }
        return this.e._inner[this.e.count - 1];
    }
    aa(a, b) {
        for (let c = 0; c < this.e.count; c++) {
            for (let d = 0; d < this.e._inner[c].count; d++) {
                if (this.e._inner[c]._inner[d].c == a && this.e._inner[c]._inner[d].b == b) {
                    this.e._inner[c].removeAt(d);
                    break;
                }
            }
        }
        this.x();
        if (this.onModified != null) {
            this.onModified(this);
        }
    }
    x() {
        for (let a = this.e.count - 1; a >= 0; a--) {
            let b = new List$1(GridFilterDialogViewModelGrouping.$, 0);
            for (let c = 0; c < this.e._inner[a].count; c++) {
                let d = this.e._inner[a]._inner[c];
                if (a > 0) {
                    if (!this.i(this.e._inner[a - 1], d.c, d.b)) {
                        b.add(d);
                    }
                }
            }
            for (let e = 0; e < b.count; e++) {
                this.e._inner[a].remove(b._inner[e]);
                this.e._inner[a - 1].add(b._inner[e]);
            }
            if (this.e._inner[a].count == 0) {
                this.e.removeAt(a);
            }
        }
        this.y();
    }
    y() {
        for (let a = this.e.count - 1; a >= 0; a--) {
            let b = new List$1(GridFilterDialogViewModelGrouping.$, 0);
            for (let c = 0; c < this.e._inner[a].count; c++) {
                b.add(this.e._inner[a]._inner[c]);
            }
            b.aa((d, e) => Base.compareSimple(d.c, e.c));
            this.e._inner[a].clear();
            for (let d = 0; d < this.e._inner[a].count; d++) {
                this.e._inner[a].add(b._inner[d]);
            }
        }
    }
    l(a, b) {
        for (let c = 0; c < this.e.count; c++) {
            for (let d = 0; d < this.e._inner[c].count; d++) {
                if (this.e._inner[c]._inner[d].c == a && this.e._inner[c]._inner[d].b == b) {
                    return true;
                }
            }
        }
        return false;
    }
    z(a, b) {
        for (let c = 0; c < this.e.count; c++) {
            for (let d = 0; d < this.e._inner[c].count; d++) {
                if (this.e._inner[c]._inner[d].c == a && this.e._inner[c]._inner[d].b == b) {
                    this.e._inner[c]._inner[d].a = !this.e._inner[c]._inner[d].a;
                }
            }
        }
        if (this.onModified != null) {
            this.onModified(this);
        }
    }
    o(a, b, c) {
        if (!this.h(a, b)) {
            return;
        }
        let d = this.d(a, b);
        let e = d;
        if (this.i(d, a, b)) {
            this.e.add(new GridFilterDialogViewModelGroupingLevel());
            e = this.d(a, b);
        }
        e.add(((() => {
            let $ret = new GridFilterDialogViewModelGrouping();
            $ret.c = a;
            $ret.b = b;
            $ret.a = c;
            return $ret;
        })()));
        this.y();
        if (this.onModified != null) {
            this.onModified(this);
        }
    }
}
GridFilterDialogViewModel.$t = markType(GridFilterDialogViewModel, 'GridFilterDialogViewModel');
/**
 * @hidden
 */
class GridFilterDialogViewModelRowCollection extends ObservableCollection$1 {
    constructor() {
        super(GridFilterDialogViewModelRow.$, 0);
        this.ae = null;
        this.af = null;
        this.collectionChanged = delegateCombine(this.collectionChanged, runOn(this, this.ah));
    }
    ah(a, b) {
        if (b.oldItems != null) {
            for (let c = 0; c < b.oldItems.count; c++) {
                let d = b.oldItems.item(c);
                d.propertyChanged = delegateRemove(d.propertyChanged, runOn(this, this.ai));
            }
        }
        if (b.newItems != null) {
            for (let e = 0; e < b.newItems.count; e++) {
                let f = b.newItems.item(e);
                f.propertyChanged = delegateCombine(f.propertyChanged, runOn(this, this.ai));
            }
        }
    }
    ai(a, b) {
        if (this.af != null) {
            this.af(this.ae);
        }
    }
    get ag() {
        return this.af;
    }
    set ag(a) {
        this.af = a;
    }
}
GridFilterDialogViewModelRowCollection.$t = markType(GridFilterDialogViewModelRowCollection, 'GridFilterDialogViewModelRowCollection', ObservableCollection$1.$.specialize(GridFilterDialogViewModelRow.$));

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TextHeaderCell extends GridCellBase {
    constructor(a) {
        super(a);
        this.b1 = null;
        this.by = null;
        this.bx = null;
        this.b3 = null;
        this.b6 = -1;
        this.b5 = -1;
        this.b2 = null;
        this.b0 = false;
        this.b1 = a.createElement("span");
        this.x.setRawStyleProperty("text-align", "left");
        this.x.setRawStyleProperty("vertical-align", "middle");
        this.b1.setRawStyleProperty("display", "inline-block");
        this.b1.setRawStyleProperty("line-height", "normal");
        this.b1.setRawStyleProperty("vertical-align", "middle");
        this.b1.setRawStyleProperty("overflow", "hidden");
        this.b1.setRawStyleProperty("white-space", "nowrap");
        this.b1.setRawStyleProperty("text-overflow", "ellipsis");
        this.x.append(this.b1);
        let b = a.createElement("div");
        b.setRawStyleProperty("display", "none");
        b.setRawStyleProperty("width", "15px");
        b.setRawStyleProperty("height", "15px");
        this.b2 = b;
        let c = a.getSubRenderer(b);
        this.bx = new GridFilterDialog();
        this.bx.ao(c);
        this.x.append(b);
        this.bx.ai(15, 15);
        b = a.createElement("div");
        b.setRawStyleProperty("display", "inline-block");
        b.setRawStyleProperty("vertical-align", "middle");
        b.setRawStyleProperty("width", "16px");
        b.setRawStyleProperty("height", "16px");
        b.setRawStyleProperty("margin", "0 0 0 5px");
        this.b3 = b;
        c = a.getSubRenderer(b);
        this.by = new GridSortIndicator();
        this.by.au(c);
        this.x.append(b);
        this.by.ao(16, 16);
        let d = this.bx;
        d.dialogOpening = delegateCombine(d.dialogOpening, runOn(this, this.b7));
        let e = this.bx;
        e.filterChanging = delegateCombine(e.filterChanging, runOn(this, this.b9));
        let f = this.bx;
        f.filterChanged = delegateCombine(f.filterChanged, runOn(this, this.b8));
    }
    get b4() {
        return this.b1;
    }
    get bz() {
        return this.by;
    }
    q(a) {
        return true;
    }
    bn(a, b) {
        super.bn(a, b);
        a -= 21;
        if (this.b0) {
            a -= 15;
        }
        let c = Math.max(0, a - b);
        if (c != this.b6) {
            this.b6 = c;
            this.b1.setRawStyleProperty("max-width", c.toString() + "px");
        }
    }
    bi(a, b) {
        super.bi(a, b);
        let c = Math.max(0, a - b);
        if (this.b5 != c) {
            this.b5 = c;
            this.b1.setRawStyleProperty("max-height", c.toString() + "px");
        }
    }
    b8(a, b) {
        this.b.columnFilterChanged(b.a);
    }
    b9(a, b) {
        this.b.columnFilterChanging(b.a);
    }
    b7(a, b) {
        if (this.b != null) {
            b.a = this.b.getColumnFilterCondition();
            b.b = this.b.getColumnPropertyType();
        }
    }
    a8(a, b, c) {
        super.a8(a, b, c);
        if (c == 2) {
            this.x.removeChild(this.b3);
            this.x.removeChild(this.b2);
            this.b1.before(this.b2);
            this.b2.before(this.b3);
            this.b3.setRawStyleProperty("margin", "0 5px 0 0");
        }
        else {
            this.x.removeChild(this.b3);
            this.x.removeChild(this.b1);
            this.b2.before(this.b1);
            this.b2.before(this.b3);
            this.b3.setRawStyleProperty("margin", "0 0 0 5px");
        }
    }
    get_o() {
        return true;
    }
}
TextHeaderCell.$t = markType(TextHeaderCell, 'TextHeaderCell', GridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TextHeaderCellPresenter extends CellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(TextCellModel.ih)) {
                b.gq = b.ij;
                this.d.b4.setRawText(b.gq);
            }
            if (a.al(CellModel.et)) {
                if (a.aw) {
                    this.d.bz.l = false;
                }
                this.d.bz.b = a.k;
                if (a.aw) {
                    this.d.bz.l = true;
                }
            }
            if (a.al(CellModel.eu)) {
                if (a.aw) {
                    this.d.bz.l = false;
                }
                this.d.bz.ax = a.id;
                if (a.aw) {
                    this.d.bz.l = true;
                }
            }
            if (a.ak("IsFilterUIVisible")) {
                this.d.b0 = b.ip;
                this.d.b2.setRawStyleProperty("display", b.ip ? "inline-block" : "none");
                this.a.bn(a.e2, (a.ed + a.ef + a.dh + a.dk));
            }
            if (a.ak("SortIndicatorStyle")) {
                this.d.bz.f = b.im;
            }
            ContentCellModelHelper.a(this.a.u, b, this.a.x, this.d.b4, this.a);
        }
    }
}
TextHeaderCellPresenter.$t = markType(TextHeaderCellPresenter, 'TextHeaderCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class RowSeparatorCell extends GridCellBase {
    constructor(a) {
        super(a);
    }
}
RowSeparatorCell.$t = markType(RowSeparatorCell, 'RowSeparatorCell', GridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class RowSeparatorCellPresenter extends CellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
}
RowSeparatorCellPresenter.$t = markType(RowSeparatorCellPresenter, 'RowSeparatorCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ImageCell extends GridCellBase {
    constructor(a) {
        super(a);
        this.b3 = null;
        this.bx = 1;
        this.by = 3;
        this.b5 = null;
        this.bz = false;
        this.b0 = 1;
        this.b2 = null;
        this.b3 = a.createElement("img");
        this.b3.listen("load", runOn(this, this.b8));
        this.b2 = a.createElement("div");
        this.b2.setRawStyleProperty("background-size", "contain");
        this.b2.setRawStyleProperty("background-repeat", "no-repeat");
        this.b2.setRawStyleProperty("background-position", "center");
        this.b2.setRawStyleProperty("width", "100%");
        this.b2.setRawStyleProperty("height", "100%");
        this.x.setRawStyleProperty("text-align", "left");
        this.x.setRawStyleProperty("vertical-align", "middle");
        this.x.append(this.b2);
    }
    get b4() {
        return this.b3;
    }
    get b1() {
        return this.b0;
    }
    set b1(a) {
        this.b0 = a;
    }
    b8(a) {
        this.bz = false;
        if (!stringIsNullOrEmpty(this.b5)) {
            this.b2.setRawStyleProperty("opacity", "1");
            this.b2.setRawStyleProperty("background-image", "url(" + this.b5 + ")");
        }
    }
    b9(a, b) {
        if (a == this.b5) {
            return;
        }
        this.b6();
        this.b2.setRawStyleProperty("opacity", "0");
        if (a == null || a.length == 0) {
            this.b7(this.b3);
            return;
        }
        if (Base.equalsStatic(a, this.b5)) {
            return;
        }
        this.cd(a, b);
        let img_ = this.b3.getNativeElement();
        if (img_ != null && (img_.complete)) {
            this.bz = false;
            this.b3.setRawStyleProperty("opacity", "1");
            this.b2.setRawStyleProperty("background-image", "url(" + this.b5 + ")");
        }
    }
    b7(a) {
        a.setAttribute("src", "");
        this.b2.setRawStyleProperty("background-image", "");
    }
    cc(a) {
        switch (a) {
            case 1:
                this.b2.setRawStyleProperty("background-size", "100% 100%");
                break;
            case 2:
                this.b2.setRawStyleProperty("background-size", "auto");
                break;
            case 0:
                this.b2.setRawStyleProperty("background-size", "contain");
                break;
        }
    }
    cd(a, b) {
        this.bz = true;
        this.b5 = a;
        this.b4.setAttribute("src", a);
    }
    b6() {
        if (this.bz) {
            this.b7(this.b3);
            this.b5 = "";
        }
    }
    ca(a) {
        this.bx = a;
    }
    cb(a) {
        this.by = a;
    }
    get_p() {
        return true;
    }
    a9(a, b, c) {
        super.a9(a, b, c);
        if (a == "Indent" || a == "IsCollapsable") {
            this.b2.setRawStyleProperty("margin-left", this.ar + this.at + this.as + "px");
        }
    }
}
ImageCell.$t = markType(ImageCell, 'ImageCell', GridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class ImageCellPresenter extends CellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(CellModel.dp) || a.al(CellModel.e1)) {
                let c = Math.min(1, Math.max(0, a.bq));
                let d = a.bi * (1 - c);
                this.d.b1 = d;
            }
            if (b.al(ImageCellModel.il) || b.al(ImageCellModel.im)) {
                this.e(b.iq, b.ii);
            }
            if (b.al(ImageCellModel.io) || b.al(ImageCellModel.dv) || b.al(ImageCellModel.e0)) {
                this.f(b.ik, b.e, b.g);
            }
            if (b.al(ImageCellModel.ev)) {
                if (a.r == 1) {
                    this.d.b6();
                }
                else if (a.r == 2) {
                    this.e(b.iq, b.ii);
                }
            }
        }
    }
    f(a, b, c) {
        this.d.cc(a);
    }
    e(a, b) {
        let c = a.toLowerCase();
        if (b == 0) {
            b = 4;
        }
        if (stringStartsWith(c, "http") || b == 4) {
            this.d.b9(a, 4);
        }
        if (stringStartsWith(c, "asset") || b == 2) {
            let d = a;
            if (stringStartsWith(c, "asset")) {
                d = a.substr(8);
            }
            this.d.b9(d, 2);
        }
        if (stringStartsWith(c, "drawable") || b == 1) {
            let e = a;
            if (stringStartsWith(c, "drawable")) {
                e = a.substr(11);
            }
            this.d.b9(e, 1);
        }
        if (stringStartsWith(c, "nativeresource") || b == 1) {
            let f = a;
            if (stringStartsWith(c, "nativeresource")) {
                f = a.substr(17);
            }
            this.d.b9(f, 1);
        }
        if (stringStartsWith(c, "embeddedresource") || b == 3) {
            let g = a;
            if (stringStartsWith(c, "embeddedresource")) {
                g = a.substr(19);
            }
            this.d.b9(g, 3);
        }
    }
}
ImageCellPresenter.$t = markType(ImageCellPresenter, 'ImageCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateCellContainer extends Base {
    constructor(a) {
        super();
        this.d = null;
        this._element = null;
        this.b = null;
        this.b = a;
        this.element = a.createElement("div");
    }
    get element() {
        return this._element;
    }
    set element(a) {
        this._element = a;
    }
    get isCanvasBased() {
        return false;
    }
}
TemplateCellContainer.$t = markType(TemplateCellContainer, 'TemplateCellContainer');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateCell extends GridCellBase {
    constructor(a) {
        super(a);
        this.bx = null;
        this.bx = new TemplateCellContainer(a);
        this.bx.element.setRawStyleProperty("box-sizing", "border-box");
        this.x.append(this.bx.element);
    }
    get by() {
        return this.bx;
    }
    get_p() {
        return true;
    }
    a9(a, b, c) {
        super.a9(a, b, c);
        if (a == "Indent" || a == "IsCollapsable") {
            this.bx.element.setRawStyleProperty("margin-left", this.ar + this.at + this.as + "px");
        }
    }
}
TemplateCell.$t = markType(TemplateCell, 'TemplateCell', GridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateCellPresenter extends CellPresenterBase {
    constructor(a, b) {
        super(a);
        this.d = null;
        this.d = b;
    }
    get e() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        let c = this.d.actualColumns._inner[a.i.al];
        if (a.al(CellModel.dp) || a.al(CellModel.e1)) {
            let d = Math.min(1, Math.max(0, a.bq));
            let e = a.bi * (1 - d);
            this.e.by.element.setRawStyleProperty("opacity", e.toString());
        }
        c.gu(a, this.e.by);
    }
}
TemplateCellPresenter.$t = markType(TemplateCellPresenter, 'TemplateCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateHeaderCell extends GridCellBase {
    constructor(a) {
        super(a);
        this.bx = null;
        this.bx = new TemplateCellContainer(a);
        this.x.append(this.bx.element);
    }
    get by() {
        return this.bx;
    }
    get_o() {
        return true;
    }
}
TemplateHeaderCell.$t = markType(TemplateHeaderCell, 'TemplateHeaderCell', GridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateHeaderCellPresenter extends CellPresenterBase {
    constructor(a, b) {
        super(a);
        this.d = null;
        this.d = b;
    }
    get e() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = this.d.actualColumns._inner[a.i.al];
        let c = b.header;
        if (a.al(CellModel.dp) || a.al(CellModel.e1)) {
            let d = Math.min(1, Math.max(0, a.bq));
            let e = a.bi * (1 - d);
            this.e.by.element.setRawStyleProperty("opacity", e.toString());
        }
        let f = a;
        c.et(f, this.e.by);
    }
}
TemplateHeaderCellPresenter.$t = markType(TemplateHeaderCellPresenter, 'TemplateHeaderCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class SectionHeaderCell extends GridCellBase {
    constructor(a) {
        super(a);
        this.bx = null;
        this.bx = a.createElement("span");
        this.x.setRawStyleProperty("text-align", "left");
        this.x.setRawStyleProperty("vertical-align", "middle");
        this.x.setRawStyleProperty("overflow", "hidden");
        this.x.setRawStyleProperty("white-space", "nowrap");
        this.x.setRawStyleProperty("text-overflow", "ellipsis");
        this.x.append(this.bx);
    }
    get by() {
        return this.bx;
    }
    get_p() {
        return true;
    }
    a9(a, b, c) {
        super.a9(a, b, c);
        if (a == "Indent") {
            this.bx.setRawStyleProperty("margin-left", this.ar + this.at + 10 + "px");
        }
        if (a == "IsCollapsable") {
            if (this.m) {
                this.bx.setRawStyleProperty("margin-left", this.ar + this.at + 10 + "px");
            }
            else {
                this.bx.setRawStyleProperty("margin-left", "0px");
            }
        }
    }
}
SectionHeaderCell.$t = markType(SectionHeaderCell, 'SectionHeaderCell', GridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class SectionHeaderCellPresenter extends CellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            if (a.al(SectionHeaderCellModel.io) || a.al(SectionHeaderCellModel.iq) || a.al(SectionHeaderCellModel.ip) || a.al(SectionHeaderCellModel.is)) {
                if (b.ij == null || (b.ij.length == 0 && b.iy == null)) {
                    if (b.fb == null) {
                        b.gq = "";
                    }
                    else {
                        b.gq = b.fb.toString();
                    }
                }
                else {
                    if (b.iw != null && b.im == 0) {
                        b.gq = b.iy + "    " + b.iw;
                    }
                    else {
                        b.gq = b.iy;
                    }
                }
                this.d.by.setRawText(b.gq);
            }
            ContentCellModelHelper.a(this.a.u, b, this.a.x, this.d.by, this.a);
        }
    }
}
SectionHeaderCellPresenter.$t = markType(SectionHeaderCellPresenter, 'SectionHeaderCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class VerticalSeparatorCell extends GridCellBase {
    constructor(a) {
        super(a);
        this.x.setStyleProperty("background-clip", "padding-box");
    }
}
VerticalSeparatorCell.$t = markType(VerticalSeparatorCell, 'VerticalSeparatorCell', GridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class VerticalSeparatorCellPresenter extends CellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
}
VerticalSeparatorCellPresenter.$t = markType(VerticalSeparatorCellPresenter, 'VerticalSeparatorCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class SummaryCell extends GridCellBase {
    constructor(a) {
        super(a);
        this.bx = null;
        this.by = null;
        this.b2 = -1;
        this.b1 = -1;
        this.x.setRawStyleProperty("vertical-align", "middle");
        this.bx = a.createElement("span");
        this.bx.setRawStyleProperty("display", "inline-block");
        this.bx.setRawStyleProperty("width", "50%");
        this.bx.setRawStyleProperty("white-space", "nowrap");
        this.bx.setRawStyleProperty("text-overflow", "ellipsis");
        this.bx.setRawStyleProperty("vertical-align", "middle");
        this.bx.setRawStyleProperty("overflow", "hidden");
        this.x.append(this.bx);
        this.by = a.createElement("span");
        this.by.setRawStyleProperty("display", "inline-block");
        this.by.setRawStyleProperty("width", "50%");
        this.by.setRawStyleProperty("text-align", "right");
        this.by.setRawStyleProperty("white-space", "nowrap");
        this.by.setRawStyleProperty("text-overflow", "ellipsis");
        this.by.setRawStyleProperty("vertical-align", "middle");
        this.by.setRawStyleProperty("overflow", "hidden");
        this.x.append(this.by);
    }
    get bz() {
        return this.bx;
    }
    get b0() {
        return this.by;
    }
    bn(a, b) {
        super.bn(a, b);
        let c = Math.max(0, a - b);
        if (this.b2 != c) {
            this.b2 = c;
        }
    }
    bi(a, b) {
        super.bi(a, b);
        let c = Math.max(0, a - b);
        if (this.b1 != c) {
            this.b1 = c;
        }
    }
    get_p() {
        return false;
    }
}
SummaryCell.$t = markType(SummaryCell, 'SummaryCell', GridCellBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class SummaryCellPresenter extends CellPresenterBase {
    constructor(a) {
        super(a);
    }
    get d() {
        return this.a;
    }
    b(a) {
        super.b(a);
        let b = a;
        if (a.ah) {
            ContentCellModelHelper.a(this.a.u, b, this.a.x, this.d.bz, this.a);
            ContentCellModelHelper.a(this.a.u, b, this.a.x, this.d.b0, this.a);
            if (a.ak("ResolvedSummaryText") || a.ak("ResolvedSummaryValue")) {
                if (b.im != null) {
                    this.d.bz.setRawText(b.im);
                }
                if (b.ip != null) {
                    this.d.b0.setRawText(b.ip);
                }
            }
            if (a.ak("SummaryNameTextColor")) {
                this.d.bz.setRawStyleProperty("color", b.it._fill);
            }
        }
    }
}
SummaryCellPresenter.$t = markType(SummaryCellPresenter, 'SummaryCellPresenter', CellPresenterBase.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DataGridPresenterManager extends Base {
    constructor(a, b) {
        super();
        this.a = null;
        this.c = false;
        this.a = a;
        this.c = b;
    }
    b(a, b) {
        if (b.p != null) {
            return b.p;
        }
        if (this.c) {
            if (typeCast(TextCellModel.$, b) !== null) {
                b.p = new CanvasTextCellPresenter(new CanvasTextCell(a));
            }
            if (typeCast(NumericCellModel.$, b) !== null) {
                b.p = new CanvasNumericCellPresenter(new CanvasNumericCell(a));
            }
            if (typeCast(DateTimeCellModel.$, b) !== null) {
                b.p = new CanvasDateTimeCellPresenter(new CanvasDateTimeCell(a));
            }
            if (typeCast(TextHeaderCellModel.$, b) !== null) {
                b.p = new CanvasTextHeaderCellPresenter(new CanvasTextHeaderCell(a));
            }
            if (typeCast(RowSeparatorModel.$, b) !== null) {
                b.p = new CanvasRowSeparatorCellPresenter(new CanvasRowSeparatorCell(a));
            }
            if (typeCast(ImageCellModel.$, b) !== null) {
                b.p = new CanvasImageCellPresenter(new CanvasImageCell(a));
            }
            if (typeCast(TemplateCellModel.$, b) !== null) {
                b.p = new CanvasTemplateCellPresenter(new CanvasTemplateCell(a), this.a);
            }
            if (typeCast(TemplateHeaderCellModel.$, b) !== null) {
                b.p = new CanvasTemplateHeaderCellPresenter(new CanvasTemplateHeaderCell(a), this.a);
            }
            if (typeCast(SectionHeaderCellModel.$, b) !== null) {
                b.p = new CanvasSectionHeaderCellPresenter(new CanvasSectionHeaderCell(a));
            }
            if (typeCast(VerticalSeparatorCellModel.$, b) !== null) {
                b.p = new CanvasVerticalSeparatorCellPresenter(new CanvasVerticalSeparatorCell(a));
            }
            if (typeCast(SummaryCellModel.$, b) !== null) {
                b.p = new CanvasSummaryCellPresenter(new CanvasSummaryCell(a));
            }
        }
        else {
            if (typeCast(TextCellModel.$, b) !== null) {
                b.p = new TextCellPresenter(new TextCell(a));
            }
            if (typeCast(NumericCellModel.$, b) !== null) {
                b.p = new NumericCellPresenter(new NumericCell(a));
            }
            if (typeCast(DateTimeCellModel.$, b) !== null) {
                b.p = new DateTimeCellPresenter(new DateTimeCell(a));
            }
            if (typeCast(TextHeaderCellModel.$, b) !== null) {
                b.p = new TextHeaderCellPresenter(new TextHeaderCell(a));
            }
            if (typeCast(RowSeparatorModel.$, b) !== null) {
                b.p = new RowSeparatorCellPresenter(new RowSeparatorCell(a));
            }
            if (typeCast(ImageCellModel.$, b) !== null) {
                b.p = new ImageCellPresenter(new ImageCell(a));
            }
            if (typeCast(TemplateCellModel.$, b) !== null) {
                b.p = new TemplateCellPresenter(new TemplateCell(a), this.a);
            }
            if (typeCast(TemplateHeaderCellModel.$, b) !== null) {
                b.p = new TemplateHeaderCellPresenter(new TemplateHeaderCell(a), this.a);
            }
            if (typeCast(SectionHeaderCellModel.$, b) !== null) {
                b.p = new SectionHeaderCellPresenter(new SectionHeaderCell(a));
            }
            if (typeCast(VerticalSeparatorCellModel.$, b) !== null) {
                b.p = new VerticalSeparatorCellPresenter(new VerticalSeparatorCell(a));
            }
            if (typeCast(SummaryCellModel.$, b) !== null) {
                b.p = new SummaryCellPresenter(new SummaryCell(a));
            }
        }
        return b.p;
    }
}
DataGridPresenterManager.$t = markType(DataGridPresenterManager, 'DataGridPresenterManager');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let IViewportManager_$type = new Type(null, 'IViewportManager');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DataGridViewportManager extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.a = a;
    }
    moveViewportTo(x_, y_) {
        let grid_ = this.a;
        if (grid_._scrollTo) {
            grid_._scrollTo(x_, y_);
        }
        else {
            grid_.scrollTo(x_, y_);
        }
        ;
    }
}
DataGridViewportManager.$t = markType(DataGridViewportManager, 'DataGridViewportManager', Base.$, [IViewportManager_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let IDelayedExecutionManager_$type = new Type(null, 'IDelayedExecutionManager');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DataGridDelayedExecutionManager extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.a = a;
    }
    cancelPending(a) {
        this.a.clearTimeout(a);
    }
    executeIn(a, b) {
        return this.a.setTimeout(() => a(), b);
    }
}
DataGridDelayedExecutionManager.$t = markType(DataGridDelayedExecutionManager, 'DataGridDelayedExecutionManager', Base.$, [IDelayedExecutionManager_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let IPropertySetter_$type = new Type(null, 'IPropertySetter');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DataGridPropertySetter extends Base {
    setProperty(target_, propertyName_, value_) {
        if (target_ == null) {
            return;
        }
        target_[propertyName_] = value_;
    }
}
DataGridPropertySetter.$t = markType(DataGridPropertySetter, 'DataGridPropertySetter', Base.$, [IPropertySetter_$type]);

class IgxGridColumnCollection extends IgCollection {
    constructor(list) {
        super();
        if (!IgxColumnComponent.$type) {
            IgxColumnComponent.$type = markType(IgxColumnComponent, "IgxColumnComponent");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxColumnComponent.$type) {
            IgxColumnComponent.$type = markType(IgxColumnComponent, "IgxColumnComponent");
        }
        let coll = new SyncableObservableCollection$2(IgxColumnComponent.$type, Column.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = IgxColumnComponent._createFromInternal(int);
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let IDraggerView_$type = new Type(null, 'IDraggerView');
/**
 * @hidden
 */
let IDragger_$type = new Type(null, 'IDragger');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DraggerView extends Base {
    constructor(a) {
        super();
        this._model = null;
        this.c = null;
        this.a = null;
        this.model = a;
    }
    get model() {
        return this._model;
    }
    set model(a) {
        this._model = a;
    }
    provideContainer(a) {
        if (a == null) {
            if (this.c != null) {
                this.c = null;
            }
            if (this.a != null) {
                this.a.ak = null;
                this.a.aq();
            }
            return;
        }
        this.c = a;
        let b = Math.round(this.c.rootWrapper.width());
        let c = Math.round(this.c.rootWrapper.height());
        this.a = new CanvasGestureDOMEventProxy(this.c.rootWrapper, this.c, true);
        this.a.c1 = true;
        let d = this.a;
        d.onMouseOver = delegateCombine(d.onMouseOver, runOn(this, this.d));
        let e = this.a;
        e.onMouseUp = delegateCombine(e.onMouseUp, runOn(this, this.e));
        this.a.ak = runOn(this, this.b);
        this.model.viewportWidth = b;
        this.model.viewportHeight = c;
    }
    onDetachedFromUI() {
        if (this.a != null) {
            this.a.bb(this.c.rootWrapper, "");
        }
    }
    onAttachedToUI() {
        if (this.a != null) {
            this.a.ap(this.c.rootWrapper, "");
        }
    }
    b(a) {
        return this.model.isDragActive;
    }
    d(a, b, c) {
        this.f(a);
    }
    e(a) {
        this.g(a);
    }
    captureMouse() {
    }
    releaseMouse() {
    }
    transformPoint(a, b) {
        let c = BaseDOMEventProxy.cx(this.c.rootWrapper);
        let d = { $type: Point_$type, x: a - c.x, y: b - c.y };
        return d;
    }
    f(a) {
        this.model.onMouseMove(a.x, a.y);
    }
    g(a) {
        this.model.onMouseUp(a.x, a.y);
    }
    onViewportSizeChanged(a, b) {
        this.a.bf = new Rect(0, 0, 0, a, b);
    }
}
DraggerView.$t = markType(DraggerView, 'DraggerView', Base.$, [IDraggerView_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DragSelectEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._startX = 0;
        this._startY = 0;
        this._currentX = 0;
        this._currentY = 0;
        this._controlPressed = false;
    }
    get startX() {
        return this._startX;
    }
    set startX(a) {
        this._startX = a;
    }
    get startY() {
        return this._startY;
    }
    set startY(a) {
        this._startY = a;
    }
    get currentX() {
        return this._currentX;
    }
    set currentX(a) {
        this._currentX = a;
    }
    get currentY() {
        return this._currentY;
    }
    set currentY(a) {
        this._currentY = a;
    }
    get controlPressed() {
        return this._controlPressed;
    }
    set controlPressed(a) {
        this._controlPressed = a;
    }
}
DragSelectEventArgs.$t = markType(DragSelectEventArgs, 'DragSelectEventArgs', EventArgs.$);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class Dragger extends Base {
    constructor() {
        super(...arguments);
        this.l = null;
        this.d = false;
        this.c = null;
        this.b = 3;
        this.e = false;
        this.a = null;
        this.g = 0;
        this.f = 0;
        this.onDrag = null;
        this.onDragEnd = null;
        this.propertyChanged = null;
    }
    get view() {
        if (this.c == null) {
            this.c = new DraggerView(this);
        }
        return this.c;
    }
    get dragType() {
        return this.b;
    }
    get isDragActive() {
        return this.e;
    }
    get cellPath() {
        return this.a;
    }
    get viewportWidth() {
        return this.g;
    }
    set viewportWidth(a) {
        let b = this.g;
        this.g = a;
        if (b != this.g) {
            this.j("ViewportWidth", b, this.g);
        }
    }
    get viewportHeight() {
        return this.f;
    }
    set viewportHeight(a) {
        let b = this.f;
        this.f = a;
        if (b != this.f) {
            this.j("ViewportHeight", b, this.f);
        }
    }
    j(a, b, c) {
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
        this.k(a, b, c);
    }
    onDetachedFromUI() {
        this.view.onDetachedFromUI();
    }
    onAttachedToUI() {
        this.view.onAttachedToUI();
    }
    provideContainer(a) {
        this.view.provideContainer(a);
    }
    onMouseMove(a, b) {
        if (this.e) {
            if (this.onDrag != null) {
                this.onDrag(this, ((() => {
                    let $ret = new DragSelectEventArgs();
                    $ret.startX = this.l.x;
                    $ret.startY = this.l.y;
                    $ret.currentX = a;
                    $ret.currentY = b;
                    $ret.controlPressed = this.d;
                    return $ret;
                })()));
            }
        }
    }
    onMouseUp(a, b) {
        if (this.e) {
            this.view.releaseMouse();
            this.e = false;
            if (this.onDragEnd != null) {
                this.onDragEnd(this, new DragSelectEventArgs());
            }
            this.b = 3;
        }
    }
    dragStart(a, b, c, d, e, f, g) {
        if (!this.e) {
            this.l = this.view.transformPoint(a + c, b + d);
            this.e = true;
            this.d = g;
            this.b = e;
            this.a = f;
            this.view.captureMouse();
        }
    }
    k(a, b, c) {
        switch (a) {
            case "ViewportWidth":
            case "ViewportHeight":
                this.view.onViewportSizeChanged(this.g, this.f);
                break;
        }
    }
}
Dragger.$t = markType(Dragger, 'Dragger', Base.$, [IDragger_$type, INotifyPropertyChanged_$type]);

let defaultFont = "\"Verdana\", Arial, sans-serif";
let LiveGridStylingDefaults = {};

class IgxColumnSummaryDescriptionCollection {
    createImplementation() {
        return new ColumnSummaryDescriptionCollection();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    add(item) {
        let iv = this.i.g((item == null ? null : item.i));
        return (iv);
    }
    insert(index, item) {
        this.i.n(index, (item == null ? null : item.i));
    }
    clear() {
        this.i.m();
    }
    indexOf(item) {
        let iv = this.i.j((item == null ? null : item.i));
        return (iv);
    }
    remove(item) {
        let iv = this.i.h((item == null ? null : item.i));
        return (iv);
    }
    removeAt(index) {
        let iv = this.i.d(index);
        return (iv == null ? null : iv.externalObject);
    }
}

class IgxGridSelectedItemsCollection extends IgCollection {
    constructor(list) {
        super();
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        let coll = new SyncableObservableCollection$2(Base.$type, Base.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext;
        };
        coll.createFrom = (int) => {
            return int;
        };
        return coll;
    }
}

class IgxGridFilterExpressionsEventArgs {
    createImplementation() {
        return new GridFilterExpressionsEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get filterExpressions() {
        if (this.i.a == null) {
            return null;
        }
        if (!this.i.a.externalObject) {
            let e = new IgxFilterExpressionCollection();
            e._implementation = this.i.a;
            this.i.a.externalObject = e;
        }
        return this.i.a.externalObject;
    }
    set filterExpressions(v) {
        v == null ? this.i.a = null : this.i.a = v.i;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Information about the entering action.
*/
class IgxResponsiveStateEnteringEventArgs {
    createImplementation() {
        return new ResponsiveStateEnteringEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
}

/**
 * Information about the entered action.
*/
class IgxResponsiveStateEnteredEventArgs {
    createImplementation() {
        return new ResponsiveStateEnteredEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
}

/**
 * Information about the exited state.
*/
class IgxResponsiveStateExitedEventArgs {
    createImplementation() {
        return new ResponsiveStateExitedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
}

/**
 * Describes a state that the grid can enter based on a set of responsive conditions.
*/
class IgxResponsiveState {
    constructor() {
        this._stateEntering = null;
        this._stateEntered = null;
        this._stateExited = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new ResponsiveState();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The name of the responsive state
    */
    get name() {
        return this.i.n;
    }
    set name(v) {
        this.i.n = v;
    }
    /**
     * Gets or sets the minimum width for which this state is active.
    */
    get minimumWidth() {
        return this.i.k;
    }
    set minimumWidth(v) {
        this.i.k = +v;
    }
    /**
     * Gets or sets the maximum width for which this state is active.
    */
    get maximumWidth() {
        return this.i.j;
    }
    set maximumWidth(v) {
        this.i.j = +v;
    }
    /**
     * Configures this responsive state to only be manually actived
    */
    get isManualState() {
        return this.i.i;
    }
    set isManualState(v) {
        this.i.i = ensureBool(v);
    }
    /**
     * Adds a responsive phase to the state.
    
    * @param phase  * The phase to add.
    */
    addResponsivePhase(phase) {
        let iv = this.i.d((phase == null ? null : phase.i));
        return (iv == null ? null : iv.externalObject);
    }
    /**
     * Adds a responsive phase to the state and returns it.
    
    */
    responsivePhase() {
        let iv = this.i.a();
        return (iv == null ? null : iv.externalObject);
    }
    /**
     * Called when a state is being entered.
    */
    get stateEntering() {
        if (this._stateEntering == null) {
            this._stateEntering = new EventEmitter();
            this.i.stateEntering = delegateCombine(this.i.stateEntering, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxResponsiveStateEnteringEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeStateEntering) {
                        this.beforeStateEntering(this, outerArgs);
                    }
                    this._stateEntering.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._stateEntering;
    }
    /**
     * Called when a state is entered.
    */
    get stateEntered() {
        if (this._stateEntered == null) {
            this._stateEntered = new EventEmitter();
            this.i.stateEntered = delegateCombine(this.i.stateEntered, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxResponsiveStateEnteredEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeStateEntered) {
                        this.beforeStateEntered(this, outerArgs);
                    }
                    this._stateEntered.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._stateEntered;
    }
    /**
     * Called when a state is exited.
    */
    get stateExited() {
        if (this._stateExited == null) {
            this._stateExited = new EventEmitter();
            this.i.stateExited = delegateCombine(this.i.stateExited, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxResponsiveStateExitedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeStateExited) {
                        this.beforeStateExited(this, outerArgs);
                    }
                    this._stateExited.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._stateExited;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxResponsiveState.prototype, "stateEntering", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxResponsiveState.prototype, "stateEntered", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxResponsiveState.prototype, "stateExited", null);

class IgxResponsiveStatesCollection extends IgCollection {
    constructor(list) {
        super();
        if (!IgxResponsiveState.$type) {
            IgxResponsiveState.$type = markType(IgxResponsiveState, "IgxResponsiveState");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxResponsiveState.$type) {
            IgxResponsiveState.$type = markType(IgxResponsiveState, "IgxResponsiveState");
        }
        let coll = new SyncableObservableCollection$2(IgxResponsiveState.$type, ResponsiveState.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = new IgxResponsiveState();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

/**
 * Animation settings for the grid.
*/
class IgxGridAnimationSettings {
    constructor() {
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridAnimationSettings();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxRowSeparatorComponent_1;
/**
 * Represents a Row separator, this is used to visually separate the rows in a grid
*/
const IgxRowSeparatorComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxRowSeparatorComponent) }];
let IgxRowSeparatorComponent = IgxRowSeparatorComponent_1 = class IgxRowSeparatorComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new RowSeparator();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
};
IgxRowSeparatorComponent = IgxRowSeparatorComponent_1 = __decorate([
    Component({
        selector: 'igx-row-separator',
        template: ``,
        providers: [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxRowSeparatorComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxRowSeparatorComponent);

class IgxGridCellPosition {
    createImplementation() {
        return new GridCellPosition();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * Gets or sets the row position of the cell.
    */
    get rowIndex() {
        return this.i.b;
    }
    set rowIndex(v) {
        this.i.b = +v;
    }
    /**
     * Gets or sets the column position of the cell.  Can be null for spanning elements like section headers.
    */
    get columnUniqueKey() {
        return this.i.d;
    }
    set columnUniqueKey(v) {
        this.i.d = v;
    }
}

/**
 * Information about the change to the selected cells in the grid.
*/
class IgxGridActiveCellChangedEventArgs {
    createImplementation() {
        return new GridActiveCellChangedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The new active cell.
    */
    get newActiveCell() {
        if (this.i.newActiveCell == null) {
            return null;
        }
        if (!this.i.newActiveCell.externalObject) {
            let e = new IgxGridCellPosition();
            e._implementation = this.i.newActiveCell;
            this.i.newActiveCell.externalObject = e;
        }
        return this.i.newActiveCell.externalObject;
    }
    set newActiveCell(v) {
        v == null ? this.i.newActiveCell = null : this.i.newActiveCell = v.i;
    }
    /**
     * The old active cell.
    */
    get oldActiveCell() {
        if (this.i.oldActiveCell == null) {
            return null;
        }
        if (!this.i.oldActiveCell.externalObject) {
            let e = new IgxGridCellPosition();
            e._implementation = this.i.oldActiveCell;
            this.i.oldActiveCell.externalObject = e;
        }
        return this.i.oldActiveCell.externalObject;
    }
    set oldActiveCell(v) {
        v == null ? this.i.oldActiveCell = null : this.i.oldActiveCell = v.i;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class DataGridScrollerKeyboardListener extends Base {
    constructor(a) {
        super();
        this.a = null;
        this.a = a;
    }
    onDownArrow(a, b) {
        return this.a.f5(a, b);
    }
    onEnd(a, b) {
        return this.a.f6(a, b);
    }
    onHome(a, b) {
        return this.a.f8(a, b);
    }
    onLeftArrow(a, b) {
        return this.a.f9(a, b);
    }
    onPageDown(a, b) {
        return this.a.ga(a, b);
    }
    onPageUp(a, b) {
        return this.a.gb(a, b);
    }
    onRightArrow(a, b) {
        return this.a.gc(a, b);
    }
    onTab(a, b) {
        return this.a.gd(a, b);
    }
    onUpArrow(a, b) {
        return this.a.ge(a, b);
    }
    onWheel() {
        this.a.n3();
    }
    onEnter(a, b) {
        return this.a.f7(a, b);
    }
}
DataGridScrollerKeyboardListener.$t = markType(DataGridScrollerKeyboardListener, 'DataGridScrollerKeyboardListener', Base.$, [IScrollerKeyboardListener_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxHeaderSeparatorComponent_1;
const IgxHeaderSeparatorComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxHeaderSeparatorComponent) }];
let IgxHeaderSeparatorComponent = IgxHeaderSeparatorComponent_1 = class IgxHeaderSeparatorComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new HeaderSeparator();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
};
IgxHeaderSeparatorComponent = IgxHeaderSeparatorComponent_1 = __decorate([
    Component({
        selector: 'igx-header-separator',
        template: ``,
        providers: [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxHeaderSeparatorComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxHeaderSeparatorComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxColumnResizingSeparatorComponent_1;
const IgxColumnResizingSeparatorComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxColumnResizingSeparatorComponent) }];
let IgxColumnResizingSeparatorComponent = IgxColumnResizingSeparatorComponent_1 = class IgxColumnResizingSeparatorComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new ColumnResizingSeparator();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the separator width for this column.
    */
    get separatorWidth() {
        return this.i.d1;
    }
    set separatorWidth(v) {
        this.i.d1 = +v;
    }
};
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxColumnResizingSeparatorComponent.prototype, "separatorWidth", null);
IgxColumnResizingSeparatorComponent = IgxColumnResizingSeparatorComponent_1 = __decorate([
    Component({
        selector: 'igx-column-resizing-separator',
        template: ``,
        providers: [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxColumnResizingSeparatorComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxColumnResizingSeparatorComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxColumnMovingSeparatorComponent_1;
const IgxColumnMovingSeparatorComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxColumnMovingSeparatorComponent) }];
let IgxColumnMovingSeparatorComponent = IgxColumnMovingSeparatorComponent_1 = class IgxColumnMovingSeparatorComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new ColumnMovingSeparator();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the separator width for this column.
    */
    get separatorWidth() {
        return this.i.d1;
    }
    set separatorWidth(v) {
        this.i.d1 = +v;
    }
};
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxColumnMovingSeparatorComponent.prototype, "separatorWidth", null);
IgxColumnMovingSeparatorComponent = IgxColumnMovingSeparatorComponent_1 = __decorate([
    Component({
        selector: 'igx-column-moving-separator',
        template: ``,
        providers: [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxColumnMovingSeparatorComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxColumnMovingSeparatorComponent);

const IgxGridComponent_PROVIDERS = [];
let GridStylingDefaults = {};
let IgxLiveGridComponent = class IgxLiveGridComponent {
    constructor(_renderer, _elRef, _ngZone, _componentFactoryResolver, _injector) {
        this._renderer = _renderer;
        this._elRef = _elRef;
        this._ngZone = _ngZone;
        this._componentFactoryResolver = _componentFactoryResolver;
        this._injector = _injector;
        /**
         * The columns actually present in the grid. Do not directly modify this array.
         * This array's contents can be modified by causing Angular to reproject the child content.
         * Or adding and removing columns from the manual columns collection on the columns property.
         */
        this.combinedColumns = [];
        this._columns = null;
        this._disableManualColumnSync = false;
        this._scrollerStyle = 1 /* Fading */;
        this._columnsAdapter = null;
        this._scroller = null;
        this._dragger = null;
        this._wrapper = null;
        this._grid = null;
        this.containerResized = function () {
            var width = this._container.clientWidth;
            var height = this._container.clientHeight;
            this._scroller.viewportWidth = width;
            this._scroller.viewportHeight = height;
            this._grid.dragger.viewportWidth = width;
            this._grid.dragger.viewportHeight = height;
            this._grid.sizeChanged(width, height);
            if (this._grid.model.actualVisibleRegion.isEmpty &&
                width > 0 && height > 0) {
                this._grid.setViewport(0, 0, width, height);
            }
            else {
                this.onScroll();
            }
        };
        this._dataSource = null;
        this._insetLeft = 0;
        this._insetTop = 0;
        this._insetRight = 0;
        this._insetBottom = 0;
        this._selectedItems = null;
        this._selectedKeys = null;
        this._selectedCells = null;
        this._selectedCellRanges = null;
        this._pinnedItems = null;
        this._pinnedKeys = null;
        this._responsiveStates = null;
        this._actualColumns = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._filterExpressionsChanging = null;
        this._filterExpressionsChanged = null;
        this._cellPreviewPointerDown = null;
        this._cellPreviewPointerUp = null;
        this._cellPointerDown = null;
        this._cellPointerUp = null;
        this._cellClicked = null;
        this._sortDescriptionsChanged = null;
        this._groupDescriptionsChanged = null;
        this._columnsAutoGenerated = null;
        this._selectedItemsChanged = null;
        this._selectedKeysChanged = null;
        this._selectedCellsChanged = null;
        this._activeCellChanged = null;
        this._selectedCellRangesChanged = null;
        this._zoneRunner = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        let useCanvas = false;
        this._zoneRunner = (act) => this._ngZone.run(act);
        this._container = _renderer.createElement("div");
        _renderer.appendChild(_elRef.element.nativeElement, this._container);
        _renderer.setStyle(this._container, "display", "block");
        _renderer.setStyle(this._container, "width", "100%");
        _renderer.setStyle(this._container, "height", "100%");
        _renderer.setStyle(this._container, "box-sizing", "border-box");
        var root;
        root = this._container;
        if (this._container.nativeElement != null) {
            root = this._container.nativeElement;
        }
        var ren = new AngularRenderer(root, this._renderer, window.document, this._ngZone, true, LiveGridStylingDefaults);
        this._wrapper = ren;
        this._implementation = new Grid();
        var grid = this.i;
        this._grid = grid;
        this._columnsAdapter = new CollectionAdapter([], this.i.columns, this.combinedColumns, (c) => c.i, (i) => {
            i._provideRenderer(this._wrapper);
            if (this._elRef && this._elRef.element.nativeElement.parentElement) {
                i._styling(this._elRef.element.nativeElement, this, this);
            }
        }, (i) => { i._provideRenderer(null); });
        grid.externalGrid = new GridExternalWrapper(this);
        grid.tickProvider = new BrowserTickProvider(ren);
        grid.platformPixelConverter = new BrowserPixelConverter();
        this._contentLayout = new DataGridCellLayoutPanel(ren, new DataGridPresenterManager(this._grid, useCanvas), window.devicePixelRatio);
        grid.renderingEngine = this._contentLayout;
        grid.viewportManager = new DataGridViewportManager(this);
        grid.delayedExecutionManager = new DataGridDelayedExecutionManager(ren);
        grid.propertySetter = new DataGridPropertySetter();
        //grid.provideContainer(ren);
        let scroller = new Scroller();
        this._scroller = scroller;
        scroller.scrollbarStyle = this.scrollbarStyle;
        scroller.provideContainer(ren);
        this._content = (this._contentLayout.element.getNativeElement());
        scroller.keyboardListener = new DataGridScrollerKeyboardListener(grid);
        scroller.provideContent(new AngularWrapper(this._content, this._renderer, this._ngZone));
        scroller.onScrolling = () => this.onScroll();
        scroller.viewportWidth = this._container.clientWidth;
        scroller.viewportHeight = this._container.clientHeight;
        scroller.verticalTrackStartInset = this.headerHeight;
        grid.dragger = new Dragger();
        grid.dragger.provideContainer(ren);
        grid.dragger.viewportWidth = this._container.clientWidth;
        grid.dragger.viewportHeight = this._container.clientHeight;
        ren.addSizeWatcher(() => {
            this.containerResized();
        });
        // supports angular themes or custom properties set in CSS 
        //this._styling(_elRef.element.nativeElement, this);
    }
    _ensureColumnsAreManual() {
        this._disableManualColumnSync = true;
        this._columnsAdapter.shiftContentToManual(this.columns, (i) => i.isFromMarkup = false);
        this._disableManualColumnSync = false;
    }
    /**
     * A collection or manually added columns for the grid.
    */
    get columns() {
        if (this._columns === null) {
            let coll = new IgxGridColumnCollection();
            let inner = coll._innerColl;
            inner.addListener((sender, e) => {
                if (this._disableManualColumnSync) {
                    return;
                }
                switch (e.action) {
                    case NotifyCollectionChangedAction.Add:
                        this._columnsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Remove:
                        this._columnsAdapter.removeManualItemAt(e.oldStartingIndex);
                        break;
                    case NotifyCollectionChangedAction.Replace:
                        this._columnsAdapter.removeManualItemAt(e.oldStartingIndex);
                        this._columnsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Reset:
                        this._columnsAdapter.clearManualItems();
                        break;
                }
            });
            this._columns = coll;
        }
        return this._columns;
    }
    set height(value) {
        this._height = value;
        this._renderer.setStyle(this._elRef.element.nativeElement, "height", value);
        this.containerResized();
    }
    get height() {
        return this._height;
    }
    set width(value) {
        this._width = value;
        this._renderer.setStyle(this._elRef.element.nativeElement, "width", value);
        this.containerResized();
    }
    get width() {
        return this._width;
    }
    set scrollbarStyle(style) {
        this._scrollerStyle = style;
        if (this._scroller) {
            this._scroller.scrollbarStyle = this._scrollerStyle;
        }
    }
    get scrollbarStyle() {
        return this._scrollerStyle;
    }
    createImplementation() {
        let test = Grid;
        return new Grid();
    }
    ngOnInit() {
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _focusScroller() {
        this._scroller.focus();
    }
    _setDefaultCursor() {
        if (this._elRef.element.nativeElement.style.cursor !== "") {
            this._elRef.element.nativeElement.style.cursor = "";
        }
    }
    _setResizeCursor() {
        if (this._elRef.element.nativeElement.style.cursor !== "col-resize") {
            this._elRef.element.nativeElement.style.cursor = "col-resize";
        }
    }
    _setHandCursor() {
        if (this._elRef.element.nativeElement.style.cursor !== "grabbing") {
            this._elRef.element.nativeElement.style.cursor = "grabbing";
        }
    }
    _insertExternalColumnAtIndex(index, column) {
        //let contentCount = this.contentColumns.length;
        let contentCount = this._columnsAdapter.actualContent.length;
        this.columns.insert(index - contentCount, column);
    }
    _removeExternalColumn(column) {
        let ind = -1;
        for (let i = 0; i < this.columns.count; i++) {
            if (this.columns.item(i) === column) {
                ind = i;
                break;
            }
        }
        if (ind >= 0) {
            this.columns.removeAt(ind);
        }
    }
    ngAfterContentInit() {
        let prev = this._grid.columnPropertyUpdatingAnimationMode;
        this._grid.columnPropertyUpdatingAnimationMode = ColumnPropertyUpdatingAnimationMode.None;
        this._styling(this._elRef.element.nativeElement, this);
        this._grid.columnPropertyUpdatingAnimationMode = prev;
        this._columnsAdapter.updateQuery(this.contentColumns);
        prev = this._grid.columnPropertyUpdatingAnimationMode;
        this._grid.columnPropertyUpdatingAnimationMode = ColumnPropertyUpdatingAnimationMode.None;
        for (let i = 0; i < this.actualColumns.count; i++) {
            let c = this.actualColumns.item(i);
            c._styling(this._elRef.element.nativeElement, this, this);
        }
        this._grid.columnPropertyUpdatingAnimationMode = prev;
        this._grid.itemsSource = this._dataSource;
    }
    get actualDataSource() {
        return this.i.actualDataSource;
    }
    refreshContentSize() {
        if (this._content != null) {
            var width = this._grid.model.absoluteWidth;
            var height = this._grid.model.absoluteHeight;
            if (this._scroller != null) {
                this._scroller.contentWidth = width;
                this._scroller.contentHeight = height;
            }
        }
    }
    onScroll() {
        let top = this._scroller.scrollTop;
        let left = this._scroller.scrollLeft;
        let width = this._scroller.viewportWidth;
        let height = this._scroller.viewportHeight;
        //console.log("top:" + top);
        this._grid.setViewport(left, top, left + width, top + height);
    }
    set dataSource(value) {
        this._dataSource = value;
        if (this._grid != null) {
            this._grid.itemsSource = this._dataSource;
        }
    }
    get dataSource() {
        return this._dataSource;
    }
    forColumnsWithPropertyPath(propertyPath, callback) {
        for (let i = 0; i < this.i.actualColumns.count; i++) {
            let col = this.i.actualColumns.item(i).externalObject;
            if (col.propertyPath == propertyPath) {
                callback(col);
            }
        }
    }
    /**
     * Gets or sets the default column width to use if a column as no local width.
     * */
    get defaultColumnWidth() {
        let ext = this.i.defaultColumnWidth.externalObject;
        if (!ext) {
            ext = new IgxColumnWidth();
            ext._implementation = this.i.defaultColumnWidth;
        }
        return ext;
    }
    set defaultColumnWidth(value) {
        if (typeof value == "string") {
            let int = ColumnWidth.parse(value);
            let ext = new IgxColumnWidth();
            ext._implementation = int;
            value = ext;
        }
        this.i.defaultColumnWidth = value.i;
    }
    /**
     * Gets or sets the amount of left inset space to use around the grid content.
    */
    get insetLeft() {
        return this._insetLeft;
    }
    set insetLeft(v) {
        this._insetLeft = +v;
        let inset = new Thickness(1, this._insetLeft, this._insetTop, this._insetRight, this._insetBottom);
        this.i.inset = inset;
    }
    /**
     * Gets or sets the amount of top inset space to use around the grid content.
    */
    get insetTop() {
        return this._insetTop;
    }
    set insetTop(v) {
        this._insetTop = +v;
        let inset = new Thickness(1, this._insetLeft, this._insetTop, this._insetRight, this._insetBottom);
        this.i.inset = inset;
    }
    /**
     * Gets or sets the amount of right inset space to use around the grid content.
    */
    get insetRight() {
        return this._insetLeft;
    }
    set insetRight(v) {
        this._insetRight = +v;
        let inset = new Thickness(1, this._insetLeft, this._insetTop, this._insetRight, this._insetBottom);
        this.i.inset = inset;
    }
    /**
     * Gets or sets the amount of bottom inset space to use around the grid content.
    */
    get insetBottom() {
        return this._insetBottom;
    }
    set insetBottom(v) {
        this._insetBottom = +v;
        let inset = new Thickness(1, this._insetLeft, this._insetTop, this._insetRight, this._insetBottom);
        this.i.inset = inset;
    }
    /**
 * Gets or sets the type of column resizing to use.
*/
    get columnResizingMode() {
        return this.i.bg;
    }
    set columnResizingMode(v) {
        this.i.bg = ensureEnum(ColumnResizingMode_$type, v);
    }
    /**
     * Gets or sets the type column moving to use.
    */
    get columnMovingMode() {
        return this.i.a7;
    }
    set columnMovingMode(v) {
        this.i.a7 = ensureEnum(ColumnMovingMode_$type, v);
    }
    /**
     * Gets or sets the header type used for sectioning off groups of rows.
    */
    get sectionHeader() {
        if (this.i.dv == null) {
            return null;
        }
        if (!this.i.dv.externalObject) {
            let e = IgxSectionHeaderComponent._createFromInternal(this.i.dv);
            if (e) {
                e._implementation = this.i.dv;
            }
            this.i.dv.externalObject = e;
        }
        return this.i.dv.externalObject;
    }
    set sectionHeader(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.dv = null : this.i.dv = v.i;
    }
    /**
     * Gets or sets the cell definition used for summary rows at the root level.
    */
    get summaryRowRoot() {
        if (this.i.d5 == null) {
            return null;
        }
        if (!this.i.d5.externalObject) {
            let e = IgxSummaryRowRootComponent._createFromInternal(this.i.d5);
            if (e) {
                e._implementation = this.i.d5;
            }
            this.i.d5.externalObject = e;
        }
        return this.i.d5.externalObject;
    }
    set summaryRowRoot(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.d5 = null : this.i.d5 = v.i;
    }
    /**
     * Gets or sets the cell definition used for summary rows at the section level.
    */
    get summaryRowSection() {
        if (this.i.d7 == null) {
            return null;
        }
        if (!this.i.d7.externalObject) {
            let e = IgxSummaryRowSectionComponent._createFromInternal(this.i.d7);
            if (e) {
                e._implementation = this.i.d7;
            }
            this.i.d7.externalObject = e;
        }
        return this.i.d7.externalObject;
    }
    set summaryRowSection(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.d7 = null : this.i.d7 = v.i;
    }
    /**
     * Gets or sets the row seperator settings.
    */
    get rowSeparator() {
        if (this.i.dr == null) {
            return null;
        }
        if (!this.i.dr.externalObject) {
            let e = IgxRowSeparatorComponent._createFromInternal(this.i.dr);
            if (e) {
                e._implementation = this.i.dr;
            }
            this.i.dr.externalObject = e;
        }
        return this.i.dr.externalObject;
    }
    set rowSeparator(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.dr = null : this.i.dr = v.i;
    }
    /**
     * Gets or sets the header seperator settings.
    */
    get headerSeparator() {
        if (this.i.c6 == null) {
            return null;
        }
        if (!this.i.c6.externalObject) {
            let e = IgxHeaderSeparatorComponent._createFromInternal(this.i.c6);
            if (e) {
                e._implementation = this.i.c6;
            }
            this.i.c6.externalObject = e;
        }
        return this.i.c6.externalObject;
    }
    set headerSeparator(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.c6 = null : this.i.c6 = v.i;
    }
    /**
     * Gets or sets the column resizing seperator settings.
    */
    get columnResizingSeparator() {
        if (this.i.bi == null) {
            return null;
        }
        if (!this.i.bi.externalObject) {
            let e = IgxColumnResizingSeparatorComponent._createFromInternal(this.i.bi);
            if (e) {
                e._implementation = this.i.bi;
            }
            this.i.bi.externalObject = e;
        }
        return this.i.bi.externalObject;
    }
    set columnResizingSeparator(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.bi = null : this.i.bi = v.i;
    }
    /**
     * Gets or sets the column resizing seperator settings.
    */
    get columnMovingSeparator() {
        if (this.i.a9 == null) {
            return null;
        }
        if (!this.i.a9.externalObject) {
            let e = IgxColumnMovingSeparatorComponent._createFromInternal(this.i.a9);
            if (e) {
                e._implementation = this.i.a9;
            }
            this.i.a9.externalObject = e;
        }
        return this.i.a9.externalObject;
    }
    set columnMovingSeparator(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.a9 = null : this.i.a9 = v.i;
    }
    /**
     * Gets or sets the desired properties for the data source to load. If specified the data source may decide to constrain the properties it fetches to these properties and must make sure that at least those properties are loaded, rather than the default behavior for that data source.
    */
    get dataSourceDesiredProperties() {
        return this.i.e;
    }
    set dataSourceDesiredProperties(v) {
        this.i.e = v;
    }
    /**
     * Gets or sets the height to use for the rows in the grid.
    */
    get rowHeight() {
        return this.i.ir;
    }
    set rowHeight(v) {
        this.i.ir = +v;
    }
    /**
     * Gets or sets the default minimum width to use on all columns. Ignored if NaN.
    */
    get defaultColumnMinWidth() {
        return this.i.g9;
    }
    set defaultColumnMinWidth(v) {
        this.i.g9 = +v;
    }
    /**
     * Gets or sets the height to use for the header row.
    */
    get headerHeight() {
        return this.i.ik;
    }
    set headerHeight(v) {
        this.i.ik = +v;
    }
    /**
     * Returns/sets the action to take when a column header is clicked.
    */
    get headerClickAction() {
        return this.i.c4;
    }
    set headerClickAction(v) {
        this.i.c4 = ensureEnum(HeaderClickAction_$type, v);
    }
    /**
     * Configures whether or not the grid will autogenerate columns when the data source is set.
    */
    get autoGenerateColumns() {
        return this.i.fd;
    }
    set autoGenerateColumns(v) {
        this.i.fd = ensureBool(v);
    }
    /**
     * Sets or gets the height to use for the row separators.
    */
    get rowSeparatorHeight() {
        return this.i.it;
    }
    set rowSeparatorHeight(v) {
        this.i.it = +v;
    }
    /**
     * Configures whether or not place holders are used for cells who do not have their data yet.
    */
    get isPlaceholderRenderingEnabled() {
        return this.i.fz;
    }
    set isPlaceholderRenderingEnabled(v) {
        this.i.fz = ensureBool(v);
    }
    /**
     * Sets or gets the Column Adding Animation mode to use.
    */
    get columnAddingAnimationMode() {
        return this.i.bl;
    }
    set columnAddingAnimationMode(v) {
        this.i.bl = ensureEnum(ColumnShowingAnimationMode_$type, v);
    }
    /**
     * Sets or gets the Column Property Updating Animation mode to use.
    */
    get columnPropertyUpdatingAnimationMode() {
        return this.i.columnPropertyUpdatingAnimationMode;
    }
    set columnPropertyUpdatingAnimationMode(v) {
        this.i.columnPropertyUpdatingAnimationMode = ensureEnum(ColumnPropertyUpdatingAnimationMode_$type, v);
    }
    /**
     * Sets or gets the cell data loaded animation mode to use.
    */
    get cellDataLoadedAnimationMode() {
        return this.i.ah;
    }
    set cellDataLoadedAnimationMode(v) {
        this.i.ah = ensureEnum(CellDataLoadedAnimationMode_$type, v);
    }
    /**
     * Sets or gets the row selection animation mode to use.
    */
    get rowSelectionAnimationMode() {
        return this.i.dp;
    }
    set rowSelectionAnimationMode(v) {
        this.i.dp = ensureEnum(RowSelectionAnimationMode_$type, v);
    }
    /**
     * Sets or gets the cell selection animation mode to use.
    */
    get cellSelectionAnimationMode() {
        return this.i.ar;
    }
    set cellSelectionAnimationMode(v) {
        this.i.ar = ensureEnum(CellSelectionAnimationMode_$type, v);
    }
    /**
     * Sets or gets the default animation settings for the grid.
    */
    get animationSettings() {
        if (this.i.b3 == null) {
            return null;
        }
        if (!this.i.b3.externalObject) {
            let e = new IgxGridAnimationSettings();
            e._implementation = this.i.b3;
            this.i.b3.externalObject = e;
        }
        return this.i.b3.externalObject;
    }
    set animationSettings(v) {
        v == null ? this.i.b3 = null : this.i.b3 = v.i;
    }
    /**
     * Sets or gets the column resizing animation mode to use. Only applies when resizing in Deferred mode.
    */
    get columnResizingAnimationMode() {
        return this.i.bd;
    }
    set columnResizingAnimationMode(v) {
        this.i.bd = ensureEnum(ColumnResizingAnimationMode_$type, v);
    }
    /**
     * Sets or gets the column showing animation mode to use.
    */
    get columnShowingAnimationMode() {
        return this.i.bm;
    }
    set columnShowingAnimationMode(v) {
        this.i.bm = ensureEnum(ColumnShowingAnimationMode_$type, v);
    }
    /**
     * Sets or gets the column moving animation mode to use.
    */
    get columnMovingAnimationMode() {
        return this.i.a4;
    }
    set columnMovingAnimationMode(v) {
        this.i.a4 = ensureEnum(ColumnMovingAnimationMode_$type, v);
    }
    /**
     * Sets or gets the column hiding animation mode to use.
    */
    get columnHidingAnimationMode() {
        return this.i.a1;
    }
    set columnHidingAnimationMode(v) {
        this.i.a1 = ensureEnum(ColumnHidingAnimationMode_$type, v);
    }
    /**
     * Sets or gets the column exchanging animation mode to use.
    */
    get columnExchangingAnimationMode() {
        return this.i.aw;
    }
    set columnExchangingAnimationMode(v) {
        this.i.aw = ensureEnum(ColumnExchangingAnimationMode_$type, v);
    }
    /**
     * Sets or gets the grid selection mode.
    */
    get selectionMode() {
        return this.i.cz;
    }
    set selectionMode(v) {
        this.i.cz = ensureEnum(GridSelectionMode_$type, v);
    }
    /**
     * Sets or gets the grid selection mode.
    */
    get activationMode() {
        return this.i.by;
    }
    set activationMode(v) {
        this.i.by = ensureEnum(GridActivationMode_$type, v);
    }
    /**
     * Sets or gets how selection behaves in the grid.
    */
    get selectionBehavior() {
        return this.i.cx;
    }
    set selectionBehavior(v) {
        this.i.cx = ensureEnum(GridSelectionBehavior_$type, v);
    }
    /**
     * Gets which items are currently selected in the grid. Collection can be updated to programatically select items.
    */
    get selectedItems() {
        if (this._selectedItems === null) {
            let coll = new IgxGridSelectedItemsCollection();
            let innerColl = this.i.z;
            if (!innerColl) {
                innerColl = new GridSelectedItemsCollection();
            }
            this._selectedItems = coll._fromInner(innerColl);
        }
        return this._selectedItems;
    }
    set selectedItems(v) {
        if (this._selectedItems !== null) {
            this._selectedItems._setSyncTarget(null);
            this._selectedItems = null;
        }
        let coll = new IgxGridSelectedItemsCollection();
        this._selectedItems = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(Base.$type);
        let innerColl = this.i.z;
        if (!innerColl) {
            innerColl = new GridSelectedItemsCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._selectedItems._setSyncTarget(syncColl);
    }
    /**
     * Gets which primary key values are currently selected in the grid. Collection can be updated to programatically select items.
    */
    get selectedKeys() {
        if (this._selectedKeys === null) {
            let coll = new IgxGridSelectedKeysCollection();
            let innerColl = this.i.ad;
            if (!innerColl) {
                innerColl = new GridSelectedKeysCollection();
            }
            this._selectedKeys = coll._fromInner(innerColl);
        }
        return this._selectedKeys;
    }
    set selectedKeys(v) {
        if (this._selectedKeys !== null) {
            this._selectedKeys._setSyncTarget(null);
            this._selectedKeys = null;
        }
        let coll = new IgxGridSelectedKeysCollection();
        this._selectedKeys = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PrimaryKeyValue.$type);
        let innerColl = this.i.ad;
        if (!innerColl) {
            innerColl = new GridSelectedKeysCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._selectedKeys._setSyncTarget(syncColl);
    }
    /**
     * Gets which cells are currently selected in the grid. Collection can be updated to programatically select cells.
    */
    get selectedCells() {
        if (this._selectedCells === null) {
            let coll = new IgxGridSelectedCellsCollection();
            let innerColl = this.i.ct;
            if (!innerColl) {
                innerColl = new GridSelectedCellsCollection();
            }
            this._selectedCells = coll._fromInner(innerColl);
        }
        return this._selectedCells;
    }
    set selectedCells(v) {
        if (this._selectedCells !== null) {
            this._selectedCells._setSyncTarget(null);
            this._selectedCells = null;
        }
        let coll = new IgxGridSelectedCellsCollection();
        this._selectedCells = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(CellKey.$type);
        let innerColl = this.i.ct;
        if (!innerColl) {
            innerColl = new GridSelectedCellsCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._selectedCells._setSyncTarget(syncColl);
    }
    /**
     * Gets which cell ranges are currently selected in the grid. Collection can be updated to programatically select cells.
    */
    get selectedCellRanges() {
        if (this._selectedCellRanges === null) {
            let coll = new IgxGridSelectedCellRangesCollection();
            let innerColl = this.i.cq;
            if (!innerColl) {
                innerColl = new GridSelectedCellRangesCollection();
            }
            this._selectedCellRanges = coll._fromInner(innerColl);
        }
        return this._selectedCellRanges;
    }
    set selectedCellRanges(v) {
        if (this._selectedCellRanges !== null) {
            this._selectedCellRanges._setSyncTarget(null);
            this._selectedCellRanges = null;
        }
        let coll = new IgxGridSelectedCellRangesCollection();
        this._selectedCellRanges = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(CellRange.$type);
        let innerColl = this.i.cq;
        if (!innerColl) {
            innerColl = new GridSelectedCellRangesCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._selectedCellRanges._setSyncTarget(syncColl);
    }
    /**
     * Gets which items are currently pinned in the grid. Collection can be updated to programatically pin items.
    */
    get pinnedItems() {
        if (this._pinnedItems === null) {
            let coll = new IgxGridSelectedItemsCollection();
            let innerColl = this.i.y;
            if (!innerColl) {
                innerColl = new GridSelectedItemsCollection();
            }
            this._pinnedItems = coll._fromInner(innerColl);
        }
        return this._pinnedItems;
    }
    set pinnedItems(v) {
        if (this._pinnedItems !== null) {
            this._pinnedItems._setSyncTarget(null);
            this._pinnedItems = null;
        }
        let coll = new IgxGridSelectedItemsCollection();
        this._pinnedItems = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(Base.$type);
        let innerColl = this.i.y;
        if (!innerColl) {
            innerColl = new GridSelectedItemsCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._pinnedItems._setSyncTarget(syncColl);
    }
    /**
     * Gets which primary keys are currently pinned in the grid. Collection can be updated to programatically pin items.
    */
    get pinnedKeys() {
        if (this._pinnedKeys === null) {
            let coll = new IgxGridSelectedKeysCollection();
            let innerColl = this.i.ac;
            if (!innerColl) {
                innerColl = new GridSelectedKeysCollection();
            }
            this._pinnedKeys = coll._fromInner(innerColl);
        }
        return this._pinnedKeys;
    }
    set pinnedKeys(v) {
        if (this._pinnedKeys !== null) {
            this._pinnedKeys._setSyncTarget(null);
            this._pinnedKeys = null;
        }
        let coll = new IgxGridSelectedKeysCollection();
        this._pinnedKeys = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PrimaryKeyValue.$type);
        let innerColl = this.i.ac;
        if (!innerColl) {
            innerColl = new GridSelectedKeysCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._pinnedKeys._setSyncTarget(syncColl);
    }
    /**
     * Gets or sets whether to show the filtering UI in the headers for columns where filtering is enabled.
    */
    get isFilterUIEnabled() {
        return this.i.fs;
    }
    set isFilterUIEnabled(v) {
        this.i.fs = ensureBool(v);
    }
    /**
     * Gets or sets if group rows will stick to the top of the grid.
    */
    get isGroupRowSticky() {
        return this.i.fv;
    }
    set isGroupRowSticky(v) {
        this.i.fv = ensureBool(v);
    }
    /**
     * Gets or sets if header separators are rendered.
    */
    get isHeaderSeparatorVisible() {
        return this.i.fw;
    }
    set isHeaderSeparatorVisible(v) {
        this.i.fw = ensureBool(v);
    }
    /**
     * Gets or sets the default background color to use for content cells when a row is in a selected state
    */
    get cellSelectedBackground() {
        return brushToString(this.i.pw);
    }
    set cellSelectedBackground(v) {
        this.i.pw = stringToBrush(v);
    }
    /**
     * Gets or sets the default background color to use for section header cells when a row is in a selected state
    */
    get sectionHeaderSelectedBackground() {
        return brushToString(this.i.qb);
    }
    set sectionHeaderSelectedBackground(v) {
        this.i.qb = stringToBrush(v);
    }
    /**
     * Gets or sets the default background color to use for summary cells at the root level.
    */
    get summaryRootBackground() {
        return brushToString(this.i.qe);
    }
    set summaryRootBackground(v) {
        this.i.qe = stringToBrush(v);
    }
    /**
     * Gets or sets the default background color to use for summary cells at the section level.
    */
    get summarySectionBackground() {
        return brushToString(this.i.qi);
    }
    set summarySectionBackground(v) {
        this.i.qi = stringToBrush(v);
    }
    /**
     * Gets or sets the default opacity to use for pinned rows
    */
    get pinnedRowOpacity() {
        return this.i.ha;
    }
    set pinnedRowOpacity(v) {
        this.i.ha = +v;
    }
    /**
     * Gets or sets the default color to use for sticky rows
    */
    get stickyRowBackground() {
        return brushToString(this.i.qd);
    }
    set stickyRowBackground(v) {
        this.i.qd = stringToBrush(v);
    }
    /**
     * Gets or sets the default color to use for pinned rows
    */
    get pinnedRowBackground() {
        return brushToString(this.i.p5);
    }
    set pinnedRowBackground(v) {
        this.i.p5 = stringToBrush(v);
    }
    /**
     * Gets or sets the default color to use for the last sticky row
    */
    get lastStickyRowBackground() {
        return brushToString(this.i.p4);
    }
    set lastStickyRowBackground(v) {
        this.i.p4 = stringToBrush(v);
    }
    /**
     * Gets or sets the position of the active cell.
    */
    get activeCell() {
        if (this.i.ca == null) {
            return null;
        }
        if (!this.i.ca.externalObject) {
            let e = new IgxGridCellPosition();
            e._implementation = this.i.ca;
            this.i.ca.externalObject = e;
        }
        return this.i.ca.externalObject;
    }
    set activeCell(v) {
        v == null ? this.i.ca = null : this.i.ca = v.i;
    }
    /**
     * Gets or sets the default background color to use for content cells
    */
    get cellBackground() {
        return brushToString(this.i.pv);
    }
    set cellBackground(v) {
        this.i.pv = stringToBrush(v);
    }
    /**
     * Gets or sets the default text color to use for content cells
    */
    get cellTextColor() {
        return brushToString(this.i.px);
    }
    set cellTextColor(v) {
        this.i.px = stringToBrush(v);
    }
    /**
     * Gets or sets the default text color to use for content cells
    */
    get headerSortIndicatorColor() {
        return brushToString(this.i.p2);
    }
    set headerSortIndicatorColor(v) {
        this.i.p2 = stringToBrush(v);
    }
    /**
     * Gets or sets the default render style for sort indicators in header cells.
    */
    get headerSortIndicatorStyle() {
        return this.i.dz;
    }
    set headerSortIndicatorStyle(v) {
        this.i.dz = ensureEnum(SortIndicatorStyle_$type, v);
    }
    /**
     * Gets or sets the font to use for content cells
    */
    get cellTextStyle() {
        if (this.i.eh == null) {
            return null;
        }
        return this.i.eh.fontString;
    }
    set cellTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.eh = fi;
    }
    /**
     * Gets or sets the default background color to use for section header cells
    */
    get sectionHeaderBackground() {
        return brushToString(this.i.qa);
    }
    set sectionHeaderBackground(v) {
        this.i.qa = stringToBrush(v);
    }
    /**
     * Gets or sets the default text color to use for section header cells
    */
    get sectionHeaderTextColor() {
        return brushToString(this.i.qc);
    }
    set sectionHeaderTextColor(v) {
        this.i.qc = stringToBrush(v);
    }
    /**
     * Gets or sets the font to use for section header cells
    */
    get sectionHeaderTextStyle() {
        if (this.i.ej == null) {
            return null;
        }
        return this.i.ej.fontString;
    }
    set sectionHeaderTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.ej = fi;
    }
    /**
     * Gets or sets the default text color to use for summary cells at the root level.
    */
    get summaryRootTextColor() {
        return brushToString(this.i.qh);
    }
    set summaryRootTextColor(v) {
        this.i.qh = stringToBrush(v);
    }
    /**
     * Gets or sets the default text color to use for summary cells at the section level.
    */
    get summarySectionTextColor() {
        return brushToString(this.i.ql);
    }
    set summarySectionTextColor(v) {
        this.i.ql = stringToBrush(v);
    }
    /**
     * Gets or sets the default text color to use for summary names in summary cells at the root level.
    */
    get summaryRootNameTextColor() {
        return brushToString(this.i.qf);
    }
    set summaryRootNameTextColor(v) {
        this.i.qf = stringToBrush(v);
    }
    /**
     * Gets or sets the default text color to use for summary names in summary cells at the section level.
    */
    get summarySectionNameTextColor() {
        return brushToString(this.i.qj);
    }
    set summarySectionNameTextColor(v) {
        this.i.qj = stringToBrush(v);
    }
    /**
     * Gets or sets the default background color to use for summary cells at the root level.
    */
    get summaryRootSelectedBackground() {
        return brushToString(this.i.qg);
    }
    set summaryRootSelectedBackground(v) {
        this.i.qg = stringToBrush(v);
    }
    /**
     * Gets or sets the default background color to use for summary cells at the section level.
    */
    get summarySectionSelectedBackground() {
        return brushToString(this.i.qk);
    }
    set summarySectionSelectedBackground(v) {
        this.i.qk = stringToBrush(v);
    }
    /**
     * Gets or sets the font to use for summary cells
    */
    get summaryTextStyle() {
        if (this.i.el == null) {
            return null;
        }
        return this.i.el.fontString;
    }
    set summaryTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.el = fi;
    }
    /**
     * Gets or sets the font to use for header cells
    */
    get summarySectionTextStyle() {
        if (this.i.ek == null) {
            return null;
        }
        return this.i.ek.fontString;
    }
    set summarySectionTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.ek = fi;
    }
    /**
     * Gets or sets the default background color to use for header separators.
    */
    get headerSeparatorWidth() {
        return this.i.ip;
    }
    set headerSeparatorWidth(v) {
        this.i.ip = +v;
    }
    /**
     * Gets or sets the default background color to use for header separators.
    */
    get headerSeparatorBackground() {
        return brushToString(this.i.p1);
    }
    set headerSeparatorBackground(v) {
        this.i.p1 = stringToBrush(v);
    }
    /**
     * Gets or sets the default background color to use for header cells
    */
    get headerBackground() {
        return brushToString(this.i.p0);
    }
    set headerBackground(v) {
        this.i.p0 = stringToBrush(v);
    }
    /**
     * Gets or sets the default text color to use for header cells
    */
    get headerTextColor() {
        return brushToString(this.i.p3);
    }
    set headerTextColor(v) {
        this.i.p3 = stringToBrush(v);
    }
    /**
     * Gets or sets the font to use for header cells
    */
    get headerTextStyle() {
        if (this.i.ei == null) {
            return null;
        }
        return this.i.ei.fontString;
    }
    set headerTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.ei = fi;
    }
    /**
     * Gets or sets the default background color to use for row separators
    */
    get rowSeparatorBackground() {
        return brushToString(this.i.p6);
    }
    set rowSeparatorBackground(v) {
        this.i.p6 = stringToBrush(v);
    }
    /**
     * Gets or sets the default sticky row background color to use for row separators
    */
    get rowSeparatorStickyRowBackground() {
        return brushToString(this.i.p9);
    }
    set rowSeparatorStickyRowBackground(v) {
        this.i.p9 = stringToBrush(v);
    }
    /**
     * Gets or sets the default last sticky row background color to use for row separators
    */
    get rowSeparatorLastStickyRowBackground() {
        return brushToString(this.i.p7);
    }
    set rowSeparatorLastStickyRowBackground(v) {
        this.i.p7 = stringToBrush(v);
    }
    /**
     * Gets or sets the pinned row background color to use for row separators
    */
    get rowSeparatorPinnedRowBackground() {
        return brushToString(this.i.p8);
    }
    set rowSeparatorPinnedRowBackground(v) {
        this.i.p8 = stringToBrush(v);
    }
    /**
     * Sets or gets the width to use for the column resizing separator.
    */
    get columnResizingSeparatorWidth() {
        return this.i.h3;
    }
    set columnResizingSeparatorWidth(v) {
        this.i.h3 = +v;
    }
    /**
     * Sets or gets the width to use for the column resizing separator.
    */
    get columnMovingSeparatorWidth() {
        return this.i.h1;
    }
    set columnMovingSeparatorWidth(v) {
        this.i.h1 = +v;
    }
    /**
     * Gets or sets the default background color to use for column resizing separator.
    */
    get columnResizingSeparatorBackground() {
        return brushToString(this.i.pz);
    }
    set columnResizingSeparatorBackground(v) {
        this.i.pz = stringToBrush(v);
    }
    /**
     * Gets or sets the default background color to use for column moving separator.
    */
    get columnMovingSeparatorBackground() {
        return brushToString(this.i.py);
    }
    set columnMovingSeparatorBackground(v) {
        this.i.py = stringToBrush(v);
    }
    /**
     * A set of states that can be applied to the columns of the grid based on available space.
    */
    get responsiveStates() {
        if (this._responsiveStates === null) {
            let coll = new IgxResponsiveStatesCollection();
            let innerColl = this.i.dl;
            if (!innerColl) {
                innerColl = new ResponsiveStatesCollection();
            }
            this._responsiveStates = coll._fromInner(innerColl);
        }
        return this._responsiveStates;
    }
    set responsiveStates(v) {
        if (this._responsiveStates !== null) {
            this._responsiveStates._setSyncTarget(null);
            this._responsiveStates = null;
        }
        let coll = new IgxResponsiveStatesCollection();
        this._responsiveStates = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(ResponsiveState.$type);
        let innerColl = this.i.dl;
        if (!innerColl) {
            innerColl = new ResponsiveStatesCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._responsiveStates._setSyncTarget(syncColl);
    }
    /**
     * Gets the region of the grid that is visible.
    */
    get actualVisibleRegion() {
        return fromRect(this.i.qn);
    }
    /**
     * Gets the current sort that is applied to the grid. Collection can be updated to modify the sort for the grid. Once sort descriptions are in this collection, the grid will no longer listen for changes on their properties.
    */
    get sortDescriptions() {
        if (this.i.bq == null) {
            return null;
        }
        if (!this.i.bq.externalObject) {
            let e = new IgxColumnSortDescriptionCollection();
            e._implementation = this.i.bq;
            this.i.bq.externalObject = e;
        }
        return this.i.bq.externalObject;
    }
    /**
     * Gets the current grouping that is applied to the grid. Collection can be updated to modify the grouping for the grid. Once grouping descriptions are in this collection, the grid will no longer listen for changes on their properties.
    */
    get groupDescriptions() {
        if (this.i.az == null) {
            return null;
        }
        if (!this.i.az.externalObject) {
            let e = new IgxColumnGroupDescriptionCollection();
            e._implementation = this.i.az;
            this.i.az.externalObject = e;
        }
        return this.i.az.externalObject;
    }
    /**
     * Gets the current filter that is applied to the grid. Collection can be updated to modify the filter for the grid. Once filter expresisons are in this collection, the grid will no longer listen for changes on their properties.
    */
    get filterExpressions() {
        if (this.i.t == null) {
            return null;
        }
        if (!this.i.t.externalObject) {
            let e = new IgxFilterExpressionCollection();
            e._implementation = this.i.t;
            this.i.t.externalObject = e;
        }
        return this.i.t.externalObject;
    }
    /**
     * Gets the current summaries that are applied to the grid.
    */
    get summaryDescriptions() {
        if (this.i.bt == null) {
            return null;
        }
        if (!this.i.bt.externalObject) {
            let e = new IgxColumnSummaryDescriptionCollection();
            e._implementation = this.i.bt;
            this.i.bt.externalObject = e;
        }
        return this.i.bt.externalObject;
    }
    /**
     * Gets or sets the scope which summaries are calculated for.
    */
    get summaryScope() {
        return this.i.r;
    }
    set summaryScope(v) {
        this.i.r = ensureEnum(DataSourceSummaryScope_$type, v);
    }
    /**
     * Gets or sets whether group headers are collapsable.
    */
    get isGroupCollapsable() {
        return this.i.ft;
    }
    set isGroupCollapsable(v) {
        this.i.ft = ensureBool(v);
    }
    get groupHeaderDisplayMode() {
        return this.i.p;
    }
    set groupHeaderDisplayMode(v) {
        this.i.p = ensureEnum(DataSourceSectionHeaderDisplayMode_$type, v);
    }
    /**
     * Gets or sets whether groups are expanded or collapsed by default.
    */
    get isGroupExpandedDefault() {
        return this.i.fu;
    }
    set isGroupExpandedDefault(v) {
        this.i.fu = ensureBool(v);
    }
    /**
     * Gets or sets the display mode summaries will use inside groups.
    */
    get groupSummaryDisplayMode() {
        return this.i.c2;
    }
    set groupSummaryDisplayMode(v) {
        this.i.c2 = ensureEnum(GroupSummaryDisplayMode_$type, v);
    }
    /**
     * Sets or gets the user provided primary key to assume for the data. Certain functionality of the grid requires a way to uniquely identify items in order to work correctly.
     * If a primary key cannot be inferred from the data source, you may need to provide one here.
    */
    get primaryKey() {
        return this.i.j;
    }
    set primaryKey(v) {
        this.i.j = v;
    }
    /**
     * Gets either the inferred primary key from the data source, or the user provided primary key, if present. Represents the actual primary key that the grid will use in operations that require it.
    */
    get actualPrimaryKey() {
        return this.i.d;
    }
    set actualPrimaryKey(v) {
        this.i.d = v;
    }
    get actualColumns() {
        if (this._actualColumns === null) {
            let coll = new IgxGridColumnCollection();
            let innerColl = this.i.actualColumns;
            if (!innerColl) {
                innerColl = new GridColumnCollection();
            }
            this._actualColumns = coll._fromInner(innerColl);
        }
        return this._actualColumns;
    }
    set actualColumns(v) {
        if (this._actualColumns !== null) {
            this._actualColumns._setSyncTarget(null);
            this._actualColumns = null;
        }
        let coll = new IgxGridColumnCollection();
        this._actualColumns = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(Column.$type);
        let innerColl = this.i.actualColumns;
        if (!innerColl) {
            innerColl = new GridColumnCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._actualColumns._setSyncTarget(syncColl);
    }
    /**
     * Sets or gets whether the grid will react to sort changes.
    */
    get reactsToSortChanges() {
        return this.i.gh;
    }
    set reactsToSortChanges(v) {
        this.i.gh = ensureBool(v);
    }
    /**
     * Sets or gets whether the grid will react to group changes.
    */
    get reactsToGroupChanges() {
        return this.i.gg;
    }
    set reactsToGroupChanges(v) {
        this.i.gg = ensureBool(v);
    }
    /**
     * Sets or gets whether the grid will react to filter changes.
    */
    get reactsToFilterChanges() {
        return this.i.gf;
    }
    set reactsToFilterChanges(v) {
        this.i.gf = ensureBool(v);
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("LiveGridComponent");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this.sectionHeader && this.sectionHeader._styling) {
            this.sectionHeader._styling(container, component, this);
        }
        if (this.summaryRowRoot && this.summaryRowRoot._styling) {
            this.summaryRowRoot._styling(container, component, this);
        }
        if (this.summaryRowSection && this.summaryRowSection._styling) {
            this.summaryRowSection._styling(container, component, this);
        }
        if (this.rowSeparator && this.rowSeparator._styling) {
            this.rowSeparator._styling(container, component, this);
        }
        if (this.headerSeparator && this.headerSeparator._styling) {
            this.headerSeparator._styling(container, component, this);
        }
        if (this.columnResizingSeparator && this.columnResizingSeparator._styling) {
            this.columnResizingSeparator._styling(container, component, this);
        }
        if (this.columnMovingSeparator && this.columnMovingSeparator._styling) {
            this.columnMovingSeparator._styling(container, component, this);
        }
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    getHitCell(x, y) {
        let iv = this.i.al(x, y);
        return (iv == null ? null : iv.externalObject);
    }
    /**
     * Forces a refresh of the grid content.
    
    */
    refresh() {
        this.i.n9();
    }
    /**
     * Makes sure pending work has completed if the grid need to be synchronously examined.
    
    */
    flush() {
        this.i.ma();
    }
    exchangeColumn(newColumn, oldColumn) {
        this.i.l9((newColumn == null ? null : newColumn.i), (oldColumn == null ? null : oldColumn.i));
    }
    moveColumn(oldIndex, newIndex) {
        this.i.mk(oldIndex, newIndex);
    }
    /**
     * Exports visual information about the current state of the grid.
    
    */
    exportVisualModel() {
        let iv = this.i.i0();
        return (iv);
    }
    /**
     * Returns a serialized copy of the exported visual model
    
    */
    exportSerializedVisualModel() {
        let iv = this.i.j0();
        return (iv);
    }
    /**
     * Scrolls the grid to given row, by index
    
    * @param rowNumber  * The row index to scroll to.
    */
    scrollToRowByIndex(rowNumber) {
        this.i.on(rowNumber);
    }
    /**
     * Scrolls the grid so that a row is the last visible, by index.
    
    * @param rowNumber  * The row index to scroll to.
    */
    scrollToLastRowByIndex(rowNumber) {
        this.i.om(rowNumber);
    }
    /**
     * Scrolls to an item, if found.
    
    * @param item  * The item to scroll to.
    */
    scrollToItem(item) {
        let iv = this.i.gm(item);
        return (iv);
    }
    scrollToPrimaryKey(key) {
        let iv = this.i.gn(key);
        return (iv);
    }
    /**
     * Scrolls the grid to given column, by index
    
    * @param columnNumber  * The column number to scroll to.
    */
    scrollToColumnByIndex(columnNumber) {
        this.i.ok(columnNumber);
    }
    /**
     * Gets the last visible index in the grid.
    
    */
    getLastVisibleIndex() {
        let iv = this.i.ig();
        return (iv);
    }
    /**
     * Gets the first visible index in the grid.
    
    */
    getFirstVisibleIndex() {
        let iv = this.i.ic();
        return (iv);
    }
    /**
     * Invalidates the bound data for the rows currently visible.
    
    */
    invalidateVisibleRows() {
        this.i.mj();
    }
    /**
     * Manually set the active responsive state of the grid.
    
    * @param name
    */
    setActiveResponsiveState(name) {
        this.i.ot(name);
    }
    notifySetItem(index, oldItem, newItem) {
        this.i.mq(index, oldItem, newItem);
    }
    /**
     * Manually notifies the grid's data source that the data it has bound to has been cleared and needs to be re-examined.
     * This should not be called if the data that the grid is bound to is already observable.
    
    */
    notifyClearItems() {
        this.i.mm();
    }
    notifyInsertItem(index, newItem) {
        this.i.mo(index, newItem);
    }
    notifyRemoveItem(index, oldItem) {
        this.i.mp(index, oldItem);
    }
    /**
     * Returns the data index of an item within the bound data source.
    
    * @param item  * The item from which to get the index.
    */
    dataIndexOfItem(item) {
        let iv = this.i.h5(item);
        return (iv);
    }
    dataIndexOfPrimaryKey(key) {
        let iv = this.i.h6(key);
        return (iv);
    }
    /**
     * Resolves the value of a specific cell.
    
    * @param cellKey  * The cell to resolve.
    */
    resolveCellValue(cellKey) {
        let iv = this.i.i2((cellKey == null ? null : cellKey.i));
        return (iv);
    }
    resolveCellValueFromPosition(row, column) {
        let iv = this.i.i3(row, column);
        return (iv);
    }
    /**
     * Gets the summary results for root level.
    
    */
    getRootSummaryResults() {
        let iv = this.i.h();
        return (iv);
    }
    /**
     * Gets the summary results for a specific section.
    
    */
    getSectionSummaryResults(sectionIndex) {
        let iv = this.i.i(sectionIndex);
        return (iv);
    }
    get filterExpressionsChanging() {
        if (this._filterExpressionsChanging == null) {
            this._filterExpressionsChanging = new EventEmitter();
            this.i.filterExpressionsChanging = delegateCombine(this.i.filterExpressionsChanging, (o, e) => {
                let outerArgs = new IgxGridFilterExpressionsEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeFilterExpressionsChanging) {
                    this.beforeFilterExpressionsChanging(this, outerArgs);
                }
                this._filterExpressionsChanging.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._filterExpressionsChanging;
    }
    get filterExpressionsChanged() {
        if (this._filterExpressionsChanged == null) {
            this._filterExpressionsChanged = new EventEmitter();
            this.i.filterExpressionsChanged = delegateCombine(this.i.filterExpressionsChanged, (o, e) => {
                let outerArgs = new IgxGridFilterExpressionsEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeFilterExpressionsChanged) {
                    this.beforeFilterExpressionsChanged(this, outerArgs);
                }
                this._filterExpressionsChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._filterExpressionsChanged;
    }
    /**
     * Previews that a pointer is down on a cell.
    */
    get cellPreviewPointerDown() {
        if (this._cellPreviewPointerDown == null) {
            this._cellPreviewPointerDown = new EventEmitter();
            this.i.cellPreviewPointerDown = delegateCombine(this.i.cellPreviewPointerDown, (o, e) => {
                let outerArgs = new IgxGridCellEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCellPreviewPointerDown) {
                    this.beforeCellPreviewPointerDown(this, outerArgs);
                }
                this._cellPreviewPointerDown.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._cellPreviewPointerDown;
    }
    /**
     * Previews that a pointer is up on a cell.
    */
    get cellPreviewPointerUp() {
        if (this._cellPreviewPointerUp == null) {
            this._cellPreviewPointerUp = new EventEmitter();
            this.i.cellPreviewPointerUp = delegateCombine(this.i.cellPreviewPointerUp, (o, e) => {
                let outerArgs = new IgxGridCellEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCellPreviewPointerUp) {
                    this.beforeCellPreviewPointerUp(this, outerArgs);
                }
                this._cellPreviewPointerUp.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._cellPreviewPointerUp;
    }
    /**
     * Indicates a pointer is down on a cell.
    */
    get cellPointerDown() {
        if (this._cellPointerDown == null) {
            this._cellPointerDown = new EventEmitter();
            this.i.cellPointerDown = delegateCombine(this.i.cellPointerDown, (o, e) => {
                let outerArgs = new IgxGridCellEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCellPointerDown) {
                    this.beforeCellPointerDown(this, outerArgs);
                }
                this._cellPointerDown.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._cellPointerDown;
    }
    /**
     * Indicates a pointer is up on a cell.
    */
    get cellPointerUp() {
        if (this._cellPointerUp == null) {
            this._cellPointerUp = new EventEmitter();
            this.i.cellPointerUp = delegateCombine(this.i.cellPointerUp, (o, e) => {
                let outerArgs = new IgxGridCellEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCellPointerUp) {
                    this.beforeCellPointerUp(this, outerArgs);
                }
                this._cellPointerUp.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._cellPointerUp;
    }
    /**
     * Called when a cell is clicked.
    */
    get cellClicked() {
        if (this._cellClicked == null) {
            this._cellClicked = new EventEmitter();
            this.i.cellClicked = delegateCombine(this.i.cellClicked, (o, e) => {
                let outerArgs = new IgxGridCellEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCellClicked) {
                    this.beforeCellClicked(this, outerArgs);
                }
                this._cellClicked.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._cellClicked;
    }
    /**
     * Called when sorting has changed.
    */
    get sortDescriptionsChanged() {
        if (this._sortDescriptionsChanged == null) {
            this._sortDescriptionsChanged = new EventEmitter();
            this.i.sortDescriptionsChanged = delegateCombine(this.i.sortDescriptionsChanged, (o, e) => {
                let outerArgs = new IgxGridSortDescriptionsChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeSortDescriptionsChanged) {
                    this.beforeSortDescriptionsChanged(this, outerArgs);
                }
                this._sortDescriptionsChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._sortDescriptionsChanged;
    }
    /**
     * Called when grouping has changed.
    */
    get groupDescriptionsChanged() {
        if (this._groupDescriptionsChanged == null) {
            this._groupDescriptionsChanged = new EventEmitter();
            this.i.groupDescriptionsChanged = delegateCombine(this.i.groupDescriptionsChanged, (o, e) => {
                let outerArgs = new IgxGridGroupDescriptionsChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeGroupDescriptionsChanged) {
                    this.beforeGroupDescriptionsChanged(this, outerArgs);
                }
                this._groupDescriptionsChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._groupDescriptionsChanged;
    }
    /**
     * Called when the columns are autogenerated.
    */
    get columnsAutoGenerated() {
        if (this._columnsAutoGenerated == null) {
            this._columnsAutoGenerated = new EventEmitter();
            this.i.columnsAutoGenerated = delegateCombine(this.i.columnsAutoGenerated, (o, e) => {
                let outerArgs = new IgxGridColumnsAutoGeneratedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeColumnsAutoGenerated) {
                    this.beforeColumnsAutoGenerated(this, outerArgs);
                }
                this._columnsAutoGenerated.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._columnsAutoGenerated;
    }
    /**
     * Called when the selected items change.
    */
    get selectedItemsChanged() {
        if (this._selectedItemsChanged == null) {
            this._selectedItemsChanged = new EventEmitter();
            this.i.selectedItemsChanged = delegateCombine(this.i.selectedItemsChanged, (o, e) => {
                let outerArgs = new IgxGridSelectedItemsChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeSelectedItemsChanged) {
                    this.beforeSelectedItemsChanged(this, outerArgs);
                }
                this._selectedItemsChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._selectedItemsChanged;
    }
    /**
     * Called when the selected keys change.
    */
    get selectedKeysChanged() {
        if (this._selectedKeysChanged == null) {
            this._selectedKeysChanged = new EventEmitter();
            this.i.selectedKeysChanged = delegateCombine(this.i.selectedKeysChanged, (o, e) => {
                let outerArgs = new IgxGridSelectedKeysChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeSelectedKeysChanged) {
                    this.beforeSelectedKeysChanged(this, outerArgs);
                }
                this._selectedKeysChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._selectedKeysChanged;
    }
    /**
     * Called when the selected cells change.
    */
    get selectedCellsChanged() {
        if (this._selectedCellsChanged == null) {
            this._selectedCellsChanged = new EventEmitter();
            this.i.selectedCellsChanged = delegateCombine(this.i.selectedCellsChanged, (o, e) => {
                let outerArgs = new IgxGridSelectedCellsChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeSelectedCellsChanged) {
                    this.beforeSelectedCellsChanged(this, outerArgs);
                }
                this._selectedCellsChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._selectedCellsChanged;
    }
    /**
     * Called when the active cell changes.
    */
    get activeCellChanged() {
        if (this._activeCellChanged == null) {
            this._activeCellChanged = new EventEmitter();
            this.i.activeCellChanged = delegateCombine(this.i.activeCellChanged, (o, e) => {
                let outerArgs = new IgxGridActiveCellChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeActiveCellChanged) {
                    this.beforeActiveCellChanged(this, outerArgs);
                }
                this._activeCellChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._activeCellChanged;
    }
    /**
     * Called when the selected cell ranges changed.
    */
    get selectedCellRangesChanged() {
        if (this._selectedCellRangesChanged == null) {
            this._selectedCellRangesChanged = new EventEmitter();
            this.i.selectedCellRangesChanged = delegateCombine(this.i.selectedCellRangesChanged, (o, e) => {
                let outerArgs = new IgxGridSelectedCellRangesChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeSelectedCellRangesChanged) {
                    this.beforeSelectedCellRangesChanged(this, outerArgs);
                }
                this._selectedCellRangesChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._selectedCellRangesChanged;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
};
__decorate([
    ContentChildren(IgxColumnComponent),
    __metadata("design:type", QueryList)
], IgxLiveGridComponent.prototype, "contentColumns", void 0);
__decorate([
    ViewChild("dynamicContent", { read: ViewContainerRef, static: true }),
    __metadata("design:type", ViewContainerRef)
], IgxLiveGridComponent.prototype, "_dynamicContent", void 0);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "height", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "width", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "scrollbarStyle", null);
__decorate([
    Input(),
    __metadata("design:type", Object),
    __metadata("design:paramtypes", [Object])
], IgxLiveGridComponent.prototype, "dataSource", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnResizingMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnMovingMode", null);
__decorate([
    Input(),
    __metadata("design:type", IgxSectionHeaderComponent),
    __metadata("design:paramtypes", [IgxSectionHeaderComponent])
], IgxLiveGridComponent.prototype, "sectionHeader", null);
__decorate([
    Input(),
    __metadata("design:type", IgxSummaryRowRootComponent),
    __metadata("design:paramtypes", [IgxSummaryRowRootComponent])
], IgxLiveGridComponent.prototype, "summaryRowRoot", null);
__decorate([
    Input(),
    __metadata("design:type", IgxSummaryRowSectionComponent),
    __metadata("design:paramtypes", [IgxSummaryRowSectionComponent])
], IgxLiveGridComponent.prototype, "summaryRowSection", null);
__decorate([
    Input(),
    __metadata("design:type", IgxRowSeparatorComponent),
    __metadata("design:paramtypes", [IgxRowSeparatorComponent])
], IgxLiveGridComponent.prototype, "rowSeparator", null);
__decorate([
    Input(),
    __metadata("design:type", IgxHeaderSeparatorComponent),
    __metadata("design:paramtypes", [IgxHeaderSeparatorComponent])
], IgxLiveGridComponent.prototype, "headerSeparator", null);
__decorate([
    Input(),
    __metadata("design:type", IgxColumnResizingSeparatorComponent),
    __metadata("design:paramtypes", [IgxColumnResizingSeparatorComponent])
], IgxLiveGridComponent.prototype, "columnResizingSeparator", null);
__decorate([
    Input(),
    __metadata("design:type", IgxColumnMovingSeparatorComponent),
    __metadata("design:paramtypes", [IgxColumnMovingSeparatorComponent])
], IgxLiveGridComponent.prototype, "columnMovingSeparator", null);
__decorate([
    Input(),
    __metadata("design:type", Array),
    __metadata("design:paramtypes", [Array])
], IgxLiveGridComponent.prototype, "dataSourceDesiredProperties", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "rowHeight", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "defaultColumnMinWidth", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "headerHeight", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "headerClickAction", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridComponent.prototype, "autoGenerateColumns", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "rowSeparatorHeight", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridComponent.prototype, "isPlaceholderRenderingEnabled", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnAddingAnimationMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnPropertyUpdatingAnimationMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "cellDataLoadedAnimationMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "rowSelectionAnimationMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "cellSelectionAnimationMode", null);
__decorate([
    Input(),
    __metadata("design:type", IgxGridAnimationSettings),
    __metadata("design:paramtypes", [IgxGridAnimationSettings])
], IgxLiveGridComponent.prototype, "animationSettings", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnResizingAnimationMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnShowingAnimationMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnMovingAnimationMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnHidingAnimationMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnExchangingAnimationMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "selectionMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "activationMode", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "selectionBehavior", null);
__decorate([
    Input(),
    __metadata("design:type", IgxGridSelectedItemsCollection),
    __metadata("design:paramtypes", [IgxGridSelectedItemsCollection])
], IgxLiveGridComponent.prototype, "selectedItems", null);
__decorate([
    Input(),
    __metadata("design:type", IgxGridSelectedKeysCollection),
    __metadata("design:paramtypes", [IgxGridSelectedKeysCollection])
], IgxLiveGridComponent.prototype, "selectedKeys", null);
__decorate([
    Input(),
    __metadata("design:type", IgxGridSelectedCellsCollection),
    __metadata("design:paramtypes", [IgxGridSelectedCellsCollection])
], IgxLiveGridComponent.prototype, "selectedCells", null);
__decorate([
    Input(),
    __metadata("design:type", IgxGridSelectedCellRangesCollection),
    __metadata("design:paramtypes", [IgxGridSelectedCellRangesCollection])
], IgxLiveGridComponent.prototype, "selectedCellRanges", null);
__decorate([
    Input(),
    __metadata("design:type", IgxGridSelectedItemsCollection),
    __metadata("design:paramtypes", [IgxGridSelectedItemsCollection])
], IgxLiveGridComponent.prototype, "pinnedItems", null);
__decorate([
    Input(),
    __metadata("design:type", IgxGridSelectedKeysCollection),
    __metadata("design:paramtypes", [IgxGridSelectedKeysCollection])
], IgxLiveGridComponent.prototype, "pinnedKeys", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridComponent.prototype, "isFilterUIEnabled", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridComponent.prototype, "isGroupRowSticky", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridComponent.prototype, "isHeaderSeparatorVisible", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "cellSelectedBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "sectionHeaderSelectedBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "summaryRootBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "summarySectionBackground", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "pinnedRowOpacity", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "stickyRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "pinnedRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "lastStickyRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", IgxGridCellPosition),
    __metadata("design:paramtypes", [IgxGridCellPosition])
], IgxLiveGridComponent.prototype, "activeCell", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "cellBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "cellTextColor", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "headerSortIndicatorColor", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "headerSortIndicatorStyle", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "cellTextStyle", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "sectionHeaderBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "sectionHeaderTextColor", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "sectionHeaderTextStyle", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "summaryRootTextColor", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "summarySectionTextColor", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "summaryRootNameTextColor", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "summarySectionNameTextColor", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "summaryRootSelectedBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "summarySectionSelectedBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "summaryTextStyle", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "summarySectionTextStyle", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "headerSeparatorWidth", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "headerSeparatorBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "headerBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "headerTextColor", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "headerTextStyle", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "rowSeparatorBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "rowSeparatorStickyRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "rowSeparatorLastStickyRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "rowSeparatorPinnedRowBackground", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnResizingSeparatorWidth", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "columnMovingSeparatorWidth", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "columnResizingSeparatorBackground", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridComponent.prototype, "columnMovingSeparatorBackground", null);
__decorate([
    Input(),
    __metadata("design:type", IgxResponsiveStatesCollection),
    __metadata("design:paramtypes", [IgxResponsiveStatesCollection])
], IgxLiveGridComponent.prototype, "responsiveStates", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "summaryScope", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridComponent.prototype, "isGroupCollapsable", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "groupHeaderDisplayMode", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridComponent.prototype, "isGroupExpandedDefault", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridComponent.prototype, "groupSummaryDisplayMode", null);
__decorate([
    Input(),
    __metadata("design:type", Array),
    __metadata("design:paramtypes", [Array])
], IgxLiveGridComponent.prototype, "primaryKey", null);
__decorate([
    Input(),
    __metadata("design:type", Array),
    __metadata("design:paramtypes", [Array])
], IgxLiveGridComponent.prototype, "actualPrimaryKey", null);
__decorate([
    Input(),
    __metadata("design:type", IgxGridColumnCollection),
    __metadata("design:paramtypes", [IgxGridColumnCollection])
], IgxLiveGridComponent.prototype, "actualColumns", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridComponent.prototype, "reactsToSortChanges", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridComponent.prototype, "reactsToGroupChanges", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridComponent.prototype, "reactsToFilterChanges", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "filterExpressionsChanging", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "filterExpressionsChanged", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "cellPreviewPointerDown", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "cellPreviewPointerUp", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "cellPointerDown", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "cellPointerUp", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "cellClicked", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "sortDescriptionsChanged", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "groupDescriptionsChanged", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "columnsAutoGenerated", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "selectedItemsChanged", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "selectedKeysChanged", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "selectedCellsChanged", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "activeCellChanged", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridComponent.prototype, "selectedCellRangesChanged", null);
IgxLiveGridComponent = __decorate([
    Component({
        selector: 'igx-live-grid',
        styles: [`:host {
		display: block;
	}`],
        template: `
    <ng-container #dynamicContent></ng-container>
  `,
        host: { 'class': 'ig-live-grid igx-live-grid' },
        providers: [],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [Renderer2,
        ViewContainerRef,
        NgZone,
        ComponentFactoryResolver,
        Injector])
], IgxLiveGridComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxTextHeaderComponent_1;
/**
 * Represents a class used to configure the appearance of a text column header cells.
*/
const IgxTextHeaderComponent_PROVIDERS = [{ provide: IgxHeaderComponent, useExisting: forwardRef(() => IgxTextHeaderComponent) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxTextHeaderComponent) }];
let IgxTextHeaderComponent = IgxTextHeaderComponent_1 = class IgxTextHeaderComponent extends IgxHeaderComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new TextHeader();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
};
IgxTextHeaderComponent = IgxTextHeaderComponent_1 = __decorate([
    Component({
        selector: 'igx-text-header',
        template: ``,
        providers: [{ provide: IgxHeaderComponent, useExisting: forwardRef(() => IgxTextHeaderComponent_1) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxTextHeaderComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxTextHeaderComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxTextHeaderModule = class IgxTextHeaderModule {
};
IgxTextHeaderModule = __decorate([
    NgModule({
        declarations: [IgxTextHeaderComponent],
        imports: [CommonModule],
        exports: [IgxTextHeaderComponent],
        entryComponents: []
    })
], IgxTextHeaderModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxTextHeaderDynamicModule = class IgxTextHeaderDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxTextHeaderComponent", IgxTextHeaderComponent);
        TypeRegistrar.register("TextHeader", TextHeader.$type);
    }
};
IgxTextHeaderDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxTextHeaderModule],
        exports: [IgxTextHeaderModule],
        entryComponents: [IgxTextHeaderComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxTextHeaderDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxSectionHeaderModule = class IgxSectionHeaderModule {
};
IgxSectionHeaderModule = __decorate([
    NgModule({
        declarations: [IgxSectionHeaderComponent],
        imports: [CommonModule],
        exports: [IgxSectionHeaderComponent],
        entryComponents: []
    })
], IgxSectionHeaderModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxSectionHeaderDynamicModule = class IgxSectionHeaderDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxSectionHeaderComponent", IgxSectionHeaderComponent);
        TypeRegistrar.register("SectionHeader", SectionHeader.$type);
    }
};
IgxSectionHeaderDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxSectionHeaderModule],
        exports: [IgxSectionHeaderModule],
        entryComponents: [IgxSectionHeaderComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxSectionHeaderDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxRowSeparatorModule = class IgxRowSeparatorModule {
};
IgxRowSeparatorModule = __decorate([
    NgModule({
        declarations: [IgxRowSeparatorComponent],
        imports: [CommonModule],
        exports: [IgxRowSeparatorComponent],
        entryComponents: []
    })
], IgxRowSeparatorModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxRowSeparatorDynamicModule = class IgxRowSeparatorDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxRowSeparatorComponent", IgxRowSeparatorComponent);
        TypeRegistrar.register("RowSeparator", RowSeparator.$type);
    }
};
IgxRowSeparatorDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxRowSeparatorModule],
        exports: [IgxRowSeparatorModule],
        entryComponents: [IgxRowSeparatorComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxRowSeparatorDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxHeaderSeparatorModule = class IgxHeaderSeparatorModule {
};
IgxHeaderSeparatorModule = __decorate([
    NgModule({
        declarations: [IgxHeaderSeparatorComponent],
        imports: [CommonModule],
        exports: [IgxHeaderSeparatorComponent],
        entryComponents: []
    })
], IgxHeaderSeparatorModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxHeaderSeparatorDynamicModule = class IgxHeaderSeparatorDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxHeaderSeparatorComponent", IgxHeaderSeparatorComponent);
        TypeRegistrar.register("HeaderSeparator", HeaderSeparator.$type);
    }
};
IgxHeaderSeparatorDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxHeaderSeparatorModule],
        exports: [IgxHeaderSeparatorModule],
        entryComponents: [IgxHeaderSeparatorComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxHeaderSeparatorDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxColumnResizingSeparatorModule = class IgxColumnResizingSeparatorModule {
};
IgxColumnResizingSeparatorModule = __decorate([
    NgModule({
        declarations: [IgxColumnResizingSeparatorComponent],
        imports: [CommonModule],
        exports: [IgxColumnResizingSeparatorComponent],
        entryComponents: []
    })
], IgxColumnResizingSeparatorModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxColumnResizingSeparatorDynamicModule = class IgxColumnResizingSeparatorDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxColumnResizingSeparatorComponent", IgxColumnResizingSeparatorComponent);
        TypeRegistrar.register("ColumnResizingSeparator", ColumnResizingSeparator.$type);
    }
};
IgxColumnResizingSeparatorDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxColumnResizingSeparatorModule],
        exports: [IgxColumnResizingSeparatorModule],
        entryComponents: [IgxColumnResizingSeparatorComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxColumnResizingSeparatorDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxColumnMovingSeparatorModule = class IgxColumnMovingSeparatorModule {
};
IgxColumnMovingSeparatorModule = __decorate([
    NgModule({
        declarations: [IgxColumnMovingSeparatorComponent],
        imports: [CommonModule],
        exports: [IgxColumnMovingSeparatorComponent],
        entryComponents: []
    })
], IgxColumnMovingSeparatorModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxColumnMovingSeparatorDynamicModule = class IgxColumnMovingSeparatorDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxColumnMovingSeparatorComponent", IgxColumnMovingSeparatorComponent);
        TypeRegistrar.register("ColumnMovingSeparator", ColumnMovingSeparator.$type);
    }
};
IgxColumnMovingSeparatorDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxColumnMovingSeparatorModule],
        exports: [IgxColumnMovingSeparatorModule],
        entryComponents: [IgxColumnMovingSeparatorComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxColumnMovingSeparatorDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxLiveGridCoreModule = class IgxLiveGridCoreModule {
    constructor() {
    }
};
IgxLiveGridCoreModule = __decorate([
    NgModule({
        declarations: [IgxLiveGridComponent],
        exports: [IgxTextHeaderDynamicModule,
            IgxSectionHeaderDynamicModule,
            IgxRowSeparatorDynamicModule,
            IgxHeaderSeparatorDynamicModule,
            IgxColumnResizingSeparatorDynamicModule,
            IgxColumnMovingSeparatorDynamicModule,
            IgxLiveGridComponent
        ],
        imports: [CommonModule, IgxTextHeaderDynamicModule,
            IgxSectionHeaderDynamicModule,
            IgxRowSeparatorDynamicModule,
            IgxHeaderSeparatorDynamicModule,
            IgxColumnResizingSeparatorDynamicModule,
            IgxColumnMovingSeparatorDynamicModule
        ],
        entryComponents: []
    }),
    __metadata("design:paramtypes", [])
], IgxLiveGridCoreModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxLiveGridCoreDynamicModule = class IgxLiveGridCoreDynamicModule {
    constructor() {
        TypeRegistrar.registerCons('IgxLiveGridComponent', IgxLiveGridComponent);
    }
};
IgxLiveGridCoreDynamicModule = __decorate([
    NgModule({
        declarations: [],
        exports: [IgxTextHeaderDynamicModule,
            IgxSectionHeaderDynamicModule,
            IgxRowSeparatorDynamicModule,
            IgxHeaderSeparatorDynamicModule,
            IgxColumnResizingSeparatorDynamicModule,
            IgxColumnMovingSeparatorDynamicModule,
            IgxLiveGridCoreModule
        ],
        imports: [CommonModule, IgxTextHeaderDynamicModule,
            IgxSectionHeaderDynamicModule,
            IgxRowSeparatorDynamicModule,
            IgxHeaderSeparatorDynamicModule,
            IgxColumnResizingSeparatorDynamicModule,
            IgxColumnMovingSeparatorDynamicModule,
            IgxLiveGridCoreModule
        ],
        entryComponents: [IgxLiveGridComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxLiveGridCoreDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxNumericColumnComponent_1;
/**
 * Represents a Numeric grid column, used to allow the developer to display a formatted number in a cell.
*/
const IgxNumericColumnComponent_PROVIDERS = [{ provide: IgxColumnComponent, useExisting: forwardRef(() => IgxNumericColumnComponent) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxNumericColumnComponent) }];
let IgxNumericColumnComponent = IgxNumericColumnComponent_1 = class IgxNumericColumnComponent extends IgxColumnComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new NumericColumn();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the string to prefix a negative value. If FormatString is specificied this value is ignored.
    */
    get negativePrefix() {
        return this.i.hf;
    }
    set negativePrefix(v) {
        this.i.hf = v;
    }
    /**
     * Gets or sets the string to prefix a positive value. If FormatString is specificied this value is ignored.
    */
    get positivePrefix() {
        return this.i.hj;
    }
    set positivePrefix(v) {
        this.i.hj = v;
    }
    /**
     * Gets or sets the string to suffix a negative value. If FormatString is specificied this value is ignored.
    */
    get negativeSuffix() {
        return this.i.hh;
    }
    set negativeSuffix(v) {
        this.i.hh = v;
    }
    /**
     * Gets or sets the string to suffix a positive value. If FormatString is specificied this value is ignored.
    */
    get positiveSuffix() {
        return this.i.hl;
    }
    set positiveSuffix(v) {
        this.i.hl = v;
    }
    /**
     * Gets or sets the maximum fraction digits. If FormatString is specificied this value is ignored.
    */
    get maxFractionDigits() {
        return this.i.gz;
    }
    set maxFractionDigits(v) {
        this.i.gz = +v;
    }
    /**
     * Gets or sets the minimum fraction digits. If FormatString is specificied this value is ignored.
    */
    get minFractionDigits() {
        return this.i.g0;
    }
    set minFractionDigits(v) {
        this.i.g0 = +v;
    }
    /**
     * Gets or sets the minimum integer digits. If FormatString is specificied this value is ignored.
    */
    get minIntegerDigits() {
        return this.i.g1;
    }
    set minIntegerDigits(v) {
        this.i.g1 = +v;
    }
    /**
     * Gets or sets whether to show a grouping separator. If FormatString is specificied this value is ignored.
    */
    get showGroupingSeparator() {
        return this.i.gu;
    }
    set showGroupingSeparator(v) {
        this.i.gu = ensureBool(v);
    }
    /**
     * Gets or sets the INTL NumericFormat object to use for formatting the date values.
    */
    get formatOverride() {
        return this.i.g3;
    }
    set formatOverride(v) {
        this.i.g3 = v;
    }
};
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxNumericColumnComponent.prototype, "negativePrefix", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxNumericColumnComponent.prototype, "positivePrefix", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxNumericColumnComponent.prototype, "negativeSuffix", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxNumericColumnComponent.prototype, "positiveSuffix", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxNumericColumnComponent.prototype, "maxFractionDigits", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxNumericColumnComponent.prototype, "minFractionDigits", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxNumericColumnComponent.prototype, "minIntegerDigits", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxNumericColumnComponent.prototype, "showGroupingSeparator", null);
__decorate([
    Input(),
    __metadata("design:type", Object),
    __metadata("design:paramtypes", [Object])
], IgxNumericColumnComponent.prototype, "formatOverride", null);
IgxNumericColumnComponent = IgxNumericColumnComponent_1 = __decorate([
    Component({
        selector: 'igx-numeric-column',
        template: ``,
        providers: [{ provide: IgxColumnComponent, useExisting: forwardRef(() => IgxNumericColumnComponent_1) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxNumericColumnComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxNumericColumnComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxNumericColumnModule = class IgxNumericColumnModule {
};
IgxNumericColumnModule = __decorate([
    NgModule({
        declarations: [IgxNumericColumnComponent],
        imports: [CommonModule],
        exports: [IgxNumericColumnComponent],
        entryComponents: []
    })
], IgxNumericColumnModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxNumericColumnDynamicModule = class IgxNumericColumnDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxNumericColumnComponent", IgxNumericColumnComponent);
        TypeRegistrar.register("NumericColumn", NumericColumn.$type);
    }
};
IgxNumericColumnDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxNumericColumnModule],
        exports: [IgxNumericColumnModule],
        entryComponents: [IgxNumericColumnComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxNumericColumnDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxDateTimeColumnComponent_1;
/**
 * A column for displaying date/time values.
*/
const IgxDateTimeColumnComponent_PROVIDERS = [{ provide: IgxColumnComponent, useExisting: forwardRef(() => IgxDateTimeColumnComponent) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxDateTimeColumnComponent) }];
let IgxDateTimeColumnComponent = IgxDateTimeColumnComponent_1 = class IgxDateTimeColumnComponent extends IgxColumnComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new DateTimeColumn();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the date time format to use for this column. If FormatString is specificied this value is ignored.
    */
    get dateTimeFormat() {
        return this.i.gv;
    }
    set dateTimeFormat(v) {
        this.i.gv = ensureEnum(DateTimeFormats_$type, v);
    }
    /**
     * Gets or sets the INTL DateTimeFormat object to use for formatting the date values.
    */
    get formatOverride() {
        return this.i.gy;
    }
    set formatOverride(v) {
        this.i.gy = v;
    }
};
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxDateTimeColumnComponent.prototype, "dateTimeFormat", null);
__decorate([
    Input(),
    __metadata("design:type", Object),
    __metadata("design:paramtypes", [Object])
], IgxDateTimeColumnComponent.prototype, "formatOverride", null);
IgxDateTimeColumnComponent = IgxDateTimeColumnComponent_1 = __decorate([
    Component({
        selector: 'igx-date-time-column',
        template: ``,
        providers: [{ provide: IgxColumnComponent, useExisting: forwardRef(() => IgxDateTimeColumnComponent_1) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxDateTimeColumnComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxDateTimeColumnComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxDateTimeColumnModule = class IgxDateTimeColumnModule {
};
IgxDateTimeColumnModule = __decorate([
    NgModule({
        declarations: [IgxDateTimeColumnComponent],
        imports: [CommonModule],
        exports: [IgxDateTimeColumnComponent],
        entryComponents: []
    })
], IgxDateTimeColumnModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxDateTimeColumnDynamicModule = class IgxDateTimeColumnDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxDateTimeColumnComponent", IgxDateTimeColumnComponent);
        TypeRegistrar.register("DateTimeColumn", DateTimeColumn.$type);
    }
};
IgxDateTimeColumnDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxDateTimeColumnModule],
        exports: [IgxDateTimeColumnModule],
        entryComponents: [IgxDateTimeColumnComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxDateTimeColumnDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxImageColumnComponent_1;
/**
 * Represents an Image grid column, used to allow the developer to display an image in a cell.
*/
const IgxImageColumnComponent_PROVIDERS = [{ provide: IgxColumnComponent, useExisting: forwardRef(() => IgxImageColumnComponent) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxImageColumnComponent) }];
let IgxImageColumnComponent = IgxImageColumnComponent_1 = class IgxImageColumnComponent extends IgxColumnComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new ImageColumn();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Gets or sets the stretch option to use when rendering images
    */
    get imageStretchOption() {
        return this.i.gw;
    }
    set imageStretchOption(v) {
        this.i.gw = ensureEnum(ImageStretchOptions_$type, v);
    }
};
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxImageColumnComponent.prototype, "imageStretchOption", null);
IgxImageColumnComponent = IgxImageColumnComponent_1 = __decorate([
    Component({
        selector: 'igx-image-column',
        template: ``,
        providers: [{ provide: IgxColumnComponent, useExisting: forwardRef(() => IgxImageColumnComponent_1) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxImageColumnComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxImageColumnComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxImageColumnModule = class IgxImageColumnModule {
};
IgxImageColumnModule = __decorate([
    NgModule({
        declarations: [IgxImageColumnComponent],
        imports: [CommonModule],
        exports: [IgxImageColumnComponent],
        entryComponents: []
    })
], IgxImageColumnModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxImageColumnDynamicModule = class IgxImageColumnDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxImageColumnComponent", IgxImageColumnComponent);
        TypeRegistrar.register("ImageColumn", ImageColumn.$type);
    }
};
IgxImageColumnDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxImageColumnModule],
        exports: [IgxImageColumnModule],
        entryComponents: [IgxImageColumnComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxImageColumnDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Information about the cell that has content which is being created or updated.
*/
class IgxTemplateCellUpdatingEventArgs {
    createImplementation() {
        return new TemplateCellUpdatingEventArgs();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get isCanvasBased() {
        return this.i.content.isCanvasBased;
    }
    /**
     * The host in which to add or update content if this is a DOM based cell.
    */
    get content() {
        if (this.isCanvasBased) {
            return null;
        }
        else {
            return this.i.content.element.getNativeElement();
        }
    }
    ensureCorrectSize() {
        return this.i.content.ensureCorrectSize();
    }
    get context() {
        if (this.isCanvasBased) {
            return this.i.content.templateContext;
        }
        else {
            return null;
        }
    }
    renderStandardBackground() {
        this.i.content.renderStandardBackground();
    }
    renderStandardContent() {
        this.i.content.renderStandardContent();
    }
    /**
     * The backing information for the current cell.
    */
    get cellInfo() {
        if (this.i.cellInfo == null) {
            return null;
        }
        if (!this.i.cellInfo.externalObject) {
            let ext = null;
            switch (this.i.cellInfo.$type.name) {
                case "DateTimeCellModel":
                    ext = new IgxDateTimeCellInfo();
                    break;
                case "ImageCellModel":
                    ext = new IgxImageCellInfo();
                    break;
                case "NumericCellModel":
                    ext = new IgxNumericCellInfo();
                    break;
                case "RowSeparatorModel":
                    ext = new IgxRowSeparatorInfo();
                    break;
                case "SectionHeaderCellModel":
                    ext = new IgxSectionHeaderCellInfo();
                    break;
                case "TemplateCellModel":
                    ext = new IgxTemplateCellInfo();
                    break;
                case "TemplateHeaderCellModel":
                    ext = new IgxTemplateHeaderCellInfo();
                    break;
                case "TemplateSectionHeaderCellModel":
                    ext = new IgxTemplateSectionHeaderCellInfo();
                    break;
                case "TextCellModel":
                    ext = new IgxTextCellInfo();
                    break;
                case "TextHeaderCellModel":
                    ext = new IgxTextHeaderCellInfo();
                    break;
            }
            ext._implementation = this.i.cellInfo;
            this.i.cellInfo.externalObject = ext;
        }
        return this.i.cellInfo.externalObject;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxTemplateColumnComponent_1;
/**
 * A column with customizable content.
*/
const IgxTemplateColumnComponent_PROVIDERS = [{ provide: IgxColumnComponent, useExisting: forwardRef(() => IgxTemplateColumnComponent) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxTemplateColumnComponent) }];
let IgxTemplateColumnComponent = IgxTemplateColumnComponent_1 = class IgxTemplateColumnComponent extends IgxColumnComponent {
    constructor() {
        super();
        this._cellUpdating = null;
    }
    createImplementation() {
        return new TemplateColumn();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Called when the cell content is being created or updated.
    */
    get cellUpdating() {
        if (this._cellUpdating == null) {
            this._cellUpdating = new EventEmitter();
            this.i.cellUpdating = delegateCombine(this.i.cellUpdating, (o, e) => {
                let outerArgs = new IgxTemplateCellUpdatingEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCellUpdating) {
                    this.beforeCellUpdating(this, outerArgs);
                }
                this._cellUpdating.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._cellUpdating;
    }
};
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxTemplateColumnComponent.prototype, "cellUpdating", null);
IgxTemplateColumnComponent = IgxTemplateColumnComponent_1 = __decorate([
    Component({
        selector: 'igx-template-column',
        template: ``,
        providers: [{ provide: IgxColumnComponent, useExisting: forwardRef(() => IgxTemplateColumnComponent_1) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxTemplateColumnComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxTemplateColumnComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxTemplateColumnModule = class IgxTemplateColumnModule {
};
IgxTemplateColumnModule = __decorate([
    NgModule({
        declarations: [IgxTemplateColumnComponent],
        imports: [CommonModule],
        exports: [IgxTemplateColumnComponent],
        entryComponents: []
    })
], IgxTemplateColumnModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxTemplateColumnDynamicModule = class IgxTemplateColumnDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxTemplateColumnComponent", IgxTemplateColumnComponent);
        TypeRegistrar.register("TemplateColumn", TemplateColumn.$type);
    }
};
IgxTemplateColumnDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxTemplateColumnModule],
        exports: [IgxTemplateColumnModule],
        entryComponents: [IgxTemplateColumnComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxTemplateColumnDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxTextColumnComponent_1;
/**
 * Represents a Text grid column, used to allow the developer to display a formatted text in a cell.
*/
const IgxTextColumnComponent_PROVIDERS = [{ provide: IgxColumnComponent, useExisting: forwardRef(() => IgxTextColumnComponent) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxTextColumnComponent) }];
let IgxTextColumnComponent = IgxTextColumnComponent_1 = class IgxTextColumnComponent extends IgxColumnComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new TextColumn();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
};
IgxTextColumnComponent = IgxTextColumnComponent_1 = __decorate([
    Component({
        selector: 'igx-text-column',
        template: ``,
        providers: [{ provide: IgxColumnComponent, useExisting: forwardRef(() => IgxTextColumnComponent_1) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxTextColumnComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxTextColumnComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxTextColumnModule = class IgxTextColumnModule {
};
IgxTextColumnModule = __decorate([
    NgModule({
        declarations: [IgxTextColumnComponent],
        imports: [CommonModule],
        exports: [IgxTextColumnComponent],
        entryComponents: []
    })
], IgxTextColumnModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxTextColumnDynamicModule = class IgxTextColumnDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxTextColumnComponent", IgxTextColumnComponent);
        TypeRegistrar.register("TextColumn", TextColumn.$type);
    }
};
IgxTextColumnDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxTextColumnModule],
        exports: [IgxTextColumnModule],
        entryComponents: [IgxTextColumnComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxTextColumnDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateHeaderCellUpdatingEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._cellInfo = null;
        this._content = null;
    }
    get cellInfo() {
        return this._cellInfo;
    }
    set cellInfo(a) {
        this._cellInfo = a;
    }
    get content() {
        return this._content;
    }
    set content(a) {
        this._content = a;
    }
}
TemplateHeaderCellUpdatingEventArgs.$t = markType(TemplateHeaderCellUpdatingEventArgs, 'TemplateHeaderCellUpdatingEventArgs', EventArgs.$);

/**
 * Information about the header cell that has content which is being created or updated.
*/
class IgxTemplateHeaderCellUpdatingEventArgs {
    createImplementation() {
        return new TemplateHeaderCellUpdatingEventArgs();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get isCanvasBased() {
        return this.i.content.isCanvasBased;
    }
    /**
     * The host in which to add or update content if this is a DOM based cell.
    */
    get content() {
        if (this.isCanvasBased) {
            return null;
        }
        else {
            return this.i.content.element.getNativeElement();
        }
    }
    get context() {
        if (this.isCanvasBased) {
            return this.i.content.templateContext;
        }
        else {
            return null;
        }
    }
    ensureCorrectSize() {
        return this.i.content.ensureCorrectSize();
    }
    renderStandardBackground() {
        this.i.content.renderStandardBackground();
    }
    renderStandardContent() {
        this.i.content.renderStandardContent();
    }
    /**
     * The backing information for the current cell.
    */
    get cellInfo() {
        if (this.i.cellInfo == null) {
            return null;
        }
        if (!this.i.cellInfo.externalObject) {
            let ext = null;
            switch (this.i.cellInfo.$type.name) {
                case "DateTimeCellModel":
                    ext = new IgxDateTimeCellInfo();
                    break;
                case "ImageCellModel":
                    ext = new IgxImageCellInfo();
                    break;
                case "NumericCellModel":
                    ext = new IgxNumericCellInfo();
                    break;
                case "RowSeparatorModel":
                    ext = new IgxRowSeparatorInfo();
                    break;
                case "SectionHeaderCellModel":
                    ext = new IgxSectionHeaderCellInfo();
                    break;
                case "TemplateCellModel":
                    ext = new IgxTemplateCellInfo();
                    break;
                case "TemplateHeaderCellModel":
                    ext = new IgxTemplateHeaderCellInfo();
                    break;
                case "TemplateSectionHeaderCellModel":
                    ext = new IgxTemplateSectionHeaderCellInfo();
                    break;
                case "TextCellModel":
                    ext = new IgxTextCellInfo();
                    break;
                case "TextHeaderCellModel":
                    ext = new IgxTextHeaderCellInfo();
                    break;
            }
            ext._implementation = this.i.cellInfo;
            this.i.cellInfo.externalObject = ext;
        }
        return this.i.cellInfo.externalObject;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateHeader extends Header {
    constructor() {
        super();
        this.cellUpdating = null;
    }
    l(a) {
        return new TemplateHeaderCellModel();
    }
    b8(a, b, c) {
        let d = "template-header-" + a.al.toString();
        return d;
    }
    ck(a, b, c, d) {
        super.ck(a, b, c, d);
        let e = a;
        let f = b.as(a.i);
        e.ij = f.fp;
        e.k = f.eb;
        e.im = f.ez && b.fs;
    }
    et(a, b) {
        if (this.cellUpdating != null) {
            this.cellUpdating(this, ((() => {
                let $ret = new TemplateHeaderCellUpdatingEventArgs();
                $ret.cellInfo = a;
                $ret.content = b;
                return $ret;
            })()));
        }
    }
}
TemplateHeader.$t = markType(TemplateHeader, 'TemplateHeader', Header.$);

var IgxTemplateHeaderComponent_1;
/**
 * A type of header with customizable content.
*/
const IgxTemplateHeaderComponent_PROVIDERS = [{ provide: IgxHeaderComponent, useExisting: forwardRef(() => IgxTemplateHeaderComponent) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxTemplateHeaderComponent) }];
let IgxTemplateHeaderComponent = IgxTemplateHeaderComponent_1 = class IgxTemplateHeaderComponent extends IgxHeaderComponent {
    constructor() {
        super();
        this._cellUpdating = null;
    }
    createImplementation() {
        return new TemplateHeader();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Called when the header cell content is being created or updated.
    */
    get cellUpdating() {
        if (this._cellUpdating == null) {
            this._cellUpdating = new EventEmitter();
            this.i.cellUpdating = delegateCombine(this.i.cellUpdating, (o, e) => {
                let outerArgs = new IgxTemplateHeaderCellUpdatingEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCellUpdating) {
                    this.beforeCellUpdating(this, outerArgs);
                }
                this._cellUpdating.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._cellUpdating;
    }
};
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxTemplateHeaderComponent.prototype, "cellUpdating", null);
IgxTemplateHeaderComponent = IgxTemplateHeaderComponent_1 = __decorate([
    Component({
        selector: 'igx-template-header',
        template: ``,
        providers: [{ provide: IgxHeaderComponent, useExisting: forwardRef(() => IgxTemplateHeaderComponent_1) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxTemplateHeaderComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxTemplateHeaderComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxTemplateHeaderModule = class IgxTemplateHeaderModule {
};
IgxTemplateHeaderModule = __decorate([
    NgModule({
        declarations: [IgxTemplateHeaderComponent],
        imports: [CommonModule],
        exports: [IgxTemplateHeaderComponent],
        entryComponents: []
    })
], IgxTemplateHeaderModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxTemplateHeaderDynamicModule = class IgxTemplateHeaderDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxTemplateHeaderComponent", IgxTemplateHeaderComponent);
        TypeRegistrar.register("TemplateHeader", TemplateHeader.$type);
    }
};
IgxTemplateHeaderDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxTemplateHeaderModule],
        exports: [IgxTemplateHeaderModule],
        entryComponents: [IgxTemplateHeaderComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxTemplateHeaderDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxLiveGridModule = class IgxLiveGridModule {
};
IgxLiveGridModule = __decorate([
    NgModule({
        declarations: [],
        exports: [IgxNumericColumnDynamicModule,
            IgxDateTimeColumnDynamicModule,
            IgxImageColumnDynamicModule,
            IgxTemplateColumnDynamicModule,
            IgxTextColumnDynamicModule,
            IgxTemplateHeaderDynamicModule,
            IgxLiveGridCoreModule
        ],
        imports: [CommonModule, IgxNumericColumnDynamicModule,
            IgxDateTimeColumnDynamicModule,
            IgxImageColumnDynamicModule,
            IgxTemplateColumnDynamicModule,
            IgxTextColumnDynamicModule,
            IgxTemplateHeaderDynamicModule,
            IgxLiveGridCoreModule
        ],
        entryComponents: []
    })
], IgxLiveGridModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxLiveGridDynamicModule = class IgxLiveGridDynamicModule {
};
IgxLiveGridDynamicModule = __decorate([
    NgModule({
        declarations: [],
        exports: [IgxNumericColumnDynamicModule,
            IgxDateTimeColumnDynamicModule,
            IgxImageColumnDynamicModule,
            IgxTemplateColumnDynamicModule,
            IgxTextColumnDynamicModule,
            IgxTemplateHeaderDynamicModule,
            IgxLiveGridCoreDynamicModule,
            IgxLiveGridModule
        ],
        imports: [CommonModule, IgxNumericColumnDynamicModule,
            IgxDateTimeColumnDynamicModule,
            IgxImageColumnDynamicModule,
            IgxTemplateColumnDynamicModule,
            IgxTextColumnDynamicModule,
            IgxTemplateHeaderDynamicModule,
            IgxLiveGridCoreDynamicModule,
            IgxLiveGridModule
        ],
        entryComponents: []
    })
], IgxLiveGridDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateSectionHeaderCellUpdatingEventArgs extends EventArgs {
    constructor() {
        super(...arguments);
        this._cellInfo = null;
        this._content = null;
    }
    get cellInfo() {
        return this._cellInfo;
    }
    set cellInfo(a) {
        this._cellInfo = a;
    }
    get content() {
        return this._content;
    }
    set content(a) {
        this._content = a;
    }
}
TemplateSectionHeaderCellUpdatingEventArgs.$t = markType(TemplateSectionHeaderCellUpdatingEventArgs, 'TemplateSectionHeaderCellUpdatingEventArgs', EventArgs.$);

/**
 * Information about the cell that has content which is being created or updated.
*/
class IgxTemplateSectionHeaderCellUpdatingEventArgs {
    createImplementation() {
        return new TemplateSectionHeaderCellUpdatingEventArgs();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The host in which to add or update content.
    */
    get content() {
        return this.i.content.element.getNativeElement();
    }
    /**
     * The backing information for the current cell.
    */
    get cellInfo() {
        if (this.i.cellInfo == null) {
            return null;
        }
        if (!this.i.cellInfo.externalObject) {
            let ext = null;
            switch (this.i.cellInfo.$type.name) {
                case "DateTimeCellModel":
                    ext = new IgxDateTimeCellInfo();
                    break;
                case "ImageCellModel":
                    ext = new IgxImageCellInfo();
                    break;
                case "NumericCellModel":
                    ext = new IgxNumericCellInfo();
                    break;
                case "RowSeparatorModel":
                    ext = new IgxRowSeparatorInfo();
                    break;
                case "SectionHeaderCellModel":
                    ext = new IgxSectionHeaderCellInfo();
                    break;
                case "TemplateCellModel":
                    ext = new IgxTemplateCellInfo();
                    break;
                case "TemplateHeaderCellModel":
                    ext = new IgxTemplateHeaderCellInfo();
                    break;
                case "TemplateSectionHeaderCellModel":
                    ext = new IgxTemplateSectionHeaderCellInfo();
                    break;
                case "TextCellModel":
                    ext = new IgxTextCellInfo();
                    break;
                case "TextHeaderCellModel":
                    ext = new IgxTextHeaderCellInfo();
                    break;
            }
            ext._implementation = this.i.cellInfo;
            this.i.cellInfo.externalObject = ext;
        }
        return this.i.cellInfo.externalObject;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class BrowserExecutionContext extends Base {
    constructor(a) {
        super();
        this.b = new Date();
        this._requestAnimationFrame = null;
        this.requestAnimationFrame = a.getRequestAnimationFrame();
        this.b = dateNow();
    }
    get requestAnimationFrame() {
        return this._requestAnimationFrame;
    }
    set requestAnimationFrame(a) {
        this._requestAnimationFrame = a;
    }
    enqueueAction(a) {
        window.setTimeout(() => a(), 0);
    }
    enqueueAnimationAction(a) {
        this.requestAnimationFrame(() => a());
    }
    execute(a) {
        window.setTimeout(() => a(), 0);
    }
    executeDelayed(a, b) {
        window.setTimeout(() => a(), b);
    }
    getCurrentRelativeTime() {
        let a = dateNow();
        return truncate(timeSpanTotalMilliseconds((+a - +(this.b))));
    }
}
BrowserExecutionContext.$t = markType(BrowserExecutionContext, 'BrowserExecutionContext', Base.$, [IExecutionContext_$type]);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * This class is used to group the settings to define an animation phase.
*/
class IgxGridAnimationPhaseSettings {
    constructor() {
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridAnimationPhaseSettings();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The duration of an animation, in milliseconds
    */
    get durationMilliseconds() {
        return this.i.l;
    }
    set durationMilliseconds(v) {
        this.i.l = +v;
    }
    /**
     * The amount of time to delay an animation, in milliseconds.
    */
    get holdInitialMilliseconds() {
        return this.i.m;
    }
    set holdInitialMilliseconds(v) {
        this.i.m = +v;
    }
    /**
     * The amount of time to delay each item animating, in milliseconds
    */
    get perItemDelayMilliseconds() {
        return this.i.n;
    }
    set perItemDelayMilliseconds(v) {
        this.i.n = +v;
    }
    /**
     * The amount of time each item animating should take, in milliseconds
    */
    get subItemDurationMilliseconds() {
        return this.i.o;
    }
    set subItemDurationMilliseconds(v) {
        this.i.o = +v;
    }
    /**
     * The desired amount of time each item animating should take, in milliseconds
    */
    get desiredSubItemDurationMilliseconds() {
        return this.i.k;
    }
    set desiredSubItemDurationMilliseconds(v) {
        this.i.k = +v;
    }
    /**
     * Configures whether all items animating should finish simultaneously
    */
    get shouldItemsFinishSimultaneously() {
        return this.i.e;
    }
    set shouldItemsFinishSimultaneously(v) {
        this.i.e = ensureBool(v);
    }
    /**
     * Configures the Easing function used to animate the individual items
    */
    get easingFunctionType() {
        return this.i.c;
    }
    set easingFunctionType(v) {
        this.i.c = ensureEnum(GridEasingFunctionType_$type, v);
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}

/**
 * Backing information for a section header cell in the grid.
*/
class IgxSummaryCellInfo extends IgxCellInfo {
    createImplementation() {
        return new SummaryCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Sets or gets the resolved summary text for the summary cell.
    */
    get resolvedSummaryText() {
        return this.i.im;
    }
    set resolvedSummaryText(v) {
        this.i.im = v;
    }
    /**
     * Sets or gets the resolved summary value for the sumamry cell.
    */
    get resolvedSummaryValue() {
        return this.i.ip;
    }
    set resolvedSummaryValue(v) {
        this.i.ip = v;
    }
    /**
     * Gets or sets the color of the text for the summary name in the cell.
    */
    get summaryNameTextColor() {
        return brushToString(this.i.it);
    }
    set summaryNameTextColor(v) {
        this.i.it = stringToBrush(v);
    }
}

/**
 * Represents backing information for vertical separators.
*/
class IgxVerticalSeparatorCellInfo extends IgxCellInfo {
    createImplementation() {
        return new VerticalSeparatorCellModel();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor() {
        super();
    }
    /**
     * Gets or sets whether the vertical separator is hit test visible.
    */
    get isHitTestVisible() {
        return this.i.ii;
    }
    set isHitTestVisible(v) {
        this.i.ii = ensureBool(v);
    }
}

/**
 * Object used to store group information for group headers.
*/
class IgxGroupData {
    createImplementation() {
        return new GroupData();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The grouping key.
    */
    get groupName() {
        return this.i.c;
    }
    set groupName(v) {
        this.i.c = v;
    }
    /**
     * The group value.
    */
    get groupValue() {
        return this.i.a;
    }
    set groupValue(v) {
        this.i.a = v;
    }
    /**
     * The value as formatted text.
    */
    get formattedText() {
        return this.i.b;
    }
    set formattedText(v) {
        this.i.b = v;
    }
}

/**
 * Object used to store summary information for group headers.
*/
class IgxSummaryData {
    createImplementation() {
        return new SummaryData();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get summaryName() {
        return this.i.e;
    }
    set summaryName(v) {
        this.i.e = v;
    }
    get summaryValue() {
        return this.i.b;
    }
    set summaryValue(v) {
        this.i.b = v;
    }
    get summaryOperand() {
        return this.i.a;
    }
    set summaryOperand(v) {
        this.i.a = v;
    }
    get formattedText() {
        return this.i.c;
    }
    set formattedText(v) {
        this.i.c = v;
    }
    get formattedValue() {
        return this.i.d;
    }
    set formattedValue(v) {
        this.i.d = v;
    }
}

class IgxGridFilterDialogOpeningEventArgs {
    createImplementation() {
        return new GridFilterDialogOpeningEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get filter() {
        return this.i.a;
    }
    set filter(v) {
        this.i.a = v;
    }
    get propertyType() {
        return this.i.b;
    }
    set propertyType(v) {
        this.i.b = ensureEnum(DataSourceSchemaPropertyType_$type, v);
    }
}

class IgxGridFilterDialogFilterChangeEventArgs {
    createImplementation() {
        return new GridFilterDialogFilterChangeEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get filter() {
        return this.i.a;
    }
    set filter(v) {
        this.i.a = v;
    }
}

/**
 * An advanced grid for displaying data.
*/
const IgxLiveGridFilterDialogComponent_PROVIDERS = [];
let IgxLiveGridFilterDialogComponent = class IgxLiveGridFilterDialogComponent {
    constructor() {
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._dialogOpening = null;
        this._filterChanging = null;
        this._filterChanged = null;
        this._zoneRunner = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridFilterDialog();
    }
    ngOnInit() {
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igx" + name + "Component";
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    get isAnimationEnabled() {
        return this.i.p;
    }
    set isAnimationEnabled(v) {
        this.i.p = ensureBool(v);
    }
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get pixelScalingRatio() {
        return this.i.u;
    }
    set pixelScalingRatio(v) {
        this.i.u = +v;
    }
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get actualPixelScalingRatio() {
        return this.i.t;
    }
    set actualPixelScalingRatio(v) {
        this.i.t = +v;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("LiveGridFilterDialogComponent");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    notifySizeChanged(width, height) {
        this.i.ai(width, height);
    }
    get dialogOpening() {
        if (this._dialogOpening == null) {
            this._dialogOpening = new EventEmitter();
            this.i.dialogOpening = delegateCombine(this.i.dialogOpening, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxGridFilterDialogOpeningEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeDialogOpening) {
                        this.beforeDialogOpening(this, outerArgs);
                    }
                    this._dialogOpening.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._dialogOpening;
    }
    get filterChanging() {
        if (this._filterChanging == null) {
            this._filterChanging = new EventEmitter();
            this.i.filterChanging = delegateCombine(this.i.filterChanging, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxGridFilterDialogFilterChangeEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeFilterChanging) {
                        this.beforeFilterChanging(this, outerArgs);
                    }
                    this._filterChanging.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._filterChanging;
    }
    get filterChanged() {
        if (this._filterChanged == null) {
            this._filterChanged = new EventEmitter();
            this.i.filterChanged = delegateCombine(this.i.filterChanged, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxGridFilterDialogFilterChangeEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeFilterChanged) {
                        this.beforeFilterChanged(this, outerArgs);
                    }
                    this._filterChanged.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._filterChanged;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
};
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridFilterDialogComponent.prototype, "isAnimationEnabled", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridFilterDialogComponent.prototype, "pixelScalingRatio", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridFilterDialogComponent.prototype, "actualPixelScalingRatio", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridFilterDialogComponent.prototype, "dialogOpening", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridFilterDialogComponent.prototype, "filterChanging", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridFilterDialogComponent.prototype, "filterChanged", null);
IgxLiveGridFilterDialogComponent = __decorate([
    Component({
        selector: 'igx-live-grid-filter-dialog',
        template: ``,
        providers: [],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxLiveGridFilterDialogComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

class IgxGridFilterDialogViewModelGrouping {
    createImplementation() {
        return new GridFilterDialogViewModelGrouping();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get startIndex() {
        return this.i.c;
    }
    set startIndex(v) {
        this.i.c = +v;
    }
    get endIndex() {
        return this.i.b;
    }
    set endIndex(v) {
        this.i.b = +v;
    }
    get isOrGrouping() {
        return this.i.a;
    }
    set isOrGrouping(v) {
        this.i.a = ensureBool(v);
    }
}

class IgxGridFilterDialogViewModelGroupingLevel extends IgCollection {
    constructor(list) {
        super();
        if (!IgxGridFilterDialogViewModelGrouping.$type) {
            IgxGridFilterDialogViewModelGrouping.$type = markType(IgxGridFilterDialogViewModelGrouping, "IgxGridFilterDialogViewModelGrouping");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxGridFilterDialogViewModelGrouping.$type) {
            IgxGridFilterDialogViewModelGrouping.$type = markType(IgxGridFilterDialogViewModelGrouping, "IgxGridFilterDialogViewModelGrouping");
        }
        let coll = new SyncableObservableCollection$2(IgxGridFilterDialogViewModelGrouping.$type, GridFilterDialogViewModelGrouping.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = new IgxGridFilterDialogViewModelGrouping();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

class IgxGridFilterDialogViewModelGroupingLevelCollection extends IgCollection {
    constructor(list) {
        super();
        if (!IgxGridFilterDialogViewModelGroupingLevel.$type) {
            IgxGridFilterDialogViewModelGroupingLevel.$type = markType(IgxGridFilterDialogViewModelGroupingLevel, "IgxGridFilterDialogViewModelGroupingLevel");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxGridFilterDialogViewModelGroupingLevel.$type) {
            IgxGridFilterDialogViewModelGroupingLevel.$type = markType(IgxGridFilterDialogViewModelGroupingLevel, "IgxGridFilterDialogViewModelGroupingLevel");
        }
        let coll = new SyncableObservableCollection$2(IgxGridFilterDialogViewModelGroupingLevel.$type, GridFilterDialogViewModelGroupingLevel.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = new IgxGridFilterDialogViewModelGroupingLevel();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

class IgxGridFilterDialogViewModelRow {
    constructor() {
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridFilterDialogViewModelRow();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get operatorTypes() {
        return this.i.f;
    }
    set operatorTypes(v) {
        this.i.f = v;
    }
    get operators() {
        return this.i.e;
    }
    set operators(v) {
        this.i.e = v;
    }
    get currentOperator() {
        return this.i.l;
    }
    set currentOperator(v) {
        this.i.l = v;
    }
    get operandNumber() {
        return this.i.d;
    }
    set operandNumber(v) {
        this.i.d = v;
    }
    get operand1() {
        return this.i.i;
    }
    set operand1(v) {
        this.i.i = v;
    }
    get operand2() {
        return this.i.j;
    }
    set operand2(v) {
        this.i.j = v;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}

class IgxGridFilterDialogViewModelRowCollection extends IgCollection {
    constructor(list) {
        super();
        if (!IgxGridFilterDialogViewModelRow.$type) {
            IgxGridFilterDialogViewModelRow.$type = markType(IgxGridFilterDialogViewModelRow, "IgxGridFilterDialogViewModelRow");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxGridFilterDialogViewModelRow.$type) {
            IgxGridFilterDialogViewModelRow.$type = markType(IgxGridFilterDialogViewModelRow, "IgxGridFilterDialogViewModelRow");
        }
        let coll = new SyncableObservableCollection$2(IgxGridFilterDialogViewModelRow.$type, GridFilterDialogViewModelRow.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = new IgxGridFilterDialogViewModelRow();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

class IgxGridFilterDialogViewModel {
    constructor() {
        this._groupingLevels = null;
        this._rows = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridFilterDialogViewModel();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get propertyType() {
        return this.i.a;
    }
    set propertyType(v) {
        this.i.a = ensureEnum(DataSourceSchemaPropertyType_$type, v);
    }
    get groupingLevels() {
        if (this._groupingLevels === null) {
            let coll = new IgxGridFilterDialogViewModelGroupingLevelCollection();
            let innerColl = this.i.e;
            if (!innerColl) {
                innerColl = new GridFilterDialogViewModelGroupingLevelCollection();
            }
            this._groupingLevels = coll._fromInner(innerColl);
            this.i.e = innerColl;
        }
        return this._groupingLevels;
    }
    set groupingLevels(v) {
        if (this._groupingLevels !== null) {
            this._groupingLevels._setSyncTarget(null);
            this._groupingLevels = null;
        }
        let coll = new IgxGridFilterDialogViewModelGroupingLevelCollection();
        this._groupingLevels = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(GridFilterDialogViewModelGroupingLevel.$type);
        let innerColl = this.i.e;
        if (!innerColl) {
            innerColl = new GridFilterDialogViewModelGroupingLevelCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._groupingLevels._setSyncTarget(syncColl);
        this.i.e = innerColl;
    }
    get isTopLevelOr() {
        return this.i.k;
    }
    set isTopLevelOr(v) {
        this.i.k = ensureBool(v);
    }
    get maxGroupingLevels() {
        return this.i.m;
    }
    set maxGroupingLevels(v) {
        this.i.m = +v;
    }
    get rows() {
        if (this._rows === null) {
            let coll = new IgxGridFilterDialogViewModelRowCollection();
            let innerColl = this.i.f;
            if (!innerColl) {
                innerColl = new GridFilterDialogViewModelRowCollection();
            }
            this._rows = coll._fromInner(innerColl);
            this.i.f = innerColl;
        }
        return this._rows;
    }
    set rows(v) {
        if (this._rows !== null) {
            this._rows._setSyncTarget(null);
            this._rows = null;
        }
        let coll = new IgxGridFilterDialogViewModelRowCollection();
        this._rows = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(GridFilterDialogViewModelRow.$type);
        let innerColl = this.i.f;
        if (!innerColl) {
            innerColl = new GridFilterDialogViewModelRowCollection();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._rows._setSyncTarget(syncColl);
        this.i.f = innerColl;
    }
    addNewRow() {
        this.i.n();
    }
    canGroupRange(startIndex, endIndex) {
        let iv = this.i.h(startIndex, endIndex);
        return (iv);
    }
    ungroupRange(startIndex, endIndex) {
        this.i.aa(startIndex, endIndex);
    }
    targetingRange(startIndex, endIndex) {
        let iv = this.i.l(startIndex, endIndex);
        return (iv);
    }
    toggleRange(startIndex, endIndex) {
        this.i.z(startIndex, endIndex);
    }
    groupRange(startIndex, endIndex, isOrGrouping) {
        this.i.o(startIndex, endIndex, isOrGrouping);
    }
}

const IgxLiveGridExpansionIndicatorComponent_PROVIDERS = [];
let IgxLiveGridExpansionIndicatorComponent = class IgxLiveGridExpansionIndicatorComponent {
    constructor() {
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._zoneRunner = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridExpansionIndicator();
    }
    ngOnInit() {
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igx" + name + "Component";
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    /**
     * Gets or sets the expansion state of the indicator.
    */
    get isExpanded() {
        return this.i.g;
    }
    set isExpanded(v) {
        this.i.g = ensureBool(v);
    }
    /**
     * Gets or sets the color of the indicator.
    */
    get iconColor() {
        return brushToString(this.i.ae);
    }
    set iconColor(v) {
        this.i.ae = stringToBrush(v);
    }
    /**
     * Gets or sets whether animations are enabled.
    */
    get isAnimationEnabled() {
        return this.i.f;
    }
    set isAnimationEnabled(v) {
        this.i.f = ensureBool(v);
    }
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get pixelScalingRatio() {
        return this.i.m;
    }
    set pixelScalingRatio(v) {
        this.i.m = +v;
    }
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get actualPixelScalingRatio() {
        return this.i.j;
    }
    set actualPixelScalingRatio(v) {
        this.i.j = +v;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("LiveGridExpansionIndicatorComponent");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    notifySizeChanged(width, height) {
        this.i.y(width, height);
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
};
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridExpansionIndicatorComponent.prototype, "isExpanded", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridExpansionIndicatorComponent.prototype, "iconColor", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridExpansionIndicatorComponent.prototype, "isAnimationEnabled", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridExpansionIndicatorComponent.prototype, "pixelScalingRatio", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridExpansionIndicatorComponent.prototype, "actualPixelScalingRatio", null);
IgxLiveGridExpansionIndicatorComponent = __decorate([
    Component({
        selector: 'igx-live-grid-expansion-indicator',
        template: ``,
        providers: [],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxLiveGridExpansionIndicatorComponent);

class IgxSortIndicatorRenderCompletedEventArgs {
    createImplementation() {
        return new SortIndicatorRenderCompletedEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
}

/**
 * An advanced grid for displaying data.
*/
const IgxLiveGridSortIndicatorComponent_PROVIDERS = [];
let IgxLiveGridSortIndicatorComponent = class IgxLiveGridSortIndicatorComponent {
    constructor() {
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._renderCompleted = null;
        this._zoneRunner = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new GridSortIndicator();
    }
    ngOnInit() {
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igx" + name + "Component";
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    get sortDirection() {
        return this.i.b;
    }
    set sortDirection(v) {
        this.i.b = ensureEnum(ColumnSortDirection_$type, v);
    }
    get iconColor() {
        return brushToString(this.i.ax);
    }
    set iconColor(v) {
        this.i.ax = stringToBrush(v);
    }
    get isAnimationEnabled() {
        return this.i.l;
    }
    set isAnimationEnabled(v) {
        this.i.l = ensureBool(v);
    }
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get pixelScalingRatio() {
        return this.i.v;
    }
    set pixelScalingRatio(v) {
        this.i.v = +v;
    }
    /**
     * Gets the actual pixel scaling ratio used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get actualPixelScalingRatio() {
        return this.i.o;
    }
    set actualPixelScalingRatio(v) {
        this.i.o = +v;
    }
    get sortIndicatorStyle() {
        return this.i.f;
    }
    set sortIndicatorStyle(v) {
        this.i.f = ensureEnum(SortIndicatorStyle_$type, v);
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("LiveGridSortIndicatorComponent");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    getDesiredScale() {
        let iv = this.i.u();
        return (iv);
    }
    notifySizeChanged(width, height) {
        this.i.ao(width, height);
    }
    get renderCompleted() {
        if (this._renderCompleted == null) {
            this._renderCompleted = new EventEmitter();
            this.i.renderCompleted = delegateCombine(this.i.renderCompleted, (o, e) => {
                let outerArgs = new IgxSortIndicatorRenderCompletedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeRenderCompleted) {
                    this.beforeRenderCompleted(this, outerArgs);
                }
                this._renderCompleted.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._renderCompleted;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
};
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridSortIndicatorComponent.prototype, "sortDirection", null);
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], IgxLiveGridSortIndicatorComponent.prototype, "iconColor", null);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], IgxLiveGridSortIndicatorComponent.prototype, "isAnimationEnabled", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridSortIndicatorComponent.prototype, "pixelScalingRatio", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridSortIndicatorComponent.prototype, "actualPixelScalingRatio", null);
__decorate([
    Input(),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], IgxLiveGridSortIndicatorComponent.prototype, "sortIndicatorStyle", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxLiveGridSortIndicatorComponent.prototype, "renderCompleted", null);
IgxLiveGridSortIndicatorComponent = __decorate([
    Component({
        selector: 'igx-live-grid-sort-indicator',
        template: ``,
        providers: [],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxLiveGridSortIndicatorComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let DragType_$type = markEnum('DragType', 'RangeSelect,0|HeaderResize,1|ColumnMove,2|None,3');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

class IgxFormatSummaryTextEventArgs {
    createImplementation() {
        return new FormatSummaryTextEventArgs();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * Gets the summary property name.
    */
    get propertyPath() {
        return this.i.e;
    }
    set propertyPath(v) {
        this.i.e = v;
    }
    /**
     * Gets the summary display name.
    */
    get displayName() {
        return this.i.b;
    }
    set displayName(v) {
        this.i.b = v;
    }
    /**
     * Gets the original value before formatting.
    */
    get summaryResult() {
        return this.i.a;
    }
    set summaryResult(v) {
        this.i.a = v;
    }
    /**
     * Gets or sets the summary value as formatted text.  Setting this property will only affect summary cells.
    */
    get formattedResult() {
        return this.i.c;
    }
    set formattedResult(v) {
        this.i.c = v;
    }
    /**
     * Gets or sets the final text that will be displayed in the group header.
    */
    get formattedText() {
        return this.i.d;
    }
    set formattedText(v) {
        this.i.d = v;
    }
}

/**
 * Represents a summary that is applied to a datasource. Changes to this object are not observed or expected after it is initially assigned to a collection.
*/
class IgxColumnSummaryDescription {
    constructor() {
        this._formatText = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new ColumnSummaryDescription(0);
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get propertyPath() {
        return this.i.t;
    }
    set propertyPath(v) {
        this.i.t = v;
    }
    get operand() {
        return this.i.e;
    }
    set operand(v) {
        this.i.e = v;
    }
    get calculator() {
        return this.i.c;
    }
    set calculator(v) {
        this.i.c = v;
    }
    /**
     * Gets or sets the name to use when displaying the calculator name.
    */
    get calculatorDisplayName() {
        return this.i.r;
    }
    set calculatorDisplayName(v) {
        this.i.r = v;
    }
    /**
     * Gets or sets the display name for the summary.
    */
    get displayName() {
        return this.i.s;
    }
    set displayName(v) {
        this.i.s = v;
    }
    /**
     * Gets or sets an INTL.DateTimeFormat or INTL.NumericFormat to use to format the value.
    */
    get formatOverride() {
        return this.i.n;
    }
    set formatOverride(v) {
        this.i.n = v;
    }
    /**
     * Gets or sets the minimum fraction digits. If FormatOverride is specificied this value is ignored.
    */
    get maxFractionDigits() {
        return this.i.l;
    }
    set maxFractionDigits(v) {
        this.i.l = +v;
    }
    equals(other) {
        let iv = this.i.equals(other);
        return (iv);
    }
    getHashCode() {
        let iv = this.i.getHashCode();
        return (iv);
    }
    /**
     * Called when the value is being formatted.
    */
    get formatText() {
        if (this._formatText == null) {
            this._formatText = new EventEmitter();
            this.i.formatText = delegateCombine(this.i.formatText, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new IgxFormatSummaryTextEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeFormatText) {
                        this.beforeFormatText(this, outerArgs);
                    }
                    this._formatText.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._formatText;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxColumnSummaryDescription.prototype, "formatText", null);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let IExternalTemplateSectionHeader_$type = new Type(null, 'IExternalTemplateSectionHeader');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let IExternalTemplateColumn_$type = new Type(null, 'IExternalTemplateColumn');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let IExternalTemplateHeaderColumn_$type = new Type(null, 'IExternalTemplateHeaderColumn');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

var IgxSectionFooterComponent_1;
/**
 * Used to configure the appearance of the section footer cells.
*/
const IgxSectionFooterComponent_PROVIDERS = [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxSectionFooterComponent) }];
let IgxSectionFooterComponent = IgxSectionFooterComponent_1 = class IgxSectionFooterComponent extends IgxDefinitionBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new SectionFooter();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
};
IgxSectionFooterComponent = IgxSectionFooterComponent_1 = __decorate([
    Component({
        selector: 'igx-section-footer',
        template: ``,
        providers: [{ provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxSectionFooterComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxSectionFooterComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxSectionFooterModule = class IgxSectionFooterModule {
};
IgxSectionFooterModule = __decorate([
    NgModule({
        declarations: [IgxSectionFooterComponent],
        imports: [CommonModule],
        exports: [IgxSectionFooterComponent],
        entryComponents: []
    })
], IgxSectionFooterModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxSectionFooterDynamicModule = class IgxSectionFooterDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxSectionFooterComponent", IgxSectionFooterComponent);
        TypeRegistrar.register("SectionFooter", SectionFooter.$type);
    }
};
IgxSectionFooterDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxSectionFooterModule],
        exports: [IgxSectionFooterModule],
        entryComponents: [IgxSectionFooterComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxSectionFooterDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxSummaryRowRootModule = class IgxSummaryRowRootModule {
};
IgxSummaryRowRootModule = __decorate([
    NgModule({
        declarations: [IgxSummaryRowRootComponent],
        imports: [CommonModule],
        exports: [IgxSummaryRowRootComponent],
        entryComponents: []
    })
], IgxSummaryRowRootModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxSummaryRowRootDynamicModule = class IgxSummaryRowRootDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxSummaryRowRootComponent", IgxSummaryRowRootComponent);
        TypeRegistrar.register("SummaryRowRoot", SummaryRowRoot.$type);
    }
};
IgxSummaryRowRootDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxSummaryRowRootModule],
        exports: [IgxSummaryRowRootModule],
        entryComponents: [IgxSummaryRowRootComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxSummaryRowRootDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxSummaryRowSectionModule = class IgxSummaryRowSectionModule {
};
IgxSummaryRowSectionModule = __decorate([
    NgModule({
        declarations: [IgxSummaryRowSectionComponent],
        imports: [CommonModule],
        exports: [IgxSummaryRowSectionComponent],
        entryComponents: []
    })
], IgxSummaryRowSectionModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxSummaryRowSectionDynamicModule = class IgxSummaryRowSectionDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxSummaryRowSectionComponent", IgxSummaryRowSectionComponent);
        TypeRegistrar.register("SummaryRowSection", SummaryRowSection.$type);
    }
};
IgxSummaryRowSectionDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxSummaryRowSectionModule],
        exports: [IgxSummaryRowSectionModule],
        entryComponents: [IgxSummaryRowSectionComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxSummaryRowSectionDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateSectionHeader extends SectionHeader {
    constructor() {
        super(...arguments);
        this.cellUpdating = null;
    }
    b8(a, b, c) {
        return "templateSectionHeader";
    }
    l(a) {
        return new TemplateSectionHeaderCellModel();
    }
    eu(a, b) {
        if (this.cellUpdating != null) {
            this.cellUpdating(this, ((() => {
                let $ret = new TemplateSectionHeaderCellUpdatingEventArgs();
                $ret.cellInfo = a;
                $ret.content = b;
                return $ret;
            })()));
        }
    }
}
TemplateSectionHeader.$t = markType(TemplateSectionHeader, 'TemplateSectionHeader', SectionHeader.$);

var IgxTemplateSectionHeaderComponent_1;
/**
 * Used to configure the appearance of the section header cells.
*/
const IgxTemplateSectionHeaderComponent_PROVIDERS = [{ provide: IgxSectionHeaderComponent, useExisting: forwardRef(() => IgxTemplateSectionHeaderComponent) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxTemplateSectionHeaderComponent) }];
let IgxTemplateSectionHeaderComponent = IgxTemplateSectionHeaderComponent_1 = class IgxTemplateSectionHeaderComponent extends IgxSectionHeaderComponent {
    constructor() {
        super();
        this._cellUpdating = null;
    }
    createImplementation() {
        return new TemplateSectionHeader();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * Called when the cell content is being created or updated.
    */
    get cellUpdating() {
        if (this._cellUpdating == null) {
            this._cellUpdating = new EventEmitter();
            this.i.cellUpdating = delegateCombine(this.i.cellUpdating, (o, e) => {
                let outerArgs = new IgxTemplateSectionHeaderCellUpdatingEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCellUpdating) {
                    this.beforeCellUpdating(this, outerArgs);
                }
                this._cellUpdating.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._cellUpdating;
    }
};
__decorate([
    Output(),
    __metadata("design:type", EventEmitter),
    __metadata("design:paramtypes", [])
], IgxTemplateSectionHeaderComponent.prototype, "cellUpdating", null);
IgxTemplateSectionHeaderComponent = IgxTemplateSectionHeaderComponent_1 = __decorate([
    Component({
        selector: 'igx-template-section-header',
        template: ``,
        providers: [{ provide: IgxSectionHeaderComponent, useExisting: forwardRef(() => IgxTemplateSectionHeaderComponent_1) }, { provide: IgxDefinitionBaseComponent, useExisting: forwardRef(() => IgxTemplateSectionHeaderComponent_1) }],
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [])
], IgxTemplateSectionHeaderComponent);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxTemplateSectionHeaderModule = class IgxTemplateSectionHeaderModule {
};
IgxTemplateSectionHeaderModule = __decorate([
    NgModule({
        declarations: [IgxTemplateSectionHeaderComponent],
        imports: [CommonModule],
        exports: [IgxTemplateSectionHeaderComponent],
        entryComponents: []
    })
], IgxTemplateSectionHeaderModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE: you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
let IgxTemplateSectionHeaderDynamicModule = class IgxTemplateSectionHeaderDynamicModule {
    constructor() {
        TypeRegistrar.registerCons("IgxTemplateSectionHeaderComponent", IgxTemplateSectionHeaderComponent);
        TypeRegistrar.register("TemplateSectionHeader", TemplateSectionHeader.$type);
    }
};
IgxTemplateSectionHeaderDynamicModule = __decorate([
    NgModule({
        declarations: [],
        imports: [CommonModule, IgxTemplateSectionHeaderModule],
        exports: [IgxTemplateSectionHeaderModule],
        entryComponents: [IgxTemplateSectionHeaderComponent]
    }),
    __metadata("design:paramtypes", [])
], IgxTemplateSectionHeaderDynamicModule);

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let GridEffectMainIntent_$type = markEnum('GridEffectMainIntent', 'Default,0|Position,1|Opacity,2|Virtualization,3|Dimensions,4|Selection,5|DataChange,6|ColumnPropertyChange,7|Activation,8');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
let GridEffectSubIntent_$type = markEnum('GridEffectSubIntent', 'Default,0|Move,1|Show,2|Hide,3|Exchange,4|HeaderPropertyChange,5');

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Indicates a column that should be exchanged with another.
*/
class IgxColumnExchanger {
    createImplementation() {
        return new ColumnExchanger(0);
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The desired location of the new column
    */
    get targetIndex() {
        return this.i.b;
    }
    set targetIndex(v) {
        this.i.b = +v;
    }
}

class IgxColumnExchangersCollection extends IgCollection {
    constructor(list) {
        super();
        if (!IgxColumnExchanger.$type) {
            IgxColumnExchanger.$type = markType(IgxColumnExchanger, "IgxColumnExchanger");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxColumnExchanger.$type) {
            IgxColumnExchanger.$type = markType(IgxColumnExchanger, "IgxColumnExchanger");
        }
        let coll = new SyncableObservableCollection$2(IgxColumnExchanger.$type, ColumnExchanger.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = new IgxColumnExchanger();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Indicates that a specified column should have a specified property set to a value.
*/
class IgxColumnPropertySetter {
    createImplementation() {
        return new ColumnPropertySetter(0);
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The name or key of the column to change the property of
    */
    get columnName() {
        return this.i.c;
    }
    set columnName(v) {
        this.i.c = v;
    }
    /**
     * The name of the property to change
    */
    get propertyName() {
        return this.i.d;
    }
    set propertyName(v) {
        this.i.d = v;
    }
    /**
     * The new value of the property
    */
    get value() {
        return this.i.b;
    }
    set value(v) {
        this.i.b = v;
    }
}

class IgxColumnPropertySettersCollection extends IgCollection {
    constructor(list) {
        super();
        if (!IgxColumnPropertySetter.$type) {
            IgxColumnPropertySetter.$type = markType(IgxColumnPropertySetter, "IgxColumnPropertySetter");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxColumnPropertySetter.$type) {
            IgxColumnPropertySetter.$type = markType(IgxColumnPropertySetter, "IgxColumnPropertySetter");
        }
        let coll = new SyncableObservableCollection$2(IgxColumnPropertySetter.$type, ColumnPropertySetter.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = new IgxColumnPropertySetter();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/**
 * Describes one phase of a responsive state to apply to the grid.
*/
class IgxResponsivePhase {
    createImplementation() {
        return new ResponsivePhase();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The name of this responsive phase
    */
    get name() {
        return this.i.k;
    }
    set name(v) {
        this.i.k = v;
    }
    /**
     * The amount of time to delay the responsive phase from starting, in milliseconds
    */
    get delayMilliseconds() {
        return this.i.i;
    }
    set delayMilliseconds(v) {
        this.i.i = +v;
    }
    /**
     * Adds a column property setter to the phase.
    
    * @param setter  * The setter to add.
    */
    addColumnPropertySetter(setter) {
        let iv = this.i.g((setter == null ? null : setter.i));
        return (iv == null ? null : iv.externalObject);
    }
    /**
     * Adds a column property setter to the phase, and returns it.
    
    */
    columnPropertySetter() {
        let iv = this.i.c();
        return (iv == null ? null : iv.externalObject);
    }
    /**
     * Adds a column exchanger the the phase.
    
    * @param exchanger  * The exchanger to add.
    */
    addColumnExchanger(exchanger) {
        let iv = this.i.f((exchanger == null ? null : exchanger.i));
        return (iv == null ? null : iv.externalObject);
    }
    /**
     * Adds a column exchanger to the phase and returns it.
    
    */
    columnExchanger() {
        let iv = this.i.h();
        return (iv == null ? null : iv.externalObject);
    }
}

class IgxResponsivePhasesCollection extends IgCollection {
    constructor(list) {
        super();
        if (!IgxResponsivePhase.$type) {
            IgxResponsivePhase.$type = markType(IgxResponsivePhase, "IgxResponsivePhase");
        }
        if (list) {
            for (let i = 0; i < list.length; i++) {
                this.add(list[i]);
            }
        }
    }
    _createInnerColl() {
        if (!IgxResponsivePhase.$type) {
            IgxResponsivePhase.$type = markType(IgxResponsivePhase, "IgxResponsivePhase");
        }
        let coll = new SyncableObservableCollection$2(IgxResponsivePhase.$type, ResponsivePhase.$type, 0);
        coll.compare = (ext, int) => {
            let comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = (ext) => {
            return ext._implementation;
        };
        coll.createFrom = (int) => {
            let ext = int.externalObject;
            if (!ext) {
                ext = new IgxResponsivePhase();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    }
}

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/

/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
/**
 * @hidden
 */
class TemplateSectionHeaderCellModelExport extends SectionHeaderCellModelExport {
    get_aa() {
        return "TemplatSectionHeaderCell";
    }
    ab(a) {
        super.ab(a);
    }
}
TemplateSectionHeaderCellModelExport.$t = markType(TemplateSectionHeaderCellModelExport, 'TemplateSectionHeaderCellModelExport', SectionHeaderCellModelExport.$);

/**
 * Generated bundle index. Do not edit.
 */

export { ActivationManager, BrowserExecutionContext, BrowserPixelConverter, BrowserTickProvider, CalculationParameters, CanvasCellPresenterBase, CanvasContentCellModelHelper, CanvasDateTimeCell, CanvasDateTimeCellPresenter, CanvasGridCellBase, CanvasImageCell, CanvasImageCellPresenter, CanvasNumericCell, CanvasNumericCellPresenter, CanvasPlaceholderView, CanvasRowSeparatorCell, CanvasRowSeparatorCellPresenter, CanvasSectionHeaderCell, CanvasSectionHeaderCellPresenter, CanvasSummaryCell, CanvasSummaryCellPresenter, CanvasTemplateCell, CanvasTemplateCellContainer, CanvasTemplateCellPresenter, CanvasTemplateHeaderCell, CanvasTemplateHeaderCellPresenter, CanvasTextCell, CanvasTextCellPresenter, CanvasTextHeaderCell, CanvasTextHeaderCellPresenter, CanvasVerticalSeparatorCell, CanvasVerticalSeparatorCellPresenter, CellContentHorizontalAlignment, CellContentHorizontalAlignment_$type, CellContentVerticalAlignment, CellContentVerticalAlignment_$type, CellDataLoadedAnimationMode, CellDataLoadedAnimationMode_$type, CellEffect, CellKey, CellModel, CellModelExport, CellPath, CellPositionEffect, CellPresenterBase, CellPropertyAnimationType, CellPropertyAnimationType_$type, CellRange, CellSelectionAnimationMode, CellSelectionAnimationMode_$type, CellStyleRequestedEventArgs, Column, ColumnCellsEffect, ColumnComparisonConditionOperatorType, ColumnComparisonConditionOperatorType_$type, ColumnComparisonFilterCondition, ColumnController, ColumnEffect, ColumnExchanger, ColumnExchangersCollection, ColumnExchangingAnimationMode, ColumnExchangingAnimationMode_$type, ColumnFilterCondition, ColumnFilterConditionCollection, ColumnFilterConditionGroup, ColumnGroupDescription, ColumnGroupDescriptionCollection, ColumnHidingAnimationMode, ColumnHidingAnimationMode_$type, ColumnInfo, ColumnMovingAnimationMode, ColumnMovingAnimationMode_$type, ColumnMovingMode, ColumnMovingMode_$type, ColumnMovingSeparator, ColumnPropertySetter, ColumnPropertySettersCollection, ColumnPropertyUpdatingAnimationMode, ColumnPropertyUpdatingAnimationMode_$type, ColumnResizingAnimationMode, ColumnResizingAnimationMode_$type, ColumnResizingMode, ColumnResizingMode_$type, ColumnResizingSeparator, ColumnShowingAnimationMode, ColumnShowingAnimationMode_$type, ColumnSortDescription, ColumnSortDescriptionCollection, ColumnSortDirection, ColumnSortDirection_$type, ColumnStates_$type, ColumnSummaryDescription, ColumnSummaryDescriptionCollection, ColumnWidth, ContentCellModelHelper, CurrentRendererSettings, DataAdapter, DataBindingEventArgs, DataGridCellLayoutPanel, DataGridDelayedExecutionManager, DataGridPresenterManager, DataGridPropertySetter, DataGridScrollerKeyboardListener, DataGridViewportManager, DataSourceNotificationBridge, DateTimeCell, DateTimeCellModel, DateTimeCellModelExport, DateTimeCellPresenter, DateTimeColumn, DateTimeColumnValueFormatter, DateTimeFormats, DateTimeFormats_$type, DefaultCellActionManager, DefaultPlatformPixelConverter, DefinitionBase, DefinitionPropertyUpdatedEventArgs, DragSelectEventArgs, DragType_$type, Dragger, DraggerView, FixedCellPositions_$type, FormatGroupTextEventArgs, FormatSummaryTextEventArgs, Grid, GridActivationMode, GridActivationMode_$type, GridActiveCellChangedEventArgs, GridAnimationManager, GridAnimationManagerAnimationCanceledEventArgs, GridAnimationManagerAnimationCompletedEventArgs, GridAnimationManagerAnimationCreatedEventArgs, GridAnimationPhaseSettings, GridAnimationSettings, GridCellBase, GridCellEventArgs, GridCellPosition, GridColumnAnimationSettings, GridColumnCollection, GridColumnSpacer, GridColumnSpacerCollection, GridColumnsAutoGeneratedEventArgs, GridEasingFunctionType, GridEasingFunctionType_$type, GridEffect, GridEffectGroup, GridEffectMainIntent_$type, GridEffectManager, GridEffectSubIntent_$type, GridExpansionIndicator, GridExpansionIndicatorView, GridExternalWrapper, GridFilterDialog, GridFilterDialogFilterChangeEventArgs, GridFilterDialogOpeningEventArgs, GridFilterDialogPanel, GridFilterDialogView, GridFilterDialogViewModel, GridFilterDialogViewModelGrouping, GridFilterDialogViewModelGroupingLevel, GridFilterDialogViewModelGroupingLevelCollection, GridFilterDialogViewModelRow, GridFilterDialogViewModelRowCollection, GridFilterExpressionsEventArgs, GridGroupDescriptionsChangedEventArgs, GridLayer, GridLayerController, GridLayerExport, GridSelectedCellRangesChangedEventArgs, GridSelectedCellRangesCollection, GridSelectedCellsChangedEventArgs, GridSelectedCellsCollection, GridSelectedItemsChangedEventArgs, GridSelectedItemsCollection, GridSelectedKeysChangedEventArgs, GridSelectedKeysCollection, GridSelectionBehavior, GridSelectionBehavior_$type, GridSelectionMode, GridSelectionMode_$type, GridSortDescriptionsChangedEventArgs, GridSortIndicator, GridSortIndicatorView, GridStyleRepository, GroupData, GroupSummaryDisplayMode, GroupSummaryDisplayMode_$type, Header, HeaderClickAction, HeaderClickAction_$type, HeaderSeparator, ICellActionManager_$type, ICellPresenter_$type, ICellRenderingEngine_$type, IDataAdapter_$type, IDelayedExecutionManager_$type, IDraggerView_$type, IDragger_$type, IExternalDefinitionBase_$type, IExternalGrid_$type, IExternalTemplateColumn_$type, IExternalTemplateHeaderColumn_$type, IExternalTemplateSectionHeader_$type, INativeCell_$type, IPlatformPixelConverter_$type, IPropertySetter_$type, IViewportManager_$type, IgxCellInfo, IgxCellKey, IgxCellRange, IgxCellStyleRequestedEventArgs, IgxColumnComponent, IgxColumnComponent_PROVIDERS, IgxColumnExchanger, IgxColumnExchangersCollection, IgxColumnGroupDescription, IgxColumnGroupDescriptionCollection, IgxColumnMovingSeparatorComponent, IgxColumnMovingSeparatorComponent_PROVIDERS, IgxColumnMovingSeparatorDynamicModule, IgxColumnMovingSeparatorModule, IgxColumnPropertySetter, IgxColumnPropertySettersCollection, IgxColumnResizingSeparatorComponent, IgxColumnResizingSeparatorComponent_PROVIDERS, IgxColumnResizingSeparatorDynamicModule, IgxColumnResizingSeparatorModule, IgxColumnSortDescription, IgxColumnSortDescriptionCollection, IgxColumnSummaryDescription, IgxColumnSummaryDescriptionCollection, IgxColumnWidth, IgxDataBindingEventArgs, IgxDateTimeCellInfo, IgxDateTimeColumnComponent, IgxDateTimeColumnComponent_PROVIDERS, IgxDateTimeColumnDynamicModule, IgxDateTimeColumnModule, IgxDefinitionBaseComponent, IgxFormatGroupTextEventArgs, IgxFormatSummaryTextEventArgs, IgxGridActiveCellChangedEventArgs, IgxGridAnimationPhaseSettings, IgxGridAnimationSettings, IgxGridCellEventArgs, IgxGridCellPosition, IgxGridColumnAnimationSettings, IgxGridColumnCollection, IgxGridColumnsAutoGeneratedEventArgs, IgxGridComponent_PROVIDERS, IgxGridFilterDialogFilterChangeEventArgs, IgxGridFilterDialogOpeningEventArgs, IgxGridFilterDialogViewModel, IgxGridFilterDialogViewModelGrouping, IgxGridFilterDialogViewModelGroupingLevel, IgxGridFilterDialogViewModelGroupingLevelCollection, IgxGridFilterDialogViewModelRow, IgxGridFilterDialogViewModelRowCollection, IgxGridFilterExpressionsEventArgs, IgxGridGroupDescriptionsChangedEventArgs, IgxGridSelectedCellRangesChangedEventArgs, IgxGridSelectedCellRangesCollection, IgxGridSelectedCellsChangedEventArgs, IgxGridSelectedCellsCollection, IgxGridSelectedItemsChangedEventArgs, IgxGridSelectedItemsCollection, IgxGridSelectedKeysChangedEventArgs, IgxGridSelectedKeysCollection, IgxGridSortDescriptionsChangedEventArgs, IgxGroupData, IgxHeaderComponent, IgxHeaderComponent_PROVIDERS, IgxHeaderSeparatorComponent, IgxHeaderSeparatorComponent_PROVIDERS, IgxHeaderSeparatorDynamicModule, IgxHeaderSeparatorModule, IgxImageCellInfo, IgxImageColumnComponent, IgxImageColumnComponent_PROVIDERS, IgxImageColumnDynamicModule, IgxImageColumnModule, IgxLiveGridComponent, IgxLiveGridCoreDynamicModule, IgxLiveGridCoreModule, IgxLiveGridDynamicModule, IgxLiveGridExpansionIndicatorComponent, IgxLiveGridExpansionIndicatorComponent_PROVIDERS, IgxLiveGridFilterDialogComponent, IgxLiveGridFilterDialogComponent_PROVIDERS, IgxLiveGridModule, IgxLiveGridSortIndicatorComponent, IgxLiveGridSortIndicatorComponent_PROVIDERS, IgxNumericCellInfo, IgxNumericColumnComponent, IgxNumericColumnComponent_PROVIDERS, IgxNumericColumnDynamicModule, IgxNumericColumnModule, IgxPrimaryKeyValue, IgxResponsivePhase, IgxResponsivePhasesCollection, IgxResponsiveState, IgxResponsiveStateEnteredEventArgs, IgxResponsiveStateEnteringEventArgs, IgxResponsiveStateExitedEventArgs, IgxResponsiveStatesCollection, IgxRowSeparatorComponent, IgxRowSeparatorComponent_PROVIDERS, IgxRowSeparatorDynamicModule, IgxRowSeparatorInfo, IgxRowSeparatorModule, IgxSectionFooterComponent, IgxSectionFooterComponent_PROVIDERS, IgxSectionFooterDynamicModule, IgxSectionFooterModule, IgxSectionHeaderCellInfo, IgxSectionHeaderComponent, IgxSectionHeaderComponent_PROVIDERS, IgxSectionHeaderDynamicModule, IgxSectionHeaderModule, IgxSortIndicatorRenderCompletedEventArgs, IgxSummaryCellInfo, IgxSummaryData, IgxSummaryRowComponent, IgxSummaryRowComponent_PROVIDERS, IgxSummaryRowRootComponent, IgxSummaryRowRootComponent_PROVIDERS, IgxSummaryRowRootDynamicModule, IgxSummaryRowRootModule, IgxSummaryRowSectionComponent, IgxSummaryRowSectionComponent_PROVIDERS, IgxSummaryRowSectionDynamicModule, IgxSummaryRowSectionModule, IgxTemplateCellInfo, IgxTemplateCellUpdatingEventArgs, IgxTemplateColumnComponent, IgxTemplateColumnComponent_PROVIDERS, IgxTemplateColumnDynamicModule, IgxTemplateColumnModule, IgxTemplateHeaderCellInfo, IgxTemplateHeaderCellUpdatingEventArgs, IgxTemplateHeaderComponent, IgxTemplateHeaderComponent_PROVIDERS, IgxTemplateHeaderDynamicModule, IgxTemplateHeaderModule, IgxTemplateSectionHeaderCellInfo, IgxTemplateSectionHeaderCellUpdatingEventArgs, IgxTemplateSectionHeaderComponent, IgxTemplateSectionHeaderComponent_PROVIDERS, IgxTemplateSectionHeaderDynamicModule, IgxTemplateSectionHeaderModule, IgxTextCellInfo, IgxTextColumnComponent, IgxTextColumnComponent_PROVIDERS, IgxTextColumnDynamicModule, IgxTextColumnModule, IgxTextHeaderCellInfo, IgxTextHeaderComponent, IgxTextHeaderComponent_PROVIDERS, IgxTextHeaderDynamicModule, IgxTextHeaderModule, IgxVerticalSeparatorCellInfo, ImageCell, ImageCellModel, ImageCellModelExport, ImageCellPresenter, ImageColumn, ImageResourceType, ImageResourceType_$type, ImageStretchOptions, ImageStretchOptions_$type, LiveGridStylingDefaults, ModelStates_$type, ModelTypes_$type, NumericCell, NumericCellFormatter, NumericCellModel, NumericCellModelExport, NumericCellPresenter, NumericColumn, PinnedRowInfo, PlaceholderView, PrimaryKeyValue, RecyclingManager, ResponsiveEngine, ResponsivePhase, ResponsivePhasesCollection, ResponsiveState, ResponsiveStateEnteredEventArgs, ResponsiveStateEnteringEventArgs, ResponsiveStateExitedEventArgs, ResponsiveStatesCollection, RowCellsEffect, RowEffect, RowPath, RowSelectionAnimationMode, RowSelectionAnimationMode_$type, RowSeparator, RowSeparatorCell, RowSeparatorCellPresenter, RowSeparatorModel, RowSeparatorModelExport, SectionFooter, SectionHeader, SectionHeaderCell, SectionHeaderCellModel, SectionHeaderCellModelExport, SectionHeaderCellPresenter, SectionInfo, SelectionManager, SortIndicatorRenderCompletedEventArgs, SortIndicatorStyle, SortIndicatorStyle_$type, SortManager, SpacerEffect, SpatialEngine, SummaryCell, SummaryCellModel, SummaryCellModelExport, SummaryCellPresenter, SummaryData, SummaryRow, SummaryRowRoot, SummaryRowSection, TemplateCell, TemplateCellContainer, TemplateCellModel, TemplateCellModelExport, TemplateCellPresenter, TemplateCellUpdatingEventArgs, TemplateColumn, TemplateHeader, TemplateHeaderCell, TemplateHeaderCellModel, TemplateHeaderCellModelExport, TemplateHeaderCellPresenter, TemplateHeaderCellUpdatingEventArgs, TemplateSectionHeader, TemplateSectionHeaderCellModel, TemplateSectionHeaderCellModelExport, TemplateSectionHeaderCellUpdatingEventArgs, TextCell, TextCellLineBreakMode, TextCellLineBreakMode_$type, TextCellModel, TextCellModelExport, TextCellPresenter, TextColumn, TextHeader, TextHeaderCell, TextHeaderCellModel, TextHeaderCellModelExport, TextHeaderCellPresenter, VerticalSeparatorCell, VerticalSeparatorCellModel, VerticalSeparatorCellPresenter, VisibilityEngine, VisualModel, VisualModelExport };
//# sourceMappingURL=igniteui-angular-grids.js.map
